(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    347325,       8967]*)
(*NotebookOutlinePosition[    348167,       8996]*)
(*  CellTagsIndexPosition[    348123,       8992]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["INTRODUCTION TO JPEG BASELINE ALGORITHM", "Title"],

Cell["\<\
Mariusz Jankowski \[Copyright]
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell["This loads the packages and sets some useful options.", "Caption"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(<< LinearAlgebra`MatrixManipulation`\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(SetOptions[ListDensityPlot, Mesh -> False, \ FrameTicks -> False]; 
    \)\)], "Input",
  CellLabel->"In[3]:="],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell[TextData[{
  "In this document we present a data compression method that has found \
application in compression of still grayscale and color images. The ",
  StyleBox["transform coding",
    FontSlant->"Italic"],
  " method compresses image data by representing the original signal with a \
small number of transform coefficients. It exploits the observation that for \
typical images a large amount of signal energy is concentrated in a small \
number of coefficients. Transform coding is an integral part of one of the \
most widely known standards for lossy image compression, the so-called JPEG \
(Joint Photographic Experts Group) standard. It is a result of the \
collaboration of the International Standards Organization (ISO)and Comite \
Consultatif International Telegraphique et Telephonique (CCITT), a United \
Nations organization.\n\nHere we explore the details of the JPEG ",
  StyleBox["baseline",
    FontSlant->"Italic"],
  " algorithm [Pennebaker and Mitchell, 1993]. The input image is \n(1) level \
shifted by subtracting 128 from each pixel,\n(2) partitioned into 8x8 blocks, \
then transformed using the 8-point DCT,\n(3) the coefficients are quantized \
using a standard quantization table Q, which effectively reduces most of the \
low-order coefficients to zero,\n(4) the remaining non-zero cosine \
coeffcients are separated into two groups, each of which is entropy coded.\n"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DCT TRANSFORM", "Section"],

Cell[TextData[{
  "Transform",
  StyleBox[
  " coding is based on the application of a unitary transform to a discrete \
signal. Unitary transforms have many desirable properties [hyperlink], they \
are ", "Text"],
  StyleBox["invertible,", "Text",
    FontSlant->"Italic"],
  StyleBox[" preserve signal energy and exhibit the ", "Text"],
  StyleBox["energy compaction property.", "Text",
    FontSlant->"Italic"],
  StyleBox[
  " The latter means that an approximation of the original signal may be \
reconstructed from a typically small subset of the coefficients. The \
discarded coefficients contribute relatively little to the signal's energy, \
so their absence does not seriously distort the image. The goal therefore is \
to minimize the number of retained transform coefficients while keeping \
distortion at an acceptable level.", "Text"]
}], "Text"],

Cell[TextData[{
  StyleBox[
  "What is the best transform to use for purposes of image compression? The \
discrete Karhunen-Loeve transform, also known as the Hotelling transform, has \
the property that it maximizes the number of coefficients that are small \
enough to be discarded. Equivalently, the KL transform minimizes the mean \
squared error between the original and reconstructed images for a given \
number of coefficients. However, since no fast algorithm exists for the \
computation of the KL transform, we settle for the second best, namely the \
discrete cosine transform (DCT) [hyperlink]. The DCT ", "Text"],
  "is a real transformation with a fast algorithm and good energy packing \
ability. For these and other reasons, it is now an integral part of two lossy \
image compression standards: JPEG and MPEG (Moving Pictures Expert Group)."
}], "Text"],

Cell["This loads an image for use in the examples below.", "Caption"],

Cell[BoxData[
    \(\(A = 
      ReadImage["\<coke.tif\>", "\<TIFF\>", ImageOutput -> RawImageData]\  // 
        Reverse; \)\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
In image transform coding, the image is divided into many subimages or blocks \
and each block is processed independently. The block size used in JPEG is \
8-by-8 pixels. There are many reasons why block processing is preferred and \
why the particular blocksize has been selected. First, block processing \
allows the coder to adapt to local image statistics. Second, block processing \
reduces computational and storage requirements. It exploits the correlation \
present among image pixels, which generally decrease as the block size grows. \
Blocksizes larger than 8-by-8 do not offer significantly better compression. \
Finally, a fixed blocksize allows the design of optimized software and \
hardware. Typically the blocks do not overlap, which significantly reduces \
computational complexity, however overlapping block processing has been shown \
useful in reducing distortion at very high compression factors [reference]. \
\
\>", "Text"],

Cell["\<\
Here we compute the block DCT transform of an example image. Note that, as \
required by JPEG, we subtracti the middle grey level from all pixel values.\
\>", "Caption"],

Cell[BoxData[
    \(\(\[ScriptCapitalA] = BlockProcessing[DCT[# - 128]\ &, A, {8, 8}]; 
    \)\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
Here we display a segment of the original image and the corresponding \
coefficients blocks.\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListDensityPlot[SubMatrix[#1, \ {41, 49}, \ {32, 32}], 
              PlotRange -> {15, 125}, \ DisplayFunction -> Identity]\ &\)\ /@
          \ {A, \ Abs[\[ScriptCapitalA]]}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6DA2B0B0A5AC94ACB0AE515A66C5C3C1C3C1C1BEC1C8B079
5D564C4AA0869B72
6FA7A9AEB5ACACA0A7B551535DC1C1D6C5C1BEBEBE805D51
514A4A4C9790A26B
68A7A99EB0A9A9AEB0A74C5361BEBAC1C1D1C1BA6B615A51
4F484C4FA78DA568
68A2A9AC92A7ACAEB0A94F4F5ABCBABEC1BEC572645F584F
4C4C4C4A7997A568
64A2A7ACAE94A0A7B0B5484F51C1BEC1B7C18D68615F5853
514C4A4A58A7A768
6BA7A9A7ACA9A799B3B358535689C8C5BCB76B68665F5351
515F56454AA5A261
6DA5A2A5A7AEACACB7B55F4C5361A9BECA896668615F7997
A2A9A25A4C84A566
66A2A59E97A9A9A9B0B3744F56586B97B76B646472A9AEA7
A597A776459BA06B
6DA5ACA7A78DACB3B7B38051566B97B5C35F6174BEB0ACAE
A9A9896B3E9BA068
68A7AEA9A5A990A2B3B08482A2ACBCB5B05F66AEB7A2A7A7
A5A59E4A4A849466
6DA99BA7A9A7A5A0A9996453589BB5BEB5616DBCB0AEA294
A59B564A4C929B66
6DA2A292A2A5A2A7745D534C5156AEB0B06166B7B5A9A99B
804C454A5F9BA766
72A7A7A09B94A56F5656534F4F5892AEB0645F6FA2977651
4F454C4A92A5A56D
6DA5A5A0A09E89454556534F4F5386B0AC615F615A58534F
4A4A4551A7A5A56B
72A9A09EA9A27B3E4A566D6F515690B0B06F5D6158534C4A
4A4A488492A5A06F
74A9A2949EA253436BA0A7A58B4FA5A9A7995D6158514848
4A4A5FA784909976
72A79B9E8B9E455AACA79B976F4F92AEA0B0745A5645484A
515DA0944CA29082
6FA9A29E9B894589A5A07D51484F82B3ACAEB08D534F4853
849053434F9B8B86
7BA7A0A09E9E435F534F4C4C4A4C79A7A9ACA7B0A5947D5D
4A4543484C9B8B8B
7BAE9989A07B41434A4F4A4A484F796BACA5A28D644F4543
434545434C928694
86A2A06D454541434C5348484F5A6F5F5F6D5A4F534C4543
4A4848454594799E
8BA7A068454543434A4F5F7D909E6F5D515D4F4C4C4C4848
484548454A946DA7
92A29E683E43454C72949E97845A6B5F5856514A4F4C4A41
4348566F899261A9
97A0926B3A4A6F8B92926B4A4A4A645F53564C4F4C4F4548
454880A28B9B5AA9
99A29E686D92845848514A4548456464565A4F4F566B4548
414345569E8D66AC
9EA79B978272823545434543454A61665D6B80929B5A4145
43434343458476A7
A2999E926B415A4143454A51688276949EA09B97644A4841
453E3E454A6F86A7
9EA594944843583E436674686892949E9E809B80484C5A53
413E4143457294A5
A0A5978951438474804F434A454C90A092724C4845519480
7D3E3E3C4A689EA2
A599978B7D79928B3E434545434853A2A07648484A749E94
8D805341456D99A5
A09B979090828D5F3C4343454543519B9E7948484C9B9B97
90867668416BA0A2
9E99999497927D373E454C4F48454A94A074484582909061
3E413E4576649E9E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF585146311C0100FF50FF6236130F4CFFFF2A0A00000000
FF8E0075760D000C
0000000000000000322B0016000000048734550000000000
2D421B0A210A000C
0000000000000000000A0000000000006859000E00000000
3928000000000000
000000000000000002000000000000000000000000000000
0C00000000000000
000000000000000000000000000000000812000005000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
FF008D004C1B0900FF7CCD3400001100FF00009E74260000
FF680182511E0000
41351416000000005E05253300000000DE6A000009000000
10625C0023000000
000000000000000074250000000000000A000A0000000000
2416001800000000
000000000000000058000000000000002C00000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000036000400000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
FFFF0D3B1834000BFF00491900000100FFCB000000000000
FFED11000700493B
55075301001400001D00360900000000BE48000000000000
00000A0025050000
02050000000000008C410B00000000001800000000000000
550B220400000000
260300000000000042002500000000007800010000000000
0000000000000000
000000000000000010000000000000001C00000000000000
0000060300000000
000001000000000007001200000000000000000000000000
0000000000000000
0000000000000000000D0000000000000400000000000000
0000000000000000
000000000000000000000000000000000005000000000000
0000000000000000
FFE900001C250E00FFA3582A00000000FF2E481E00000000
FFFFA90000000000
120000000000000000000003010000002F2F572600000000
170D0E0000030100
1A000D23000000005800000000000000000E0B1800030000
0000160000040000
151A0E000000000015000100000000001A371F0000000000
260D000000000000
000000000000000017000000000000001900000000000000
000F060000000000
000000000000000006000000000000000000000000000000
0E00000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{355.438, 111.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005S0000Ka000`40n007h00OooooI?oo003ooomT
ool00?ooofCoo`002OooJP002OooJP00OOoo0009ool00`00ooooo`1Vool00`00ooooo`07ool00`00
ooooo`1Vool00`00ooooo`1kool000Woo`03003ooooo06Koo`03003ooooo00Ooo`03003ooooo06Ko
o`03003ooooo07_oo`002Ooo00D00?ooJfecKV]]00>U5007[GFeUZee]IJ]MKFF[GD00jDd00V]EJee
[EFD/YBBU;:]EJee[ED00Zee00FeUZee]GJ]MKEf00=BRP06F^]Jbe[[Hba[CF</1LHh01_66<Hh_QO6
6;hGaSS66<Hh_QO66;hGaQRn5lHH_OO5n;ggaORn5lHH_QO>FLHhcUV]MKFF[GD00g_?01aJjf;/F^]J
be:ZF/]BZU9ZBVUBJTY9BVU:BJDDW?>U58@`S364<9ccW=>Llg>>LjicSW>^ool000Woo`03003ooooo
00?oo`=Jb`=BRP03BTU2:4Y900<aQP038>@Hhb3T00L000?oo`=BRP?oo`0@H`aS;6<<>LLaYSW7<JHH
Xa226:<@HQ22469BJTYYDVX7ool01RUU:DDYI@Q12648@@d000?oo`03U7:<LIAb00<0000:Njmc[W^_
Ljikcg>^4688HA1R264300001@QQ4688HOoo0000OOoo0009ool00`00oom[K@02Jfd06YdCYABM4kFF
[GFeUZee]IJ]MKFFYABU=:DD[GF]EJeeU9:D/YBB[GF]EJee[EFeUZee]IH3[GD00e::BXUBRP03F//0
5F/]Hba[;LHHaSS66<Hh_QO66;hGaQRmmlHH_QO66;hGaQRmmlHH_OO66005_OL03<HH_OO66<HhcUW6
>;FF[GFeUW?>NlmccP=Jj`06DZYJZe:ZFZ]:BDYY14Y900>LljDDW?<00h@`00VDdYcCU=9cSV^=Lhi[
SOoo00002Ooo00<00?ooool00ooo00UBZU[;DZYBRTZ9DXY2:4XY@RP00c6600<H`aSS6<<01`000ooo
00=BRTYYDXX00ooo0f<<00HaYSVW<JHiYa224:8248801@QQ489:BDYYBTT01ooo0bU50`Q13@000ooo
0haa0`001W>^00@8HA1R264@HP<000052648@@QQool0001mool000Woo`05003oof]]Lfi[K@03YA@0
1jee]IJ]MKFF[GFeUZee00>U=009[EF]MJeEU;:DTYBb[EF]MJeE00:]M@05]IJ]MKEf[GFeMP03DXX0
1U[[F/]Jjf</JdeS;0G6>00KaQS6>;hGaQRn5lHhaQS6>;hGaQRn5lHH_QO66;ggaORmmlGh_QO66;hG
cUW6><iI[GFeUZee00=kc`0LF^]Rk5[[F/]BZU[;DZYBJTYYDVY:BDYYBTVU59ccYAB4<8`aQ32LlicC
W?=cSW>^Lhic[_oo0009ool00`00ooooo`03ool3F//3DXX00dY9@RQ:B@03<HH00b3T6><Pi0070003
ool3DXX3ool046<<HbaS33W7<JHiac6V6:<@PQRS468@PQ1RDVY:JE9Z1ooo00HYIBU5:FD8@@QQ244=
0003ool00iAbS76DLP0300002W^_Ljik[g>^Nlmc[Q1R264@HPQQ0`0000D8HA1R267oo`0007goo`00
2Ooo00D00?ooLhi[KG>>00>U=004[EFU=:eEYC@3[GD03KFF]KJeUZee[EF]MJeE[GF]EJDDW?>U59cc
00>U=005]IJe][FFDXY:R@02DXX00e:ZDXYJj`02F^/01kggaQRmmlHH_OO66;gg00?F^P06aQS6><HH
aQRmmlHH2[gg00=kkh@@Nnl00e[[00I:RE::BXUBRTZ9DXX7BTT04TYYBTU:JIBbW;>D/YBBS76DTYdC
YABM4f]]Jde[KF]=ool000Woo`03003oo`0001T000<aQP03:FDYABUU00<000036:<@XQRS00/00009
020008`aQ32<<C66<JHaQS6V00=BZQ000003<FHYIC5V00=220036><H`aSS00<8@@<Q10@8@@<00005
2648@@QQool0001mool000Woo`0?003oof]]Lhi[KJeEYCB]EJED[EFUE:eE[GFeMZee00>e]P0=[EF]
MJeE[GF]EJeeW?>U59ccYABU=:eEYC@00kFf0e::00eBZU::DZYJjf;/F^_66;hGaQRn5lHH_QO66003
e[X3aSP04khGaQRn5lGh_OO5n;ggaORmmlGh_OO5n;ggQ11kkh@@F^]Rk5[[00IBRP06BVU:BDYYBTU:
JDY90TYY00QBJTYYW=>D/YcCS76DTXaa0jDD00I[CF]]Jde[KOoo0009ool00`00ool0000I00001S6V
<HHaYRU5<FHYA@<000034:8H`a2R00X0000=224080PQQ32<DH@`>JLaYSVW<JIJZe:ZFZ/0400000`Y
IC5V:FE2:488@RPH`b3T6<<8H@Q126438@@010QQ2448H@Q10`0000D8HA1R267oo`0007goo`002Ooo
00D00?ooLhi[KG>>00>U=004[EFU=:eEYC@3[GD03KFF]KJeUZee[EF]MJeE[GF]EJDDW?>U59cc00>U
=005]IJe][FFDXY:R@02DXX00e:ZDXYJj`02F^/01kggaQRmmlHH_OO66;gg00?F^P06aQS6><HHaQRm
mlHH2[gg00=kkh@@Nnl00e[[00I:RE::BXUBRTZ9DXX7BTT04TYYBTU:JIBbW;>D/YBBS76DTYdCYABM
4f]]Jde[KF]=ool000Woo`03003oo`0001T000<aQP03:FDYABUU00<000036:<@XQRS00/000090200
08`aQ32<<C66<JHaQS6V00=BZQ000003<FHYIC5V00=220036><H`aSS00<8@@<Q10@8@@<000052648
@@QQool0001mool000Woo`0X003oof=<JdeSC:eEYCB]EJED[EFUE:eEW?>Tm9cc]IJ]MKFFYEB]EJED
[EFUE:eE[GFeMZee]GJ]MKFF[GF]EJDd[EE:JE9ZBVUBZU::DZX3H``01<Gh_OO5n;gg0kgG00bn5lHH
_QO66;hGaQS>VMJJcYW66;hGaQP4_ML00f]=Jfe[C@03H``00e[;F^]Jb`03DXX00dYYDXY:J@04BTT0
359ZBVUBJTYYDXY:JJeEYCB]EHaaU7:<L@>U=006Hda[CF=<Jdgoo`002Ooo00<00?oo0000700000<8
@@QQ24404`0000=SC6]=Hd`015[;0`0000<8HA2226403@000cW70bU54`0000?oo`00ool0O?oo0009
ool01@00oom[CF</Jdd00jDd00B]EJDd[EFU=0>Ll`09[GFeUZee[EFU=:eEYCB]EJDd00B]M@03]IJ]
MKFF00>U=009BVU:BDYYDXYBZU::H`aK2f<<00Bmm`0I]MJmekGFaQRmmlHH_OO66;ggeY[>NMJJ_OO6
6;gg_MNee[gG]MI[KF]=JfeK2f<<F`/00e[;00U:RE::BXUBRTYYDXY2:4Y9@RP00TY900E:JDY9DXY:
JE::00>U=00<S76<DHaaYABU=:DDJdeS;6]=Hbcoo`002Ooo00<00?oo000070000`Q14`0000M[CF</
JdeBbU[;D/YJb`0300000a1R264@HP0=00001SW7<LHiab4T:DDQ91<00003ool00?oo07coo`002Ooo
02P00?ooHda[CF=<[EFU=:eEYEB]EJED[EFLljCdW?>eUZee]IJUE:eEYEB]EJED[EF]MKEf[GFeMZee
]IJ]MJeEYCB]EDYYDVY:JE:ZDXYBZP=S3004aORmmlGh_OL3_ML03;hGaQRn5lHH_QO66<jIeY[>VLHH
_QO660Bme`03Jde[KF]=00=S3003F/]Jje[;00=BRP03BVUBRTYY00A:B@0<DVY:JE9ZBVUBRTYY[EFU
=:eES76DLXaa0jDd00ISC6]=Hda[COoo0009ool00`00ool0000L00000`Q12648@@0C00000f=<JdeS
C004F//300000`QQ4888H@0=0003>LL3:DDC00000ooo003oo`1lool000Woo`05003oof]=Hba[C@03
YC@01:eEYCB]EJDd0icc00V]MKFF[GF]EJDd[EFU=:eEYC@01:ee00>eUZee]IH00jDd00U:JDY9BVUB
RU:ZDXYS35/;H``01;gg01Vee[gG]MK66;ggaQRmmlHH_OOFV/iieYZmmlHH_ONmekGF_MNeeV]]Jde[
KE/;H`aK2`03F//02DZ9DXY:RE::BVUBRT8XBTU2:002BTT01DYYBTUBRTYYDXX00jDd00b<LHaAS76U
5:DdYAA[CF</JdeS;?oo0009ool00`00ool0000L0003244C00001f]=Hba[CE;:F/]BbU[;00<00003
4688HA1R00d00006>LLaaSW78B@YAB4T4`0000?oo`00ool0O?oo0009ool01@00oomSC6]=Hd`00jDD
00>UE:eEYE@00ZeE00>]MJeEU9800YBB00FU=:eEYCB]MJeE00:]M@0E]GJ]MKEf[GFeUZee[EFUE:eE
BVUBRTYYDXY:JE::F/]Jje[;_ONmekgg00Bme`09_OO5n;ggaQRn5lHH_OO5n;gg00?6>00:Lhic[W>>
LjiS;6/]HbaS35[[H``3F//045::BVUBRTYYDVY:JE9ZBVUBJTYYDVY:JE9ZBTU:JDY90g_?00>D/YcC
U;800jDd00ISC6]=Hda[COoo0009ool00`00ool0000I00000`0P0000800`00000`QQ4688H@0F0000
0ooo003oo`1lool000Woo`0B003oof]=Hba[CIdCYABM4jeEYCB]EJDd[GF]EJeeS96DTXbA0jDd00>]
EJee[ED01:ee00beUZee]IJU=:eEYCABRTYYDXY:JE::BVT3F//01kgG_ONmekgg]MJmekGF00Bmm`03
aQRmmkgg00:mm`0BaQS6><HHLhi[SG>>JheS;6<<HbaJjf<<F^]Jbe:ZF/]:JE::0TYY00Q:BDYYBTU:
JDY9BVU:BDYY14Y900mccW_?LljL/iBbW;>U5:DdYAA[CF</JdeS;?oo00002Ooo00<00?oo0000C000
00<8H@Q126405P0000?oo`00ool0O?oo0009ool01@00oomSC6]=Hd`00jDD00>UE:eEYE@00ZeE00>]
MJeEU9800YBB00FU=:eEYCB]MJeE00:]M@0E]GJ]MKEf[GFeUZee[EFUE:eEBVUBRTYYDXY:JE::F/]J
je[;_ONmekgg00Bme`09_OO5n;ggaQRn5lHH_OO5n;gg00?6>00:Lhic[W>>LjiS;6/]HbaS35[[H``3
F//045::BVUBRTYYDVY:JE9ZBVUBJTYYDVY:JE9ZBTU:JDY90g_?00>D/YcCU;800jDd00ISC6]=Hda[
COoo0009ool00`00ool0000I00000`0P0000800`00000`QQ4688H@0F00000ooo003oo`1lool000Wo
o`08003oof</H`aS;9dCYABM4`BU=003[GF]EJee00>]M@06U;:DTYBbW?>U59cc1:Dd01>eUZee]IJe
U[Ff]II:BD8XBTU:JE::BVUBRTZ9DXZmmlHH_OO66003_OL00lHH_OO66003]KH05LHH_OO668aAS76<
DF]=Hba[CF</H`aK2f<<F^]S35[[F/]BZU[;DXYBZP02DXX01TZ9DXY:BDYYBTU:J@I:B@03DZYJbe:Z
00JU=006JdeS;6]=Hbcoo`002Ooo00<00?oo0000<P0000<8@@0P244011221P0000<080PQ02008`00
00?oo`00ool0O?oo0009ool01@00oomS;6/]Hb`00jDD00>U=:eEYC@00ZeE01:]MJeE]GJ]MKEfU9:D
/YBBYABLljDDYCB]EJDd[EF]MKFF[GD3]KH3BTT00e::BVUBRP03DXX05lHH_QO66;hGaORmmlGh_QO6
6;hG_MNe][gG_QO66;hGU7:<LIAbHda[CF=<Jdd016<<00=Jjf<<F//00U[;00=BZU::DZX00e::00=B
JTYYDVX00TYY00E:BDYYBTU:JDY900=Jb`0<YCB]EJDd[EFU=:eEHda[CF=<Jdgoo`002Ooo00<00?oo
0000<P000`Q100@@XQ224:8@PPH00003224080PQ02<00003ool00?oo07coo`002Ooo00P00?ooHbaS
36</WA>U59dC1:Dd00>]MJeE[GD00jee00JD/YBBU;:LljDDW?<4YC@04kFF[GFeU[FF]KJeUTY9@RQ:
BDYYDXY:JE::BXUBR[ggaQRmmlHH00>mm`03aQRmmlHH00>e]P0EaQRmmlHHS56<LHaAJdeS;6]=HbaS
35/;H`aJjf<<F^]Jbe:ZF/]BRU:Z009BRP06BXUBRTY9BVU:BDYY1TY900=BZU[;DZX01ZDd00I[CF</
JdeS;?oo0009ool00`00ool0000b00000`Q10208@@04488600000`0P2240800S00000ooo003oo`1l
ool000Woo`0R003oof]=Jfe[CJeEYCB]EJED[EFUE:eEYCB]EJDd[GF]EJeeYEB]EJED[EFU=:eEU=:L
diCBW=>eU[Ff]IJe][FF]KH3F//01U:ZDXYBZU:ZF/]BZPB<D@03cUW6><iI00?6>00E_ONmekgg]KJm
ekFfJfe[CF]]Hda[CF=<JdeS;6]=HbaS35[[H`aBRU:Z00MBRP0=H`aJjf<<F^]Jbe:ZF/]2:4XY@RQ:
JDY9BVT00jDd0jDD16<<00?oo`00ool02?oo00<00?oo0000I@0000?oo`00ool0O?oo0009ool01@00
oom[KF]=Jfd00jDd00>]EJDd[ED01:Dd00J]EJee[EF]EJDd[ED3YC@06IcCU;:LdiBb]IJ]UKFF[IFe
UZfEF/]BZU[;DXYBZU::FZ]BZUZ[Q32<DH@`S576><iI00;6>005aQS6>;gG_ONme`03]KH07F]=Jfe[
CF]=Hba[CF</JbeS;6/]F^]S35[[DZYBRU:ZBXUBRTZ9DXY:RE::F^]S35[[H`aBZUZ[DZX00d8X0dY9
00bU=:DDYCBM4jDDWA=S35/;H`aK2ooo0009ool00`00ool0001U00000ooo003oo`1lool000Woo`0R
003oof]=Jfe[CJeEYCB]EJED[EFUE:eEYCB]EJDd[GF]EJeeYEB]EJED[EFU=:eEU=:LdiCBW=>eU[Ff
]IJe][FF]KH3F//01U:ZDXYBZU:ZF/]BZPB<D@03cUW6><iI00?6>00E_ONmekgg]KJmekFfJfe[CF]]
Hda[CF=<JdeS;6]=HbaS35[[H`aBRU:Z00MBRP0=H`aJjf<<F^]Jbe:ZF/]2:4XY@RQ:JDY9BVT00jDd
0jDD16<<00?oo`00ool02?oo00<00?oo0000I@0000?oo`00ool0O?oo0009ool00`00oom[K@02Jfd0
2JDDYCBU5:DDWA>U59dCYCBU5004YC@3[GD01jeE[GF]EJee[EF]MJeE00>e]P0C]IJe][FFH`aJjf<<
BTU:JDY9DZYBRU:ZF`]S35/;H`bU=:eEYC@00kgg02?6F<iIaUR<DH@`S55S;6/]Hba[CF</JdeS;6<<
F`]S35[[H`aJjg_?LlikciBbW;>D/ZDDWA>U5:Dd[EFU=:eEWA>U59dC00=Jb`0?BTU:JDY9Q32448@`
YABU=:DDJbeS;6/]Hbcoo`0000Woo`03003oo`0006D00003ool00?oo07coo`002Ooo00D00?ooJfec
KV]]00>U=0BU50>U=005[EFU=:eE[GFeMP02[GD02:eE[GF]EJee[EF]MKFf_ML4]KH02E[[H`aJje9Z
BVUBJU::DZYBRP04H``01ZeEYEB]EKggaORmm`?>F@><D@07JdeS;6]=Hda[CF=<Jdd016<<00=Jjf<<
Nll00W_?00>LdiBbW=<00jDD00B]EJED[EFUE0>U5009F/]Jje[;DVY:JE9ZQ124<8@@00>U=006Hba[
CF</Jdgoo`002Ooo00<00?oo0000I@0000?oo`00ool0O?oo0009ool00`00oom[K@02Jfd02JDDYCBU
5:DDWA>U59dCYCBU5004YC@3[GD01jeE[GF]EJee[EF]MJeE00>e]P0C]IJe][FFH`aJjf<<BTU:JDY9
DZYBRU:ZF`]S35/;H`bU=:eEYC@00kgg02?6F<iIaUR<DH@`S55S;6/]Hba[CF</JdeS;6<<F`]S35[[
H`aJjg_?LlikciBbW;>D/ZDDWA>U5:Dd[EFU=:eEWA>U59dC00=Jb`0?BTU:JDY9Q32448@`YABU=:DD
JbeS;6/]Hbcoo`0000Woo`03003oo`0006D00003ool00?oo07coo`002Ooo00D00?ooHba[CF</00>U
50BU=00FW?>Tm9ccW=>D/YcCYEB]EJED[EFUE:eEYEB]EJED[EF]MKFF[GFe][FF]KH3Ljh01U::BVUB
RU:ZF/]BZPAJb`0OJfe[CF]]U;:LdiBb_MNe][gGJde[KF]=JbeS;6/]Hba[;F</JbecSW>^Lhj]EJED
[EF]MKEf[GF]EJDd[ED00jDd01VLdiBbW=>D/ZeEYCB]EG>^Nlmc[TXY@RQ::IcCW?>LdjDDW?>U56]=
Jfe[CF]]ool00009ool00`00ool0001U00000ooo003oo`1lool000Woo`0<003oof/]Hba[;IdCYABM
4jDdYABU=:DD0icc02JD/YbcU;:]EJDd[EFU=:eEYCB]EJDd[EFU=;FF[GFeUZfE]IJ]UG>^Lhic[TYY
DXY:JEZ[DZYJZe:ZF/]BZU[;Jde[KF]=W;>D/Ybc0kFf011[KF]=JfeS36</H`aS;6<<HbaS37>>Jhec
SZDd[EFU=0>]M@BU=006YABU=9BbW;>D/Ybc0jDd0g>^0d8X00bLdiCBW=>LljDDW?=[KF]=Jfe[COoo
0009ool00`00ool0001U00000ooo003oo`1lool000Woo`05003oof</JdeS;003YA@4YC@05YccY?BL
licCU;:LdjED[EFUE:eEYEB]EJED[EFUE:eE[GFeUZee]KJeU[Ff0g>^00IBRTYYDXYBZU[;DZX4F//0
7f]]Jde[KIBbW=>D/[gG]KJmef]=Jfe[CF/]Hba[;F</JbeS;6/]Lhic[W>>[EFUE:eE[GFeMZee[EFU
=:eE00>U=00IW=>D/YcCU;:]EJDd[EEc[W_?Lji::D8XBRVLdiccW=>U59ccYAA[CF]]Jde[KOoo0000
2Ooo00<00?oo0000I@0000?oo`00ool0O?oo0009ool00`00oom[K@02Jfd01jDDYCBU5:ee[EF]MJeE
00JU=00:S76<DHaa[EF]MJeE]IJ]UKFF[ID3]KH08jfE]IJ]UH@@Nnn444Z9DXY:REZ[DZYJZf]=Jfe[
CF]]U;:L/iBb]KJeU[Ff_QO66;hGH`aJjf<<F`]S35/;LjicSW>^Lhh00kgg00F]MKFF[GF]MJeE00B]
M@0L[EFU=:eEYCB]EJDd[EF4<8aAQ31[KF]=Jfdiid7X>NNLdiCBW=>LljDDW?=[CF</JdeS;?oo0009
ool00`00ooooo`03ool300000haaS56<L@0300001TYYBTU:JAS36><H``@8@@<000?oo`09Nnmkcg__
cUW>NLiI<JHaQS6V00L000<@PP<000?oo`L000>Ll`06Lhic[W>>:BDQ92TU1`000ooo00=S;6]=Hb`0
0`0000Yl3h@@O0mBRTZ9DXXHhb3T6><Pi0H00003ool00?oo07coo`002Ooo00D00?ooJfecKV]]00>U
=00C[EF]MJeE[GFU=:eEYCB]EJDd[EF<LIAbS76]MJeE[GFeU[Ff]IH00[Ff00RmekFf]KJeU[FfNnn4
47__0e::00YBZU[;DZY[KF]=Jfe[CIcCU;:Ld`>e]P06aSS66<HhF^]S35[[0f<<17>^01>mmlGh_ONe
UZee]IJ]EJee[EFeMZee]GJUE:eEYEB]EJED[EFUE003S5404V]=Jfe[CD88>NM229cCW?>LdjDDW?>U
56=<JdeSC6]=ool000Woo`03003ooooo00?oo`<00003S76DLXaa00<00006BVUBJTYY8>@H`b3T10Q1
0`000ooo0g__0lii00<aYSVW<JH01`000a220`000ooo1`0000>LljCdW?<00g>^00<Q92U58B@01`00
0ooo00=[CF=<Jdd00`000h@@0e::00@Q11SS8@@Hh`H00003ool00?oo07coo`002Ooo00<00?ooJfd0
0V]]00NU5:DdYAB]MJeE[GF]E@06YC@02XaaS56<LJeE[GF]EKFF[IFeUZfE0kFf02>]UKFF[IF447__
Q11:RE::BXUJZe:ZFZ][CF]]Jde[KIBbW;>D/[Ff]IJe][hGaQRn5f<<F^]S35/;H`aK2g>^Lhic[W>>
00>mm`05[GFeUZee[GF]E@04[GD07:eEYCB]EJDd[EFU=:eEQ32<DH@`Jfe[CF]]>NM1j3WWW=>DdYcC
W?>U59ccJdeS;6]=Hbcoo`002Ooo00<00?ooool00ooo0`0000><LHaAS7400`0000I:JDY9BVTH`aSS
6<<424430003ool02G__NlmkkliIcWW>FC6V<HHaYP07000348830003ool70003W?<01W>>LjicSRTU
8B@Y9@L000?oo`03Hba[CF</00<0000:O0n447`?DXY:RE::6><Pi1SS8>@600000ooo003oo`1lool0
00Woo`0?003oof=<JdeSC:eEYCB]EJee]GJ]MKEfYEB]EJED00>U=006YEB]EJEDU9:<LIBB1:DD00Re
U[Ff]IJeUZee]IJ448@`18@@0jDD00N]MJeE[GF]EKgg_MNmm`03]KH04;FF[GFeUU[[H`aJjf]=Hba[
CJee]GJ]MKEf]KJmekFf0jDD00JU=:eEYCB]EJDd[ED7YC@05JCdW?>Tm4Y9BVU:BDYYBTU:JH@@Q324
49BbU9:D/V</JdeS;6]=ool00009ool00`00oom22003@PP02CVW<JHiYa2R6:<@XQS34:8H``0=0000
36<<F^]S300P224082TU8B@Y9C66>JLaQPd000?Nn`04Jfe[CF]]Jdd60003244:000348801V</H`aS
;5[[H^aJj`<000038@@Y9B4400X00003ool00?oo07coo`002Ooo00D00?ooJdeS;6]=00>U=0B]M@0b
[EFU=:eEYABU=:DD[EFU=:eES76DTXaaYABM4jDDWA>eUZfE]IJ]MKFF[GF4<8@@Q31l3h@@O0nU59dC
YAB]EJee[EF]MKgG_ONmekFf]IJe]Zee]IJ]MF<<F^]S36</JbeS;0B]M@>e]P03WA>U59dC00NU=006
YABU=:DDYCBU5:Dd0icc1TY900b4<8@@Q32DTYBbU99[;F</JbeS;?oo0009ool01P00oolj1d88>PM2
20<aYP064:8@PQ2R4:8HXa2R3@0000aJjf;/F^/88@0P224Q92TU8B@aYS66<JH=0003g_/016=<JdeS
C6]=1P000`Q12P0000<@PPQQ48800f<<00=Jje[;F^/00`0000<Q92448B@02P0000?oo`00ool0O?oo
0009ool03`00oomSC6]=Hdb]EJDd[EF]MKEf[GFeMZED[EFUE003YC@01ZED[EFUE9BBS76DTPBU5008
]IJe][FF]IJ]MKFFQ124<0B440>U5007[GF]EJee[EFmmkgG_OL00kFf012eUZee]IIJjf<<F^][CF</
Jdf]MKEf[GFeM[Ff_MNe]P>U5006YCB]EJDd[EFU=:eE1jDd01FTm9ccY?A:BDYYBTU:JDY9BVV448@`
Q12D/YBBU;9S;6]=Hba[COoo00002Ooo00<00?oo@PP00d8800TiYc6V>JL@XQRS4:8H`a2R6<<03@00
00aS35[[H``080PQ020Y9B4T:BDaQSVW<HH=0003g_/016]]Jde[KF]=1P000`Q12P000a2200IS;6<<
HbaJjf;/F^/300000b44:BDQ100:00000ooo003oo`1lool000Woo`03003oof]]009[K@07YCB]EJDd
W=>DdYcCU=801:Dd00>]EJDdYC@00ZDd01fU5:DdYABU59ccYABLljeEYCB]EIBbW=>D/V</H`aS;5::
DZYBRU[;DZYJbiCBW=>DdYcC]IJe][FF00>mm`06]IJe][FFH`aK2f<<0f]]00NmmkgG_ONmekFF[GFe
UP03[GD04:DDWA>U59BBU;:DTZDdYABU=9CBW=>DdYcCDZYJZe:Z14Y900i:JDY9U9:<TIBBU=:LdiCB
JbeS;6/]Hbcoo`002Ooo00<00?oo00006@0000IcSW>^LhhY9B4T:BDC000324440003244@00001R4T
8@@Q912R6:<@XP<000034:8H`a2R00d00003ool00?oo07coo`002Ooo01@00?ooJfecKV]][EFUE:eE
W=>LlicCW?>U=:eEYCB]EJED[EFU=:eE1:Dd012LljDDW?>U5:ED[EFUE9cCU=:Ldf</JbeS;5:ZDXYB
ZP=Jb`04W?>LdiccW=<3]KH00kggaORmm`03]KH3H``03G=^JfecK[gG_ONmekgg[GFeUZee]GJ]MKEf
00>U5003U;:DTYBb00>U=00=W?>LdiccW==Jbe:ZF/]:BDYYBTUBJTYYDVX00iBB00VLlicCW?=S;6]=
Hba[COoo00002Ooo00<00?oo00006@000g>^00<Q92TU8B@04`0000<8@@QQ2440100000<8H@Q12640
400000HQ92TU8B@H`a2R6<<300036<<=00000ooo003oo`1lool000Woo`03003oof]]009[K@07YCB]
EJDdW=>DdYcCU=801:Dd00>]EJDdYC@00ZDd01fU5:DdYABU59ccYABLljeEYCB]EIBbW=>D/V</H`aS
;5::DZYBRU[;DZYJbiCBW=>DdYcC]IJe][FF00>mm`06]IJe][FFH`aK2f<<0f]]00NmmkgG_ONmekFF
[GFeUP03[GD04:DDWA>U59BBU;:DTZDdYABU=9CBW=>DdYcCDZYJZe:Z14Y900i:JDY9U9:<TIBBU=:L
diCBJbeS;6/]Hbcoo`002Ooo00<00?oo00006@0000IcSW>^LhhY9B4T:BDC000324440003244@0000
1R4T8@@Q912R6:<@XP<000034:8H`a2R00d00003ool00?oo07coo`002Ooo00D00?ooJfecKV]]00NU
50>DTP>U50>U=0>U5004YCB]EJDd[ED3Ljh02F;/F^]Rk5::DZYBRU9ZBVUBJP03DXX03E[;DZYJbe:Z
]GJ]MKEf[GFeUZee]IJ]MKFF00=S3007JdeS;6]=]KJmekFf_ML00kFf02F]EJED[EFUE:eEYEBLlicC
W?=kkh@@NnmBJTYYDVY:JDXY@RQ::DY9BVU:BF<<F^]S39cCW?>LdjeEYCB]EF</JdeS;6]=ool00009
ool00`00ool0000I0003F//F00000bUU<FHYI@0`00000ooo003oo`1lool000Woo`03003oof]]009[
K@0CWA>U59dCYABM4jDDWA>DTXbAU9:M4jDDWA>U=:DDYCBM4jDDWA<01:Dd00=c[W>>Ljh00e[[00eB
ZU::DZY:BDYYBTUBRTZ9DXYBZUZ[DZYJZ`03[GD03;FF[GFeUZee]IJ]MF<<F`]S36</JbeS;0Fe]P0B
]IJe]ZDd[EFU=:eEYCB]EICBW=>DdX@@Nnn444Y9BVU:BDYY0d8X0dY900IJjf<<F^^LdiCBW=<3YC@0
1V/]Hba[;F</ool000Woo`03003oo`0001T00003DZYJbe:Z01H00003:FDYABUU03000003ool00?oo
07coo`002Ooo00D00?ooJfecKV]]00NU50>DTP>U50>U=0>U5004YCB]EJDd[ED3Ljh02F;/F^]Rk5::
DZYBRU9ZBVUBJP03DXX03E[;DZYJbe:Z]GJ]MKEf[GFeUZee]IJ]MKFF00=S3007JdeS;6]=]KJmekFf
_ML00kFf02F]EJED[EFUE:eEYEBLlicCW?=kkh@@NnmBJTYYDVY:JDXY@RQ::DY9BVU:BF<<F^]S39cC
W?>LdjeEYCB]EF</JdeS;6]=ool00009ool00`00ool0000I0003F//F00000bUU<FHYI@0`00000ooo
003oo`1lool000Woo`03003oof]]009[K@0CWA>U59dCYABM4jDDWA>DTXbAU9:M4jDDWA>U=:DDYCBM
4jDDWA<01:Dd00=c[W>>Ljh00e[[00eBZU::DZY:BDYYBTUBRTZ9DXYBZUZ[DZYJZ`03[GD03;FF[GFe
UZee]IJ]MF<<F`]S36</JbeS;0Fe]P0B]IJe]ZDd[EFU=:eEYCB]EICBW=>DdX@@Nnn444Y9BVU:BDYY
0d8X0dY900IJjf<<F^^LdiCBW=<3YC@01V/]Hba[;F</ool000Woo`03003oo`0001T00003DZYJbe:Z
01H00003:FDYABUU03000003ool00?oo07coo`002Ooo00h00?ooLhic[W>>[EFU=:eEYCB]EJDd[EFL
ljDD0Ycc00FLdiccU9:D/YBB00>U=00<JfecSV]]LhiBZU[;DZYJbe:ZF/]BRU:Z0U::00E:JE::BVUB
RTYY00AJb`>DTP0@[GFeMZee]IJ]MKFFHba[;F</H`aJjf<<JfecSV]]Lhh3YA@01YcCU;:Ldg>^Nlmc
[P=BRP0=BVUBRTYYBRU2:4XY@RQBJTYYDVY:BDYYBTT00iBB1ZDd00I[KG=^JfecK_oo0009ool00`00
ool0001U00000ooo003oo`1lool000Woo`05003oog>>JhecSP07YC@05JDDW?>U59CBW=>DdYBbU9:D
/ZDDYCBU57>>JfecSV]]FZ]BZUZ[DZYJZ`02DZX03e::DZY:JE::BVUBRTYYDXYBZU[;DZYJbhbAU9:<
T@04[GD04[FF[GES;6<<HbaJjf<<F^]cSV]]Lhi[KJDDWA>U59BbW;>D/P=c[P06BXUBRTZ9DXY:JE::
148X00=:BDYYBTT00dY900V<TIBBS96U=:DDYCBU5:DdYA@016]]00?oo`00ool02?oo00<00?oo0000
I@0000?oo`00ool0O?oo0009ool03P00oomcSW>^Lhj]EJDd[EFU=:eEYCB]EIccYA@2W?<01IcCW?>D
TYBbU9800jDd00a[KG>>JfecSU:ZF/]BZU[;DZYJbe::DZX2DXX01DYYDXY:JE::BVT015[;0iBB012]
MKEf[GFeUZee]IIS;6/]HbaS35[[H`a[KG>>JfecSP>U5006W=>D/YcCLjikcg>^0e::00e:JE::BVU:
:D8XBRU2:59ZBVUBJTY9BVU:B@03U986YC@01V]]Lfi[KG=^ool000Woo`03003oo`0006D00003ool0
0?oo07coo`002Ooo00<00?ooJfd00V]]00JU5:DdYABU=:DDYC@2YA@019ccYABLljDD19cc00>4<8aA
Q3001d8X00]BZUZ[DZYBZU::DZY:JE::BVUBRTYY009BRP03DZYBRU:Z00>4<00@]IJ]MKFF[EF]MJeE
H`aK2f<<F^]S35[[H`aK2f<<F`/3F//02E:ZF/]BZU:ZDXYBZTYYDXY:J@07BTT3@RP00e::BXUBRP04
YC@02jDDYCBU5:DdYAA[KF]=Jfe[COoo00002Ooo00<00?oo00006@0000<aYSVW<JH0100000<08000
0000@P0000?oo`00ool0O?oo0009ool01@00oom[KG=^Jfd01jDd00VLljDDW?>U59ccYABLljCdW?<0
0haA00a2:4XY@RQ::D8XBRU2:5[;DZYJbe::DZX2DXX03TYYDXY:JE::BVUBZU::DZYBRX`aQ32<<Jee
]IH2[GD00jeE[GES3003H``00e[[H`aS3003H``00e[;F^]Jb`03F//045::DZYBRU::BVUBRTY9BVU:
BDYYBTU:JDY9BRU2:4XY0e::00>]EJDd[ED01ZDd00I[CF]]Jde[KOoo0009ool00`00ool0000I0000
0cW7<JHia`0300000`PQ02088@1300000ooo003oo`1lool000Woo`03003oof]]009[K@06YABU=:DD
YCBU5:Dd0ZDD00BLljDDW?>U50BLl`03Q32<DH@`00M2:00;DZYJZe:ZDZYBRU:ZBVUBRTYYDXY:J@02
DXX00e:ZDXYBZP03Q3004;FF[GFeUZeE[GF]EF<<F`]S35[[H`aJjf<<F`]S35/;0e[;00UBZU[;DZYB
ZU::DZY:JE::BVT01dY90d8X00=BRTZ9DXX01:Dd00^U5:DdYABU=:DDJfe[CF]]Jdgoo`0000Woo`03
003oo`0001T00003<JHiYc6V00@000030200000004800003ool00?oo07coo`002Ooo01800?ooLhic
[W>>[EFUE:eEW?>U59ccYABLljCdW?>]EJED[ED3YA@04g__NlmkkcWW@PPiid88BTU:JDY9F/]BZU[;
JfecKV]]Lhi[KG>>00=BRP0CF/]BZU[;DZZDTXaaU9:]MKFF[GFeUZee]II[KG>>JfeRk5[[H^`016<<
0e[;00EBZU::DZY:JE9Z009:J@08BTU:JDY9BVU:BDYYBTU:J@A:B@03Q124<8@@00>DTP>U=009YABL
ljDDJfecSV]]Lhkoo`0000Woo`03003oo`0006D00003ool00?oo07coo`002Ooo00/00?ooLhi[SG>>
YCB]EJDdYABLljDD00BLl`0=YCB]EJDdYABM4jDDNlmkkg_?@NPiid7X>NL00dY900=BZUZ[DZX016]]
01EcSV]]DXY:RE::DZYJZe:ZFZ^<LIBBS76eUZee]IJ]MKFF[GEcSV]]Lhh00e[[00eS35/;H`aK2e[;
DZYJbe::DZYBRTYYBTU:J@0:BTT05D8XBTU2:8@`Q124<8bAU9:<TJDdYABU=9ccYABLlg>>JfecSV]]
ool00009ool00`00ool0001U00000ooo003oo`1lool000Woo`0B003oog>>LjicSZeEYEB]EIccYABL
ljDDW?>Tm9cc[EFUE:eE0jDD01=kkg_?Nnliid88>NM224Y9BVU:BE[;DZYJbf]]Lfi[KG>>JfecSP03
DXX04e[;DZYJbe:ZU9:<LIBB[GFeUZee]IJ]MKFFJfecSV]]H^aJjf;/00AS30=Jb`05DZYBRU:ZBVUB
JP02BVT024Y9BVU:BDYYBTU:JDY9BVT4BTT00h@@Q3244003U983YC@02JDDW?>U56]]Lhi[KG>>ool0
0009ool00`00ool0001U00000ooo003oo`1lool000Woo`0?003oog>^Lhic[ZDd[EFU=:DDWA>U59dC
U;:DTYBb00>Ll`0@YABM4jDDDXYBZU::@RQ2248X@PQ[KF]=JffLljDDW?<3YC@00jDDYCBU5003S540
2TYYDXY:JE::YABU=:DD[EFU=:eE0jDd00>LdiBbW=<00e[[011S35/;H`aK2e[;DZYJbdZ9DXY:RDY9
@RQ:BD8XBTU2:0M:B@03F^]S35[[00>U=009Q124<8@@U9:<LIBBU;:LdiBb00Ac[P03ool00?oo00So
o`03003oo`0006D00003ool00?oo07coo`002Ooo00<00?ooLjh00W>^00>]EJED[ED01:DD00JDTYBb
U9:Tm9ccY?@3YA@03e:ZDXYBZT88@RQ2248XJde[KF]=YABLljDDYCB]E@04YC@01haAS76<DE::BVUB
RTYY00>U=00<YEB]EJED[EFU=:eEU=:LdiCBH^aJjf;/16<<0e[;0e::1dY901]:JDY9BVU:BDYYBTUS
35[[H`bU=:eEYCB4<8@@Q32<LIBBS76LdiCBW==c[W_?Ljikcooo00002Ooo00<00?oo0000I@0000?o
o`00ool0O?oo0009ool03`00oomc[W>>LjjU=:eEYCBU59dCYABM4iBbU9:D/P03W?<04:DDWA>U55::
DZYBRT8X@PQ2:488Jfe[CF]]W?>U59cc0jDd00>U5:DdYA@00haA00Y:JE::BVUBRZDDYCBU5:eEYCB]
E@>U=003W=>D/YcC00=Jj`0@H`aK2f<<F`]Jbe:ZF/]:RE::BXU:BD8XBTU2:4Y9@RP7BTT00e[[H`aJ
j`03YC@02H@@Q32449BBS76DTYBbW=>D/P04Ljh00ooo003oo`08ool00`00ool0001U00000ooo003o
o`1lool000Woo`0;003oog>>LjicSZeEYCB]EIcCW?>Ld`02W?<04JCdW?><LHaAS76LljCdW?=::D8X
BRUJbe[[F/]JjjeE[GD00ZeE00BU=:eEW=>Ll`:Ld`09U;:Ldf]]Lhi[KE::BVUBRTYY00>DTP09[GFe
MZeeYABLljDD[GFeUZee00=c[P0:F/]Jje[;F^]BZU[;DZY::D8XBRT3BTT00dYYBTU:J@03DXX03F;/
F^]Rk5[[YABLljDDU9:D/YBBDVY:JE9Z00>U5003U9:<LIBB00B44003ool00?oo00Soo`03003ooooo
00Koo`06264@HPQQ>NLiacWW0aS300<iYc6V>JL0100000<8@A1R24400ooo0`000dY90aS33@000ooo
00C>NLiIcWW>FA<000?oo`?_O@<@PP<000032248@@PQ00@000=:B@05>LLiicW7ool0001mool000Wo
o`05003oog>>JhecSP03YC@019cCU=:LdiCB0icc0haA0icc0d8X15[;00>]MJeE[GD00jDd012LdiCB
W=>D/YbcU;9cSV]]Lhi:JE::BVUBRXbAU9:<T@>]M@09W?>U59cc]IJ]MKFFLhic[W>>00AJb`03FZ]B
ZUZ[00=2:003BTU2:4Y900=:B@03DXY:RE::00AJj`0EW?>U59ccU;:DTYBbBTU:JDY9YABM4jDDS76D
TXaaQ11l3h@@O0ooo`0000Woo`03003ooooo00Koo`0<4688HA1R>LLiicW76<<@XQS3<HHaYS661000
00<8H@Q126400ooo0`0000=2B4Y9@TP00aS33@000ooo00C6F<iIaUS>FA<000?oo`03keg_ONmM00<@
PP<00003244080Q100@00008@TQ:BD98>NLiacWWool007goo`002Ooo00/00?ooLhic[W>>[EFU=:eE
W=>LlicC00:Ll`0AY?BLlhaaS56<LIccY?BLldXY@RQ::E[;F^]Jbe[[[EF]M@02[ED01:Dd[EFLdicc
0YcC00VD/YcCJfecSV]]DXY:JE::BVT00iBB00V]MKEf[GFU59ccYAB]MKFF[GD00g>^00YJbe[[F/]J
je:ZF/]BZTXY@RQ::@=:B@03BVU:BDYY00=BRP0=H^aJjf;/F^^U59ccYABDTYBbU99BJTYYDVX00jDD
00>DTXaaU98018@@00?oo`00ool02?oo00<00?ooool01_oo00H8HA1R264iicW7>NL36<<00cVW<JHi
Y`0400000`Q14688@@03ool30003BTT36<<=0003ool01<iicUW>NLiI4`000ooo0nmm0a220`0000<8
8@Q1224010000dY900DiacWW>LOoo`0007goo`002Ooo00`00?ooLhi[KG>>YCB]EJDdYABM4jDDWA<3
W?<01YCBW=>DdXaAQ32<D@=2:00:S564<8aAQ32U=:DDYCBLljDDW?<3Nnl04dZ9DXY:RDY9@RQ:BDYY
DXY:JE::O0n447`?]IJ]UKFF[EF]MJeE00B]M@0U]IJ]MHaaS56<LHaADZYBRU:ZBVUBRTYYBTU2:4Y9
DXYBZU::Q32448@`S76DTXaaU99BRU:ZDXY2:488@RQ:JE::BVVLdiCBW=<00haA18@`00?oo`00ool0
2?oo00<00?ooDZX00e:Z00H080Q1021BZU::DZX600000a224:8@PP0700000aSS8>@Hh`0300000c6V
>JLaYP03244=0003_OL0148XBTU2:4Y96@000`Q10`0000LY9B4T:BD080PQ02088@0600000ooo003o
o`1lool000Woo`08003oof]]Lhi[KJeEYEB]E@BU5006W?>Tm9ccW?>Ldicc0haA00=::D8XBRT018aA
0jDd00JU59ccYAAkkh?`Nnl3DXX3BTT015::BVUBRTYY0h@@00FeU[Ff]IJ]MJeE00:]M@0;]GJ]MKFF
[GFeUXaaU7:<LIAbDXYBZP02DXX00dYYDXY:B@02BTT07e:ZDXYBZX@@Q32449BBS76DTXaaDZYBRU:Z
@PQ2:488DXY:JE::W=>LlicCS76<DHaaQ32<<H@`S37oo`0000Woo`0<003ooeZ[DZYJZe:Z24488@Q1
DXYBZU::1P0000<HXa2R6:<01`0000<Pi1SS8>@00`0000<iac6V>LL00`Q13@0000>mmlGh_OL014Y9
6@0000<8@@QQ24400`0000LQ92TU8B@88@0P2240800600000ooo003oo`1lool000Woo`0<003oog>>
JfecSZDd[EFU=:DDWA>U59dC0icc00JDdYcCU=:<DH@`S543@RP02XaAQ32<DH@`YCBU5:DdW?>U59cc
0g__01=:RE::BXU:BD8XBTU:JE::BVUBRW`?Q11l3kFF[IFeUZeE[GF]E@04[GD09KFF[GF<LHaAS76<
DE:ZDXYBZTYYDXY:JDY9@RQ:BE::DZYBRX@`Q124<8aaU9:<LIBBDXYBZU::@RQ2248XBVUBRTYYW=>D
dYcC00><D@B4<003ool00?oo00Soo`03003ooe:Z00=BZP060208@@0PDZYBRU:Z1P0000<@PQ2R4880
1`0000<Hhb3T6><00`0000<aYSVW<JH00`Q13@000kgg00A2:4Y9@RQ:BAT000<8@@<00007:BDQ92TU
02088@0P22401P0000?oo`00ool0O?oo0009ool07P00oomkcg__Nln]EJDd[EFLljDDW?>U59ccYABL
ljCdW?>Tm9ccY?BLld8X@PQ2:5[[H`aJjf<<DXYBZP9BRP0?BVUBRTYYDVY:JE9ZBVUBJTY9BVU:BE9Z
BVUBJTYY00=kc`05YCB]EJDd[EFUE002[ED02Jee[EF]EJDd[EF]MKFF[GFeUP03YC@03iBbU9:D/W__
Po1kkf;/F^]Rk4Y9BVU:BDXY@RQ::@02@RP00d88@RQ:B@02BTT03e9ZBVUBJYcCW?>LdhaaS56<LHaA
S76<DHaaool00009ool02@00ool08000020000PQ02088@0C00000haaS56<L@03@PP00a1R244@HP0@
00036<<G000035:ZFZ]BZQ1R244@HR448B@Q10PQ02088@d00003ool00?oo07coo`002Ooo00D00?oo
Nnmkcg__00>U=007YABLljDDW?>U59ccYA@01Ycc00a2248X@PQS35[[H`aJje:ZDXYBZTYYDXX2BVT0
14Y9BVU:BDYY1DY900I:JDY9BVUccW_?Llh4YC@01JeEYCB]MJeE[GD00jDd00ZeUZee]IJ]MJDdYABU
=9BBU;:DTP=kk`=Jj`=:B@A2:005@PQ2:488BTU2:002BTT01DYYBTVLdiCBW=<01haA00?oo`00ool0
2?oo00<00?oo00000`0000<080PQ02004`0000V<DHaaS55223X7@PP8@@QQ2440400000<H`a2R6<<0
5`000e:Z00<8@@QQ24400b4400<0000P00003@0000?oo`00ool0O?oo0009ool07P00oomkcg__Nln]
EJDd[EFLljDDW?>U59ccYABLljCdW?>Tm9ccY?BLld8X@PQ2:5[[H`aJjf<<DXYBZP9BRP0?BVUBRTYY
DVY:JE9ZBVUBJTY9BVU:BE9ZBVUBJTYY00=kc`05YCB]EJDd[EFUE002[ED02Jee[EF]EJDd[EF]MKFF
[GFeUP03YC@03iBbU9:D/W__Po1kkf;/F^]Rk4Y9BVU:BDXY@RQ::@02@RP00d88@RQ:B@02BTT03e9Z
BVUBJYcCW?>LdhaaS56<LHaAS76<DHaaool00009ool02@00ool08000020000PQ02088@0C00000haa
S56<L@03@PP00a1R244@HP0@00036<<G000035:ZFZ]BZQ1R244@HR448B@Q10PQ02088@d00003ool0
0?oo07coo`002Ooo00D00?ooNnmkcg__00>]M@0DW=>D/YcCU;:<DH@`S56LljDDW?=kkg_?Nnlj1d88
>PM2:488@RQ220=:B@03BVUBRTYY00M:B@0O@RQ:BDYYDXY:JE::Llikcg?>Jfe[CF]][EF]MJeEYCBU
5:DdWA>U59dCS76<DHaaS55S;6<<Hba:JE::BVT00d8X00E2248X@PQ2:48800U2:008@PQ2:4Y9BVU:
BIBBS96DTP>4<006U;:DTYBbU9;oo`002Ooo00P00?oo8B@Y9B4T:BD0000P50000d880`0000<Q92TU
8B@0400000=kcg>^Nll0<00000?oo`00ool0O?oo0009ool03000oomkcg__NlneMZee]GJDdYcCU=:L
d`><D@06YABLljDDNlmkkg_?148800m2:488@RQ:BDYYBTUBRTYYDXY:BDYYBTU:JDY9BVT00dY900AB
RTYYDXY:J@=kc`06Jde[KF]=[GF]EJee0jDd0jDD00b<LIAbS76DLV</JbeS;5::BVUBRT8XBRT2@RP0
4T88@RQ2248X@PQ::D8XBRU2:4XY@RQ::D88@RQ2259ZBVUBJP>DTP09S364<8`aU9:D/YBBU;;oo`00
00Woo`09003oobU58B@YAB4T224000PQ01<00003@RQ2248X00<00003:BDQ92TU01000003Llikcg?>
03000003ool00?oo07coo`002Ooo00D00?ooNnmkcg__00>]M@0DW=>D/YcCU;:<DH@`S56LljDDW?=k
kg_?Nnlj1d88>PM2:488@RQ220=:B@03BVUBRTYY00M:B@0O@RQ:BDYYDXY:JE::Llikcg?>Jfe[CF]]
[EF]MJeEYCBU5:DdWA>U59dCS76<DHaaS55S;6<<Hba:JE::BVT00d8X00E2248X@PQ2:48800U2:008
@PQ2:4Y9BVU:BIBBS96DTP>4<006U;:DTYBbU9;oo`002Ooo00P00?oo8B@Y9B4T:BD0000P50000d88
0`0000<Q92TU8B@0400000=kcg>^Nll0<00000?oo`00ool0O?oo0009ool01@00oon4<8`aQ3000jDD
00fLljDDW?>U56]]Lfi[KDXY@RQ::D8XBRU2:004@PP02D8X@PQ2:4YYDVY:JE:ZDXYBZP06BTT06DYY
DXY:JE[[F/]Jje[;Lhi[KG>>F^]S35[[H`aJjf<<JfecKV]]F^]Jbe[[BVUBRTYY009BRP07DZYBRU9Z
BVUBJT8XBRT00T8X00A2248XBTU:J@Q:B@09@RQ::D8XBRU2:4XYU9:D/YBB00=kc`06W?>Tm9ccY?Co
o`002Ooo00<00?oo00006@000a225P0000<Hhb3T6><07@0000H080Q102088@00224=00000ooo003o
o`1lool000Woo`03003ooh@`00:4<007WA>U59dCYABLljDDW?<00f]]1T8X01Hj1d88>PM2:488@RQ2
24YYBTU:JE::DZYBRTY9@RQ:BD8XBTU2:5::BVUBRPAJb`09JfecSV]]H`aJjf<<F^]S35[[00=[K@=J
b`0:DXY:JE::BVUBZU::DZY:BDYYBTT3@RP00d88@RQ22003BTT01T8XBTU2:4Y9@RQ:B@M2:006U;:D
TYBbLlikcg?>19cc00?oo`00ool02?oo00<00?oo00006@0000<8HA2226405P0000<HhaS36><07@00
00D88@0P2240000P00h00003ool00?oo07coo`002Ooo00D00?ooQ32<<H@`00>U500=W?>U59ccYAA[
KG=^Jfe::D8XBRU2:4XY@RP0148800U2:488@RQ:JE9ZBVUBZU::DZX01TY901U:JE::BVUJje[;F^]J
bg>>JfecSU[[H`aJjf<<F^]S36]]Lfi[KE[[F/]JjdYYDXY:J@02DXX01e:ZDXYBJTYYDVY2:4XY0092
:004@PQ2:4Y9BVT8BTT02D8XBRU2:4XY@RQ::IBBU;:DTP03Nll01YccY?BLljCdool000Woo`03003o
o`0001T000<@PQH000036><Pi1SS01d000060208@@0P224000PQ3@0000?oo`00ool0O?oo0009ool0
0`00oon4<002Q3001idCYABM4jDDW?>U59cc00=[K@I2:00F>PM223X7@RQ2248X@PQ:JDY9BVUBRU:Z
DXY:BD8XBTU2:4Y9@RQBRTYYDXX4F//02F]]Lhi[KF<<F^]S35[[H`aJj`03Jfd3F//02U::BVUBRTYY
DZYBRU:ZBTU:JDY90d8X00=2248X@PP00dY900I2:4Y9@RQ:BD8XBTT7@RP01YBbU9:D/W?>NlmccPBL
l`03ool00?oo00Soo`03003oo`0001T00003264@PPQQ01H000036><H`aSS01d00005224080PQ0000
800>00000ooo003oo`1lool000Woo`0D003oohaAS76<DJeEYCB]EIccYABLljDDHda[CF=<BRU2:4XY
@RQ::@92:00O@PQ2:488@RQ2248XBTU:JDY9DXY:JE::F^]S35[[Po1kkh?`S76DTXaaY?BLljCdW?=c
SV]]LhiJjf;/F^/00e::011Jjf;/F^]BRTYYDXY:JE9ZBVUBJTYYDVY:JE9ZBVUBJPU:B@04BRU2:4XY
@RP3BTT04T8XBRU2:4YYBTU:JIBBU;:DTW=^JfecKZDd[EFU=:eEool000Woo`03003oo`0001T00003
24488@Q100<000034:8@PQ2R04<00003ool00?oo07coo`002Ooo00<00?ooS5400XaA0jDd00NU59cc
YABLlf]=Hba[C@06@RP01d88@RQ2248X@PQ2:48800=:B@06BVUBRTYYH`aJjf<<0g__00>DTXaaU980
19cc00=[KG>>Jfd00e[[00=:RE::BXT00e[[00a:JE::BVU:JDY9BVU:BDYYBTU:JDY9BVT2BTT0248X
BTU2:4Y9@RQ:BD8XBTT5@RP00dY9@RQ2:002@RP3BTT00iBbU9:D/P03Jfd4YC@00ooo003oo`08ool0
0`00ool0000I00000`0P244080030003489300000ooo003oo`1lool000Woo`0D003oohaAS76<DJeE
YCB]EIccYABLljDDHda[CF=<BRU2:4XY@RQ::@92:00O@PQ2:488@RQ2248XBTU:JDY9DXY:JE::F^]S
35[[Po1kkh?`S76DTXaaY?BLljCdW?=cSV]]LhiJjf;/F^/00e::011Jjf;/F^]BRTYYDXY:JE9ZBVUB
JTYYDVY:JE9ZBVUBJPU:B@04BRU2:4XY@RP3BTT04T8XBRU2:4YYBTU:JIBBU;:DTW=^JfecKZDd[EFU
=:eEool000Woo`03003oo`0001T0000324488@Q100<000034:8@PQ2R04<00003ool00?oo07coo`00
2Ooo00P00?ooU9:<TIBBWA>U59dC19cc00Q[CF</Jddiid7X>NM2:488148X00Y:JDY9BVU:BG>>Jhec
SYBBU;:DTP>Ll`06U;:L/iBbQ32448@`15[;00m[CF]]JdeS35[[H`aBZU[;DZYJZe:ZFZ]:RE::BXT0
14Y900EBRTYYDXY:BDYY00A:B@05>PM223X7@RQ22002@RP064Y9@RQ:BE:ZFZ]BZW>>JfecSX@`S564
<9BBS96DTU/;H`aK2jeEYCB]EJDdool000Woo`03003oo`0001`000034688HA1R01<000030200000P
03000003ool00?oo07coo`002Ooo00<00?ooU9800YBB0jDD00VLljCdW?>Tm6=<JdeSC488>NL00T88
0292:488BRU2:4XYBVUBJTYYDVYcSW>^LhjD/YBBU;:LljCdW?>LdiBbW=>448@`Q11Jje[;F^]Jbf]]
Jde[KE[[H`aJj`=Jb`03DZYJbe:Z00=BRP03BTU:JDY9009:J@08DXY:JE9ZBVUBJTY9BVU:B@A22003
@RQ224Y900=:B@06F/]BZU[;JfecSV]]0haA0iBB0f<<00JUE:eEYEB]EOoo0009ool00`00ool0000L
00000`QQ4688H@0C00000`0P2240800`00000ooo003oo`1lool000Woo`08003ooiBBS96DTYdCYABM
4`BLl`08JdeS;6]=>NM1j3WW@RQ220A2:00:BVU:BDYYBTUcSV^=LhjDTYBbU983W?<01YBbW;>D/X@`
Q124<0AJb`0?Jde[KF]=H`aJjf<<DZYJbe:ZFZ]BZUZ[BXUBRTZ900A:B@05DXY:JE::BTU:J@04BTT0
1CX7@PPj1d8X@PP00T8X01Q:BD8XBTUBZUZ[DZYcSV]]Lhj4<8aAQ32DTXbAU99K2f<<F`^]EJDd[EFU
=?oo0009ool00`00ool0000L00000a1R264@HP0C00000`0P0000800`00000ooo003oo`1lool000Wo
o`08003ooiBbW=>D/ZDDW?>U50BDTP0@Jde[KF]=>NLiacWWBTU:JDY9Lhi[KG>>S56<LHaAS746U980
5F]=Jfe[CDYYBTU:JDY9BVU:BDYYBTU:JDY9JbeS;6/]F^]S35[[DZYBRP02DZX04U[;DZYBJTYYDVY:
JE::BVUBRTYYDVY:JE::BVUBRT8XBRU2:0=:B@03@RQ::D8X00A:B@03Q11kkh@@00>U500?S76<DHaa
W=>LlicCF^]Jbe[[YEB]EJED[EGoo`0000Woo`03003oo`0003D00004224080PQ020/00000ooo003o
o`1lool000Woo`0?003ooibcU;:L/iccYABLliBBS96DTXbAJfe[CF]]00<ia`=:B@03JfecSV]]00B<
D@09U9:<TIBBS96DTXbAJfe[CF]]00Y:B@0BH`aS;6<<H`aJjf<<DXYBZU::FZ]BZUZ[BTU:JDY9DXY:
JE::0TYY00E:BDYYBVUBRTYY00A2:003BTU2:48X00=2:009BTU2:4Y9Nnn447__YABM4jDD00><D@03
W=>DdYcC00=Jb`06[EFU=:eEYCCoo`002Ooo00<00?oo0000=@0000@080PQ02088B`00003ool00?oo
07coo`002Ooo00P00?ooU;:LdiBbYABLljDD19BB011[CF]]JddiicW7>NM:BDYYBTUcSV]]Lhj<DHaa
S56<L@JDTP0EJde[KF]=BVU:BDYYBTU:JDY9BVU:BDYYBTU[;F</JbeJjf<<F^]BZU::009BZP0BF/]B
ZU9ZBVUBJTYYDXY:JE::BVUBJTYYDXY:JE::@RQ::D8X0dY900=2:4XY@RP014Y900>447__Q1000jDD
00n<LHaAS76LdiccW==Jje[;F^^UE:eEYEB]EOoo00002Ooo00<00?oo0000=@0000@88@0P224082`0
0003ool00?oo07coo`002Ooo00P00?ooW=>D/YcCWA>U59dC19cc00=[CF</Jdd00f]]012DTXbAU9:4
48@`Q11Jbe:ZF/]BZTY9@RQ:BDZ9DXY:R@=:B@=2:003BTU2:4Y900A2:009H`aS;6<<HbaS36</DZYJ
Ze:Z00=Jb`0=BVUBRTYYDXY:JE::BVUJZe:ZFZ][CF]]Jdd0148X00A:BD8X@PPj1`922003@RQ2248X
00=2:003FZ]BZUZ[00>Ll`0<S76<DHaaHba[;F</[GF]EJee[EGoo`002Ooo00<00?ooool00ooo00?W
?>mMic`01P0000XHhaS36><Q92TU8B@@HPQQ4688H@<000?oo`06YABM4jDDDZYJbe:Z0bU53@000ooo
00XYIC5V:FDaIT8XBTU2:23T6><Pi0d000Koo`03[EFU=:eE01000003ool00?oo07coo`002Ooo00D0
0?ooU=:LdiCB00>U500:W?>Tm9ccY?ASC6]=HdacKV]]Lfh3U9800h@`Q124<004F//3BTT3DXX01TY9
BVU:BDXY@RQ::@=:B@0<BRU2:4XY@RQ[;F</JbeS;6/]HbaJbe:Z0U[;019Jje[;DXY:JE::BVUBRTYY
DXYBZU[;DZY[KF]=Jfe2:4XY@RP3BTT3@PP06D8X@PQ2:488BRU2:4XYDZYJbe:ZY?BLljCdS76DLXaa
JdeS;6]=[EF]MJeE[GGoo`0000Woo`03003ooooo00?oo`03kegWG>mM00H0000:6><Pi1SS:BDQ92TU
264@PPQQ48830003ool00jDDYCBU5003F//00bU5:FDYA@0=0003ool01366:FDaQRUU0dY900<Hhb44
6><03@001_oo00>UE:eEYE@0400000?oo`00ool0O?oo0009ool02000oonLdiBbW=>M4jDDWA<4W?<0
0f]=Hba[C@03Jfd049BBS96DTX@@Q32445[;DZYJbe:ZBTU2:4Y9BXUBRTZ90dY90d8X00=:BD8XBTT0
148X00US36</H`aS;6<<HbaBZUZ[DZX00e[;00e:JE::BVUBRTYYDXY:JEZ[DZYJZf]=Jfe[C@04@RP0
14Y9@RQ223X70T8800=2:488@RP00d8X00=JZe:ZFZ/00icc00b<LHaAS75S;6/]Hbb]MJeE[GF]EOoo
0009ool00`00ooooo`03ool00nLlkegW?00600002QSS6<<Hhb4T:BDQ911R264@HPQQ0`000ooo00JU
59dCYAABZU[;DZX3:DD=0003ool02RUU<FHYIC5V@RQ:BD8X8>@Hhb3T3@001_oo00>]EJDd[ED04000
00?oo`00ool0O?oo0009ool03`00oonLljCdW?>]EJDd[EFLdiccW=>LliBbW=>D/P03Q1000g>>Ljic
SP03Q1001S6V>JLaYSVW@RQ::@92:004@PQ2:48XBRT2@RP02D88@RQ2:4XY@RQ:JDY9BVU:B@03H``0
36</JdeS;6;/F^]Rk6]=Jfe[CH@@Nnn440BDTP06W=>LlicCF^]Jbe[[0d8801m::D8XBRU2248X@PQ2
:488@RQ2248X@PQ2:488@RQ224XY@RQ::H@@Q32447_?LjikcjDd[EFU=:eEool00009ool01P00ool@
XQ224:8@PR0000032240000000`0000=<FHaQS5V<HHaIS66<FIJbe:ZF//Q92U58B@03@0000THXaS3
6:<@HPQQ4688HA2226401P0000<88@0022401`0000?oo`00ool0O?oo0009ool00`00oonLl`02W?<3
YC@049cCU=:LdiCBW;>D/YbcO0n447`?Lhi[SG>>O0n447`?136V0d8X00=2248X@PP00d8X00=2248X
@PP00d8X14Y900IK2f<<F`][;F</Jbd3F^/03F]]Jde[KG__Q11kkiBBS96DTXbAW=>DdYcC00=Jb`03
@PPj1d8800A2:00;@PQ2:488@RQ2248X@PQ2:488@RQ22004@RP00h@`Q124<003Ljh4YC@00ooo003o
o`08ool00`00ool@PP03488O00000`0P0000800=00003C66:FDaQRUU<HHYIC66DZYJbe:Z:BDQ92TU
00d000096<<@XQS3264@HPQQ4688HA1R00L000030200000P00H00003ool00?oo07coo`002Ooo00l0
0?ooW?>Tm9cc[EFU=:eEW=>LlicCW?>D/YcCU;800h@@00=cSW>^Lhh00h@@00HaYSVW<JHiYd8XBRT2
@RP01488@RQ2:4XY0T8X00U2248X@RQ::D8XBVU:BDYYBTT00f<<00aS;6]=HbaRk5[[H^a[CF]]Jdf4
47__Q104U9801YcCW?>Lde[[F/]Jj`=2200OBRU2:4XY@PQ2:488@RQ2248X@PQ2:488@RQ2248X@PQ:
:D8XBRV448@`Q11kcg>^NlnU=:eEYCB]EOoo00002Ooo00H00?oo4:8@PQ2R488P00000`PQ0000000<
00003C5V<HHaIS66<FHaQS5VF/]BZU[;8B@YAB4T00d000096:<H`aRS4688HA1R264@PPQQ00H00003
224000PQ00L00003ool00?oo07coo`002Ooo00P00?ooYABM4jDDU;:LdiBb19cc00VDTXbAU99[CF]]
Jde223X7@PP00e[;00I223X7@PPj1d8X@PP4@RP3BTT02TZ9DXY:RF]=Hba[CG`?Q11l3h@@0g>^00>D
/YBBU;800icc00fU59ccYABDdYcCU=:L/iBbW;>D/V</H`aS;004BTT01D8XBTTj1d88>PL00d8X00Li
id7X>NM1j3WW@NPii`03@RP3BTT00g>>JfecSP03Q304YC@00ooo003oo`08ool00`00oolH``036<<3
00001Q1R264@HR448B@Q10d00003DZYJbe:Z01T0000:264@HPQQ4688@@QQ244H`a2R6<<300000`0P
0000800=00000aRS4:8HX`0700000`0P0000800600000ooo003oo`1lool000Woo`03003oojDD00:U
5007W=>DdYcCW?>Tm9ccY?@00iBB00=[KF]=Jfd00d8800=Jje[;F^/01D8800Q2:488BRU2:4XYBTU:
JDY90e::00=SC6]=Hd`018@@00]kcg>^NlnDTYBbU9:Tm9ccY?BLljDD00:Ll`0<W=>LliBbW=>D/YcC
Hba[;F</BVU:BDYY0dY90d8801a2:4XY@RQ223WW@PPiid88>NM2248XBRU2:4YYBTU:JF]]Lhi[KH`a
Q32<<JDd[EFU=:eEool000Woo`06003ooaSS6<<HhaS30`0000H8HA1R264Y9B44:BD=0003F//I0000
1a22264@PPQQ4688@A1R00<H``@000032240000000`000034:8H`a2R00H00004224080PQ02060000
0ooo003oo`1lool000Woo`08003oojDDWA>U59BbW=>D/PBLl`09U9:<TIBBJde[KF]=@PPj1d8800=J
b`06@PPj1d88>PM2:488148X0dY900Y:RE::BXU[CF</Jdel3h@@O0n440=c[P03U;:DTYBb00>Ll`0=
YABLljDDU=:LdiCBW;>D/YbcU;9S;6<<Hb`014Y900E2:4Y9>PM223X700=2:007>NM1j3WW@NPiid7X
>NL00d8X0dY900=cSV]]Lhh00h@`1:Dd00?oo`00ool02?oo00<00?oo6<<00aS30`0000H@HPQQ468Q
124T8@@=00000e:ZF/]BZP0I00002PQQ4688HA1R2448H@Q16<<@XQS30`0000<0800002003@0000<H
Xa2R6:<01`0000<0800002001P0000?oo`00ool0O?oo0009ool01@00oonLljCdW?<00jDd00NDTYBb
U9:D/YBBU;:DTP03BTT00d88@RQ22003F//00cWW@PPii`02@PP01D8X@PQ[CF</Jdd00g>^00I[CF=<
JdeSC6]=Hd`4U9804iBbU9:D/YccY?BLljCdW?>Tm7__Q11kkiccW=>Llg__Q11kkh@@00=:B@09DVY:
JE9ZF/]Jje[;DZYBRU:Z00A22003>NM223WW00A2200;@RQ224XY@RQ::G>>LjicSYBbU9:D/P04YC@0
0ooo003oo`08ool03000oolHXa2R6:<@XQSS6<<Hh`QQ4888HA0000036:<@XQRS01H0000:6<<HhaS3
>LLaYSW7<JHQ123T8@@@00001R4T:DDQ911R264@HQ<00003ool00?oo07coo`002Ooo00<00?ooW?<0
0Ycc00bU5:DdYABD/YBBU;:DTYBbU9:D/T8XBTT2@RP06d88@RQBZU[;DZY1j3WW@NPiid8X@PQ2:6</
JbeS;7>^Lhic[V</JdeS;6]=Hba[CHbAU9:<T@02U9800iBbU9:Ll`05W?<038@@Nnn449CBW=>DdX@@
Nnn447__BTU2:09:B@03BVU:BE[;009Jb`0?DXYBZU::@PPj1d88>NM1j3WW@NPj1d88>PM2:48800A2
:00<Lhi[SG>>U9:D/YBBYCBU5:DdYACoo`002Ooo00H00?oo4:8HXa2R6:<36<<00a1R264@HP0@0000
0a2R6:<@XP0F00036<<01c6V>LLaYSW76><Q11SS01000006:BDQ92TU264@HPQQ4`0000?oo`00ool0
O?oo0009ool01@00oonLljCdW?<00jDd00NDTYBbU9:D/YBBU;:DTP03BTT00d88@RQ22003F//00cWW
@PPii`02@PP01D8X@PQ[CF</Jdd00g>^00I[CF=<JdeSC6]=Hd`4U9804iBbU9:D/YccY?BLljCdW?>T
m7__Q11kkiccW=>Llg__Q11kkh@@00=:B@09DVY:JE9ZF/]Jje[;DZYBRU:Z00A22003>NM223WW00A2
200;@RQ224XY@RQ::G>>LjicSYBbU9:D/P04YC@00ooo003oo`08ool03000oolHXa2R6:<@XQSS6<<H
h`QQ4888HA0000036:<@XQRS01H0000:6<<HhaS3>LLaYSW7<JHQ123T8@@@00001R4T:DDQ911R264@
HQ<00003ool00?oo07coo`002Ooo00@00?ooYABLl`:U500OYCBU59bcU;:L/iBbS564<8aABXUBRTZ9
@RQ2248XQ124<8@@LjicSW>^Lhj447__Q11:JE::BVU2:488@RP00dY90d8X019:BDYYBTU:JHaaU9:<
LJDDW?>U58bAU9:<TG>>JhecSTY9BVT2BTT00d8XBTU2:003@RP024Z9DXY:RIBbU9:D/W__Q104Nnl0
1SWW@NPiid7X>NM1j08ii`03>LLiidY9009:B@03JdeS;6]=00>Ll`06YABM4jDDWA?oo`002Ooo00<0
0?oo00006@0000<@XQS34:805P000aS36P0000H8HA2226488@0P224@00000ooo003oo`1lool000Wo
o`05003ooiccYABLl`03YC@019BbW=>D/YcC0haA0e::00I2248X@PR4<8@@Q304Ljh06G__Q11kke::
BVUBRT88@RQ224YYBTU:JD8XBRU2:59ZBVUBJTYYU9:<LIBBW?>U59cc00>DTP06Lhic[W>>DVY:JE9Z
14Y900=2:4XY@RP00e::01bDTYBbU9:447__Q11kkh?`Nnm223WW@PPiid88>NM223WW@NPiidYYBTU:
JF=<JdeSC:CdW?>Tm0BU5003ool00?oo00Soo`03003oo`0001T000036<<HXaS301H000<H`aX00006
488@HQ220208@@0P400000?oo`00ool0O?oo0009ool01000oonU59cc0ZDD01nU=:DDW;>D/YbcU;:<
DH@`S55:RE::BXU2:488@RR448@`Q11c[W>>LjicSX@@Nnn444YYDXY:JD8X@PQ2:003BTT3@RP04TY9
BVU:BDYYS76DTXaaYABLljDDS96DTXbALhi[SG>>BTU:J@9:B@03@RQ:BD8X00=2:008BXUBRTZ9U;:D
TYBbNnn440Akk`06>NM1j3WW@NPiid7X0SWW00<iacWWBTT00TY900=[CF</Jdd00icc00JU59dCYABM
4ooo0009ool00`00ool0000I00000a2R6<<@XP0F00036<<J00001PQQ4888H@PQ02088A000003ool0
0?oo07coo`002Ooo00<00?ooYC@00ZDd00fLdiCBW=>D/YcCU;:LdhaAS76<DH?`Nnn3l003Nll3U980
2HaAS76<DHaa>NM223WW@RQ22002@RP024XY@RQ::D8XBRU2248X@PP4BTT00e:ZDXYBZP04YA@01Icc
YAAc[W_?Ljh024Y900=:JDY9Ljh00W>^012LljCdW?>D/YBBU;:<LIAbS76447__Q11kke:ZDXYBZP=2
2009BRU2:4XYJfecKV]]W=>DdYcC00BU=003ool00?oo00Soo`03003oo`0001T00003244080Q10300
0003264@PPQQ01H00003ool00?oo07coo`002Ooo00`00?ooYCBU5:DdU;:LdiBbW;>D/YbcU;83S543
Nnl01W_?LlikchbAU9:<T@B<D@06@NPiid7X@PQ2:4881d8X00m2248X@RQ:BD8XBTUBRU:ZDXZU59dC
YABLljDDW?<00g>^00M2:4Y9@RQ:BD8XBTU2:003BTT00g>>LjicSP03W?<049BBU;:DTXaaS56<LG__
Q11kkh@@DXYBZU::@PPj1d880d8X0f]]00VD/YcCU;:U=:DDYCBU5?oo00002Ooo00<00?oo00006@00
00<080PQ0200<00000<@HPQQ46805P0000?oo`00ool0O?oo0009ool00`00oonU=002YC@03IcCU=:L
diBbW=>D/YcCS56<LHaAPo1kkh?`00=kc`>DTP09S56<LHaAS74iid88>NM2:4880092:008BRU2:4XY
@RQ::D88@RQ220A:B@03DZYBRU:Z00BU5005W?>U57>^Nlmc[P08BTT00dYYBTUc[P02Ljh049ccY?BL
liBbU9:D/XaaU7:<LH@@Nnn447__DZYBRU:Z0d8800U::D8XBRU[KG=^JffLdiCBW=<01:Dd00?oo`00
ool02?oo00<00?oo00006@0000<8@@0P2440<00000<8HA2226405P0000?oo`00ool0O?oo0009ool0
3000oonU=:DDYCBD/YcCU;:L/iBbW;>D/P><D@=kk`06NlmccW_?S96DTXbA18aA00I1j3WW@NQ2248X
@PP7@RP03d88@RQ2:4Y9@RQ:BE::DZYBRZDDWA>U59ccYABLl`03Ljh01d8XBTU2:4Y9@RQ:BD8X00=:
B@03Lhic[W>>00>Ll`0@U9:D/YBBS76<DHaaNnn447__Q11BRU:ZDXY223X7@PP3@RP3Jfd02IBbW=>D
/ZDdYABU=:DDool00009ool00`00ool0000I00000`0P2240800`00000a1R264@HP0F00000ooo003o
o`1lool000Woo`04003ooiccYA@2W?<039cCW?>D/YcCU;:LdhaaU9:<LIBBS76DTP>4400EU7:<LIAb
F^]S35[[H``iid7X>NM2:488@RQ2248X@PQ::D8XBRU2:4XY0092:003@PQ2:48800=BRP06W=>LlicC
Y?BLljCd0g_?1dY900Q:JE9ZBVVLlicCW?>Ldicc0YcC00nD/YcCS76DTXaaS364<8`aQ31kcg>^NlmS
C6]=Hd`00d8800E[CF]]JdfU59cc00FU5003ool00?oo00Soo`03003oo`0006D00003ool00?oo07co
o`002Ooo02@00?ooYABLljDDU=:LdiCBW;>D/YbcU;:DTXaaU9:<LIBBS76447`?Q12<DHaaS55S35[[
H`aJjcWW>LLiid88@RQ2248X@PP7@RP02T88@RQ2248XBXUBRTZ9W=>DdYcC0icc01Ukcg?>Nlm2:4Y9
@RQ:BD8XBTU2:4YYBTU:JICBW=>DdYcCU=:LdiBbW;>D/YBBS76DTP04Q303Ljh04V]=Hba[CCX7@PPj
1f]]Jde[KIccYABLljDDWA>U59dCool000Woo`03003oo`0006D00003ool00?oo07coo`002Ooo00@0
0?ooW?>U50:Ll`0<W=>LliBbW=>D/YcCS76DTXaaU9:<LIBB0h@@01FDLXaaU79Jjf<<F^]S33WW@NPi
id8X@PQ2:488@RQ224XY@RQ::D8XBRT00T8X00=2248X@PP00e::00JLdiccW=>Tm9ccY?@3Nll7BTT0
24YYDVY:JIccW=>LlicCW?<2W=<03iBbW=><LIBBS76<<H@`S364<7_?Ljikcf=<JdeSC003@PP01F]=
Jfe[CJDDW?<01JDD00?oo`00ool02?oo00<00?oo0000I@0000?oo`00ool0O?oo0009ool00`00oonL
l`02W?<01YBbW=>D/YcCU;:Ld`:D/P08U9:D/YBbW;>D/YBBS96DTP=kk`07>LLaYSW7<JI1j3WW@NP0
0d8X00U:JDY9BVU:JE::BVU:BD8XBTT0148X0dY900^D/YBBU;:LljDDW?=c[W>>Lji2:4Y900E2:00F
Q11l3h@@S76DTXaaU9:<LIBBF`]S35/;@NPiid7X>PM223X7@PPiid7X>NL3@RP3Ljh00f</H`aS;007
W?<00ooo003oo`08ool00`00ool0001U00000ooo003oo`1lool000Woo`0B003ooiccY?BLlicCU=:L
diCBW=>DdYcCU9:D/YBBW=>D/YcC0iBB01>3l7__Po0aYSW7<JHiacWW@PPiidXY@RQ::DYYDVY:JE::
BVUBRP03BTT03DXY@RQ::D8XBVU:BDYYU9:D/YBBYABLljDD00=c[P=:B@04@RQ::D8XBRT3Q1001YBB
S76DTXaaU9:<L@=S3003>NM223WW00E2200D>NM2248XBRU2:7_?Ljikcf</JbeS;:CdW?>Tm9ccY?BL
ljCdool000Woo`03003oo`0006D00003ool00?oo07coo`002Ooo00<00?ooW?<00Ycc00JD/YcCU;:L
diBbW=<2U;8029BBU;:D/YbcU;:DTXbAU983Nnl01cW7<JHiac6V@NPiid7X00=2:009BVU:BDYYBVUB
RTYYBTU2:4Y900A2:0=:B@0;U;:DTYBbW?>U59ccLjicSW>^@RQ:B@05@RP05X@@O0n448aaU9:<LIBB
S76DTU/;H`aK2d7X>NM1j3X7@PPj1d88>NM1j3WW0d8X0g>^00=S;6<<Hb`01icc00?oo`00ool02?oo
00<00?oo0000I@0000?oo`00ool0O?oo0009ool00`00ooooo`1Vool00`00ooooo`07ool00`00oooo
o`1Vool00`00ooooo`1kool000Woo`03003ooooo06Koo`03003ooooo00Ooo`03003ooooo06Koo`03
003ooooo07_oo`002OooJP002OooJP00OOoo003ooomTool00?ooofCoo`00\
\>"],
  ImageRangeCache->{{{0, 354.438}, {110.062, 0}} -> {-0.0850059, -0.0234375, 
  0.00894379, 0.00894379}, {{9.5, 114.312}, {107.438, 
  2.5625}} -> {-3.70363, -1.52539, 0.318281, 0.318281}, {{124.75, 229.625}, {
  107.438, 2.5625}} -> {-40.3618, -1.51492, 0.318091, 0.318091}}]
}, Open  ]],

Cell["\<\
Select an 8-by-8 block of DCT coefficients for use in the next few \
calculations.\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[\[ScriptCapitalC] = 
          SubMatrix[\[ScriptCapitalA], \ {41, \ 49}, \ {8, 8}], 4]\  // 
      MatrixForm\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {
              RowBox[{"-", 
                StyleBox["709.499999999999975`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["52.8622526031450057`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["50.0904518774489027`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["45.2742805654083646`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["36.0624458405139236`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["27.1351496338743292`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["15.6067815616473275`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["9.91238736900574224`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}]},
            {
              StyleBox["6.86240740050536857`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["2.76690679404213035`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["4.41326294069663838`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["1.49327736676700562`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["3.84875642325210911`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["1.6834728663305909`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["2.4387674788606839`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["0.322714630563593196`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4]},
            {
              StyleBox["2.26327154578910061`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["0.24941327512593201`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["0.314339828220179384`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["3.07903690951564357`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["0.956708580912724748`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["0.916928216391374206`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["4.67309703885627936`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["2.70041965681157014`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}]},
            {
              RowBox[{"-", 
                StyleBox["0.00956432689170183536`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["5.91376592496160036`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["6.79213478029395911`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["0.0364571846446913028`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["4.17876055155951409`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["0.622810611491333521`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["0.172779130054566421`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["0.0210347264828569402`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4]},
            {
              RowBox[{"-", 
                StyleBox["8.13172798364529825`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["0.511222594612543446`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["3.01222388631856219`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["8.44913973313078159`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["1.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["2.51093207526874939`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["3.3524628646253336`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["4.51895002651887178`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}]},
            {
              StyleBox["1.67310137797391789`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["2.3871512499996732`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["4.60063066801916686`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["1.36024747856778982`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["1.37192702052863912`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["1.13480675519513685`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["4.74247352216275697`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["4.79854467626777125`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}]},
            {
              RowBox[{"-", 
                StyleBox["2.85089493142441376`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["1.05776038154282892`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["0.0769029611437218285`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["0.0761476836047765548`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["2.30969883127821606`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["2.77528885443988704`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["2.43566017177982008`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["1.116878386873001`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4]},
            {
              RowBox[{"-", 
                StyleBox["0.779746735909823129`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["1.41472223651286483`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["0.356654566880060697`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["1.60421653244003632`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["4.80550210670529853`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["5.62716084325019139`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["0.792789862986476023`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["3.63474363540742384`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4]}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[6]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "An inspection of the block cosine transform reveals that a large number of \
the cosine coefficients have relatively small values. For purposes of \
compression, it is of interest to discard these small values. This may be \
implemented by one of two possible schemes. The coefficients to be retained \
may be selected based on their position in the DCT block, typically the \
low-frequency ",
  StyleBox["zone",
    FontSlant->"Italic"],
  " of the transform domain.  ",
  StyleBox["A",
    FontSlant->"Italic"],
  "lternatively, they may be selected based on their value relative to a \
fixed ",
  StyleBox["threshold",
    FontSlant->"Italic"],
  ". The zone method is simpler but inefficient since large valued \
coefficients outside of the prescribed zone may be discarded increasing the \
approximation error. For this reason, the threshold method, with its ability \
to capture all large valued coefficients and adapt to the local image \
statistics is preferred."
}], "Text"],

Cell["\<\
Here is a typical zone mask which retains 15 of a total of 64 DCT  \
coefficients.\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((M\_Z = 
          ZeroPad[{{1, 1, 1, 1, 1}, {1, 1, 1, 1, 0}, {1, 1, 1, 0, 0}, {1, 1, 
                0, 0, 0}, {1, 0, 0, 0, 0}}, \ {0, 3}, {0, 3}])\)\  // 
      MatrixForm\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "1", "1", "1", "0", "0", "0"},
            {"1", "1", "1", "1", "0", "0", "0", "0"},
            {"1", "1", "1", "0", "0", "0", "0", "0"},
            {"1", "1", "0", "0", "0", "0", "0", "0"},
            {"1", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[7]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "Here are the DCT coefficients of the ",
  StyleBox["\[ScriptCapitalC]",
    FontSlant->"Italic"],
  " block after application of the mask."
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[\[ScriptCapitalC]\ *\ M\_Z, \ 4] // MatrixForm\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {
              RowBox[{"-", 
                StyleBox["709.499999999999975`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["52.8622526031450057`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["50.0904518774489027`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["45.2742805654083646`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["36.0624458405139236`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "0", "0", "0"},
            {
              StyleBox["6.86240740050536857`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["2.76690679404213035`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              RowBox[{"-", 
                StyleBox["4.41326294069663838`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["1.49327736676700562`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "0", "0", "0", "0"},
            {
              StyleBox["2.26327154578910061`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["0.24941327512593201`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], 
              StyleBox["0.314339828220179384`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], "0", "0", "0", "0", "0"},
            {
              RowBox[{"-", 
                StyleBox["0.00956432689170183536`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              StyleBox["5.91376592496160036`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4], "0", "0", "0", "0", "0", "0"},
            {
              RowBox[{"-", 
                StyleBox["8.13172798364529825`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[8]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The 15 remaining coefficients define an approximation of the original \
signal. The distortion or ",
  StyleBox["approximation error",
    FontSlant->"Italic"],
  " may be measured in a number of equivalent ways. A commonly used metric is \
the so-called ",
  StyleBox["signal-to-noise",
    FontSlant->"Italic"],
  " (SNR) ratio. In our present situation, the noise is the approximation \
error or difference between the original and reconstructed signals. From \
Parseval's theorem it may be shown that the SNR may be defined "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`SNR\  = \ \ 
        \(\[Sum]\+\(i = 1\)\%8
              \(\[Sum]\+\(j = 1\)\%8\( \[ScriptCapitalC]\^2\)[i, j]
                \)\)\/\(\[Sum]\+\(i = 1\)\%8
                \(\[Sum]\+\(j = 1\)\%8\( \[ScriptCapitalC]\^2\)[i, j]\)\ \  - 
            \[Sum]\+\(i = 1\)\%8
                \(\[Sum]\+\(j = 1\)\%8\( \[ScriptCapitalC]\_Z\^2\)[i, j]
                  \)\)\)]]
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC][i, j]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_Z[i, j]\)]],
  " represent the original and zone masked DCT coefficients, respectively. \
The SNR is typically given in units of decibels (dB). The denominator \
expression defines the total signal power, while the numerator is the signal \
power within the zone defined by mask ",
  Cell[BoxData[
      \(TraditionalForm\`M\_Z\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1\/\(1 - 
        \((Plus\ @@\ \(Flatten[\[ScriptCapitalC]*M\_Z]\^2\))\)\/\((
            Plus\ @@\ \(Flatten[\[ScriptCapitalC]]\^2\))\)\)\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(340.055867611370121`\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["The is the value in decibels", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(10\ Log[10, \ %]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(25.3155027293092604`\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["\<\
We now turn to the threshold method. We pick a threshold, say T=8, and \
discard all coefficients with magnitudes smaller than this threshold.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(M\_T = Threshold[Abs[\[ScriptCapitalC]], \ 8]; \n
    N[\[ScriptCapitalC]\ *\ M\_T, \ 4] // MatrixForm\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {
              RowBox[{"-", 
                StyleBox["709.499999999999975`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["52.8622526031450057`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["50.0904518774489027`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["45.2742805654083646`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["36.0624458405139236`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["27.1351496338743292`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["15.6067815616473275`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], 
              RowBox[{"-", 
                StyleBox["9.91238736900574224`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}]},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {
              RowBox[{"-", 
                StyleBox["8.13172798364529825`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "0", "0", 
              RowBox[{"-", 
                StyleBox["8.44913973313078159`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->4]}], "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[12]//MatrixForm="]
}, Open  ]],

Cell["Here is the total number of retained coefficients:", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Count[M\_T\  // Flatten, \ 1]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(10\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
The SNR resulting from application of threshold masking instead of zone \
masking is given by\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1\/\(1 - 
        \((Plus\ @@\ \(Flatten[\[ScriptCapitalC]*M\_T]\^2\))\)\/\((
            Plus\ @@\ \(Flatten[\[ScriptCapitalC]]\^2\))\)\)\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(1074.93447584208245`\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(10\ Log[10, \ %]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(30.3138199202138292`\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["resulting in an approximately 5 dB improvement.", "Text"],

Cell[TextData[{
  "The threshold masking method improves image fidelity, but complicates the \
reconstruction process. Note that the positions of the coefficients need to \
be known in order to correctly reconstruct an approximation to the original \
image. The JPEG standard adopted a clever scheme to order the coefficients in \
a one-dimensional list, so that a coefficient's position in this list \
uniquely identifies its place in the 2D coefficient array.  This is \
accomplished by ordering all the coefficients according to the following \
zig-zag scanning pattern:\n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"\[RightArrow]", "\[LowerLeftArrow]", "\[RightArrow]", 
                "\[LowerLeftArrow]"},
              {"\[DownArrow]", "\[UpperRightArrow]", "\[LowerLeftArrow]", 
                "\[UpperRightArrow]"},
              {"\[UpperRightArrow]", "\[LowerLeftArrow]", 
                "\[UpperRightArrow]", "\[Placeholder]"},
              {"\[DownArrow]", "\[UpperRightArrow]", "\[Placeholder]", 
                "\[Placeholder]"},
              {"\[UpperRightArrow]", "\[Placeholder]", "\[Placeholder]", 
                "\[Placeholder]"}
              }], ")"}], TraditionalForm]]],
  "\n\nAdditionally, all zeros beyond the last non-zero value are dropped and \
replaced by a special end-of-buffer (EOB) symbol. Here is an example. (The \
function ",
  StyleBox["ZigZagOrder", "Program"],
  " is located in the Appendix.) This operation is performed for each image \
block."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZigZagOrder[Round[\[ScriptCapitalC]\ *\ M\_T]]\)], "Input"],

Cell[BoxData[
    \({\(-719\), \(-52\), 0, 0, 0, \(-50\), \(-44\), 0, 0, 0, 0, 0, 0, 0, 
      \(-35\), \(-26\), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, \(-16\), \(-10\), 0, 
      0, 0, \(-9\), "EOB"}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["QUANTIZATION", "Section"],

Cell["\<\
Image pixels are quantized samples of a continuous valued signal. The typical \
luminance resolution is 256-levels or 8-bits per pixel. This gives a total of \
256 bits per image block. Compression by elimination of transform \
coefficients with relatively small magnitudes is only one of two factors that \
combine to give significant reduction of image bits. The second important \
factor is quantization of cosine coefficients.  In this section we will \
address the problem of DCT coefficient quantization.\
\>", "Text"],

Cell[TextData[
"Here is the dynamic range of the cosine coefficients in segment \
\[ScriptCapitalC]."], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SignalRange[\[ScriptCapitalC]]\)], "Input"],

Cell[BoxData[
    \({\(-719.249999999999989`\), 7.41703476491154134`}\)], "Output"]
}, Open  ]],

Cell["\<\
Clearly a large number of bits would be needed to uniformly code the values \
in the coefficient array. Note that the range is larger than that of the \
original pixel values. Even a casual inspection of coefficient values (see \
the histogram below) suggests that they should be coded with a variable \
number of bits, with those in the vicinity of the DC coefficient requiring \
more bits than those in the high frequency corner of the array.\
\>", "Text"],

Cell["\<\
Here we calculate and plot the histogram of the DCT coefficients.\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h = Histogram[\[ScriptCapitalA], \ SignalRange[\[ScriptCapitalA]]]; \n
    ListPlot[Thread[{Range\ @@\ Round[SignalRange[\[ScriptCapitalA]]], h}], \ 
      PlotRange -> {0, \ 200}]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.644206 0.000518726 0 0.00309017 [
[.12548 -0.0125 -15 -9 ]
[.12548 -0.0125 15 0 ]
[.25516 -0.0125 -12 -9 ]
[.25516 -0.0125 12 0 ]
[.38484 -0.0125 -12 -9 ]
[.38484 -0.0125 12 0 ]
[.51452 -0.0125 -12 -9 ]
[.51452 -0.0125 12 0 ]
[.77389 -0.0125 -9 -9 ]
[.77389 -0.0125 9 0 ]
[.90357 -0.0125 -9 -9 ]
[.90357 -0.0125 9 0 ]
[.63171 .07725 -12 -4.5 ]
[.63171 .07725 0 4.5 ]
[.63171 .15451 -12 -4.5 ]
[.63171 .15451 0 4.5 ]
[.63171 .23176 -12 -4.5 ]
[.63171 .23176 0 4.5 ]
[.63171 .30902 -18 -4.5 ]
[.63171 .30902 0 4.5 ]
[.63171 .38627 -18 -4.5 ]
[.63171 .38627 0 4.5 ]
[.63171 .46353 -18 -4.5 ]
[.63171 .46353 0 4.5 ]
[.63171 .54078 -18 -4.5 ]
[.63171 .54078 0 4.5 ]
[.63171 .61803 -18 -4.5 ]
[.63171 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.12548 0 m
.12548 .00625 L
s
[(-1000)] .12548 -0.0125 0 1 Mshowa
.25516 0 m
.25516 .00625 L
s
[(-750)] .25516 -0.0125 0 1 Mshowa
.38484 0 m
.38484 .00625 L
s
[(-500)] .38484 -0.0125 0 1 Mshowa
.51452 0 m
.51452 .00625 L
s
[(-250)] .51452 -0.0125 0 1 Mshowa
.77389 0 m
.77389 .00625 L
s
[(250)] .77389 -0.0125 0 1 Mshowa
.90357 0 m
.90357 .00625 L
s
[(500)] .90357 -0.0125 0 1 Mshowa
.125 Mabswid
.02173 0 m
.02173 .00375 L
s
.04767 0 m
.04767 .00375 L
s
.07361 0 m
.07361 .00375 L
s
.09954 0 m
.09954 .00375 L
s
.15142 0 m
.15142 .00375 L
s
.17735 0 m
.17735 .00375 L
s
.20329 0 m
.20329 .00375 L
s
.22923 0 m
.22923 .00375 L
s
.2811 0 m
.2811 .00375 L
s
.30703 0 m
.30703 .00375 L
s
.33297 0 m
.33297 .00375 L
s
.35891 0 m
.35891 .00375 L
s
.41078 0 m
.41078 .00375 L
s
.43672 0 m
.43672 .00375 L
s
.46265 0 m
.46265 .00375 L
s
.48859 0 m
.48859 .00375 L
s
.54046 0 m
.54046 .00375 L
s
.5664 0 m
.5664 .00375 L
s
.59233 0 m
.59233 .00375 L
s
.61827 0 m
.61827 .00375 L
s
.67014 0 m
.67014 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.72201 0 m
.72201 .00375 L
s
.74795 0 m
.74795 .00375 L
s
.79982 0 m
.79982 .00375 L
s
.82576 0 m
.82576 .00375 L
s
.8517 0 m
.8517 .00375 L
s
.87763 0 m
.87763 .00375 L
s
.92951 0 m
.92951 .00375 L
s
.95544 0 m
.95544 .00375 L
s
.98138 0 m
.98138 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.64421 .07725 m
.65046 .07725 L
s
[(25)] .63171 .07725 1 0 Mshowa
.64421 .15451 m
.65046 .15451 L
s
[(50)] .63171 .15451 1 0 Mshowa
.64421 .23176 m
.65046 .23176 L
s
[(75)] .63171 .23176 1 0 Mshowa
.64421 .30902 m
.65046 .30902 L
s
[(100)] .63171 .30902 1 0 Mshowa
.64421 .38627 m
.65046 .38627 L
s
[(125)] .63171 .38627 1 0 Mshowa
.64421 .46353 m
.65046 .46353 L
s
[(150)] .63171 .46353 1 0 Mshowa
.64421 .54078 m
.65046 .54078 L
s
[(175)] .63171 .54078 1 0 Mshowa
.64421 .61803 m
.65046 .61803 L
s
[(200)] .63171 .61803 1 0 Mshowa
.125 Mabswid
.64421 .01545 m
.64796 .01545 L
s
.64421 .0309 m
.64796 .0309 L
s
.64421 .04635 m
.64796 .04635 L
s
.64421 .0618 m
.64796 .0618 L
s
.64421 .09271 m
.64796 .09271 L
s
.64421 .10816 m
.64796 .10816 L
s
.64421 .12361 m
.64796 .12361 L
s
.64421 .13906 m
.64796 .13906 L
s
.64421 .16996 m
.64796 .16996 L
s
.64421 .18541 m
.64796 .18541 L
s
.64421 .20086 m
.64796 .20086 L
s
.64421 .21631 m
.64796 .21631 L
s
.64421 .24721 m
.64796 .24721 L
s
.64421 .26266 m
.64796 .26266 L
s
.64421 .27812 m
.64796 .27812 L
s
.64421 .29357 m
.64796 .29357 L
s
.64421 .32447 m
.64796 .32447 L
s
.64421 .33992 m
.64796 .33992 L
s
.64421 .35537 m
.64796 .35537 L
s
.64421 .37082 m
.64796 .37082 L
s
.64421 .40172 m
.64796 .40172 L
s
.64421 .41717 m
.64796 .41717 L
s
.64421 .43262 m
.64796 .43262 L
s
.64421 .44807 m
.64796 .44807 L
s
.64421 .47898 m
.64796 .47898 L
s
.64421 .49443 m
.64796 .49443 L
s
.64421 .50988 m
.64796 .50988 L
s
.64421 .52533 m
.64796 .52533 L
s
.64421 .55623 m
.64796 .55623 L
s
.64421 .57168 m
.64796 .57168 L
s
.64421 .58713 m
.64796 .58713 L
s
.64421 .60258 m
.64796 .60258 L
s
.25 Mabswid
.64421 0 m
.64421 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .00309 Mdot
.02433 0 Mdot
.02485 0 Mdot
.02537 0 Mdot
.02588 0 Mdot
.0264 0 Mdot
.02692 0 Mdot
.02744 0 Mdot
.02796 0 Mdot
.02848 0 Mdot
.029 0 Mdot
.02952 0 Mdot
.03003 0 Mdot
.03055 0 Mdot
.03107 0 Mdot
.03159 0 Mdot
.03211 0 Mdot
.03263 0 Mdot
.03315 0 Mdot
.03367 0 Mdot
.03418 0 Mdot
.0347 0 Mdot
.03522 0 Mdot
.03574 0 Mdot
.03626 0 Mdot
.03678 0 Mdot
.0373 0 Mdot
.03782 0 Mdot
.03833 0 Mdot
.03885 0 Mdot
.03937 0 Mdot
.03989 0 Mdot
.04041 0 Mdot
.04093 0 Mdot
.04145 0 Mdot
.04196 0 Mdot
.04248 0 Mdot
.043 0 Mdot
.04352 0 Mdot
.04404 0 Mdot
.04456 0 Mdot
.04508 0 Mdot
.0456 0 Mdot
.04611 0 Mdot
.04663 0 Mdot
.04715 0 Mdot
.04767 0 Mdot
.04819 0 Mdot
.04871 0 Mdot
.04923 0 Mdot
.04975 0 Mdot
.05026 0 Mdot
.05078 0 Mdot
.0513 0 Mdot
.05182 0 Mdot
.05234 0 Mdot
.05286 0 Mdot
.05338 0 Mdot
.0539 0 Mdot
.05441 0 Mdot
.05493 .00309 Mdot
.05545 0 Mdot
.05597 0 Mdot
.05649 0 Mdot
.05701 0 Mdot
.05753 0 Mdot
.05805 0 Mdot
.05856 0 Mdot
.05908 0 Mdot
.0596 0 Mdot
.06012 0 Mdot
.06064 0 Mdot
.06116 0 Mdot
.06168 0 Mdot
.0622 0 Mdot
.06271 0 Mdot
.06323 0 Mdot
.06375 0 Mdot
.06427 .00309 Mdot
.06479 0 Mdot
.06531 0 Mdot
.06583 0 Mdot
.06635 0 Mdot
.06686 0 Mdot
.06738 0 Mdot
.0679 0 Mdot
.06842 .00309 Mdot
.06894 0 Mdot
.06946 0 Mdot
.06998 0 Mdot
.07049 0 Mdot
.07101 0 Mdot
.07153 0 Mdot
.07205 0 Mdot
.07257 0 Mdot
.07309 0 Mdot
.07361 0 Mdot
.07413 0 Mdot
.07464 .00309 Mdot
.07516 0 Mdot
.07568 0 Mdot
.0762 0 Mdot
.07672 0 Mdot
.07724 0 Mdot
.07776 0 Mdot
.07828 0 Mdot
.07879 0 Mdot
.07931 0 Mdot
.07983 0 Mdot
.08035 0 Mdot
.08087 0 Mdot
.08139 0 Mdot
.08191 0 Mdot
.08243 0 Mdot
.08294 0 Mdot
.08346 0 Mdot
.08398 0 Mdot
.0845 0 Mdot
.08502 0 Mdot
.08554 0 Mdot
.08606 0 Mdot
.08658 0 Mdot
.08709 0 Mdot
.08761 0 Mdot
.08813 0 Mdot
.08865 0 Mdot
.08917 0 Mdot
.08969 0 Mdot
.09021 0 Mdot
.09073 0 Mdot
.09124 0 Mdot
.09176 .00309 Mdot
.09228 .00618 Mdot
.0928 0 Mdot
.09332 0 Mdot
.09384 0 Mdot
.09436 0 Mdot
.09487 .00309 Mdot
.09539 0 Mdot
.09591 0 Mdot
.09643 0 Mdot
.09695 0 Mdot
.09747 0 Mdot
.09799 0 Mdot
.09851 0 Mdot
.09902 0 Mdot
.09954 0 Mdot
.10006 0 Mdot
.10058 0 Mdot
.1011 0 Mdot
.10162 0 Mdot
.10214 0 Mdot
.10266 0 Mdot
.10317 0 Mdot
.10369 0 Mdot
.10421 0 Mdot
.10473 0 Mdot
.10525 0 Mdot
.10577 0 Mdot
.10629 0 Mdot
.10681 0 Mdot
.10732 0 Mdot
.10784 0 Mdot
.10836 0 Mdot
.10888 0 Mdot
.1094 0 Mdot
.10992 0 Mdot
.11044 0 Mdot
.11096 .00309 Mdot
.11147 0 Mdot
.11199 0 Mdot
.11251 0 Mdot
.11303 0 Mdot
.11355 0 Mdot
.11407 0 Mdot
.11459 0 Mdot
.11511 0 Mdot
.11562 0 Mdot
.11614 0 Mdot
.11666 0 Mdot
.11718 0 Mdot
.1177 0 Mdot
.11822 0 Mdot
.11874 0 Mdot
.11926 0 Mdot
.11977 0 Mdot
.12029 0 Mdot
.12081 0 Mdot
.12133 .00309 Mdot
.12185 0 Mdot
.12237 0 Mdot
.12289 0 Mdot
.1234 0 Mdot
.12392 0 Mdot
.12444 0 Mdot
.12496 0 Mdot
.12548 0 Mdot
.126 0 Mdot
.12652 .00309 Mdot
.12704 0 Mdot
.12755 0 Mdot
.12807 0 Mdot
.12859 0 Mdot
.12911 0 Mdot
.12963 0 Mdot
.13015 0 Mdot
.13067 0 Mdot
.13119 0 Mdot
.1317 0 Mdot
.13222 0 Mdot
.13274 .00309 Mdot
.13326 0 Mdot
.13378 0 Mdot
.1343 0 Mdot
.13482 0 Mdot
.13534 0 Mdot
.13585 .00309 Mdot
.13637 0 Mdot
.13689 0 Mdot
.13741 0 Mdot
.13793 0 Mdot
.13845 0 Mdot
.13897 0 Mdot
.13949 0 Mdot
.14 0 Mdot
.14052 0 Mdot
.14104 0 Mdot
.14156 0 Mdot
.14208 0 Mdot
.1426 0 Mdot
.14312 0 Mdot
.14364 0 Mdot
.14415 0 Mdot
.14467 0 Mdot
.14519 0 Mdot
.14571 0 Mdot
.14623 0 Mdot
.14675 0 Mdot
.14727 0 Mdot
.14779 0 Mdot
.1483 0 Mdot
.14882 0 Mdot
.14934 0 Mdot
.14986 0 Mdot
.15038 0 Mdot
.1509 0 Mdot
.15142 0 Mdot
.15193 0 Mdot
.15245 .00309 Mdot
.15297 0 Mdot
.15349 0 Mdot
.15401 0 Mdot
.15453 0 Mdot
.15505 0 Mdot
.15557 0 Mdot
.15608 0 Mdot
.1566 0 Mdot
.15712 0 Mdot
.15764 0 Mdot
.15816 0 Mdot
.15868 0 Mdot
.1592 0 Mdot
.15972 0 Mdot
.16023 0 Mdot
.16075 0 Mdot
.16127 0 Mdot
.16179 .00309 Mdot
.16231 0 Mdot
.16283 0 Mdot
.16335 0 Mdot
.16387 0 Mdot
.16438 0 Mdot
.1649 0 Mdot
.16542 0 Mdot
.16594 0 Mdot
.16646 .00309 Mdot
.16698 0 Mdot
.1675 0 Mdot
.16802 0 Mdot
.16853 .00309 Mdot
.16905 0 Mdot
.16957 0 Mdot
.17009 0 Mdot
.17061 .00309 Mdot
.17113 0 Mdot
.17165 0 Mdot
.17217 .00309 Mdot
.17268 0 Mdot
.1732 0 Mdot
.17372 0 Mdot
.17424 0 Mdot
.17476 0 Mdot
.17528 0 Mdot
.1758 0 Mdot
.17631 0 Mdot
.17683 0 Mdot
.17735 0 Mdot
.17787 .00309 Mdot
.17839 0 Mdot
.17891 0 Mdot
.17943 0 Mdot
.17995 0 Mdot
.18046 0 Mdot
.18098 0 Mdot
.1815 0 Mdot
.18202 0 Mdot
.18254 0 Mdot
.18306 0 Mdot
.18358 0 Mdot
.1841 0 Mdot
.18461 .00309 Mdot
.18513 .00309 Mdot
.18565 0 Mdot
.18617 0 Mdot
.18669 0 Mdot
.18721 0 Mdot
.18773 0 Mdot
.18825 0 Mdot
.18876 0 Mdot
.18928 0 Mdot
.1898 0 Mdot
.19032 .00309 Mdot
.19084 0 Mdot
.19136 0 Mdot
.19188 0 Mdot
.1924 0 Mdot
.19291 0 Mdot
.19343 0 Mdot
.19395 0 Mdot
.19447 0 Mdot
.19499 0 Mdot
.19551 0 Mdot
.19603 0 Mdot
.19655 0 Mdot
.19706 0 Mdot
.19758 0 Mdot
.1981 0 Mdot
.19862 .00309 Mdot
.19914 0 Mdot
.19966 0 Mdot
.20018 0 Mdot
.2007 .00309 Mdot
.20121 0 Mdot
.20173 0 Mdot
.20225 0 Mdot
.20277 0 Mdot
.20329 .00309 Mdot
.20381 0 Mdot
.20433 0 Mdot
.20484 0 Mdot
.20536 0 Mdot
.20588 0 Mdot
.2064 0 Mdot
.20692 .00309 Mdot
.20744 0 Mdot
.20796 0 Mdot
.20848 0 Mdot
.20899 0 Mdot
.20951 0 Mdot
.21003 0 Mdot
.21055 .00309 Mdot
.21107 0 Mdot
.21159 0 Mdot
.21211 0 Mdot
.21263 0 Mdot
.21314 0 Mdot
.21366 0 Mdot
.21418 0 Mdot
.2147 0 Mdot
.21522 0 Mdot
.21574 0 Mdot
.21626 0 Mdot
.21678 0 Mdot
.21729 0 Mdot
.21781 0 Mdot
.21833 0 Mdot
.21885 0 Mdot
.21937 .00309 Mdot
.21989 0 Mdot
.22041 .00309 Mdot
.22093 .00309 Mdot
.22144 .00309 Mdot
.22196 0 Mdot
.22248 0 Mdot
.223 0 Mdot
.22352 0 Mdot
.22404 0 Mdot
.22456 0 Mdot
.22508 0 Mdot
.22559 0 Mdot
.22611 .00309 Mdot
.22663 0 Mdot
.22715 0 Mdot
.22767 .00309 Mdot
.22819 0 Mdot
.22871 0 Mdot
.22923 0 Mdot
.22974 0 Mdot
.23026 .00309 Mdot
.23078 0 Mdot
.2313 0 Mdot
.23182 0 Mdot
.23234 0 Mdot
.23286 0 Mdot
.23337 .00309 Mdot
.23389 0 Mdot
.23441 .00618 Mdot
.23493 0 Mdot
.23545 .00309 Mdot
.23597 0 Mdot
.23649 .00309 Mdot
.23701 0 Mdot
.23752 .00309 Mdot
.23804 0 Mdot
.23856 0 Mdot
.23908 0 Mdot
.2396 0 Mdot
.24012 0 Mdot
.24064 0 Mdot
.24116 0 Mdot
.24167 0 Mdot
.24219 0 Mdot
.24271 0 Mdot
.24323 0 Mdot
.24375 0 Mdot
.24427 0 Mdot
.24479 0 Mdot
.24531 0 Mdot
.24582 0 Mdot
.24634 0 Mdot
.24686 0 Mdot
.24738 0 Mdot
.2479 0 Mdot
.24842 0 Mdot
.24894 0 Mdot
.24946 .00309 Mdot
.24997 0 Mdot
.25049 0 Mdot
.25101 0 Mdot
.25153 0 Mdot
.25205 .00309 Mdot
.25257 0 Mdot
.25309 .00309 Mdot
.25361 0 Mdot
.25412 0 Mdot
.25464 0 Mdot
.25516 0 Mdot
.25568 0 Mdot
.2562 0 Mdot
.25672 0 Mdot
.25724 0 Mdot
.25775 0 Mdot
.25827 0 Mdot
.25879 0 Mdot
.25931 0 Mdot
.25983 0 Mdot
.26035 .00309 Mdot
.26087 0 Mdot
.26139 .00618 Mdot
.2619 0 Mdot
.26242 .00309 Mdot
.26294 0 Mdot
.26346 .00309 Mdot
.26398 0 Mdot
.2645 .00618 Mdot
.26502 0 Mdot
.26554 .00309 Mdot
.26605 0 Mdot
.26657 .00309 Mdot
.26709 .00309 Mdot
.26761 0 Mdot
.26813 0 Mdot
.26865 .00309 Mdot
.26917 0 Mdot
.26969 .00618 Mdot
.2702 0 Mdot
.27072 0 Mdot
.27124 .00309 Mdot
.27176 0 Mdot
.27228 0 Mdot
.2728 0 Mdot
.27332 0 Mdot
.27384 0 Mdot
.27435 0 Mdot
.27487 0 Mdot
.27539 .00309 Mdot
.27591 0 Mdot
.27643 .00309 Mdot
.27695 .00618 Mdot
.27747 0 Mdot
.27799 .00309 Mdot
.2785 0 Mdot
.27902 0 Mdot
.27954 0 Mdot
.28006 0 Mdot
.28058 .00927 Mdot
.2811 0 Mdot
.28162 0 Mdot
.28214 .00309 Mdot
.28265 0 Mdot
.28317 .00309 Mdot
.28369 0 Mdot
.28421 .00309 Mdot
.28473 0 Mdot
.28525 0 Mdot
.28577 0 Mdot
.28628 0 Mdot
.2868 .00309 Mdot
.28732 0 Mdot
.28784 .00618 Mdot
.28836 .00618 Mdot
.28888 0 Mdot
.2894 0 Mdot
.28992 .00309 Mdot
.29043 0 Mdot
.29095 0 Mdot
.29147 0 Mdot
.29199 .00309 Mdot
.29251 0 Mdot
.29303 0 Mdot
.29355 0 Mdot
.29407 0 Mdot
.29458 .00309 Mdot
.2951 0 Mdot
.29562 0 Mdot
.29614 0 Mdot
.29666 .00618 Mdot
.29718 .00309 Mdot
.2977 0 Mdot
.29822 0 Mdot
.29873 0 Mdot
.29925 0 Mdot
.29977 .00618 Mdot
.30029 0 Mdot
.30081 .00618 Mdot
.30133 0 Mdot
.30185 .00618 Mdot
.30237 0 Mdot
.30288 .00309 Mdot
.3034 0 Mdot
.30392 .00309 Mdot
.30444 0 Mdot
.30496 0 Mdot
.30548 0 Mdot
.306 .00309 Mdot
.30652 0 Mdot
.30703 0 Mdot
.30755 0 Mdot
.30807 .00309 Mdot
.30859 0 Mdot
.30911 0 Mdot
.30963 .00309 Mdot
.31015 0 Mdot
.31067 .00309 Mdot
.31118 0 Mdot
.3117 0 Mdot
.31222 .00309 Mdot
.31274 .00618 Mdot
.31326 .00618 Mdot
.31378 0 Mdot
.3143 0 Mdot
.31481 0 Mdot
.31533 .00309 Mdot
.31585 .00618 Mdot
.31637 0 Mdot
.31689 .00309 Mdot
.31741 .00309 Mdot
.31793 0 Mdot
.31845 0 Mdot
.31896 0 Mdot
.31948 0 Mdot
.32 .00309 Mdot
.32052 0 Mdot
.32104 0 Mdot
.32156 .00309 Mdot
.32208 0 Mdot
.3226 0 Mdot
.32311 .00309 Mdot
.32363 0 Mdot
.32415 0 Mdot
.32467 0 Mdot
.32519 0 Mdot
.32571 .00309 Mdot
.32623 .00309 Mdot
.32675 .00309 Mdot
.32726 0 Mdot
.32778 0 Mdot
.3283 0 Mdot
.32882 .00618 Mdot
.32934 0 Mdot
.32986 .00309 Mdot
.33038 .00309 Mdot
.3309 0 Mdot
.33141 0 Mdot
.33193 0 Mdot
.33245 0 Mdot
.33297 .00309 Mdot
.33349 0 Mdot
.33401 .00309 Mdot
.33453 0 Mdot
.33505 .00309 Mdot
.33556 .00309 Mdot
.33608 .00309 Mdot
.3366 .00309 Mdot
.33712 .00618 Mdot
.33764 0 Mdot
.33816 0 Mdot
.33868 0 Mdot
.33919 0 Mdot
.33971 .00309 Mdot
.34023 .00309 Mdot
.34075 0 Mdot
.34127 .00309 Mdot
.34179 0 Mdot
.34231 0 Mdot
.34283 0 Mdot
.34334 .00309 Mdot
.34386 .00309 Mdot
.34438 0 Mdot
.3449 0 Mdot
.34542 0 Mdot
.34594 0 Mdot
.34646 .00309 Mdot
.34698 .00309 Mdot
.34749 0 Mdot
.34801 0 Mdot
.34853 .00309 Mdot
.34905 0 Mdot
.34957 0 Mdot
.35009 0 Mdot
.35061 0 Mdot
.35113 0 Mdot
.35164 .00618 Mdot
.35216 0 Mdot
.35268 0 Mdot
.3532 0 Mdot
.35372 0 Mdot
.35424 0 Mdot
.35476 0 Mdot
.35528 .00309 Mdot
.35579 .00309 Mdot
.35631 0 Mdot
.35683 0 Mdot
.35735 0 Mdot
.35787 .00309 Mdot
.35839 .00309 Mdot
.35891 0 Mdot
.35943 0 Mdot
.35994 0 Mdot
.36046 0 Mdot
.36098 0 Mdot
.3615 .00618 Mdot
.36202 .00309 Mdot
.36254 0 Mdot
.36306 .00309 Mdot
.36358 0 Mdot
.36409 .00309 Mdot
.36461 .00309 Mdot
.36513 .00618 Mdot
.36565 0 Mdot
.36617 0 Mdot
.36669 .00309 Mdot
.36721 .00309 Mdot
.36772 0 Mdot
.36824 0 Mdot
.36876 0 Mdot
.36928 0 Mdot
.3698 0 Mdot
.37032 .00309 Mdot
.37084 .00309 Mdot
.37136 .00309 Mdot
.37187 0 Mdot
.37239 .00309 Mdot
.37291 0 Mdot
.37343 0 Mdot
.37395 0 Mdot
.37447 0 Mdot
.37499 0 Mdot
.37551 0 Mdot
.37602 0 Mdot
.37654 0 Mdot
.37706 0 Mdot
.37758 0 Mdot
.3781 0 Mdot
.37862 .00309 Mdot
.37914 0 Mdot
.37966 0 Mdot
.38017 0 Mdot
.38069 .00309 Mdot
.38121 0 Mdot
.38173 .00309 Mdot
.38225 .00309 Mdot
.38277 0 Mdot
.38329 .00309 Mdot
.38381 0 Mdot
.38432 0 Mdot
.38484 0 Mdot
.38536 0 Mdot
.38588 0 Mdot
.3864 .00309 Mdot
.38692 0 Mdot
.38744 .00309 Mdot
.38796 .00309 Mdot
.38847 0 Mdot
.38899 0 Mdot
.38951 .00309 Mdot
.39003 0 Mdot
.39055 0 Mdot
.39107 0 Mdot
.39159 0 Mdot
.3921 0 Mdot
.39262 0 Mdot
.39314 .00309 Mdot
.39366 .00309 Mdot
.39418 0 Mdot
.3947 0 Mdot
.39522 0 Mdot
.39574 .00309 Mdot
.39625 0 Mdot
.39677 0 Mdot
.39729 .00309 Mdot
.39781 .00618 Mdot
.39833 0 Mdot
.39885 .00309 Mdot
.39937 0 Mdot
.39989 0 Mdot
.4004 0 Mdot
.40092 0 Mdot
.40144 0 Mdot
.40196 .00309 Mdot
.40248 0 Mdot
.403 .00309 Mdot
.40352 0 Mdot
.40404 0 Mdot
.40455 0 Mdot
.40507 0 Mdot
.40559 0 Mdot
.40611 0 Mdot
.40663 0 Mdot
.40715 0 Mdot
.40767 0 Mdot
.40819 0 Mdot
.4087 0 Mdot
.40922 0 Mdot
.40974 .00309 Mdot
.41026 .00309 Mdot
.41078 0 Mdot
.4113 0 Mdot
.41182 0 Mdot
.41234 0 Mdot
.41285 0 Mdot
.41337 0 Mdot
.41389 .00309 Mdot
.41441 0 Mdot
.41493 0 Mdot
.41545 0 Mdot
.41597 0 Mdot
.41649 0 Mdot
.417 0 Mdot
.41752 0 Mdot
.41804 .00309 Mdot
.41856 0 Mdot
.41908 .00309 Mdot
.4196 0 Mdot
.42012 0 Mdot
.42063 .00309 Mdot
.42115 0 Mdot
.42167 0 Mdot
.42219 .00309 Mdot
.42271 0 Mdot
.42323 0 Mdot
.42375 .00618 Mdot
.42427 0 Mdot
.42478 0 Mdot
.4253 0 Mdot
.42582 0 Mdot
.42634 .00309 Mdot
.42686 0 Mdot
.42738 0 Mdot
.4279 .00309 Mdot
.42842 0 Mdot
.42893 0 Mdot
.42945 0 Mdot
.42997 0 Mdot
.43049 .00309 Mdot
.43101 0 Mdot
.43153 0 Mdot
.43205 0 Mdot
.43257 0 Mdot
.43308 .00309 Mdot
.4336 0 Mdot
.43412 0 Mdot
.43464 0 Mdot
.43516 0 Mdot
.43568 0 Mdot
.4362 0 Mdot
.43672 0 Mdot
.43723 .00618 Mdot
.43775 0 Mdot
.43827 0 Mdot
.43879 .00309 Mdot
.43931 0 Mdot
.43983 0 Mdot
.44035 0 Mdot
.44087 0 Mdot
.44138 0 Mdot
.4419 0 Mdot
.44242 .00309 Mdot
.44294 0 Mdot
.44346 0 Mdot
.44398 0 Mdot
.4445 0 Mdot
.44502 0 Mdot
.44553 0 Mdot
.44605 0 Mdot
.44657 0 Mdot
.44709 0 Mdot
.44761 0 Mdot
.44813 0 Mdot
.44865 .00309 Mdot
.44916 0 Mdot
.44968 0 Mdot
.4502 0 Mdot
.45072 0 Mdot
.45124 0 Mdot
.45176 0 Mdot
.45228 0 Mdot
.4528 0 Mdot
.45331 0 Mdot
.45383 0 Mdot
.45435 .00309 Mdot
.45487 .00309 Mdot
.45539 0 Mdot
.45591 0 Mdot
.45643 .00309 Mdot
.45695 0 Mdot
.45746 0 Mdot
.45798 0 Mdot
.4585 0 Mdot
.45902 0 Mdot
.45954 0 Mdot
.46006 0 Mdot
.46058 0 Mdot
.4611 0 Mdot
.46161 .00309 Mdot
.46213 0 Mdot
.46265 0 Mdot
.46317 .00618 Mdot
.46369 .00309 Mdot
.46421 0 Mdot
.46473 .00309 Mdot
.46525 0 Mdot
.46576 0 Mdot
.46628 0 Mdot
.4668 0 Mdot
.46732 0 Mdot
.46784 0 Mdot
.46836 0 Mdot
.46888 0 Mdot
.4694 0 Mdot
.46991 0 Mdot
.47043 0 Mdot
.47095 .00309 Mdot
.47147 0 Mdot
.47199 0 Mdot
.47251 0 Mdot
.47303 0 Mdot
.47354 0 Mdot
.47406 .00309 Mdot
.47458 0 Mdot
.4751 0 Mdot
.47562 0 Mdot
.47614 .00309 Mdot
.47666 0 Mdot
.47718 0 Mdot
.47769 0 Mdot
.47821 0 Mdot
.47873 .00309 Mdot
.47925 0 Mdot
.47977 0 Mdot
.48029 0 Mdot
.48081 0 Mdot
.48133 0 Mdot
.48184 0 Mdot
.48236 0 Mdot
.48288 0 Mdot
.4834 .00309 Mdot
.48392 .00309 Mdot
.48444 0 Mdot
.48496 0 Mdot
.48548 .00309 Mdot
.48599 0 Mdot
.48651 0 Mdot
.48703 0 Mdot
.48755 0 Mdot
.48807 0 Mdot
.48859 0 Mdot
.48911 0 Mdot
.48963 0 Mdot
.49014 0 Mdot
.49066 0 Mdot
.49118 0 Mdot
.4917 .00309 Mdot
.49222 0 Mdot
.49274 0 Mdot
.49326 0 Mdot
.49378 .00309 Mdot
.49429 0 Mdot
.49481 .00618 Mdot
.49533 0 Mdot
.49585 0 Mdot
.49637 0 Mdot
.49689 .00309 Mdot
.49741 0 Mdot
.49793 0 Mdot
.49844 .00309 Mdot
.49896 0 Mdot
.49948 0 Mdot
.5 0 Mdot
.50052 0 Mdot
.50104 0 Mdot
.50156 0 Mdot
.50207 0 Mdot
.50259 0 Mdot
.50311 0 Mdot
.50363 0 Mdot
.50415 0 Mdot
.50467 0 Mdot
.50519 .00309 Mdot
.50571 0 Mdot
.50622 0 Mdot
.50674 0 Mdot
.50726 0 Mdot
.50778 0 Mdot
.5083 0 Mdot
.50882 0 Mdot
.50934 0 Mdot
.50986 .00309 Mdot
.51037 0 Mdot
.51089 0 Mdot
.51141 0 Mdot
.51193 0 Mdot
.51245 0 Mdot
.51297 0 Mdot
.51349 0 Mdot
.51401 0 Mdot
.51452 0 Mdot
.51504 0 Mdot
.51556 0 Mdot
.51608 0 Mdot
.5166 0 Mdot
.51712 0 Mdot
.51764 0 Mdot
.51816 0 Mdot
.51867 0 Mdot
.51919 .00309 Mdot
.51971 .00309 Mdot
.52023 0 Mdot
.52075 0 Mdot
.52127 0 Mdot
.52179 0 Mdot
.52231 0 Mdot
.52282 0 Mdot
.52334 0 Mdot
.52386 .00309 Mdot
.52438 0 Mdot
.5249 .00309 Mdot
.52542 0 Mdot
.52594 0 Mdot
.52646 0 Mdot
.52697 0 Mdot
.52749 0 Mdot
.52801 0 Mdot
.52853 0 Mdot
.52905 0 Mdot
.52957 0 Mdot
.53009 0 Mdot
.5306 0 Mdot
.53112 0 Mdot
.53164 0 Mdot
.53216 0 Mdot
.53268 0 Mdot
.5332 0 Mdot
.53372 0 Mdot
.53424 0 Mdot
.53475 0 Mdot
.53527 0 Mdot
.53579 0 Mdot
.53631 .00309 Mdot
.53683 0 Mdot
.53735 0 Mdot
.53787 0 Mdot
.53839 0 Mdot
.5389 .00309 Mdot
.53942 0 Mdot
.53994 0 Mdot
.54046 0 Mdot
.54098 0 Mdot
.5415 0 Mdot
.54202 0 Mdot
.54254 0 Mdot
.54305 .00309 Mdot
.54357 .00309 Mdot
.54409 .00309 Mdot
.54461 0 Mdot
.54513 0 Mdot
.54565 0 Mdot
.54617 0 Mdot
.54669 0 Mdot
.5472 0 Mdot
.54772 0 Mdot
.54824 0 Mdot
.54876 0 Mdot
.54928 0 Mdot
.5498 0 Mdot
.55032 0 Mdot
.55084 0 Mdot
.55135 0 Mdot
.55187 0 Mdot
.55239 0 Mdot
.55291 0 Mdot
.55343 0 Mdot
.55395 0 Mdot
.55447 0 Mdot
.55498 0 Mdot
.5555 0 Mdot
.55602 0 Mdot
.55654 0 Mdot
.55706 0 Mdot
.55758 0 Mdot
.5581 0 Mdot
.55862 0 Mdot
.55913 0 Mdot
.55965 0 Mdot
.56017 0 Mdot
.56069 0 Mdot
.56121 0 Mdot
.56173 0 Mdot
.56225 0 Mdot
.56277 0 Mdot
.56328 0 Mdot
.5638 0 Mdot
.56432 0 Mdot
.56484 0 Mdot
.56536 .00618 Mdot
.56588 0 Mdot
.5664 0 Mdot
.56692 0 Mdot
.56743 0 Mdot
.56795 0 Mdot
.56847 0 Mdot
.56899 0 Mdot
.56951 0 Mdot
.57003 0 Mdot
.57055 0 Mdot
.57107 .00309 Mdot
.57158 0 Mdot
.5721 0 Mdot
.57262 0 Mdot
.57314 0 Mdot
.57366 0 Mdot
.57418 0 Mdot
.5747 0 Mdot
.57522 0 Mdot
.57573 .00309 Mdot
.57625 0 Mdot
.57677 0 Mdot
.57729 0 Mdot
.57781 0 Mdot
.57833 .00309 Mdot
.57885 0 Mdot
.57937 0 Mdot
.57988 0 Mdot
.5804 .00309 Mdot
.58092 0 Mdot
.58144 0 Mdot
.58196 0 Mdot
.58248 0 Mdot
.583 .00309 Mdot
.58351 0 Mdot
.58403 .00309 Mdot
.58455 0 Mdot
.58507 0 Mdot
.58559 .00309 Mdot
.58611 0 Mdot
.58663 0 Mdot
.58715 0 Mdot
.58766 0 Mdot
.58818 0 Mdot
.5887 0 Mdot
.58922 0 Mdot
.58974 .00618 Mdot
.59026 0 Mdot
.59078 .00927 Mdot
.5913 0 Mdot
.59181 .00309 Mdot
.59233 .00309 Mdot
.59285 0 Mdot
.59337 0 Mdot
.59389 0 Mdot
.59441 .00618 Mdot
.59493 .00309 Mdot
.59545 .00618 Mdot
.59596 .00618 Mdot
.59648 .01236 Mdot
.597 .00309 Mdot
.59752 .00309 Mdot
.59804 .00618 Mdot
.59856 .00927 Mdot
.59908 .00927 Mdot
.5996 .01236 Mdot
.60011 0 Mdot
.60063 .01236 Mdot
.60115 .01236 Mdot
.60167 0 Mdot
.60219 .00309 Mdot
.60271 .00618 Mdot
.60323 .00309 Mdot
.60375 .00309 Mdot
.60426 .00309 Mdot
.60478 .01236 Mdot
.6053 .01545 Mdot
.60582 .00309 Mdot
.60634 .00618 Mdot
.60686 .00618 Mdot
.60738 .00309 Mdot
.6079 .00309 Mdot
.60841 .00618 Mdot
.60893 .00309 Mdot
.60945 .01236 Mdot
.60997 .01236 Mdot
.61049 .01545 Mdot
.61101 0 Mdot
.61153 .02163 Mdot
.61204 .00927 Mdot
.61256 .00309 Mdot
.61308 .00927 Mdot
.6136 .00927 Mdot
.61412 0 Mdot
.61464 .01236 Mdot
.61516 .00618 Mdot
.61568 .01545 Mdot
.61619 .02163 Mdot
.61671 .00927 Mdot
.61723 .00309 Mdot
.61775 .01545 Mdot
.61827 .00927 Mdot
.61879 .00618 Mdot
.61931 .01236 Mdot
.61983 .02163 Mdot
.62034 .00618 Mdot
.62086 .00618 Mdot
.62138 .01854 Mdot
.6219 .00618 Mdot
.62242 .01545 Mdot
.62294 .00618 Mdot
.62346 .01545 Mdot
.62398 .02163 Mdot
.62449 .01236 Mdot
.62501 .02163 Mdot
.62553 .02163 Mdot
.62605 .03708 Mdot
.62657 .01854 Mdot
.62709 .02472 Mdot
.62761 .03708 Mdot
.62813 .02163 Mdot
.62864 .02163 Mdot
.62916 .01236 Mdot
.62968 .0309 Mdot
.6302 .02781 Mdot
.63072 .05562 Mdot
.63124 .03399 Mdot
.63176 .04017 Mdot
.63228 .03708 Mdot
.63279 .04944 Mdot
.63331 .04944 Mdot
.63383 .05253 Mdot
.63435 .08652 Mdot
.63487 .05562 Mdot
.63539 .06489 Mdot
.63591 .07107 Mdot
.63642 .08034 Mdot
.63694 .07107 Mdot
.63746 .08343 Mdot
.63798 .12361 Mdot
.6385 .12979 Mdot
.63902 .19468 Mdot
.63954 .22249 Mdot
.64006 .25648 Mdot
.64057 .27193 Mdot
.64109 .40481 Mdot
.64161 .47589 Mdot
.64732 .37391 Mdot
.64784 .30284 Mdot
.64836 .25648 Mdot
.64887 .20704 Mdot
.64939 .14215 Mdot
.64991 .14524 Mdot
.65043 .17614 Mdot
.65095 .15142 Mdot
.65147 .08961 Mdot
.65199 .0958 Mdot
.65251 .0618 Mdot
.65302 .0618 Mdot
.65354 .05562 Mdot
.65406 .05253 Mdot
.65458 .05871 Mdot
.6551 .05562 Mdot
.65562 .0309 Mdot
.65614 .01854 Mdot
.65666 .04326 Mdot
.65717 .03708 Mdot
.65769 .03708 Mdot
.65821 .02472 Mdot
.65873 .0309 Mdot
.65925 .02472 Mdot
.65977 .0309 Mdot
.66029 .02163 Mdot
.66081 .02781 Mdot
.66132 .01854 Mdot
.66184 .00309 Mdot
.66236 .02472 Mdot
.66288 .01854 Mdot
.6634 .02163 Mdot
.66392 .02163 Mdot
.66444 .01545 Mdot
.66495 .00927 Mdot
.66547 .01854 Mdot
.66599 .01545 Mdot
.66651 .01236 Mdot
.66703 .0309 Mdot
.66755 .01854 Mdot
.66807 .00618 Mdot
.66859 .01236 Mdot
.6691 .01236 Mdot
.66962 .00618 Mdot
.67014 0 Mdot
.67066 .00618 Mdot
.67118 .00927 Mdot
.6717 .00618 Mdot
.67222 .01854 Mdot
.67274 .01854 Mdot
.67325 .01854 Mdot
.67377 .00618 Mdot
.67429 .01854 Mdot
.67481 0 Mdot
.67533 .00309 Mdot
.67585 .00618 Mdot
.67637 0 Mdot
.67689 .00927 Mdot
.6774 .00309 Mdot
.67792 .01236 Mdot
.67844 .00927 Mdot
.67896 .01236 Mdot
.67948 0 Mdot
.68 .00927 Mdot
.68052 .00618 Mdot
.68104 .00618 Mdot
.68155 0 Mdot
.68207 .00309 Mdot
.68259 .01236 Mdot
.68311 .00618 Mdot
.68363 .00927 Mdot
.68415 .00618 Mdot
.68467 .01236 Mdot
.68519 .00309 Mdot
.6857 .00618 Mdot
.68622 .01236 Mdot
.68674 .01236 Mdot
.68726 .00927 Mdot
.68778 0 Mdot
.6883 .00309 Mdot
.68882 .00309 Mdot
.68933 .00618 Mdot
.68985 .00309 Mdot
.69037 0 Mdot
.69089 .00618 Mdot
.69141 0 Mdot
.69193 .00309 Mdot
.69245 .00927 Mdot
.69297 .00309 Mdot
.69348 .00309 Mdot
.694 0 Mdot
.69452 .00927 Mdot
.69504 0 Mdot
.69556 .00309 Mdot
.69608 0 Mdot
.6966 .00309 Mdot
.69712 .00309 Mdot
.69763 .00618 Mdot
.69815 .00927 Mdot
.69867 0 Mdot
.69919 .00309 Mdot
.69971 0 Mdot
.70023 .00309 Mdot
.70075 .00618 Mdot
.70127 .00309 Mdot
.70178 .00309 Mdot
.7023 .00309 Mdot
.70282 0 Mdot
.70334 .00309 Mdot
.70386 0 Mdot
.70438 .00309 Mdot
.7049 .00309 Mdot
.70542 0 Mdot
.70593 0 Mdot
.70645 0 Mdot
.70697 0 Mdot
.70749 0 Mdot
.70801 0 Mdot
.70853 0 Mdot
.70905 0 Mdot
.70957 0 Mdot
.71008 .00618 Mdot
.7106 0 Mdot
.71112 0 Mdot
.71164 0 Mdot
.71216 0 Mdot
.71268 .00927 Mdot
.7132 0 Mdot
.71372 0 Mdot
.71423 0 Mdot
.71475 0 Mdot
.71527 0 Mdot
.71579 0 Mdot
.71631 0 Mdot
.71683 0 Mdot
.71735 0 Mdot
.71786 0 Mdot
.71838 .00309 Mdot
.7189 0 Mdot
.71942 0 Mdot
.71994 0 Mdot
.72046 0 Mdot
.72098 0 Mdot
.7215 0 Mdot
.72201 0 Mdot
.72253 0 Mdot
.72305 .00309 Mdot
.72357 0 Mdot
.72409 0 Mdot
.72461 0 Mdot
.72513 0 Mdot
.72565 0 Mdot
.72616 .00309 Mdot
.72668 0 Mdot
.7272 0 Mdot
.72772 0 Mdot
.72824 0 Mdot
.72876 0 Mdot
.72928 .00309 Mdot
.7298 0 Mdot
.73031 0 Mdot
.73083 0 Mdot
.73135 0 Mdot
.73187 0 Mdot
.73239 0 Mdot
.73291 0 Mdot
.73343 .00309 Mdot
.73395 .00309 Mdot
.73446 0 Mdot
.73498 0 Mdot
.7355 0 Mdot
.73602 0 Mdot
.73654 0 Mdot
.73706 0 Mdot
.73758 0 Mdot
.7381 0 Mdot
.73861 .00309 Mdot
.73913 .00309 Mdot
.73965 0 Mdot
.74017 .00309 Mdot
.74069 0 Mdot
.74121 0 Mdot
.74173 .00309 Mdot
.74225 0 Mdot
.74276 0 Mdot
.74328 .00309 Mdot
.7438 0 Mdot
.74432 0 Mdot
.74484 .00309 Mdot
.74536 .00309 Mdot
.74588 0 Mdot
.74639 0 Mdot
.74691 0 Mdot
.74743 0 Mdot
.74795 0 Mdot
.74847 0 Mdot
.74899 0 Mdot
.74951 0 Mdot
.75003 0 Mdot
.75054 0 Mdot
.75106 0 Mdot
.75158 0 Mdot
.7521 .00309 Mdot
.75262 0 Mdot
.75314 0 Mdot
.75366 0 Mdot
.75418 0 Mdot
.75469 0 Mdot
.75521 0 Mdot
.75573 0 Mdot
.75625 .00309 Mdot
.75677 0 Mdot
.75729 0 Mdot
.75781 0 Mdot
.75833 0 Mdot
.75884 0 Mdot
.75936 0 Mdot
.75988 .00309 Mdot
.7604 .00309 Mdot
.76092 0 Mdot
.76144 0 Mdot
.76196 0 Mdot
.76248 0 Mdot
.76299 0 Mdot
.76351 0 Mdot
.76403 0 Mdot
.76455 0 Mdot
.76507 .00309 Mdot
.76559 0 Mdot
.76611 0 Mdot
.76663 0 Mdot
.76714 0 Mdot
.76766 .00309 Mdot
.76818 0 Mdot
.7687 .00309 Mdot
.76922 0 Mdot
.76974 0 Mdot
.77026 0 Mdot
.77077 0 Mdot
.77129 0 Mdot
.77181 0 Mdot
.77233 0 Mdot
.77285 0 Mdot
.77337 0 Mdot
.77389 0 Mdot
.77441 .00309 Mdot
.77492 0 Mdot
.77544 0 Mdot
.77596 0 Mdot
.77648 0 Mdot
.777 0 Mdot
.77752 0 Mdot
.77804 0 Mdot
.77856 0 Mdot
.77907 0 Mdot
.77959 0 Mdot
.78011 .00309 Mdot
.78063 0 Mdot
.78115 0 Mdot
.78167 0 Mdot
.78219 0 Mdot
.78271 0 Mdot
.78322 0 Mdot
.78374 0 Mdot
.78426 0 Mdot
.78478 0 Mdot
.7853 0 Mdot
.78582 0 Mdot
.78634 0 Mdot
.78686 0 Mdot
.78737 .00309 Mdot
.78789 0 Mdot
.78841 0 Mdot
.78893 0 Mdot
.78945 0 Mdot
.78997 0 Mdot
.79049 0 Mdot
.79101 0 Mdot
.79152 0 Mdot
.79204 0 Mdot
.79256 0 Mdot
.79308 0 Mdot
.7936 .00309 Mdot
.79412 0 Mdot
.79464 0 Mdot
.79516 0 Mdot
.79567 0 Mdot
.79619 0 Mdot
.79671 0 Mdot
.79723 0 Mdot
.79775 0 Mdot
.79827 0 Mdot
.79879 0 Mdot
.7993 0 Mdot
.79982 0 Mdot
.80034 0 Mdot
.80086 0 Mdot
.80138 0 Mdot
.8019 .00309 Mdot
.80242 0 Mdot
.80294 0 Mdot
.80345 0 Mdot
.80397 0 Mdot
.80449 0 Mdot
.80501 0 Mdot
.80553 0 Mdot
.80605 0 Mdot
.80657 0 Mdot
.80709 0 Mdot
.8076 0 Mdot
.80812 0 Mdot
.80864 0 Mdot
.80916 0 Mdot
.80968 0 Mdot
.8102 0 Mdot
.81072 0 Mdot
.81124 0 Mdot
.81175 0 Mdot
.81227 0 Mdot
.81279 0 Mdot
.81331 0 Mdot
.81383 0 Mdot
.81435 0 Mdot
.81487 0 Mdot
.81539 0 Mdot
.8159 0 Mdot
.81642 0 Mdot
.81694 0 Mdot
.81746 .00309 Mdot
.81798 0 Mdot
.8185 0 Mdot
.81902 0 Mdot
.81954 0 Mdot
.82005 0 Mdot
.82057 0 Mdot
.82109 .00309 Mdot
.82161 0 Mdot
.82213 0 Mdot
.82265 0 Mdot
.82317 0 Mdot
.82369 0 Mdot
.8242 0 Mdot
.82472 0 Mdot
.82524 0 Mdot
.82576 0 Mdot
.82628 0 Mdot
.8268 0 Mdot
.82732 0 Mdot
.82783 .00309 Mdot
.82835 0 Mdot
.82887 0 Mdot
.82939 0 Mdot
.82991 .00309 Mdot
.83043 0 Mdot
.83095 0 Mdot
.83147 0 Mdot
.83198 0 Mdot
.8325 0 Mdot
.83302 0 Mdot
.83354 0 Mdot
.83406 0 Mdot
.83458 0 Mdot
.8351 0 Mdot
.83562 0 Mdot
.83613 0 Mdot
.83665 0 Mdot
.83717 0 Mdot
.83769 0 Mdot
.83821 0 Mdot
.83873 0 Mdot
.83925 0 Mdot
.83977 0 Mdot
.84028 0 Mdot
.8408 0 Mdot
.84132 0 Mdot
.84184 0 Mdot
.84236 0 Mdot
.84288 0 Mdot
.8434 0 Mdot
.84392 0 Mdot
.84443 0 Mdot
.84495 0 Mdot
.84547 0 Mdot
.84599 0 Mdot
.84651 .00309 Mdot
.84703 0 Mdot
.84755 0 Mdot
.84807 0 Mdot
.84858 0 Mdot
.8491 0 Mdot
.84962 0 Mdot
.85014 0 Mdot
.85066 0 Mdot
.85118 0 Mdot
.8517 0 Mdot
.85221 0 Mdot
.85273 0 Mdot
.85325 0 Mdot
.85377 0 Mdot
.85429 0 Mdot
.85481 0 Mdot
.85533 .00309 Mdot
.85585 .00309 Mdot
.85636 0 Mdot
.85688 0 Mdot
.8574 0 Mdot
.85792 0 Mdot
.85844 0 Mdot
.85896 0 Mdot
.85948 0 Mdot
.86 0 Mdot
.86051 0 Mdot
.86103 0 Mdot
.86155 0 Mdot
.86207 0 Mdot
.86259 0 Mdot
.86311 0 Mdot
.86363 0 Mdot
.86415 0 Mdot
.86466 0 Mdot
.86518 0 Mdot
.8657 0 Mdot
.86622 0 Mdot
.86674 0 Mdot
.86726 0 Mdot
.86778 0 Mdot
.8683 0 Mdot
.86881 0 Mdot
.86933 0 Mdot
.86985 0 Mdot
.87037 0 Mdot
.87089 0 Mdot
.87141 0 Mdot
.87193 0 Mdot
.87245 0 Mdot
.87296 0 Mdot
.87348 0 Mdot
.874 0 Mdot
.87452 0 Mdot
.87504 0 Mdot
.87556 0 Mdot
.87608 0 Mdot
.8766 0 Mdot
.87711 0 Mdot
.87763 .00309 Mdot
.87815 0 Mdot
.87867 0 Mdot
.87919 0 Mdot
.87971 0 Mdot
.88023 0 Mdot
.88074 0 Mdot
.88126 0 Mdot
.88178 0 Mdot
.8823 0 Mdot
.88282 0 Mdot
.88334 0 Mdot
.88386 0 Mdot
.88438 0 Mdot
.88489 0 Mdot
.88541 .00309 Mdot
.88593 0 Mdot
.88645 0 Mdot
.88697 0 Mdot
.88749 0 Mdot
.88801 0 Mdot
.88853 0 Mdot
.88904 0 Mdot
.88956 0 Mdot
.89008 0 Mdot
.8906 0 Mdot
.89112 0 Mdot
.89164 0 Mdot
.89216 0 Mdot
.89268 0 Mdot
.89319 0 Mdot
.89371 0 Mdot
.89423 0 Mdot
.89475 0 Mdot
.89527 0 Mdot
.89579 0 Mdot
.89631 0 Mdot
.89683 0 Mdot
.89734 0 Mdot
.89786 0 Mdot
.89838 0 Mdot
.8989 0 Mdot
.89942 0 Mdot
.89994 0 Mdot
.90046 0 Mdot
.90098 0 Mdot
.90149 0 Mdot
.90201 0 Mdot
.90253 0 Mdot
.90305 0 Mdot
.90357 0 Mdot
.90409 0 Mdot
.90461 .00309 Mdot
.90513 0 Mdot
.90564 0 Mdot
.90616 0 Mdot
.90668 .00309 Mdot
.9072 0 Mdot
.90772 0 Mdot
.90824 0 Mdot
.90876 0 Mdot
.90927 0 Mdot
.90979 0 Mdot
.91031 0 Mdot
.91083 0 Mdot
.91135 0 Mdot
.91187 0 Mdot
.91239 0 Mdot
.91291 0 Mdot
.91342 0 Mdot
.91394 0 Mdot
.91446 0 Mdot
.91498 0 Mdot
.9155 0 Mdot
.91602 0 Mdot
.91654 0 Mdot
.91706 0 Mdot
.91757 0 Mdot
.91809 0 Mdot
.91861 0 Mdot
.91913 0 Mdot
.91965 0 Mdot
.92017 0 Mdot
.92069 0 Mdot
.92121 0 Mdot
.92172 0 Mdot
.92224 0 Mdot
.92276 0 Mdot
.92328 0 Mdot
.9238 0 Mdot
.92432 0 Mdot
.92484 0 Mdot
.92536 0 Mdot
.92587 0 Mdot
.92639 0 Mdot
.92691 .00309 Mdot
.92743 0 Mdot
.92795 0 Mdot
.92847 0 Mdot
.92899 0 Mdot
.92951 0 Mdot
.93002 0 Mdot
.93054 0 Mdot
.93106 0 Mdot
.93158 0 Mdot
.9321 0 Mdot
.93262 0 Mdot
.93314 0 Mdot
.93365 0 Mdot
.93417 0 Mdot
.93469 0 Mdot
.93521 0 Mdot
.93573 0 Mdot
.93625 0 Mdot
.93677 0 Mdot
.93729 0 Mdot
.9378 0 Mdot
.93832 .00309 Mdot
.93884 0 Mdot
.93936 0 Mdot
.93988 0 Mdot
.9404 0 Mdot
.94092 0 Mdot
.94144 0 Mdot
.94195 0 Mdot
.94247 0 Mdot
.94299 0 Mdot
.94351 0 Mdot
.94403 0 Mdot
.94455 0 Mdot
.94507 0 Mdot
.94559 0 Mdot
.9461 0 Mdot
.94662 0 Mdot
.94714 0 Mdot
.94766 0 Mdot
.94818 0 Mdot
.9487 0 Mdot
.94922 0 Mdot
.94974 0 Mdot
.95025 0 Mdot
.95077 0 Mdot
.95129 0 Mdot
.95181 0 Mdot
.95233 0 Mdot
.95285 0 Mdot
.95337 .00309 Mdot
.95389 0 Mdot
.9544 0 Mdot
.95492 0 Mdot
.95544 .00309 Mdot
.95596 0 Mdot
.95648 .00309 Mdot
.957 0 Mdot
.95752 .00309 Mdot
.95804 0 Mdot
.95855 0 Mdot
.95907 0 Mdot
.95959 0 Mdot
.96011 0 Mdot
.96063 0 Mdot
.96115 0 Mdot
.96167 0 Mdot
.96218 0 Mdot
.9627 0 Mdot
.96322 0 Mdot
.96374 0 Mdot
.96426 0 Mdot
.96478 0 Mdot
.9653 0 Mdot
.96582 0 Mdot
.96633 0 Mdot
.96685 0 Mdot
.96737 0 Mdot
.96789 0 Mdot
.96841 0 Mdot
.96893 0 Mdot
.96945 0 Mdot
.96997 0 Mdot
.97048 0 Mdot
.971 0 Mdot
.97152 0 Mdot
.97204 0 Mdot
.97256 0 Mdot
.97308 0 Mdot
.9736 0 Mdot
.97412 0 Mdot
.97463 0 Mdot
.97515 0 Mdot
.97567 0 Mdot
.97619 .00309 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000VOol5
0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0DOol30003Ool0
0`00Oomoo`02Ool00`00Oomoo`0bOol30003Ool00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0QOol002Qoo`07001oogooOol007oo00000Woo00<007oo
00000Woo00<007oo000057oo00L007ooOomoo`00Ool00002Ool00`00Ool0000DOol00`00Ool00002
Ool00`00Ool00002Ool00`00Ool0000EOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0000c
Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0000EOol00`00Ool00002Ool00`00Ool00002
Ool00`00Ool0000ROol0029oo`<000=oo`07001oogooOol007oo00000Woo00<007oo00000Woo00<0
07oo00003Woo0`000goo00<007ooOol00goo00H007ooOol007oo000?Ool30004Ool01P00Oomoo`00
Ool0009oo`03001oo`00011oo`<000=oo`03001oogoo00=oo`06001oogoo001oo`00=7oo00<007oo
Ool00goo00H007ooOol007oo000GOol01P00Oomoo`00Ool0009oo`03001oo`00029oo`00:7oo00L0
07ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool0000EOol00`00Oomoo`020003Ool00`00
Ool0000DOol20003Ool00`00Ool00002Ool00`00Ool0000FOol01000Oomoogoo0P000goo00<007oo
0000=7oo00@007ooOomoo`8000=oo`03001oo`0001Eoo`8000=oo`03001oo`00009oo`03001oo`00
029oo`00:7oo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool0000COol00`00Ool0
0002Ool00`00Oomoo`02Ool00`00Ool0000DOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0
000EOol00`00Ool00002Ool00`00Oomoo`02Ool00`00Ool0000cOol00`00Ool00002Ool00`00Oomo
o`02Ool00`00Ool0000EOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0000ROol002Moo`80
00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo019oo`<0009oo`<000=oo`03001oogoo
01=oo`<000=oo`03001oogoo009oo`03001oogoo01Eoo`04001oogooOol30003Ool00`00Oomoo`0c
Ool01000Oomoogoo0`000goo00<007ooOol057oo0`000goo00<007ooOol00Woo00<007ooOol08Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol001=ooiL00003Ool0000000iooe0001Eoo`00
3Gooo`001P003Woo000COol00`00Oomoo`04Ool20002Ool30004Ool00`00Ool00002Ool01000Ool0
07oo0`000goo0P0000=oo`0000000`0000Aoo`00001oo`@0009oo`03001oo`00008000=oob000003
Ool0000000D00003Ool0000000T00005Ool007oo001oo`08000017oo000007oo0`000Woo0`0017oo
40001Goo00H007ooOomoo`00Ool<00000goo0000000<00002Goo000007oo001oo`00Ool00003Ool4
0003Ool01000Ool0000017oo0`0017oo0P0017oo0P0000=oo`00Ool00Woo0P0017oo00<007oo0000
4goo000UOol00`00Oomoo`0ROol00`00Oomoo`04Ool01000Ool007oo0P0000=oo`00Ool00P000Woo
0P000Woo00<007oo00000goo00<007ooOol00P001goo00<007ooOol017oo00@007ooOol000Ioo`03
001oogoo00Eoo`03001oogoo00moo`03001oogoo00Aoo`T000Eoo`03001oogoo009oo`/00003Ool0
000005Uoo`00EWoo00<007ooOol0CGoo00<007oo000020000goo00<007ooOol00Woo2P000goo00<0
07ooOol0Egoo002XOol90003Ool200000goo00000007001POol00:]oo`03001oo`0000<000=oo`03
001oogoo00H006=oo`00Zgoo00<007oo00000`000goo00@007ooOomoo`8006Ioo`00[goo0P000goo
00<007ooOol01000IGoo002`Ool20002Ool200001Goo000007oo0000IGoo002_Ool30002Ool01000
Oomoo`00J7oo002_Ool30002Ool01000Oomoo`00J7oo002aOol01000Oomoo`000Woo00<007ooOol0
IWoo002aOol00`00Oomoo`0200000goo001oo`1WOol00;5oo`06001oogoo001oo`00JGoo002`Ool2
0002Ool01000Ool00000J7oo002`Ool20002Ool01000Ool00000J7oo002bOol00`00Ool00003001X
Ool00;9oo`03001oo`0006]oo`00Z7oo0`000goo00L007ooOomoo`00Ool0001[Ool00:Qoo`03001o
ogoo009oo`03001oo`00009oo`03001oo`0006]oo`00ZGoo00<007ooOol00goo00D007ooOol007oo
00<006Uoo`00ZGoo00@007ooOomoo`8000=oo`03001oo`0006]oo`00Z7oo00<007oo00000Woo00@0
07ooOomoo`800003Ool007oo06Yoo`00ZGoo00@007ooOomoo`<00007Ool007ooOol007oo0000JGoo
002dOol3001YOol00;Aoo`03001oo`0006Uoo`00]7oo00<007ooOol0JGoo002dOol00`00Oomoo`1Y
Ool00;Aoo`8006Yoo`00]7oo00<007ooOol0JGoo002dOol00`00Oomoo`1YOol00;9oo`03001oo`00
06]oo`00/Woo00@007oo000006Yoo`00/Woo00<007oo0000Jgoo002bOol00`00Ool0001[Ool00;Ao
o`03001oogoo06Uoo`00]7oo0P00JWoo002dOol2001ZOol00:Uoo`03001oogoo009oo`03001oogoo
00=oo`8006Yoo`00Z7oo00<007oo00000Woo00<007oo000017oo00<007oo0000JGoo002ZOol01P00
Oomoo`00Ool000Aoo`<006Uoo`00Z7oo0P000goo00<007oo000017oo00<007ooOol0JGoo002XOol0
0`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`1YOol00:Qoo`<000=oo`03001oogoo00=oo`03
001oogoo06Uoo`00]7oo0P00JWoo002dOol2001ZOol00;Aoo`8006Yoo`00]7oo00<007ooOol0JGoo
002dOol2001ZOol00;Aoo`03001oogoo06Uoo`00/goo0P00Jgoo002cOol2001[Ool00;Aoo`8006Yo
o`00]7oo0P00JWoo002dOol2001ZOol00;Aoo`03001oogoo06Uoo`00]7oo0P00JWoo002cOol2001[
Ool00:Uoo`03001oogoo009oo`03001oogoo009oo`8006]oo`00ZGoo00L007ooOomoo`00Ool00004
Ool00`00Oomoo`1YOol00:Uoo`03001oogoo00=oo`03001oogoo009oo`<006Uoo`00ZWoo00<007oo
Ool00P001Goo00<007ooOol0JGoo002XOol00`00Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`1Y
Ool00:Qoo`<0009oo`<000Aoo`03001oogoo06Uoo`00]7oo0P00JWoo002dOol00`00Oomoo`1YOol0
0;=oo`<006Yoo`00/goo0`00JWoo002dOol2001ZOol00;Aoo`03001oogoo06Uoo`00/goo0P00Jgoo
002cOol2001[Ool00;Aoo`8006Yoo`00]7oo00<007ooOol0JGoo002dOol00`00Oomoo`1YOol00;Ao
o`03001oogoo06Uoo`00]7oo0P00JWoo002dOol00`00Oomoo`1YOol00:9oo`D0009oo`03001oogoo
009oo`03001oogoo00=oo`8006Yoo`00Y7oo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool2
001ZOol00:Aoo`07001oogooOol007oo00000Woo00<007oo000017oo0`00JGoo002TOol01`00Oomo
ogoo001oo`00009oo`03001oo`0000Aoo`03001oogoo06Uoo`00Y7oo00L007ooOomoo`00Ool00002
Ool00`00Ool00004Ool00`00Oomoo`1YOol00:=oo`8000Aoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo06Uoo`00]7oo0P00JWoo002dOol00`00Oomoo`1YOol00;Aoo`03001oogoo06Uoo`00
]7oo00<007ooOol0JGoo002dOol2001ZOol00;Aoo`03001oogoo06Uoo`00]7oo00<007ooOol0JGoo
002dOol00`00Oomoo`1YOol00;Aoo`8006Yoo`00]7oo00<007ooOol0JGoo002dOol00`00Oomoo`1Y
Ool00;Aoo`03001oogoo06Uoo`00]7oo0P00JWoo002dOol2001ZOol00:9oo`D00004Ool000000003
Ool00`00Oomoo`03Ool00`00Oomoo`1YOol00:Aoo`05001oogooOol00004Ool00`00Ool00004Ool0
0`00Oomoo`1YOol00:Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`<006Uoo`00
Y7oo00<007ooOol00Woo00@007ooOomoo`8000Eoo`03001oogoo06Uoo`00Y7oo00L007ooOomoo`00
Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`1YOol00:=oo`8000Aoo`04001oogooOol30004Ool0
0`00Oomoo`1YOol00;=oo`<006Yoo`00/goo0P00Jgoo002dOol00`00Oomoo`1YOol00;Aoo`03001o
ogoo06Uoo`00]7oo0P00JWoo002dOol00`00Oomoo`1YOol00;Aoo`03001oogoo06Uoo`00]7oo00<0
07ooOol0JGoo002dOol2001ZOol00;Aoo`03001oogoo06Uoo`00]7oo00<007ooOol0JGoo002dOol0
0`00Oomoo`1YOol00;Aoo`8006Yoo`00]7oo00<007ooOol0JGoo002ROol50002Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`1YOol00:Aoo`07001oogooOol007oo00000Woo00<007oo0000
17oo00<007ooOol0JGoo002TOol00`00Oomoo`03Ool01P00Oomoo`00Ool000Aoo`<006Uoo`00Y7oo
00@007ooOomoo`8000=oo`03001oo`0000Aoo`03001oogoo06Uoo`00Y7oo00D007ooOomoo`0000Ao
o`03001oo`0000Aoo`03001oogoo06Uoo`00Xgoo0P000goo0`000goo00<007ooOol00Woo0P00Jgoo
002cOol3001ZOol00;Aoo`03001oogoo06Uoo`00]7oo00<007ooOol0JGoo002dOol00`00Oomoo`1Y
Ool00;Aoo`8006Yoo`00]7oo00<007ooOol0JGoo002dOol00`00Oomoo`1YOol00;Aoo`03001oogoo
06Uoo`00]7oo0P00JWoo002dOol00`00Oomoo`1YOol00;Aoo`03001oogoo06Uoo`00]7oo00<007oo
Ool0JGoo002dOol2001ZOol00;Aoo`03001oogoo06Uoo`00XWoo1@000Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0JGoo002TOol00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`03
001oogoo06Uoo`00Y7oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo0`00JGoo002T
Ool00`00Oomoo`03Ool00`00Oomoo`020005Ool00`00Oomoo`1YOol00:Aoo`07001oogooOol007oo
00000Woo00<007ooOol017oo00<007ooOol0JGoo002SOol20003Ool30002Ool30004Ool00`00Oomo
o`1YOol00;Aoo`8006Yoo`00]7oo00<007ooOol0JGoo002dOol00`00Oomoo`1YOol00;Aoo`03001o
ogoo06Uoo`00]7oo0P00JWoo002dOol00`00Oomoo`1YOol00;Aoo`03001oogoo06Uoo`00]7oo00<0
07ooOol0JGoo002dOol2001ZOol00;Aoo`03001oogoo06Uoo`00]7oo00<007ooOol0JGoo002dOol0
0`00Oomoo`1YOol00;Aoo`8006Yoo`00]7oo00<007ooOol0JGoo002SOol30003Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`1YOol00:=oo`03001oogoo009oo`03001oo`00009oo`03001o
o`0000Aoo`03001oogoo06Uoo`00Y7oo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool3001Y
Ool00:Aoo`07001oogooOol007oo00000Woo00<007oo0000L7oo002SOol00`00Ool00002Ool00`00
Ool00002Ool00`00Ool0001`Ool00:Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo06mo
o`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1345.27, -15.2823, 7.43739, 
  1.24846}}]
}, Open  ]],

Cell[TextData[{
  "The characteristics of the DCT coeffcients shown here are typical for a \
large class of images. An overwhelming majority of the coefficients have \
relatively small values, the large values appear in the low-frequency \
sub-region of each 8-by-8 block. The bit-allocation strategy makes use of \
these findings. In the case of ",
  StyleBox["zonal coding",
    FontSlant->"Italic"],
  ", the strategy is to allocate a decreasing number of bits to DCT \
coefficients as a function of their position relative to the DC coefficient, \
within the confines of a fixed zone. For example, \n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"8", "7", "5", "3", "1", "1", "0", "..."},
              {"7", "5", "3", "2", "1", "0", "...", "."},
              {"4", "3", "2", "1", "1", "0", "...", "."},
              {"3", "3", "2", "1", "1", "0", "...", "."},
              {"2", "1", "1", "1", "0", "...", ".", "."},
              {"1", "1", "0", "...", ".", ".", ".", "."},
              {"...", ".", ".", ".", ".", ".", ".", "."}
              }], ")"}], TraditionalForm]]],
  " \n\nThis allocation scheme results in a total of 71 bits for an average \
bit rate of ",
  Cell[BoxData[
      \(TraditionalForm\`r = 1.1\)]],
  " bits/pixel. The standard method of determining the number of bits \
allocated to each coefficient is based on an analysis of the variance of \
these coefficients. If we allocate ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(i, j\)\)]],
  " per quantized DCT coefficient, then the the desired average compressed \
bit rate ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is given by"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`r = \ \(1\/64\) 
          \(\[Sum]\+\(i = 1\)\%8\(\[Sum]\+\(j = 1\)\%8 b\_\(i, j\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Given an image, let N be the number of 8-by-8 blocks in the image and let \
",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_n[i, \ j]\)]],
  " denote the ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  "-th DCT coefficient in block ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". Define the mean and variance of the ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  "-th coefficient by"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Mu]\_\(i, j\)\  = \ 
        1\/N\ \(\[Sum]\+\(n = 1\)\%N \[ScriptCapitalC]\_n[i, \ j]\)\)]]
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Sigma]\_\(i, j\)\^2\  = \ 
        1\/N\ \(\[Sum]\+\(n = 1\)\%N
              \((\[ScriptCapitalC]\_n[i, \ j] - \ \[Mu]\_\(i, j\))\)\^2\)\)]]
}], "Text"],

Cell["The optimum bit  allocation is now given by ", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`b\_\(i, j\)\  = \ 
        r\  + \ 1\/2\ log\_2\ 
            \[Sigma]\_\(i, j\)\^2
                \/\((\[Product]\+\(i, j\)\[Sigma]\_\(i, j\)\^2)
                  \)\^\(1\/64\)\)]]
}], "Text"],

Cell["\<\
For images with 8-bits/pixel, the maximum range of the AC coefficients is \
from -1023 to 1023 (why?). The quantization step size needs to be\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`Q\_\(i, j\)\  = \ 2046\/2\^b\_\(i, j\)\)]]
}], "Text"],

Cell[TextData[{
  "A second technique for calculating the quantization step size and one that \
actually leads to the pair of ",
  StyleBox["quantization tables",
    FontSlant->"Italic"],
  " listed in Annex K of the JPEG standard, is based on human perception. \
Simply stated, a series of tests using human observers may be conducted to \
determine the just noticeable level for each of the DCT coefficients. This \
so-called ",
  StyleBox["visibility threshold",
    FontSlant->"Italic"],
  " determines the magnitude of the quantization step size. In either of the \
two cases, the threshold and quantization steps may be combined by dividing \
the coefficient values by scaling factors stored in a quantization table ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  ". The suggested luminance quantization table has the following scaling \
factors:"
}], "Text"],

Cell[BoxData[
    \(\(Q = {{16, 11, 10, 16, 24, 40, 51, 61}, \n
        \t\ \ \ \ \ \t{12, 12, 14, 19, 26, 58, 60, 55}, \n
        \t\t\ \ \ \ \ {14, 13, 16, 24, 40, 57, 69, 56}, \n
        \t\t\ \ \ \ \ {14, 17, 22, 29, 51, 87, 80, 62}, \n
        \t\t\ \ \ \ \ {18, 22, 37, 56, 68, 109, 103, 77}, \n
        \t\t\ \ \ \ \ {24, 35, 55, 64, 81, 104, 113, 92}, \n
        \t\t\ \ \ \ \ {49, 64, 78, 87, 103, 121, 120, 101}, \n
        \t\t\ \ \ \ \ {72, 92, 95, 98, 112, 100, 103, 99}}; \)\)], "Input",
  CellLabel->"In[17]:="],

Cell[TextData[
"Here is the result of scaling \[ScriptCapitalC] with the quantization mask \
Q. "], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[Round[\[ScriptCapitalC]/Q]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(-45\), \(-5\), \(-5\), \(-3\), \(-1\), \(-1\), "0", "0"},
            {"1", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The scaling factors may be changed according to a quality factor ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " with values ",
  Cell[BoxData[
      \(TraditionalForm\`q = 1\/2, \ 1, \ 2, \ 4\)]],
  ". A factor of ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " results in images practically indistiguishable from the original. As the \
factor increases, the distortion in the compressed image increases. A zig-zag \
ordering of the coefficient values in the quantized block yields the \
following list:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ ZigZagOrder[\ Round[\[ScriptCapitalC]/Q]\ ]\)\)], "Input"],

Cell[BoxData[
    \({\(-45\), \(-5\), 1, 0, 0, \(-5\), \(-3\), 0, 0, 0, 0, 0, 0, 0, \(-1\), 
      \(-1\), "EOB"}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ENTROPY CODING", "Section"],

Cell[TextData[{
  "The last processing step in JPEG is an entropy coder [reference or give a \
short overview]. This step improves overall compression by performing \
lossless coding of the quantized DCT coeffcients. The entropy coder is not a \
straightforward implementation of a Huffman or arithmetic coding method. \
First, the ",
  StyleBox["DC",
    FontSlant->"Italic"],
  " and ",
  StyleBox["AC",
    FontSlant->"Italic"],
  " coefficients are separated. The DC coefficient is the zero frequency \
coefficient, or ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC][1, 1]\)]],
  " (note that this is simply the average value of all the pixels in the \
block), while the AC coefficients are all the remaining coefficients within \
the block. Due to the correlation of DC values among adjacent blocks, JPEG \
uses differential coding of the coefficients. The AC coefficients are \
pre-processed by using a run-length coder. Finally, in the JPEG baseline \
algorithm, the differential DC values and the run-length pairs are Huffman \
coded, typically using Huffman tables that are defined as part of the \
standard (custom coding tables may also be used)."
}], "Text"],

Cell["Coding of DC coefficients", "Subsection"],

Cell["\<\
We first turn our attention to the DC coefficients. Note that they have \
relatively large values, but neighboring blocks are highly correlated because \
of their spatial proximity. It is reasonable to expect that average values of \
neighboring blocks are similar. For this reason, the approach used in JPEG is \
to use differential coding.\
\>", "Text"],

Cell["\<\
Here we apply the scaling factors to every DCT block in image A.\
\>", "Caption"],

Cell[BoxData[
    \(\(\[ScriptCapitalA]\_Q = 
      BlockProcessing[Round[#/Q]\ &\ , \ \[ScriptCapitalA], \ {8, 8}]; \)\)], 
  "Input",
  CellLabel->"In[18]:="],

Cell["\<\
 Here we obtain the AC, DC coefficients and the DC differentials.\
\>", "Caption"],

Cell[BoxData[
    \(tmp = 
      ZigZagOrder\ /@\ Flatten[Partition[\[ScriptCapitalA]\_Q, \ {8, 8}], 1]; 
    \nac = Rest\ /@\ tmp; \ndc = First\ /@\ tmp; \n
    dif = Join[{First[dc]}, \ Drop[RotateLeft[dc] - dc, \ \(-1\)]]; \)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListPlot[#, \ PlotRange -> All, \ DisplayFunction -> Identity]\ &
            \)\ /@\ {dc, \ dif}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.393469 0.00511829 [
[.20682 .38097 -6 -9 ]
[.20682 .38097 6 0 ]
[.39356 .38097 -9 -9 ]
[.39356 .38097 9 0 ]
[.5803 .38097 -9 -9 ]
[.5803 .38097 9 0 ]
[.76704 .38097 -9 -9 ]
[.76704 .38097 9 0 ]
[.95378 .38097 -9 -9 ]
[.95378 .38097 9 0 ]
[.00757 .08637 -18 -4.5 ]
[.00757 .08637 0 4.5 ]
[.00757 .18874 -18 -4.5 ]
[.00757 .18874 0 4.5 ]
[.00757 .2911 -18 -4.5 ]
[.00757 .2911 0 4.5 ]
[.00757 .49583 -12 -4.5 ]
[.00757 .49583 0 4.5 ]
[.00757 .5982 -12 -4.5 ]
[.00757 .5982 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20682 .39347 m
.20682 .39972 L
s
[(50)] .20682 .38097 0 1 Mshowa
.39356 .39347 m
.39356 .39972 L
s
[(100)] .39356 .38097 0 1 Mshowa
.5803 .39347 m
.5803 .39972 L
s
[(150)] .5803 .38097 0 1 Mshowa
.76704 .39347 m
.76704 .39972 L
s
[(200)] .76704 .38097 0 1 Mshowa
.95378 .39347 m
.95378 .39972 L
s
[(250)] .95378 .38097 0 1 Mshowa
.125 Mabswid
.05742 .39347 m
.05742 .39722 L
s
.09477 .39347 m
.09477 .39722 L
s
.13212 .39347 m
.13212 .39722 L
s
.16947 .39347 m
.16947 .39722 L
s
.24416 .39347 m
.24416 .39722 L
s
.28151 .39347 m
.28151 .39722 L
s
.31886 .39347 m
.31886 .39722 L
s
.35621 .39347 m
.35621 .39722 L
s
.43091 .39347 m
.43091 .39722 L
s
.46825 .39347 m
.46825 .39722 L
s
.5056 .39347 m
.5056 .39722 L
s
.54295 .39347 m
.54295 .39722 L
s
.61765 .39347 m
.61765 .39722 L
s
.655 .39347 m
.655 .39722 L
s
.69234 .39347 m
.69234 .39722 L
s
.72969 .39347 m
.72969 .39722 L
s
.80439 .39347 m
.80439 .39722 L
s
.84174 .39347 m
.84174 .39722 L
s
.87908 .39347 m
.87908 .39722 L
s
.91643 .39347 m
.91643 .39722 L
s
.99113 .39347 m
.99113 .39722 L
s
.25 Mabswid
0 .39347 m
1 .39347 L
s
.02007 .08637 m
.02632 .08637 L
s
[(-60)] .00757 .08637 1 0 Mshowa
.02007 .18874 m
.02632 .18874 L
s
[(-40)] .00757 .18874 1 0 Mshowa
.02007 .2911 m
.02632 .2911 L
s
[(-20)] .00757 .2911 1 0 Mshowa
.02007 .49583 m
.02632 .49583 L
s
[(20)] .00757 .49583 1 0 Mshowa
.02007 .5982 m
.02632 .5982 L
s
[(40)] .00757 .5982 1 0 Mshowa
.125 Mabswid
.02007 .11196 m
.02382 .11196 L
s
.02007 .13755 m
.02382 .13755 L
s
.02007 .16315 m
.02382 .16315 L
s
.02007 .21433 m
.02382 .21433 L
s
.02007 .23992 m
.02382 .23992 L
s
.02007 .26551 m
.02382 .26551 L
s
.02007 .31669 m
.02382 .31669 L
s
.02007 .34229 m
.02382 .34229 L
s
.02007 .36788 m
.02382 .36788 L
s
.02007 .41906 m
.02382 .41906 L
s
.02007 .44465 m
.02382 .44465 L
s
.02007 .47024 m
.02382 .47024 L
s
.02007 .52143 m
.02382 .52143 L
s
.02007 .54702 m
.02382 .54702 L
s
.02007 .57261 m
.02382 .57261 L
s
.02007 .06078 m
.02382 .06078 L
s
.02007 .03519 m
.02382 .03519 L
s
.02007 .0096 m
.02382 .0096 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.008 w
.02381 .58796 Mdot
.02754 .60332 Mdot
.03128 .58796 Mdot
.03501 .57261 Mdot
.03875 .55725 Mdot
.04248 .5419 Mdot
.04622 .52654 Mdot
.04995 .51119 Mdot
.05369 .49583 Mdot
.05742 .47536 Mdot
.06116 .47536 Mdot
.06489 .46512 Mdot
.06863 .45489 Mdot
.07236 .46512 Mdot
.0761 .49072 Mdot
.07983 .51119 Mdot
.08357 .58796 Mdot
.0873 .58796 Mdot
.09104 .57773 Mdot
.09477 .55725 Mdot
.09851 .54702 Mdot
.10224 .52654 Mdot
.10598 .50607 Mdot
.10971 .4856 Mdot
.11345 .47024 Mdot
.11718 .46001 Mdot
.12092 .46001 Mdot
.12465 .45489 Mdot
.12838 .44977 Mdot
.13212 .44977 Mdot
.13585 .46001 Mdot
.13959 .47024 Mdot
.14332 .52143 Mdot
.14706 .50607 Mdot
.15079 .48048 Mdot
.15453 .43953 Mdot
.15826 .36788 Mdot
.162 .31158 Mdot
.16573 .24504 Mdot
.16947 .20921 Mdot
.1732 .21945 Mdot
.17694 .22457 Mdot
.18067 .29622 Mdot
.18441 .2911 Mdot
.18814 .28598 Mdot
.19188 .30646 Mdot
.19561 .33205 Mdot
.19935 .33205 Mdot
.20308 .35252 Mdot
.20682 .35764 Mdot
.21055 .3474 Mdot
.21429 .32181 Mdot
.21802 .25527 Mdot
.22176 .18874 Mdot
.22549 .15803 Mdot
.22923 .20921 Mdot
.23296 .14267 Mdot
.23669 .14267 Mdot
.24043 .21945 Mdot
.24416 .22457 Mdot
.2479 .24504 Mdot
.25163 .28087 Mdot
.25537 .30134 Mdot
.2591 .30646 Mdot
.26284 .33717 Mdot
.26657 .33717 Mdot
.27031 .30646 Mdot
.27404 .26039 Mdot
.27778 .21945 Mdot
.28151 .18362 Mdot
.28525 .15291 Mdot
.28898 .13755 Mdot
.29272 .18362 Mdot
.29645 .08125 Mdot
.30019 .23992 Mdot
.30392 .25016 Mdot
.30766 .2348 Mdot
.31139 .27575 Mdot
.31513 .28598 Mdot
.31886 .29622 Mdot
.3226 .32181 Mdot
.32633 .32693 Mdot
.33007 .30134 Mdot
.3338 .2911 Mdot
.33754 .26039 Mdot
.34127 .19897 Mdot
.345 .16826 Mdot
.34874 .12732 Mdot
.35247 .12732 Mdot
.35621 .0659 Mdot
.35994 .22457 Mdot
.36368 .23992 Mdot
.36741 .22968 Mdot
.37115 .27063 Mdot
.37488 .28087 Mdot
.37862 .28598 Mdot
.38235 .32181 Mdot
.38609 .31669 Mdot
.38982 .29622 Mdot
.39356 .27575 Mdot
.39729 .26551 Mdot
.40103 .19386 Mdot
.40476 .14267 Mdot
.4085 .09149 Mdot
.41223 .10173 Mdot
.41597 .07613 Mdot
.4197 .21433 Mdot
.42344 .2348 Mdot
.42717 .22457 Mdot
.43091 .26551 Mdot
.43464 .27063 Mdot
.43838 .27063 Mdot
.44211 .30646 Mdot
.44585 .30646 Mdot
.44958 .2911 Mdot
.45331 .25527 Mdot
.45705 .26039 Mdot
.46078 .19386 Mdot
.46452 .08125 Mdot
.46825 .05566 Mdot
.47199 .04031 Mdot
.47572 .05566 Mdot
.47946 .20409 Mdot
.48319 .2348 Mdot
.48693 .20921 Mdot
.49066 .25527 Mdot
.4944 .26039 Mdot
.49813 .26039 Mdot
.50187 .28087 Mdot
.5056 .28598 Mdot
.50934 .28598 Mdot
.51307 .2348 Mdot
.51681 .25016 Mdot
.52054 .19897 Mdot
.52428 .10173 Mdot
.52801 .01472 Mdot
.53175 .05566 Mdot
.53548 .04542 Mdot
.53922 .20921 Mdot
.54295 .2348 Mdot
.54669 .20409 Mdot
.55042 .24504 Mdot
.55415 .24504 Mdot
.55789 .24504 Mdot
.56162 .26039 Mdot
.56536 .26551 Mdot
.56909 .26551 Mdot
.57283 .21945 Mdot
.57656 .23992 Mdot
.5803 .20409 Mdot
.58403 .10684 Mdot
.58777 .05566 Mdot
.5915 .03519 Mdot
.59524 .04031 Mdot
.59897 .20409 Mdot
.60271 .22457 Mdot
.60644 .19386 Mdot
.61018 .22968 Mdot
.61391 .22968 Mdot
.61765 .22968 Mdot
.62138 .23992 Mdot
.62512 .24504 Mdot
.62885 .24504 Mdot
.63259 .19897 Mdot
.63632 .21945 Mdot
.64006 .19386 Mdot
.64379 .10173 Mdot
.64753 .09661 Mdot
.65126 .07102 Mdot
.655 .1222 Mdot
.65873 .18874 Mdot
.66246 .20921 Mdot
.6662 .1785 Mdot
.66993 .21433 Mdot
.67367 .21433 Mdot
.6774 .20921 Mdot
.68114 .21433 Mdot
.68487 .22457 Mdot
.68861 .22457 Mdot
.69234 .1785 Mdot
.69608 .20409 Mdot
.69981 .18362 Mdot
.70355 .11196 Mdot
.70728 .11196 Mdot
.71102 .10684 Mdot
.71475 .1222 Mdot
.71849 .1785 Mdot
.72222 .19386 Mdot
.72596 .16315 Mdot
.72969 .18874 Mdot
.73343 .19386 Mdot
.73716 .18874 Mdot
.7409 .19386 Mdot
.74463 .20921 Mdot
.74837 .20921 Mdot
.7521 .16315 Mdot
.75584 .18874 Mdot
.75957 .16826 Mdot
.76331 .13755 Mdot
.76704 .11708 Mdot
.77077 .12732 Mdot
.77451 .14267 Mdot
.77824 .16315 Mdot
.78198 .17338 Mdot
.78571 .14779 Mdot
.78945 .17338 Mdot
.79318 .17338 Mdot
.79692 .17338 Mdot
.80065 .18362 Mdot
.80439 .19386 Mdot
.80812 .19897 Mdot
.81186 .15803 Mdot
.81559 .1785 Mdot
.81933 .16315 Mdot
.82306 .14779 Mdot
.8268 .14267 Mdot
.83053 .13755 Mdot
.83427 .14779 Mdot
.838 .15803 Mdot
.84174 .16826 Mdot
.84547 .13755 Mdot
.84921 .16315 Mdot
.85294 .16826 Mdot
.85668 .16315 Mdot
.86041 .19897 Mdot
.86415 .20409 Mdot
.86788 .20409 Mdot
.87162 .16315 Mdot
.87535 .19386 Mdot
.87908 .18362 Mdot
.88282 .17338 Mdot
.88655 .17338 Mdot
.89029 .17338 Mdot
.89402 .16826 Mdot
.89776 .17338 Mdot
.90149 .1785 Mdot
.90523 .14779 Mdot
.90896 .1785 Mdot
.9127 .18362 Mdot
.91643 .17338 Mdot
.92017 .20921 Mdot
.9239 .22968 Mdot
.92764 .22457 Mdot
.93137 .16315 Mdot
.93511 .19897 Mdot
.93884 .19386 Mdot
.94258 .18874 Mdot
.94631 .19386 Mdot
.95005 .18874 Mdot
.95378 .17338 Mdot
.95752 .1785 Mdot
.96125 .18874 Mdot
.96499 .18362 Mdot
.96872 .21945 Mdot
.97246 .22457 Mdot
.97619 .20409 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0200747 0.00373483 0.230536 0.00981006 [
[.20682 .21804 -6 -9 ]
[.20682 .21804 6 0 ]
[.39356 .21804 -9 -9 ]
[.39356 .21804 9 0 ]
[.5803 .21804 -9 -9 ]
[.5803 .21804 9 0 ]
[.76704 .21804 -9 -9 ]
[.76704 .21804 9 0 ]
[.95378 .21804 -9 -9 ]
[.95378 .21804 9 0 ]
[.00757 .03434 -18 -4.5 ]
[.00757 .03434 0 4.5 ]
[.00757 .13244 -18 -4.5 ]
[.00757 .13244 0 4.5 ]
[.00757 .32864 -12 -4.5 ]
[.00757 .32864 0 4.5 ]
[.00757 .42674 -12 -4.5 ]
[.00757 .42674 0 4.5 ]
[.00757 .52484 -12 -4.5 ]
[.00757 .52484 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20682 .23054 m
.20682 .23679 L
s
[(50)] .20682 .21804 0 1 Mshowa
.39356 .23054 m
.39356 .23679 L
s
[(100)] .39356 .21804 0 1 Mshowa
.5803 .23054 m
.5803 .23679 L
s
[(150)] .5803 .21804 0 1 Mshowa
.76704 .23054 m
.76704 .23679 L
s
[(200)] .76704 .21804 0 1 Mshowa
.95378 .23054 m
.95378 .23679 L
s
[(250)] .95378 .21804 0 1 Mshowa
.125 Mabswid
.05742 .23054 m
.05742 .23429 L
s
.09477 .23054 m
.09477 .23429 L
s
.13212 .23054 m
.13212 .23429 L
s
.16947 .23054 m
.16947 .23429 L
s
.24416 .23054 m
.24416 .23429 L
s
.28151 .23054 m
.28151 .23429 L
s
.31886 .23054 m
.31886 .23429 L
s
.35621 .23054 m
.35621 .23429 L
s
.43091 .23054 m
.43091 .23429 L
s
.46825 .23054 m
.46825 .23429 L
s
.5056 .23054 m
.5056 .23429 L
s
.54295 .23054 m
.54295 .23429 L
s
.61765 .23054 m
.61765 .23429 L
s
.655 .23054 m
.655 .23429 L
s
.69234 .23054 m
.69234 .23429 L
s
.72969 .23054 m
.72969 .23429 L
s
.80439 .23054 m
.80439 .23429 L
s
.84174 .23054 m
.84174 .23429 L
s
.87908 .23054 m
.87908 .23429 L
s
.91643 .23054 m
.91643 .23429 L
s
.99113 .23054 m
.99113 .23429 L
s
.25 Mabswid
0 .23054 m
1 .23054 L
s
.02007 .03434 m
.02632 .03434 L
s
[(-20)] .00757 .03434 1 0 Mshowa
.02007 .13244 m
.02632 .13244 L
s
[(-10)] .00757 .13244 1 0 Mshowa
.02007 .32864 m
.02632 .32864 L
s
[(10)] .00757 .32864 1 0 Mshowa
.02007 .42674 m
.02632 .42674 L
s
[(20)] .00757 .42674 1 0 Mshowa
.02007 .52484 m
.02632 .52484 L
s
[(30)] .00757 .52484 1 0 Mshowa
.125 Mabswid
.02007 .05396 m
.02382 .05396 L
s
.02007 .07358 m
.02382 .07358 L
s
.02007 .0932 m
.02382 .0932 L
s
.02007 .11282 m
.02382 .11282 L
s
.02007 .15206 m
.02382 .15206 L
s
.02007 .17168 m
.02382 .17168 L
s
.02007 .1913 m
.02382 .1913 L
s
.02007 .21092 m
.02382 .21092 L
s
.02007 .25016 m
.02382 .25016 L
s
.02007 .26978 m
.02382 .26978 L
s
.02007 .2894 m
.02382 .2894 L
s
.02007 .30902 m
.02382 .30902 L
s
.02007 .34826 m
.02382 .34826 L
s
.02007 .36788 m
.02382 .36788 L
s
.02007 .3875 m
.02382 .3875 L
s
.02007 .40712 m
.02382 .40712 L
s
.02007 .44636 m
.02382 .44636 L
s
.02007 .46598 m
.02382 .46598 L
s
.02007 .4856 m
.02382 .4856 L
s
.02007 .50522 m
.02382 .50522 L
s
.02007 .54446 m
.02382 .54446 L
s
.02007 .56408 m
.02382 .56408 L
s
.02007 .5837 m
.02382 .5837 L
s
.02007 .60332 m
.02382 .60332 L
s
.02007 .01472 m
.02382 .01472 L
s
.25 Mabswid
.02007 0 m
.02007 .61803 L
s
.008 w
.02381 .60332 Mdot
.02754 .25997 Mdot
.03128 .20111 Mdot
.03501 .20111 Mdot
.03875 .20111 Mdot
.04248 .20111 Mdot
.04622 .20111 Mdot
.04995 .20111 Mdot
.05369 .20111 Mdot
.05742 .1913 Mdot
.06116 .23054 Mdot
.06489 .21092 Mdot
.06863 .21092 Mdot
.07236 .25016 Mdot
.0761 .27959 Mdot
.07983 .26978 Mdot
.08357 .37769 Mdot
.0873 .23054 Mdot
.09104 .21092 Mdot
.09477 .1913 Mdot
.09851 .21092 Mdot
.10224 .1913 Mdot
.10598 .1913 Mdot
.10971 .1913 Mdot
.11345 .20111 Mdot
.11718 .21092 Mdot
.12092 .23054 Mdot
.12465 .22073 Mdot
.12838 .22073 Mdot
.13212 .23054 Mdot
.13585 .25016 Mdot
.13959 .25016 Mdot
.14332 .32864 Mdot
.14706 .20111 Mdot
.15079 .18149 Mdot
.15453 .15206 Mdot
.15826 .0932 Mdot
.162 .12263 Mdot
.16573 .10301 Mdot
.16947 .16187 Mdot
.1732 .25016 Mdot
.17694 .24035 Mdot
.18067 .36788 Mdot
.18441 .22073 Mdot
.18814 .22073 Mdot
.19188 .26978 Mdot
.19561 .27959 Mdot
.19935 .23054 Mdot
.20308 .26978 Mdot
.20682 .24035 Mdot
.21055 .21092 Mdot
.21429 .18149 Mdot
.21802 .10301 Mdot
.22176 .10301 Mdot
.22549 .17168 Mdot
.22923 .32864 Mdot
.23296 .10301 Mdot
.23669 .23054 Mdot
.24043 .37769 Mdot
.24416 .24035 Mdot
.2479 .26978 Mdot
.25163 .29921 Mdot
.25537 .26978 Mdot
.2591 .24035 Mdot
.26284 .2894 Mdot
.26657 .23054 Mdot
.27031 .17168 Mdot
.27404 .14225 Mdot
.27778 .15206 Mdot
.28151 .16187 Mdot
.28525 .17168 Mdot
.28898 .20111 Mdot
.29272 .31883 Mdot
.29645 .03434 Mdot
.30019 .53465 Mdot
.30392 .25016 Mdot
.30766 .20111 Mdot
.31139 .30902 Mdot
.31513 .25016 Mdot
.31886 .25016 Mdot
.3226 .27959 Mdot
.32633 .24035 Mdot
.33007 .18149 Mdot
.3338 .21092 Mdot
.33754 .17168 Mdot
.34127 .11282 Mdot
.345 .17168 Mdot
.34874 .15206 Mdot
.35247 .23054 Mdot
.35621 .11282 Mdot
.35994 .53465 Mdot
.36368 .25997 Mdot
.36741 .21092 Mdot
.37115 .30902 Mdot
.37488 .25016 Mdot
.37862 .24035 Mdot
.38235 .29921 Mdot
.38609 .22073 Mdot
.38982 .1913 Mdot
.39356 .1913 Mdot
.39729 .21092 Mdot
.40103 .0932 Mdot
.40476 .13244 Mdot
.4085 .13244 Mdot
.41223 .25016 Mdot
.41597 .18149 Mdot
.4197 .49541 Mdot
.42344 .26978 Mdot
.42717 .21092 Mdot
.43091 .30902 Mdot
.43464 .24035 Mdot
.43838 .23054 Mdot
.44211 .29921 Mdot
.44585 .23054 Mdot
.44958 .20111 Mdot
.45331 .16187 Mdot
.45705 .24035 Mdot
.46078 .10301 Mdot
.46452 .01472 Mdot
.46825 .18149 Mdot
.47199 .20111 Mdot
.47572 .25997 Mdot
.47946 .51503 Mdot
.48319 .2894 Mdot
.48693 .18149 Mdot
.49066 .31883 Mdot
.4944 .24035 Mdot
.49813 .23054 Mdot
.50187 .26978 Mdot
.5056 .24035 Mdot
.50934 .23054 Mdot
.51307 .13244 Mdot
.51681 .25997 Mdot
.52054 .13244 Mdot
.52428 .04415 Mdot
.52801 .06377 Mdot
.53175 .30902 Mdot
.53548 .21092 Mdot
.53922 .54446 Mdot
.54295 .27959 Mdot
.54669 .17168 Mdot
.55042 .30902 Mdot
.55415 .23054 Mdot
.55789 .23054 Mdot
.56162 .25997 Mdot
.56536 .24035 Mdot
.56909 .23054 Mdot
.57283 .14225 Mdot
.57656 .26978 Mdot
.5803 .16187 Mdot
.58403 .04415 Mdot
.58777 .13244 Mdot
.5915 .1913 Mdot
.59524 .24035 Mdot
.59897 .54446 Mdot
.60271 .26978 Mdot
.60644 .17168 Mdot
.61018 .29921 Mdot
.61391 .23054 Mdot
.61765 .23054 Mdot
.62138 .25016 Mdot
.62512 .24035 Mdot
.62885 .23054 Mdot
.63259 .14225 Mdot
.63632 .26978 Mdot
.64006 .18149 Mdot
.64379 .05396 Mdot
.64753 .22073 Mdot
.65126 .18149 Mdot
.655 .32864 Mdot
.65873 .35807 Mdot
.66246 .26978 Mdot
.6662 .17168 Mdot
.66993 .29921 Mdot
.67367 .23054 Mdot
.6774 .22073 Mdot
.68114 .24035 Mdot
.68487 .25016 Mdot
.68861 .23054 Mdot
.69234 .14225 Mdot
.69608 .27959 Mdot
.69981 .1913 Mdot
.70355 .0932 Mdot
.70728 .23054 Mdot
.71102 .22073 Mdot
.71475 .25997 Mdot
.71849 .33845 Mdot
.72222 .25997 Mdot
.72596 .17168 Mdot
.72969 .27959 Mdot
.73343 .24035 Mdot
.73716 .22073 Mdot
.7409 .24035 Mdot
.74463 .25997 Mdot
.74837 .23054 Mdot
.7521 .14225 Mdot
.75584 .27959 Mdot
.75957 .1913 Mdot
.76331 .17168 Mdot
.76704 .1913 Mdot
.77077 .25016 Mdot
.77451 .25997 Mdot
.77824 .26978 Mdot
.78198 .25016 Mdot
.78571 .18149 Mdot
.78945 .27959 Mdot
.79318 .23054 Mdot
.79692 .23054 Mdot
.80065 .25016 Mdot
.80439 .25016 Mdot
.80812 .24035 Mdot
.81186 .15206 Mdot
.81559 .26978 Mdot
.81933 .20111 Mdot
.82306 .20111 Mdot
.8268 .22073 Mdot
.83053 .22073 Mdot
.83427 .25016 Mdot
.838 .25016 Mdot
.84174 .25016 Mdot
.84547 .17168 Mdot
.84921 .27959 Mdot
.85294 .24035 Mdot
.85668 .22073 Mdot
.86041 .29921 Mdot
.86415 .24035 Mdot
.86788 .23054 Mdot
.87162 .15206 Mdot
.87535 .2894 Mdot
.87908 .21092 Mdot
.88282 .21092 Mdot
.88655 .23054 Mdot
.89029 .23054 Mdot
.89402 .22073 Mdot
.89776 .24035 Mdot
.90149 .24035 Mdot
.90523 .17168 Mdot
.90896 .2894 Mdot
.9127 .24035 Mdot
.91643 .21092 Mdot
.92017 .29921 Mdot
.9239 .26978 Mdot
.92764 .22073 Mdot
.93137 .11282 Mdot
.93511 .29921 Mdot
.93884 .22073 Mdot
.94258 .22073 Mdot
.94631 .24035 Mdot
.95005 .22073 Mdot
.95378 .20111 Mdot
.95752 .24035 Mdot
.96125 .25016 Mdot
.96499 .22073 Mdot
.96872 .29921 Mdot
.97246 .24035 Mdot
.97619 .1913 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 84.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000E1000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo000Kool00`00ooooo`3oool3
ool001_oo`03003ooooo0?ooo`?oo`006ooo00<00?ooool0=?oo00<00?ooool0E?oo00<00?ooool0
M?oo000Kool00`00ooooo`2;ool00`00ooooo`0]ool00`00ooooo`14ool001_oo`03003ooooo02ko
o`03003ooooo00[oo`03003ooooo043oo`@000?oo`8000Coo`03003ooooo07Coo`006ooo00<00?oo
ool0=Ooo00<00?ooool0A_oo00<00?ooool00ooo00@00?ooool000?oo`03003ooooo01_oo`03003o
oooo05Koo`006ooo00<00?ooool0;Ooo0P001Ooo00<00?ooool00ooo00<00?ooool0@_oo00<00?oo
ool00_oo00@00?ooool000?oo`03003ooooo03?oo`03003ooooo00Coo`03003ooooo03Ooo`006ooo
00<00?ooool08Ooo00<00?ooool0E?oo10001?oo00D00?ooooooo`0000;oo`05003oooooool00012
ool00`00ooooo`0aool000ooo`8000Coo`8000Coo`03003ooooo02Soo`03003ooooo01Koo`03003o
oooo03goo`04003ooooo0002ool01@00oooooooo0000=_oo00<00?ooool0?Ooo000>ool01000oooo
o`000_oo00@00?ooool000?oo`03003ooooo01_oo`03003ooooo00ooo`03003ooooo04koo`04003o
oooo0002ool01000ooooo`000ooo00<00?ooool0M?oo000>ool01000ooooo`000_oo00@00?ooool0
00?oo`03003ooooo02Ooo`03003ooooo01Ooo`03003ooooo03_oo`8000Coo`8000Coo`03003ooooo
07Coo`002?oo10000_oo0`000ooo00@00?ooool000?oo`03003ooooo02Ooo`03003ooooo00Woo`03
003ooooo00[oo`03003ooooo04Soo`03003ooooo07Coo`003_oo00<00?ooool00ooo00@00?ooool0
00?oo`03003ooooo03[oo`03003ooooo00[oo`03003ooooo047oo`03003ooooo00coo`03003ooooo
01Ooo`03003ooooo01koo`03003ooooo02[oo`003_oo00<00?ooool00ooo00@00?ooool000?oo`03
003ooooo047oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo03_oo`03003ooooo00goo`03
003ooooo00;oo`<001Ooo`03003ooooo04Goo`003ooo0`000ooo0P001?oo00<00?ooool08?oo0P00
;?oo00<00?ooool0>_oo00<00?ooool08?oo0P00?Ooo00<00?ooool04_oo000Kool00`00ooooo`0D
ool00`00ooooo`03ool00`00ooooo`09ool00`00ooooo`0Tool20005ool00`00ool0000Wool40003
ool20004ool00`00ooooo`0<ool00`00ooooo`1Uool001_oo`03003ooooo04ooo`03003ooooo00;o
o`8000Koo`03003ooooo027oo`05003oooooool00002ool01@00oooooooo0000:?oo0P002_oo0P00
1_oo00<00?ooool0=ooo000Kool00`00ooooo`0Cool00`00ooooo`04ool00`00ooooo`0eool01000
ooooo`00:_oo00D00?ooooooo`0000;oo`05003oooooool0000Jool00`00ooooo`0Nool00`00oooo
o`03ool00`00ooooo`03ool00`00ooooo`04ool00`00ooooo`0Uool001_oo`03003ooooo023oo`03
003ooooo02Koo`03003ooooo00800003ool00?oo00;oo`03003ooooo00800004ool00?oo0003ool0
0`00ooooo`0Fool40004ool01@00oooooooo00000_oo00D00?ooooooo`0000goo`03003ooooo00_o
o`03003ooooo00Coo`03003ooooo02ooo`03003ooooo00Coo`03003ooooo01Soo`004?oo00<00?oo
ool00_oo0P001?oo00<00?ooool0@ooo00<00?oo00000_oo00<00?ooool01?oo0`0000?oo`00ool0
1Ooo1@000ooo00<00?ooool06ooo00D00?ooooooo`0000;oo`05003oooooool0000?ool00`00oooo
o`09ool00`00ooooo`0@ool00`00ooooo`0:ool00`00ooooo`0hool0013oo`05003oooooool00002
ool01@00oooooooo00005Ooo00<00?ooool00ooo0P009ooo00D00?ooooooo`0000;oo`800003ool0
0?oo00?oo`03003ooooo00Koo`04003ooooo0002ool4000Jool30003ool01000ooooo`000ooo00<0
0?ooool03?oo0`001?oo0P000ooo00<00?oo00000_oo10000ooo0P001?oo0P001Ooo100000?oo`00
00000P000_oo00@00?oo000000?oo`03003oo`0000@000;oo`8000Coo`8000;oo`04003oooooool4
0002ool30004ool2000;ool000goo`D000;oo`04003ooooo0003ool00`00ooooo`0Pool00`00oooo
o`03ool00`00ooooo`03ool00`00ooooo`04ool00`00ooooo`06ool00`00ooooo`020008ool30006
ool00`00ooooo`03ool20006ool2000Nool00`00ooooo`02ool20004ool00`00ooooo`0;ool01@00
oooooooo00000_oo00@00?ooool000Soo`8000?oo`05003ooooo003oo`020002ool200000ooo003o
o`02ool00`00ooooo`04ool01000ooooo`000_oo0P000ooo00<00?ooool00ooo00<00?ooool00P00
00Goo`00ooooo`0000Goo`03003ooooo00Koo`04003ooooo0002ool00`00ooooo`08ool000Soo`@0
0005ool00?ooool00003ool01000ooooo`000ooo00<00?ooool0;_oo00<00?ooool01Ooo00H00?oo
ool00?oo000:ool00`00ooooo`0?ool00`00ooooo`09ool00`00ooooo`0Tool01@00oooooooo0000
0ooo0`001ooo00@00?ooool000;oo`03003ooooo00Ooo`06003oooooool00?oo0P000_oo00@00?oo
ool000Koo`03003ooooo00Coo`800005ool00?ooool00005ool00`00ooooo`02ool01000ool00000
0_oo00@00?ooool000Koo`03003ooooo00Goo`800005ool00?ooool0000:ool000koo`03003oo`00
00?oo`04003ooooo0003ool00`00ooooo`0=ool00`00ooooo`03ool00`00ooooo`0Bool00`00oooo
o`04ool00`00ooooo`03ool00`00ooooo`0:ool30006ool00`00ooooo`0@ool00`00ooooo`0Zool5
0005ool01000oooooooo10000ooo00@00?ooool000Coo`03003oo`0000;oo`05003oooooool00002
ool01@00ooooo`00ool00P0000?oo`00ool00ooo00@00?ooooooo`<000?oo`04003ooooo0006ool0
1@00oooooooo00000_oo00D00?ooool00?oo008000Ooo`04003oooooool30003ool01000ooooo`00
2_oo000?ool20003ool01000ooooo`000ooo00<00?ooool03Ooo0P001_oo00D00?ooooooo`0000So
o`03003ooooo00Coo`03003ooooo00goo`04003ooooo0002ool00`00ooooo`03ool00`00ooooo`0G
ool01000oooooooo0P009_oo00<00?ooool00_oo00H00?ooool00?oo0004ool00`00ooooo`02ool2
0002ool00`00ooooo`07ool00`00ooooo`020002ool01000ooooo`000_oo00<00?ooool01?oo00D0
0?oo003oo`0000Goo`04003ooooo0007ool01000ooooo`000_oo00@00?ooool000;oo`03003ooooo
00?oo`03003ooooo00800003ool00?oo00Coo`04003ooooo000:ool0013oo`03003ooooo00;oo`80
00Coo`03003ooooo01coo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00Coo`04003ooooo
0002ool00`00ooooo`05ool00`00ooooo`0Nool00`00ooooo`0Zool00`00ooooo`08ool20002ool0
1000ooooo`000_oo00@00?ooool000Ooo`<000?oo`800005ool00?ooool00002ool00`00ooooo`02
ool30003ool00`00ooooo`03ool00`00ooooo`020002ool200001?oo00000?oo0P000_oo00@00?oo
ool000;oo`04003ooooo0002ool200000ooo003oo`0300001Ooo003ooooo00000_oo00<00?ooool0
2?oo000Kool00`00ooooo`0=ool00`00ooooo`05ool00`00ooooo`03ool00`00ooooo`04ool00`00
ooooo`0Aool200000ooo003oo`03ool2001;ool01@00oooooooo00000_oo00@00?ooooooo`8000;o
o`D000;oo`8000?oo`03003ooooo00Coo`03003oo`0000;oo`8000Coo`8000Coo`04003oo`000003
ool40002ool30003ool00`00ool000020003ool30002ool40004ool00`00ool000020003ool40003
ool2000;ool001_oo`03003ooooo01coo`03003ooooo01?oo`03003ooooo05Coof`000goo`006ooo
00<00?ooool04_oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool02_oo00D00?ooooooo`00
00Koo`03003ooooo057oo`03003ooooo00koo`04003ooooo0003ool00`00ool00006ool00`00oooo
o`03ool00`00ooooo`03ool00`00ool00003ool20006ool01000ooooo`000_oo00<00?ooool00ooo
00<00?ooool00ooo0P001_oo00<00?ooool00_oo0P000ooo0P000ooo0P0000?oo`00ool03_oo000K
ool00`00ooooo`0Sool01000ooooo`000_oo0P003Ooo00<00?ooool0D?oo00<00?ooool00ooo00<0
0?ooool00ooo0P000_oo00<00?ooool03?oo0P001Ooo00D00?ooooooo`0001Koo`03003ooooo00Co
o`03003ooooo00Koo`800003ool0000000;oo`8000_oo`03003ooooo00ooo`003_oo10000ooo0P00
1?oo00<00?ooool05_oo00<00?ooool00ooo00<00?ooool01?oo00<00?oo00002ooo00<00?ooool0
Eooo0P008ooo00<00?ooool02Ooo00D00?ooooooo`0000Coo`03003ooooo00koo`800005ool00?oo
ool0000Uool000koo`03003ooooo00?oo`04003ooooo0003ool00`00ooooo`0?ool00`00ooooo`0;
ool00`00ool00004ool00`00ooooo`04ool00`00ooooo`03ool2001Hool00`00ooooo`03ool00`00
ooooo`09ool00`00ool00003ool2000Aool00`00ooooo`06ool00`00ooooo`05ool01000ooooo`00
0_oo00@00?ooool000coo`05003oooooool0000:ool00`00ooooo`0Cool000ooo`03003ooooo00;o
o`04003ooooo0003ool00`00ooooo`0>ool00`00ooooo`0<ool00`00ooooo`05ool00`00ooooo`1S
ool00`00ooooo`03ool00`00ooooo`0:ool00`00ooooo`0;ool00`00ooooo`0Dool00`00ooooo`0>
ool01000ooooo`000_oo00D00?ooooooo`0000Goo`03003ooooo01_oo`002?oo10001?oo00D00?oo
ooooo`0000;oo`05003oooooool0000Aool00`00ooooo`04ool30005ool00`00ooooo`09ool2001O
ool00`00ooooo`0Gool00`00ooooo`0Eool00`00ooooo`0Wool01@00oooooooo00005_oo000Aool0
1000ooooo`000_oo00D00?ooooooo`0000koo`03003ooooo01Goo`03003ooooo06Coo`03003ooooo
01Koo`03003ooooo00_oo`03003ooooo00?oo`03003ooooo013oo`03003ooooo00?oo`03003ooooo
01;oo`03003ooooo00?oo`03003oo`0000;oo`03003ooooo00koo`003_oo00@00?ooool000;oo`04
003ooooo0003ool00`00ooooo`0Bool00`00ooooo`09ool00`00ooooo`03ool00`00ooooo`1Tool0
0`00ooooo`0Lool00`00ooooo`04ool00`00ooooo`03ool00`00ooooo`08ool00`00ool0000mool0
00ooo`8000Coo`8000Coo`03003ooooo00coo`<00004ool00?ooool20002ool20004ool40003ool2
0004ool20005ool40002ool30004ool20005ool40003ool20004ool20006ool40002ool30004ool2
000Eool40003ool20004ool00`00ooooo`0Jool00`00ooooo`0Cool00`00ooooo`11ool001_oo`03
003ooooo00ooo`04003oo`000002ool00`00ooooo`07ool01@00oooooooo00000_oo00@00?ooool0
00;oo`03003ooooo00Coo`03003ooooo00Coo`04003ooooo0002ool00`00ooooo`02ool00`00oooo
o`03ool01000ooooo`000_oo00@00?ooool000Goo`03003ooooo00Koo`04003ooooo0002ool00`00
ooooo`0Dool01@00oooooooo00000_oo00D00?ooooooo`0000coo`03003ooooo00Koo`03003ooooo
02_oo`03003ooooo033oo`006ooo00<00?ooool03ooo00@00?oo000000;oo`03003ooooo00Ooo`05
003oooooool00002ool01000ooooo`000_oo00<00?ooool01?oo00<00?ooool01?oo00@00?ooool0
00;oo`03003ooooo00?oo`03003ooooo00;oo`04003ooooo0002ool01000ooooo`001_oo00<00?oo
ool01Ooo00@00?ooool000;oo`03003ooooo01Coo`05003oooooool00002ool01@00oooooooo0000
B_oo00<00?ooool0:Ooo000Kool00`00ooooo`0<ool30002ool20002ool00`00ooooo`07ool01@00
oooooooo00000_oo00@00?ooool000;oo`03003ooooo00Coo`04003oooooool30003ool01000oooo
o`001_oo00D00?ooooooo`0000;oo`04003ooooo0002ool00`00ooooo`05ool01000oooooooo0`00
0ooo00@00?ooool001Koo`05003oooooool00002ool01@00oooooooo0000M_oo000Kool00`00oooo
o`0<ool00`00ooooo`03ool01000ooooo`002Ooo00D00?ooooooo`0000;oo`04003ooooo0002ool0
0`00ooooo`04ool01@00oooooooo00001Ooo00@00?ooool000Ooo`04003ooooo0002ool01000oooo
o`000_oo00<00?ooool01_oo00@00?ooool000Goo`04003ooooo000Fool01@00oooooooo00000_oo
00D00?ooooooo`0004Coo`03003ooooo02ooo`006ooo00<00?ooool03?oo00<00?ooool00ooo00@0
0?ooool000Ooo`<000?oo`04003ooooo0002ool01000ooooo`001?oo0`000ooo00<00?ooool00ooo
00@00?ooool000Coo`04003ooooo0002ool01000ooooo`000_oo00@00?ooool000Goo`04003ooooo
0002ool00`00ooooo`03ool01000ooooo`005?oo0`000ooo00@00?ooool000?oo`03003ooooo00ko
o`03003ooooo06?oo`006ooo00<00?ooool03?oo10000ooo0P002_oo00<00?ooool00_oo0P001?oo
0P001ooo00@00?ooooooo`@000?oo`8000Koo`8000Coo`8000Coo`8000Ooo`8000?oo`@000?oo`80
01Ooo`03003ooooo00;oo`8000Coo`03003ooooo00Coo`03003ooooo00koo`03003ooooo05coo`00
6OooK0009?oo00<00?ooool0M?oo000Kool00`00ooooo`2;ool00`00ooooo`1dool001_oo`03003o
oooo08_oo`03003ooooo07Coo`006ooo00<00?ooool0O_oo10000ooo0P001?oo00<00?ooool0M?oo
000Kool00`00ooooo`0;ool00`00ooooo`1`ool00`00ooooo`03ool01000ooooo`000ooo00<00?oo
ool0M?oo000Kool00`00ooooo`1oool00`00ooooo`02ool01000ooooo`000ooo00<00?ooool0M?oo
000Kool00`00ooooo`02ool00`00ooooo`03ool2001fool01@00oooooooo00000_oo00D00?oooooo
o`0007Koo`006ooo00<00?ooool00_oo0P000ooo0`00Mooo00@00?ooool000;oo`05003oooooool0
001fool001_oo`05003oooooool00005ool01000ooooo`00Looo00@00?ooool000;oo`04003ooooo
0003ool00`00ooooo`1dool000koo`@000?oo`8000Coo`03003ooooo00Ooo`05003oooooool0001c
ool20004ool20004ool00`00ooooo`1dool000koo`03003ooooo00?oo`04003ooooo0003ool01`00
oooooooo003oo`0008Ooo`03003ooooo07Coo`003ooo00<00?ooool00_oo00@00?ooool000?oo`03
003ooooo08_oo`03003ooooo07Coo`004?oo00D00?ooooooo`0000;oo`05003oooooool00002ool0
1000ooooo`000_oo00<00?ooool00_oo00<00?ooool0OOoo00<00?ooool0:?oo00<00?ooool0BOoo
000Aool01000ooooo`000_oo00D00?ooooooo`0000coo`03003ooooo07koo`03003ooooo07Coo`00
3_oo00@00?ooool000;oo`04003ooooo0003ool01000ooooo`001Ooo00<00?ooool0M_oo0P001?oo
0P001?oo00<00?ooool0;_oo00<00?ooool0@ooo000?ool20004ool20004ool00`00ool0001nool0
1000ooooo`000_oo00@00?ooool000?oo`03003ooooo07Coo`006ooo00<00?ooool01Ooo00<00?oo
ool0NOoo00@00?ooool000;oo`05003oooooool0000Mool00`00ooooo`04ool00`00ooooo`1?ool0
01_oo`03003oo`0000Goo`03003ooooo07Ooo`8000?oo`04003ooooo0003ool00`00ooooo`0eool0
0`00ooooo`03ool00`00ooooo`0fool001_oo`03003ooooo087oo`04003ooooo0002ool01@00oooo
oooo0000M_oo000Kool00`00ool00005ool00`00ooooo`1fool01000ooooo`000_oo00@00?ooool0
00?oo`03003ooooo07Coo`004?oo00<00?ooool00_oo0P001?oo0P001Ooo00<00?ooool0N?oo0P00
1?oo0P001?oo00<00?ooool0M?oo000@ool01@00oooooooo00000_oo00D00?ooooooo`0008goo`03
003ooooo07Coo`003Ooo1@000_oo00@00?ooool000?oo`8008coo`03003ooooo07Coo`003Ooo00@0
0?ooool000?oo`04003ooooo0003ool00`00ooooo`2;ool00`00ooooo`1dool000koo`03003oo`00
00?oo`04003ooooo0003ool00`00ooooo`2;ool00`00ooooo`1dool000ooo`8000?oo`04003ooooo
002Aool00`00ooooo`1dool0013oo`03003ooooo00;oo`800?ooo`[oo`00oooo8Ooo003ooolQool0
0?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {83.75, 0}} -> {-0.0589635, -0.0147182, 
  0.00737954, 0.00737954}, {{7.9375, 137}, {81.75, 
  1.9375}} -> {-67.7341, -90.2687, 2.4823, 1.81134}, {{149.938, 279}, {81.75, 
  1.9375}} -> {-420.221, -31.9797, 2.4823, 0.945048}}]
}, Open  ]],

Cell["\<\
Here we compute the probability distribution of the differences of the DC \
coefficients.\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h = Histogram[dif, \ SignalRange[dif]]; \n
    ListPlot[Thread[{Range@@SignalRange[dif], \ h}], \ PlotJoined -> True, \ 
      PlotRange -> All]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.362793 0.0161421 0.0147151 0.0235442 [
[.03995 .00222 -9 -9 ]
[.03995 .00222 9 0 ]
[.20137 .00222 -9 -9 ]
[.20137 .00222 9 0 ]
[.52421 .00222 -6 -9 ]
[.52421 .00222 6 0 ]
[.68563 .00222 -6 -9 ]
[.68563 .00222 6 0 ]
[.84705 .00222 -6 -9 ]
[.84705 .00222 6 0 ]
[.35029 .13244 -6 -4.5 ]
[.35029 .13244 0 4.5 ]
[.35029 .25016 -12 -4.5 ]
[.35029 .25016 0 4.5 ]
[.35029 .36788 -12 -4.5 ]
[.35029 .36788 0 4.5 ]
[.35029 .4856 -12 -4.5 ]
[.35029 .4856 0 4.5 ]
[.35029 .60332 -12 -4.5 ]
[.35029 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03995 .01472 m
.03995 .02097 L
s
[(-20)] .03995 .00222 0 1 Mshowa
.20137 .01472 m
.20137 .02097 L
s
[(-10)] .20137 .00222 0 1 Mshowa
.52421 .01472 m
.52421 .02097 L
s
[(10)] .52421 .00222 0 1 Mshowa
.68563 .01472 m
.68563 .02097 L
s
[(20)] .68563 .00222 0 1 Mshowa
.84705 .01472 m
.84705 .02097 L
s
[(30)] .84705 .00222 0 1 Mshowa
.125 Mabswid
.07224 .01472 m
.07224 .01847 L
s
.10452 .01472 m
.10452 .01847 L
s
.1368 .01472 m
.1368 .01847 L
s
.16909 .01472 m
.16909 .01847 L
s
.23366 .01472 m
.23366 .01847 L
s
.26594 .01472 m
.26594 .01847 L
s
.29822 .01472 m
.29822 .01847 L
s
.33051 .01472 m
.33051 .01847 L
s
.39508 .01472 m
.39508 .01847 L
s
.42736 .01472 m
.42736 .01847 L
s
.45964 .01472 m
.45964 .01847 L
s
.49193 .01472 m
.49193 .01847 L
s
.5565 .01472 m
.5565 .01847 L
s
.58878 .01472 m
.58878 .01847 L
s
.62107 .01472 m
.62107 .01847 L
s
.65335 .01472 m
.65335 .01847 L
s
.71792 .01472 m
.71792 .01847 L
s
.7502 .01472 m
.7502 .01847 L
s
.78249 .01472 m
.78249 .01847 L
s
.81477 .01472 m
.81477 .01847 L
s
.00767 .01472 m
.00767 .01847 L
s
.87934 .01472 m
.87934 .01847 L
s
.91162 .01472 m
.91162 .01847 L
s
.94391 .01472 m
.94391 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.36279 .13244 m
.36904 .13244 L
s
[(5)] .35029 .13244 1 0 Mshowa
.36279 .25016 m
.36904 .25016 L
s
[(10)] .35029 .25016 1 0 Mshowa
.36279 .36788 m
.36904 .36788 L
s
[(15)] .35029 .36788 1 0 Mshowa
.36279 .4856 m
.36904 .4856 L
s
[(20)] .35029 .4856 1 0 Mshowa
.36279 .60332 m
.36904 .60332 L
s
[(25)] .35029 .60332 1 0 Mshowa
.125 Mabswid
.36279 .03826 m
.36654 .03826 L
s
.36279 .0618 m
.36654 .0618 L
s
.36279 .08535 m
.36654 .08535 L
s
.36279 .10889 m
.36654 .10889 L
s
.36279 .15598 m
.36654 .15598 L
s
.36279 .17952 m
.36654 .17952 L
s
.36279 .20307 m
.36654 .20307 L
s
.36279 .22661 m
.36654 .22661 L
s
.36279 .2737 m
.36654 .2737 L
s
.36279 .29724 m
.36654 .29724 L
s
.36279 .32079 m
.36654 .32079 L
s
.36279 .34433 m
.36654 .34433 L
s
.36279 .39142 m
.36654 .39142 L
s
.36279 .41497 m
.36654 .41497 L
s
.36279 .43851 m
.36654 .43851 L
s
.36279 .46205 m
.36654 .46205 L
s
.36279 .50914 m
.36654 .50914 L
s
.36279 .53269 m
.36654 .53269 L
s
.36279 .55623 m
.36654 .55623 L
s
.36279 .57977 m
.36654 .57977 L
s
.25 Mabswid
.36279 0 m
.36279 .61803 L
s
.5 Mabswid
.02381 .03826 m
.03995 .03826 L
.05609 .03826 L
.07224 .08535 L
.08838 .01472 L
.10452 .01472 L
.12066 .01472 L
.1368 .03826 L
.15295 .15598 L
.16909 .08535 L
.18523 .08535 L
.20137 .0618 L
.21751 .17952 L
.23366 .10889 L
.2498 .22661 L
.26594 .22661 L
.28208 .20307 L
.29822 .29724 L
.31437 .36788 L
.33051 .36788 L
.34665 .4856 L
.36279 .57977 L
.37893 .60332 L
.39508 .53269 L
.41122 .20307 L
.42736 .2737 L
.4435 .25016 L
.45964 .13244 L
.47579 .25016 L
.49193 .10889 L
.50807 .10889 L
.52421 .0618 L
.54036 .01472 L
.5565 .01472 L
.57264 .03826 L
.58878 .01472 L
.60492 .08535 L
.62107 .01472 L
.63721 .01472 L
.65335 .01472 L
.66949 .01472 L
.68563 .01472 L
.70178 .01472 L
.71792 .01472 L
.73406 .01472 L
.7502 .01472 L
.76634 .01472 L
.78249 .03826 L
.79863 .01472 L
.81477 .01472 L
Mistroke
.83091 .01472 L
.84705 .0618 L
.8632 .03826 L
.87934 .0618 L
.89548 .01472 L
.91162 .01472 L
.92776 .01472 L
.94391 .01472 L
.96005 .01472 L
.97619 .03826 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000@Ool3
0003Ool00`00Oomoo`0ROol50002Ool00`00Oomoo`1<Ool50002Ool00`00Oomoo`0ROol30003Ool0
0`00Oomoo`0SOol20004Ool00`00Oomoo`0^Ool0011oo`03001oogoo009oo`03001oo`0002Eoo`07
001oogooOol007oo0000Cgoo00L007ooOomoo`00Ool0000SOol00`00Oomoo`02Ool00`00Ool0000V
Ool01P00Oomoo`00Ool002moo`002goo0`000goo00L007ooOomoo`00Ool0000OOol30003Ool01`00
Oomoogoo001oo`0004moo`07001oogooOol007oo000097oo00L007ooOomoo`00Ool0000UOol01`00
Oomoogoo001oo`0002moo`004Goo00L007ooOomoo`00Ool0000UOol01`00Oomoogoo001oo`0004mo
o`07001oogooOol007oo000097oo00L007ooOomoo`00Ool0000VOol01P00Oomoo`00Ool002moo`00
47oo00<007oo00000Woo00<007oo00009Goo00L007ooOomoo`00Ool0001?Ool01`00Oomoogoo001o
o`0002=oo`03001oo`00009oo`03001oo`0002Aoo`03001oo`00009oo`03001oo`0002moo`004Goo
00<007ooOol00Woo00<007ooOol08goo0P0017oo00<007ooOol0CGoo0P0017oo00<007ooOol08goo
00<007ooOol00Woo00<007ooOol097oo00<007ooOol00Woo00<007ooOol0;Woo003oOolQOol006Yo
o`03001oogoo0;=oo`00JWoo00<007ooOol0/goo001ZOol00`00Oomoo`2cOol006Yoo`03001oogoo
0;=oo`001gooo`004P0027oo0009Ool00`00Oomoo`06Ool00`00Oomoo`06Ool01@00Oomoogoo0000
0goo00<007ooOol00goo00@007ooOol000Qoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`05001oogooOol00003Ool20006
Ool20008Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo
00Ioo`03001oogoo009oo`05001oogooOol00008Ool00`00Oomoo`02Ool01000Oomoo`003goo000B
Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0YOol00`00Oomoo`0Y
Ool01000Oomoo`001Woo00<007ooOol00goo00<007oo00001goo00<007ooOol03Woo00<007ooOol0
5Goo00<007ooOol00goo00<007ooOol027oo00@007ooOol000aoo`03001oogoo011oo`03001oogoo
011oo`007Woo00<007ooOol02Goo00<007ooOol0?Goo00<007ooOol0;7oo00<007ooOol01Goo00D0
07ooOomoo`00009oo`03001oogoo00Aoo`03001oogoo02Qoo`05001oogooOol0000;Ool00`00Oomo
o`0=Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool001ioo`03001oogoo00Yoo`03001oogoo03aoo`03
001oogoo02aoo`03001oogoo00Eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`0XOol0
1000Oomoo`0037oo00<007ooOol037oo00<007ooOol04goo00<007ooOol03Woo000NOol00`00Oomo
o`0:Ool00`00Oomoo`0lOol00`00Oomoo`0[Ool00`00Oomoo`07Ool00`00Ool00003Ool00`00Oomo
o`04Ool00`00Oomoo`0YOol00`00Ool0000=Ool00`00Oomoo`0;Ool00`00Oomoo`0COol00`00Oomo
o`0>Ool000ioo`T000Moo`03001oogoo00]oo`03001oogoo03]oo`8002aoo`03001oogoo00Qoo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo02Yoo`03001oogoo00aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo01Aoo`03001oogoo00eoo`005Woo00<007ooOol01Goo00<007ooOol0
2goo00<007ooOol0>goo00<007ooOol0:goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol0
>Goo00<007ooOol00goo00<007oo000017oo00<007ooOol09Goo000GOol00`00Oomoo`03Ool00`00
Oomoo`0<Ool00`00Oomoo`0kOol00`00Oomoo`0[Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00
Oomoo`0jOol00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`0UOol001Moo`03001oogoo00=o
o`03001oogoo00aoo`03001oogoo03]oo`03001oogoo02Yoo`03001oogoo00moo`03001oogoo009o
o`03001oogoo03]oo`05001oogooOol00003Ool01@00Oomoogoo00009goo000HOol00`00Oomoo`02
Ool00`00Oomoo`0=Ool00`00Oomoo`0jOol00`00Oomoo`0ZOol00`00Oomoo`0@Ool01@00Oomoogoo
0000?Goo00@007ooOol000Aoo`04001oogoo000XOol001Qoo`03001oogoo009oo`03001oogoo00eo
o`03001oogoo03Yoo`03001oogoo02Yoo`03001oogoo011oo`05001oogooOol0000mOol00`00Ool0
0006Ool00`00Ool0000XOol001Qoo`05001oogooOol0000@Ool00`00Oomoo`0jOol00`00Oomoo`0Y
Ool00`00Oomoo`0AOol01000Oomoo`00?goo0P001Woo0P00:Goo000IOol01000Oomoo`0047oo00<0
07ooOol03Woo00<007ooOol0:Goo0P00:Woo00<007ooOol04Goo00@007ooOol003moo`03001oogoo
00Ioo`03001oogoo02Moo`006Goo00@007ooOol0011oo`03001oogoo00eoo`8002]oo`03001oogoo
02Uoo`03001oogoo019oo`03001oo`00079oo`006Goo00@007ooOol0011oo`03001oogoo00aoo`03
001oo`0002]oo`03001oogoo02Qoo`03001oogoo01=oo`03001oo`00079oo`006Woo00<007oo0000
4Goo00<007ooOol02Woo00@007ooOol002]oo`03001oogoo02Qoo`03001oogoo01=oo`03001oo`00
079oo`006Woo0P004Woo00<007ooOol02Woo00D007ooOomoo`0002Yoo`03001oogoo02Moo`03001o
ogoo01Aoo`8007=oo`006goo00<007ooOol047oo00<007ooOol02Goo00<007ooOol00Woo00<007oo
Ool0:7oo00<007ooOol09goo00<007ooOol05Goo00<007ooOol0LGoo000KOol00`00Oomoo`0@Ool0
0`00Oomoo`04Ool50005Ool00`00Oomoo`0XOol2000XOol00`00Oomoo`0EOol00`00Oomoo`1aOol0
02ioo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo02Qoo`03001oogoo02Ioo`03001oogoo
08Yoo`00;Woo00<007ooOol017oo00<007ooOol01goo00<007ooOol0:7oo00<007ooOol09Woo00<0
07ooOol0RWoo000_Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0XOol00`00Oomoo`0V
Ool00`00Oomoo`2:Ool002moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo02Qoo`03001o
ogoo02Eoo`03001oogoo08]oo`00;goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0:7oo
00<007ooOol09Goo00<007ooOol0Rgoo000_Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomo
o`0WOol00`00Oomoo`0TOol00`00Oomoo`2<Ool002moo`03001oogoo009oo`03001oogoo00Uoo`03
001oogoo00Aoo`03001oogoo021oo`80025oo`D008ioo`00;goo00D007ooOomoo`0000aoo`03001o
ogoo00Aoo`03001oogoo021oo`03001oogoo021oo`03001oogoo091oo`00;goo00D007ooOomoo`00
00aoo`03001oogoo00=oo`80029oo`03001oogoo021oo`03001oogoo091oo`00<7oo00@007ooOol0
00aoo`03001oogoo00=oo`80029oo`03001oogoo021oo`03001oogoo091oo`00<7oo00@007ooOol0
00aoo`03001oogoo00=oo`03001oo`0001Yoo`03001oogoo00Aoo`03001oogoo01moo`03001oogoo
095oo`00<7oo00<007oo00003Goo00<007ooOol00goo00<007oo00006Goo00<007oo00001Goo00<0
07ooOol07goo00<007ooOol0TGoo000`Ool00`00Ool0000=Ool00`00Oomoo`02Ool01000Oomoo`00
6goo00<007ooOol00goo0P0067oo00<007ooOol01Goo00<007ooOol0TGoo000`Ool00`00Ool0000>
Ool01@00Oomoogoo00000Woo00<007ooOol05goo0P001Woo00<007ooOol05goo00<007ooOol01Goo
00<007ooOol0TGoo000`Ool00`00Ool0000>Ool01@00Oomoogoo00000Woo00<007ooOol05goo00<0
07ooOol01Goo00<007ooOol05goo00<007ooOol01Goo00<007ooOol0TGoo000aOol2000>Ool01@00
Oomoogoo00000Woo00<007ooOol05goo0`001Goo00<007ooOol05goo00<007ooOol01Goo00<007oo
Ool0TGoo000aOol00`00Oomoo`0=Ool01000Oomoo`000goo00<007ooOol07goo00<007ooOol05Woo
00<007oo00001Woo00<007ooOol0TGoo000aOol00`00Oomoo`0=Ool01000Oomoo`000goo00<007oo
Ool07goo00<007ooOol05Woo00<007oo00001Woo00<007ooOol0TGoo000aOol00`00Oomoo`0=Ool0
1000Oomoo`0017oo00<007ooOol07Woo0P005goo00<007oo00001Goo00<007ooOol0TWoo0011Ool0
1000Oomoo`0017oo00<007ooOol07Woo00<007ooOol05Woo00<007oo00001Goo00<007ooOol0TWoo
0011Ool00`00Ool00005Ool00`00Oomoo`0NOol00`00Oomoo`0FOol00`00Ool00005Ool00`00Oomo
o`2BOol0049oo`8000Eoo`03001oogoo01ioo`03001oogoo01Ioo`03001oo`0000Eoo`03001oogoo
099oo`00@Woo0P001Goo00<007ooOol07Woo00<007ooOol05Woo00<007oo00001Goo00<007ooOol0
TWoo0012Ool20005Ool00`00Oomoo`0NOol00`00Oomoo`0FOol00`00Ool00005Ool00`00Oomoo`2B
Ool0049oo`03001oogoo00Aoo`03001oogoo01ioo`03001oogoo01Eoo`05001oogooOol00004Ool0
0`00Oomoo`2BOol0049oo`03001oogoo00Aoo`03001oogoo01ioo`8001Ioo`05001oogooOol00003
Ool00`00Oomoo`2COol004Yoo`03001oogoo01eoo`03001oogoo01Eoo`05001oogooOol00003Ool0
0`00Oomoo`2COol004Yoo`03001oogoo01eoo`03001oogoo01Eoo`05001oogooOol00003Ool00`00
Oomoo`2COol004Yoo`03001oogoo01eoo`03001oogoo01Eoo`05001oogooOol00003Ool00`00Oomo
o`2COol004Yoo`03001oogoo01eoo`03001oogoo01Eoo`05001oogooOol00003Ool00`00Oomoo`2C
Ool004Yoo`03001oogoo01eoo`03001oogoo01Eoo`05001oogooOol00003Ool00`00Oomoo`2COol0
04Yoo`03001oogoo00Moo`03001oogoo01=oo`8000]oo`03001oogoo00Qoo`05001oogooOol00003
Ool00`00Oomoo`2COol004Yoo`03001oogoo00Ioo`8001Eoo`03001oogoo00Yoo`03001oogoo00Mo
o`03001oogoo00=oo`04001oogoo002EOol004Yoo`03001oogoo00Ioo`8001Eoo`03001oogoo00Yo
o`03001oogoo00Moo`03001oogoo00=oo`03001oo`0009Ioo`00Bgoo00<007ooOol017oo00<007oo
00005Goo00<007ooOol02Woo0P0027oo00<007ooOol00goo00<007oo0000UWoo001;Ool00`00Oomo
o`03Ool01@00Oomoogoo000057oo00<007ooOol02Woo0P0027oo00<007ooOol00goo00<007oo0000
UWoo001;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool20008
Ool00`00Oomoo`03Ool00`00Ool0002FOol004]oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo019oo`03001oogoo00Yoo`8000Qoo`03001oogoo00=oo`03001oo`0009Ioo`00Bgoo1@001Goo
00<007ooOol04Woo0P002goo0P0027oo00<007ooOol00goo00<007oo0000UWoo001EOol00`00Oomo
o`0BOol00`00Oomoo`0:Ool00`00Ool00007Ool00`00Oomoo`03Ool00`00Ool0002FOol005Eoo`03
001oogoo019oo`03001oogoo00Uoo`04001oogoo0006Ool00`00Oomoo`05Ool2002FOol005Ioo`03
001oogoo015oo`03001oogoo00Uoo`04001oogoo0006Ool00`00Oomoo`05Ool00`00Oomoo`2EOol0
05Ioo`03001oogoo00=oo`D0009oo`03001oogoo00Aoo`03001oogoo00Uoo`04001oogoo0006Ool0
0`00Oomoo`05Ool00`00Oomoo`2EOol005Ioo`03001oogoo00Eoo`07001oogooOol007oo00001Goo
00<007ooOol02Goo00D007ooOomoo`0000Eoo`03001oogoo00Eoo`03001oogoo09Eoo`00EWoo00<0
07ooOol01Goo00L007ooOomoo`00Ool00005Ool2000:Ool01@00Oomoogoo00001Goo00<007ooOol0
1Goo00<007ooOol0UGoo001FOol00`00Oomoo`05Ool01`00Oomoogoo001oo`0000Eoo`03001oogoo
00Uoo`05001oogooOol00004Ool00`00Oomoo`2NOol005Ioo`03001oogoo00Eoo`07001oogooOol0
07oo00001Goo00<007ooOol02Goo00D007ooOomoo`0000=oo`03001oogoo09moo`00EWoo00<007oo
Ool017oo0P0017oo00<007ooOol017oo00<007ooOol02Goo00D007ooOomoo`00009oo`03001oogoo
0:1oo`00Egoo00<007ooOol047oo00<007ooOol02Goo00<007ooOol00Woo00<007oo0000XWoo001G
Ool00`00Oomoo`0@Ool00`00Oomoo`09Ool00`00Oomoo`02Ool2002SOol005Moo`03001oogoo011o
o`8000Yoo`03001oogoo009oo`03001oogoo0:9oo`00Egoo00<007ooOol047oo00<007ooOol02Goo
00<007ooOol0Ygoo001GOol00`00Oomoo`0@Ool00`00Oomoo`09Ool00`00Oomoo`2WOol005Moo`03
001oogoo011oo`03001oogoo00Uoo`03001oogoo0:Moo`00F7oo00<007ooOol03goo00<007ooOol0
2Goo00<007ooOol0Ygoo001HOol00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`2WOol005Qo
o`03001oogoo00moo`03001oogoo00Uoo`03001oogoo0:Moo`00F7oo00<007ooOol03goo0P002Woo
00<007ooOol0Ygoo001HOol00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`2XOol005Uoo`03
001oogoo00ioo`03001oogoo00Qoo`03001oogoo0:Qoo`00FGoo00<007ooOol03Woo00<007ooOol0
27oo00<007ooOol0Z7oo001IOol00`00Oomoo`0>Ool00`00Oomoo`08Ool00`00Oomoo`2XOol005Uo
o`03001oogoo00ioo`03001oogoo00Qoo`03001oogoo0:Qoo`00FWoo00<007ooOol03Goo0P002Goo
00<007ooOol0Z7oo001JOol00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomoo`2XOol005Yoo`03
001oogoo00eoo`03001oogoo00Qoo`03001oogoo0:Qoo`00FWoo00<007ooOol03Goo00<007ooOol0
27oo00<007ooOol0Z7oo001KOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`2XOol005]o
o`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo0:Qoo`00Fgoo00<007ooOol037oo00<007oo
Ool027oo00<007ooOol0Z7oo001KOol00`00Oomoo`0<Ool20009Ool00`00Oomoo`2XOol005aoo`03
001oogoo00]oo`03001oogoo00Qoo`03001oogoo0:Qoo`00G7oo00<007ooOol02goo00<007ooOol0
27oo00<007ooOol0Z7oo001LOol00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`2XOol005ao
o`D0009oo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo0:Qoo`00GGoo0P000goo00<007oo
00001Goo00<007ooOol027oo00<007ooOol0Z7oo001MOol50002Ool00`00Oomoo`03Ool20008Ool0
0`00Oomoo`2YOol005ioo`03001oogoo00<000Ioo`03001oogoo00Moo`03001oogoo0:Uoo`00GWoo
00<007ooOol00P001goo00<007ooOol01goo00<007ooOol0ZGoo001MOol20002Ool40005Ool00`00
Oomoo`07Ool00`00Oomoo`2YOol0069oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo0:Uo
o`00HWoo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0ZGoo001ROol00`00Oomoo`05Ool2
0008Ool00`00Oomoo`2YOol0069oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo0:Uoo`00
HWoo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0ZGoo001ROol00`00Oomoo`05Ool00`00
Oomoo`07Ool00`00Oomoo`2YOol0069oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo0:Uo
o`00HWoo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0ZGoo001SOol00`00Oomoo`04Ool0
0`00Oomoo`07Ool00`00Oomoo`2YOol006=oo`03001oogoo00Aoo`8000Qoo`03001oogoo0:Uoo`00
Hgoo00<007ooOol017oo00<007ooOol01goo00<007ooOol0ZGoo001SOol00`00Oomoo`04Ool00`00
Oomoo`07Ool00`00Oomoo`2YOol006=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo0:Uo
o`00Hgoo00<007ooOol017oo00<007ooOol01goo00<007ooOol0ZGoo001SOol00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`2ZOol006=oo`03001oogoo00Aoo`8000Moo`03001oogoo0:Yoo`00
I7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0ZWoo001TOol00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`2ZOol006Aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo0:Yo
o`00I7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0ZWoo001TOol00`00Oomoo`03Ool0
0`00Oomoo`06Ool00`00Oomoo`2ZOol006Aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo
0:Yoo`00I7oo00<007ooOol00goo0P001goo00<007ooOol0ZWoo001TOol00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`2ZOol006Eoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0:Yo
o`00IGoo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0ZWoo001MOol30003Ool00`00Ool0
0004Ool00`00Oomoo`06Ool00`00Oomoo`2ZOol005eoo`03001oogoo009oo`04001oo`000004Ool0
0`00Oomoo`06Ool00`00Oomoo`2ZOol005ioo`06001oogooOol007oo0P0017oo0P001goo00<007oo
Ool0ZWoo001NOol01P00Oomoogoo001oo`8000Aoo`03001oogoo00Ioo`03001oogoo0:Yoo`00GGoo
00<007oo00000Woo00@007oo000000Aoo`03001oogoo00Ioo`03001oogoo0:Yoo`00GWoo00<007oo
Ool00Woo00@007ooOol000=oo`03001oogoo00Ioo`03001oogoo0:Yoo`00IWoo00D007ooOomoo`00
00Moo`03001oogoo0:]oo`00IWoo00D007ooOomoo`0000Moo`03001oogoo0:]oo`00IWoo00@007oo
Oomoo`8000Ioo`03001oogoo0:]oo`00IWoo00D007ooOomoo`0000Moo`03001oogoo0:]oo`00Igoo
00@007ooOol000Moo`03001oogoo0:]oo`00Igoo00@007ooOol000Moo`03001oogoo0:]oo`00Igoo
00@007ooOol000Moo`03001oogoo0:]oo`00Igoo00@007ooOol000Moo`03001oogoo0:]oo`00Igoo
00@007ooOol000Moo`03001oogoo0:]oo`00J7oo00@007oo000000Ioo`03001oogoo0:]oo`00J7oo
00<007oo00001goo00<007ooOol0Zgoo001XOol00`00Ool00007Ool00`00Oomoo`2[Ool006Qoo`03
001oo`0000Ioo`03001oogoo0:aoo`00J7oo00<007oo00001Woo00<007ooOol0[7oo001XOol00`00
Ool00006Ool00`00Oomoo`2/Ool006Uoo`<000Eoo`03001oogoo0:aoo`00JGoo0P001Woo00<007oo
Ool0[7oo001YOol20005Ool00`00Oomoo`2]Ool006Uoo`8000Eoo`03001oogoo0:eoo`00JGoo0P00
1Goo00<007ooOol0[Goo001ZOol00`00Oomoo`03Ool00`00Oomoo`2]Ool006Yoo`03001oogoo009o
o`03001oogoo0:ioo`00JWoo0P000goo00<007ooOol0[Woo001ZOol20003Ool00`00Oomoo`2^Ool0
06Yoo`8000=oo`03001oogoo0:ioo`00JWoo00<007oo00000Woo00<007ooOol0[Woo001MOol30003
Ool00`00Oomoo`04Ool00`00Oomoo`02002aOol005eoo`03001oogoo009oo`03001oo`0000Eoo`03
001oogoo00800;5oo`00GWoo00<007ooOol00goo00<007ooOol00goo0P000Woo00<007ooOol0[goo
001NOol01000Oomoogoo0P001Woo00<007ooOol0/goo001MOol00`00Ool00002Ool00`00Oomoo`05
Ool00`00Oomoo`2cOol005ioo`04001oogooOol30005Ool00`00Oomoo`2cOol006Yoo`03001oogoo
0;=oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.1958, -1.93675, 
  0.227845, 0.156212}}]
}, Open  ]],

Cell[TextData[{
  "For 8-bit-per-pixel data, DC differentials can take values in the range \
from -2047 to 2047 (why?) This range is divided into 12 size categories, \
where the ",
  StyleBox["i",
    FontSlant->"Italic"],
  "-th category includes all differentials that can be represented by ",
  StyleBox["i",
    FontSlant->"Italic"],
  " bits (see Table 1). "
}], "Text"],

Cell[BoxData[GridBox[{
        {"Category", \(Difference\ values\)},
        {"0", "0"},
        {"1", \(\(-1\), 1\)},
        {"2", \(\(-3\), \(-2\), 2, 3\)},
        {"3", \(\(-7\), \[CenterEllipsis], \(-4\), 4, \[CenterEllipsis], 7
          \)},
        {"4", \(\(-15\), \[CenterEllipsis], \(-8\), 8, \[CenterEllipsis], 15
          \)},
        {"5", \(\(-31\), \[CenterEllipsis], \(-16\), 16, \[CenterEllipsis], 31
          \)},
        {"6", \(\(-63\), \[CenterEllipsis], \(-32\), 32, \[CenterEllipsis], 63
          \)},
        {"7", \(\(-127\), \[CenterEllipsis], \(-64\), 64, \[CenterEllipsis], 
          127\)},
        {"8", \(\(-255\), \[CenterEllipsis], \(-128\), 128, 
          \[CenterEllipsis], 255\)},
        {"9", \(\(-511\), \[CenterEllipsis], \(-256\), 256, 
          \[CenterEllipsis], 511\)},
        {"10", \(\(-1023\), \[CenterEllipsis], \(-512\), 512, 
          \[CenterEllipsis], 1023\)},
        {"11", \(\(-2047\), \[CenterEllipsis], \(-1024\), 1024, 
          \[CenterEllipsis], 2047\)}
        }]], "NumberedTable"],

Cell[TextData[{
  "Each differential is then described by a pair of numbers: category and \
amplitude. The amplitude is simply an ",
  StyleBox["i",
    FontSlant->"Italic"],
  "-bit biased integer representation of the actual differential value. The \
DC category value is coded using a variable length Huffman encoder (see Table \
2). The JPEG standard includes an example Huffman category table that may be \
used instead of a local encoder."
}], "Text"],

Cell[BoxData[GridBox[{
        {"Category", \(Code\ length\), \(Code\ word\)},
        {"0", "2", "00"},
        {"1", "3", "010"},
        {"2", "3", "011"},
        {"3", "3", "100"},
        {"4", "3", "101"},
        {"5", "3", "110"},
        {"6", "4", "1110"},
        {"7", "5", "11110"},
        {"8", "6", "111110"},
        {"9", "7", "1111110"},
        {"10", "8", "11111110"},
        {"11", "9", "111111110"}
        }]], "NumberedTable"],

Cell[TextData[{
  "Here we compute the DC category for each of the DC differential values \
(the function ",
  StyleBox["Category", "Program"],
  " is defined in the Appendix)."
}], "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Category\ \ /@\ dif\)], "Input"],

Cell[BoxData[
    \({6, 2, 2, 3, 2, 3, 2, 2, 2, 2, 1, 2, 2, 2, 3, 3, 4, 1, 2, 3, 2, 3, 3, 
      3, 2, 2, 0, 1, 1, 0, 2, 2, 4, 2, 3, 4, 4, 4, 4, 3, 2, 1, 4, 2, 1, 3, 3, 
      1, 2, 1, 1, 3, 4, 4, 3, 4, 4, 1, 4, 2, 2, 3, 3, 1, 3, 0, 3, 4, 3, 3, 3, 
      2, 4, 5, 5, 2, 2, 4, 2, 2, 3, 1, 3, 2, 3, 4, 3, 3, 1, 4, 5, 2, 2, 4, 2, 
      1, 3, 1, 2, 3, 1, 4, 4, 4, 2, 3, 5, 3, 2, 4, 1, 0, 3, 0, 2, 4, 1, 4, 5, 
      3, 2, 2, 5, 3, 3, 4, 1, 0, 3, 1, 0, 4, 2, 4, 5, 5, 4, 2, 6, 3, 3, 3, 0, 
      0, 2, 1, 0, 4, 3, 3, 5, 4, 3, 1, 6, 3, 3, 3, 0, 0, 2, 1, 0, 4, 3, 3, 5, 
      0, 3, 4, 4, 3, 3, 3, 0, 1, 1, 2, 0, 4, 3, 3, 4, 0, 2, 3, 4, 2, 3, 3, 0, 
      1, 1, 2, 0, 4, 3, 3, 3, 3, 2, 2, 3, 2, 3, 3, 0, 0, 2, 2, 1, 4, 3, 2, 2, 
      1, 1, 2, 2, 2, 3, 3, 1, 1, 3, 1, 0, 4, 3, 2, 2, 0, 0, 1, 1, 1, 3, 3, 1, 
      2, 3, 3, 1, 4, 3, 1, 1, 1, 1, 2, 1, 2, 1, 3, 1, 3}\)], "Output"]
}, Open  ]],

Cell["\<\
Given the category and differential values computed above we may, by simple \
table lookup using Tables 1 and 2 obtain the binary codes for all DC \
coefficients. For example, consider the following three DC differential \
values:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Take[dif, \ {17, 19}]\)], "Input"],

Cell[BoxData[
    \({15, 1, \(-3\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The corresponding category values are ",
  Cell[BoxData[
      \(TraditionalForm\`{4, \ 1, \ 2}\)]],
  ". Now, from Table 2, the binary codes for each of the categories are ",
  Cell[BoxData[
      \(TraditionalForm\`{101, \ 010, \ 011}\)]],
  ". To each of these 3-bit code words we append the differential value, in \
binary using a biased representation. A positive differential value is \
represented by its unsigned binary code (note it will always have a leading \
1), while negative valued differentials are represented by the one's \
complement of its absolute value. Thus, the three differentials shown above \
have the following codes: ",
  Cell[BoxData[
      \(TraditionalForm\`{111, \ 1, \ 00}\)]],
  ". Appending to the category codes we get  ",
  Cell[BoxData[
      \(TraditionalForm\`{101  111\+_, \ 010  1\+_, \ 011  00\+_}\)]],
  ", where the differential amplitudes have been underlined for easier \
visualization."
}], "Text"],

Cell["Coding of AC coefficients", "Subsection"],

Cell[TextData[{
  "For 8-bit pixels, AC coefficients may take any value in the range from \
-1023 to 1023. As for the DC coefficients, this range is subdivided into 10 \
categories and each AC coefficient may be described by the pair of numbers \
category/amplitude. Significant additional savings are possible by preceding \
the coding stage by a run length coder which given the zig-zag ordered AC \
coefficients returns pairs of numbers: the value of a nonzero coefficient and \
the number of preceding zeros, the so-called ",
  StyleBox["run",
    FontSlant->"Italic"],
  " of zeros. For example, consider the first few AC coefficients in some \
block ",
  Cell[BoxData[
      \(TraditionalForm\`C\_n\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`{27, 0, 5, \(-1\), \(-1\), 0, 0, 0, 1,  ... \ }\)]],
  ". The corresponding category assignments are: ",
  Cell[BoxData[
      \(TraditionalForm\`{5, 0, 3, 1, 1, 0, 0, 0, 1, \  ... \ }\)]],
  ". Combining these with the respective runs we get the following symbols: ",
  
  Cell[BoxData[
      \(TraditionalForm\`{0/5, \ 1/3, \ 0/1, 0/1, 3/1, \  ... \ }\)]],
  ". The binary codes for each of the paired symbols are obtained from the \
JPEG Huffman table for AC luminance coefficients. This table has been \
developed from the average statistics of a large set of images with 8-bit \
precision. A few of the entries are shown below."
}], "Text"],

Cell[BoxData[GridBox[{
        {\(Run/Category\), \(Code\ length\), \(Code\ word\)},
        {\(0/0\ \((EOB)\)\), "4", "1010"},
        {\(0/1\), "2", "00"},
        {\(0/2\), "2", "01"},
        {\(0/3\), "3", "100"},
        {\(0/4\), "4", "1011"},
        {\(0/5\), "5", "11010"},
        {".", ".", "."},
        {\(1/1\), "4", "1100"},
        {\(1/2\), "5", "11011"},
        {\(1/3\), "7", "1111001"},
        {".", ".", "."},
        {\(3/1\), "6", "111010"},
        {".", ".", "."}
        }]], "NumberedTable"],

Cell[TextData[{
  "Appending the binary coded AC amplitudes to the code words read from the \
Huffman table we get: ",
  Cell[BoxData[
      \(TraditionalForm
      \`{11010  11011\+_, \ 1111001  101\+_, \ 00  0\+_, \ 00  0\+_, \ 
        111010  1\+_, \  ... \ }\)]]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IMAGE RECONSTRUCTION", "Section"],

Cell["\<\
JPEG decoding reverses the processing steps described in previous sections. \
We proceed with computing an approximation of our example image using the \
standard quantization table and evaluate the approximation error. We also \
estimate the compression ratio and average bit-rate. A simple estimate of the \
compression ratio and bit-rate may be obtained by counting the total number \
of non-zero DCT coefficients and adopting a uniform coding scheme with 8-bits \
per coefficient (in reality, a much more efficient non-uniform coding scheme \
is used). \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nonzero = 
      Select[Flatten[\[ScriptCapitalA]\_Q], \((#\  =!= \ 0)\)&]\  // Length
        \)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(1500\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["The compression ratio and bit rate are: ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmp = nonzero\/128\^2; \n{1\/tmp, \ 8*tmp}\  // N\)], "Input"],

Cell[BoxData[
    \({10.9226666666666671`, 0.732421875`}\)], "Output"]
}, Open  ]],

Cell["\<\
Next, an approximation to the original image is computed, the reconstructed \
image and the quantization error signal are shown.\
\>", "Text"],

Cell[BoxData[
    \(\(B = 
      BlockProcessing[Round[InverseDCT[Q\ *\ #]]\ &, \ 
          \[ScriptCapitalA]\_Q, {8, 8}] + 128; \)\)], "Input",
  CellLabel->"In[20]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[\n
        \t\t{ListDensityPlot[B, \ DisplayFunction -> Identity]\ , \n\t\t\t
          ListDensityPlot[A - B + 128, \ PlotRange -> {0, 255}, \ 
            DisplayFunction -> Identity]}]]; \)\)], "Input",
  CellLabel->"In[22]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F3F5F8FBFCFCFCFCFEFEFEFEFEFEFEFEF9F9F8F8F6F6F5F5
F6F6F6F5F5F3F3F3F2F2F2F0F0EFEFEFECECEAEAE9E9E7E7
E7E5E5E5E4E4E2E2E2E1E1E1DFDFDEDED9D8D8D8D6D5D5D5
D3D2D2D2D0CECECECECECECECECECECED2D2D2D0D0CECECE
CBCDCED2D6D9DBDCE4E5E9EFF3F9FCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
F6F8FBFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFCFCFBFBF9F9
F9F9F9F8F8F6F6F6F3F3F3F2F2F0F0F0EDEDEDECECEAEAE9
EDEDECECEAEAEAE9E5E5E4E4E2E2E1E1E4E2E2E2E1E1DFDF
DEDCDCDCDBDBD9D9D9D9D9D9D9D9D9D9D8D6D6D5D5D3D3D3
D2D2D3D6D8D9DBDCD0D2D3D6D8DBDCDECBCDCED0D2D3D3D5
D0D2D3D6D8D8D8D8
F9FBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFE
FCFCFCFBFBF9F9F9F6F6F6F5F5F3F3F2F0F0F0EFEFEDEDED
F0F0EFEFEDEDECECEAEAE9E9E7E7E5E5EAEAEAE9E9E7E7E5
E4E4E4E2E2E1E1DFE1E1E1E1E1E1E1E1DCDCDBDBD9D9D9D8
D8D8D8D9D9D9D9D9CDCDCDCDCDCDCDCDD0D0D0D0D2D2D2D2
CED0D2D5D5D5D5D3
F9FBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFBFBF9F9F9F8F9F8F8F8F6F6F5F5F3F3F3F2F2F0F0F0
EDEDECECEAEAEAE9EDEDEDECECEAEAEAE9E7E7E7E5E5E4E4
E2E1E1E1DFDFDEDEDFDFDFDFDFDFDFDFDEDEDEDCDCDBDBDB
DBDBD9D8D8D6D5D5D0D0D0D2D2D3D3D3DBDBDBD9D8D8D6D6
DEDFE1E2E2E2E1DF
F6F9FBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FBF9F9F9F8F8F6F6F9F9F9F8F8F6F6F6F6F5F5F3F3F2F2F2
EFEDEDEDECECEAEAEFEFEDEDECECEAEAE5E5E5E4E4E2E2E2
DFDFDFDEDEDCDCDCDEDEDEDEDEDEDEDEDEDCDCDBDBD9D9D9
DBD9D8D6D3D2D0D0CBCBCED0D3D6D8D9DBD9D9D8D8D6D6D5
DBDCDCDEDEDCDBD9
F6F8FBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFCFCFB
F9F9F9F8F8F6F6F6F9F9F8F8F6F6F5F5F6F5F5F5F3F3F2F2
F2F2F2F0F0EFEFEFEDECECEAEAE9E9E9E7E7E7E5E5E4E4E4
E1E1E1DFDFDEDEDEE1E1E1E1E1E1E1E1DCDCDBDBD9D9D8D8
D8D8D6D5D3D2D0CED0D2D5D6D9DCDFE1E2E2E2E2E2E2E2E2
E7E7E9E9E7E5E2E1
F9FBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFCFC
FCFCFCFBFBF9F9F9F8F8F6F6F5F5F3F3F5F5F5F3F3F2F2F0
F2F0F0EFEFEDEDEDE9E9E9E7E7E5E5E5E7E5E5E4E4E2E2E2
E1DFDFDEDEDCDCDCDFDFDFDFDFDFDFDFDEDEDCDCDBDBD9D9
D8D8D6D6D5D5D5D3DEDEDEDFDFDFE1E1D5D6D6D8D9DBDCDE
DFDFE1E1DFDCD9D8
FCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFE
FFFFFFFEFEFCFCFCF6F6F6F5F5F3F3F3F5F3F3F3F2F2F0F0
ECEAEAEAE9E7E7E7E7E5E5E5E4E2E2E2E1E1E1DFDFDEDEDE
DBDBDBD9D9D8D8D8DCDCDCDCDCDCDCDCDFDFDFDEDEDCDCDB
D8D8D8D8D8D8D9D9DFDFDEDBD9D6D5D5DBDCDEE1E2E5E7E9
E1E2E2E1DFDEDBD9
FEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFB
FBFBFBF9F9F8F8F8FBFBF9F9F8F8F6F6F3F3F2F0EFEDEDEC
ECECECEAEAE9E9E7EAEAE9E9E7E7E7E5E5E5E5E4E4E2E2E2
E1E1DFDFDEDEDCDCDCDCDCDCDCDCDCDCDBDBDBDBDBDBDBDB
D9D9D9D9D9D9D9D9DBDBDBDBDBDBDBDBD6D6D6D8D8D9D9D9
DBDCDEDEDEDEDCDB
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFB
FBFBF9F9F8F8F6F6F9F9F9F8F6F6F6F5F5F3F3F2F0EFEDEC
ECECECEAEAE9E9E9E7E7E7E5E5E4E4E4E1E1DFDFDEDEDEDC
DCDCDBDBD9D9D8D8DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DCDCDCDCDCDCDCDCD8D8D8D8D8D8D8D8D6D6D8D8D9D9DBDB
DCDCDEDFDFDEDCDC
FCFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFFFFFFCFBF9
F9F9F8F8F6F6F6F5F8F8F6F6F5F5F3F3F5F3F3F2F0EFEDEC
EDECECEAEAE9E9E9E5E4E4E4E2E2E1E1E1E1DFDFDEDEDCDC
DCDCDBDBD9D9D8D8DCDCDCDCDCDCDCDCDCDCDCDCDCDCDCDC
DBDBDBDBDBDBDBDBD5D5D5D5D5D5D5D5D8D8D9D9DBDBDCDC
DCDEDFDFDFDFDEDC
FCFCFEFEFFFFFFFFFEFEFEFEFEFEFEFEFCFCFEFEFCFBF9F8
F8F8F6F6F5F5F3F3F5F5F5F3F3F2F2F2F3F3F2F0EFEDECEC
ECECEAEAE9E9E7E7E4E4E4E2E2E1E1DFE4E4E2E2E1E1DFDF
DFDFDFDEDEDCDCDCDBDBDBDBDBDBDBDBD9D9D9D9D9D9D9D9
D3D3D3D3D3D3D3D3D5D5D5D5D5D5D5D5D9D9D9DBDBDCDCDC
DCDEDFDFDFDFDEDC
FBFCFCFCFEFEFFFFFEFEFEFEFEFEFEFEFBFBFCFCFBF9F8F6
F6F6F5F5F3F3F2F2F2F2F2F0F0EFEFEFF0F0EFEDECEAE9E9
E9E9E9E7E5E5E5E4E4E4E2E2E1E1DFDFDFDFDFDEDEDCDCDC
DEDCDCDCDBDBD9D9D9D9D9D9D9D9D9D9D3D3D3D3D3D3D3D3
D2D2D2D2D2D2D2D2D5D5D5D5D5D5D5D5D8D8D9D9DBDBDBDC
DBDCDEDEDEDEDCDB
FBFBFBFCFCFEFEFFFCFCFCFCFCFCFCFCF9F9FBFBF9F8F6F5
F5F3F3F3F2F2F0F0F0F0EFEFEDEDECECEDECECEAE9E7E5E4
E5E4E4E2E2E1E1E1DFDFDFDEDEDCDCDCD6D6D6D5D3D3D3D2
D5D5D3D3D2D2D0D0D5D5D5D5D5D5D5D5D0D0D0D0D0D0D0D0
D3D3D3D3D3D3D3D3D5D5D5D5D5D5D5D5D5D6D6D8D8D9D9D9
D8D9D9DBDBD9D9D8
F9FBFBFBFCFEFEFEFCFCFCFCFCFCFCFCF8F8F9F9F8F6F5F3
F3F3F2F2F0F0EFEFEFEDEDEDECEAEAEAE9E9E7E5E4E2E1E1
E1E1DFDFDEDEDCDCD9D9D8D8D6D6D6D5D2D2D2D0CECECECD
D0D0D0CECECDCDCDD2D2D2D2D2D2D2D2D0D0D0D0D0D0D0D0
D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D3D3D3D5D5D6D6D6
D5D5D6D8D8D6D5D5
F9F9FBFBFCFCFEFEFCFCFCFCFCFCFCFCF6F8F8F8F8F6F3F3
F2F2F2F0F0EFEFEFEDEDECECEAEAE9E9E7E5E4E4E1DFDFDE
DEDEDEDCDCDBDBDBD3D3D3D2D2D0D0D0D3D3D3D2D2D0D0D0
D3D3D2D2D0D0CECECECECECECECECECED2D2D2D2D2D2D2D2
CBCBCBCBCBCBCBCBCECECECECECECECED2D2D2D3D3D5D5D5
D2D3D5D6D6D5D3D2
FBF9F8F5F5F5F6F6F3F3F3F3F3F3F3F3F3F2F2F0EDECECEA
EDEDEDEDEAE9E5E4E2E2E4E4E5E7E7E7E2E1E1E1DFDFDFDE
D6D9DBDBD6CEC7C1DBD6CEC8C7C8CDD0C1C2C4C7C7C7C5C5
C1C8C5B9B6C5D3D8C5C5C5C5C5C5C5C5C8C8C8C8C8C8C8C8
C2C2C2C2C2C2C2C2C4C4C4C5C5C7C7C8C8CACACACBCBCDCD
CBCDCED0D0CECDCB
F3F2F0EFEDEDEFEFF5F5F5F5F5F5F5F5F0F0EFEDECEAE9E9
E4E5E7E7E7E5E2E2DFDFDFDFDFDFDEDEDBD9D9D8D5D3D3D2
DFD9D0C5BCB7B4B47C776F68625F5D5D6668696B6C6C6B69
686E6F717D94A5ABBEBEBEBEBEBEBEBEB9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B6B6B7B7B9B9BBBBB9B9B9BBBBBCBCBC
B0B1B3B3B3B3B1B0
F6F5F3F2F0F0F2F2F2F2F2F2F2F2F2F2F0EFEFEDECEAE9E7
E2E4E4E5E4E2E1DFDCDCDBD8D6D5D3D2CBCAC8C5C2BFBCBB
A0937F6B605F63688886837F7A74716E696B6C6E6F6E6E6C
6F6E717C93AAB9BFAEAEAEAEAEAEAEAEA5A5A5A5A5A5A5A5
A0A0A0A0A0A0A0A0A7A7A7A8A8AAAAAAABABABADADAEAEAE
A8AAABABABABAAA8
F8F6F5F3F2F2F3F3F0F0F0F0F0F0F0F0F0F0EFEDECEAE9E9
E9E7E7E4E1DED9D8D5D3D0CBC8C4C2C1B6B4B1AEAAA5A2A0
A79C897A74767D835B5F626565636260696B6C6F6F6F6E6E
766B6671828D93969D9D9D9D9D9D9D9D9999999999999999
94949494949494949D9D9F9FA0A0A0A2AAAAAAABADADADAE
B0B1B3B3B3B3B1B0
F3F2F0EDEDEDEFEFEFEFEFEFEFEFEFEFEDECEAE9E7E5E5E4
E5E4DFDBD5CDC7C2BFBCB9B6B1ADAAA8A2A09D9994918E8D
7D7A767272777D809194999D9F9F9D9CABADAEB0B1B1B0B0
B6A79FA5AAA4A2AA97979797979797979999999999999999
9A9A9A9A9A9A9A9A9D9F9F9FA0A0A2A2ABABABADADAEAEB0
AAABADAEAEADABAA
F3F2EFEDEDEDEDEFE9E9E9E9E9E9E9E9DEDEDCDBD9D8D6D6
D3D2CDC7BFB7B1ADA7A5A29F9A9693919391908D89868383
8D9093979CA0A4A5A8A7A7A7A5A4A2A2999A9C9D9F9F9D9D
9F918E948D7A7C8D9C9C9C9C9C9C9C9C9A9A9A9A9A9A9A9A
9C9C9C9C9C9C9C9CA0A2A2A2A4A5A5A5A8AAAAAAABABADAD
A7A8AAAAAAAAA8A7
E5E4E1DFDFDFDFE1D2D2D2D2D2D2D2D2C8C8C7C5C4C2C1C1
BCBCBBB7B3ADA8A79C9A999693908E8D8D8D8B8988868585
909090919497999C908D898886898D8E8D8E919393939391
90868B917C5F66839C9C9C9C9C9C9C9C9C9C9C9C9C9C9C9C
9797979797979797A2A2A2A4A4A5A5A5A8A8A8AAAAABABAB
ABADAEB0B0AEADAB
C8C7C5C4C2C2C4C4B9B9B9B9B9B9B9B9B9B7B6B4B3B1B1B0
B0B1B1B1B0AEADAB9F9D9C99979493938D8B8B8B89898988
8E89827D7A7C8083807D7C7C80899399949697999A999997
9690979A7C575F8397979797979797979A9A9A9A9A9A9A9A
9F9F9F9F9F9F9F9F9FA0A0A0A2A2A4A4AAAAAAABABADADAE
ABADAEB0B0AEADAB
BCBCBBBBB9B9B7B7B7B7B7B9B9BBBBBBBBBBBBBBB9B6B4B3
B3B3B3B3B1AEADABA7A5A09C9997969694938E8D93948269
7C90767F866F85967D838B93969694939F9C9996999DA4A8
9D8D9C9C947458919D9D9D9C9A9A99999F9F9F9F9F9D9D9D
A09A999F9F99979F9D9F9FA0A4A5A5A7A8A8AAAAABABADAD
AAAAAAAAAAAAAAAA
BCBBBBBBB9B7B7B7B7B7B7B9B9BBBBBBBBBBBBBBB9B6B3B1
B3B3B3B3B1AEABAAA7A4A09C999796968E8E89868D8E7C66
76917F8D967F8E999C9DA0A0A09D9A979399A0A7A8A49C96
A796A4A096714E7F9F9F9F9D9D9C9C9C9A9C9C9D9F9FA0A0
9D9694999C9A9FA89D9F9FA0A4A5A5A7A8A8A8AAABABABAD
AAAAAAAAAAAAAAAA
BBBBBBB9B9B7B7B6B7B7B7B9B9BBBBBBB9BBBBBBB7B6B3B1
B1B3B3B3B0AEABAAA5A49F9C999696969193908B8E90806E
72968999A48D979C9F9D9C9D9FA09D9C9A9C9C9A948D837F
9A8D9D9D99794E769D9D9D9C9C9C9C9C9A9A9C9D9FA0A2A2
A49A979C9D9A9FA89D9F9FA0A4A5A5A7A7A8A8AAAAABABAB
AAAAAAAAAAAAAAAA
BBB9B9B9B7B7B6B6B7B7B7B9B9BBBBBBB9B9B9B9B7B4B3B0
B1B1B1B1B0ADABA8A5A29F9A979694949396938D8D8D8272
749A8990978691917F7C7D85939C9F9DA89A836F63606569
766E868E9A885D7A91919191939393939696969696949494
A09C9DA5A49A979A9D9F9FA0A4A5A5A7A7A7A8A8AAAAAAAB
AAAAAAAAAAAAAAAA
B9B9B7B7B6B6B6B4B7B7B7B9B9BBBBBBB7B9B9B7B6B4B1B0
B0B1B1B0AEADAAA8A4A29D9A969494939094918885867F74
6F94797174697A77726F717F939F9F9A8D806B584F51575D
5A576F7C968E6276A0A0A2A4A4A5A7A7ABAAA7A5A09F9C9A
838694A5A89C93939D9F9FA0A4A5A5A7A5A7A7A7A8A8AAAA
AAAAAAAAAAAAAAAA
B9B7B7B6B6B4B4B4B7B7B7B9B9BBBBBBB7B7B7B7B6B3B0AE
B0B0B0B0AEABA8A7A4A09D9996949393949A998D8888857D
658B6B5A5B556660857F808D9CA2998D5A5D626563605A57
5854666E8B8B5A6380808283858888896563625F5B585555
666C809AA49D97999D9F9FA0A4A5A5A7A5A5A5A7A7A8A8AA
AAAAAAAAAAAAAAAA
B7B7B7B6B4B4B4B3B7B7B7B9B9BBBBBBB6B7B7B6B4B3B0AE
AEB0B0AEADABA8A7A2A09C9996939393909796898082807C
5F8D726265606C5F857F7F8B999783715157606869655F5A
5B546263858B585B525455575A5B5D5F8383838585858585
747480949D9A9CA09D9F9FA0A4A5A5A7A4A5A5A5A7A8A8A8
AAAAAAAAAAAAAAAA
B7B7B6B6B4B4B3B3B7B7B7B9B9BBBBBBB6B6B7B6B4B1B0AE
AEAEB0AEADAAA8A7A2A09C97949391917A8382746B6B6C69
5F9483777A767D696E696C7A89866F5869655F5A57585B5F
58515B5D839060608E90919396999A9C8B8D9093979A9D9F
9791909699969AA49D9F9FA0A4A5A5A7A4A4A5A5A7A7A8A8
AAAAAAAAAAAAAAAA
B7B7B6B6B4B4B3B3B3B3B4B4B6B6B7B7ADB7AEBEB6AEAB6B
5D5B5A55514B46434949494B4B4B4B4B5A5D62666B6C6E6E
5289837A684B5B659C93939785665B6569635D575455585B
654957525AA8626697979797979797979999999999999999
9D7C80999A9AA09A9F9F9FA0A0A2A2A2A4A4A5A5A7A7A8A8
A8A8A8A8A8A8A8A8
B7B6B6B6B4B3B3B3B3B3B3B4B6B6B6B7AEB7AEBCB6AEAB6C
999A9DA0A2A2A2A299999796969494938385868686868583
4F88807A6B4F6269999494937C5D576551555B6266686665
62494E4B52A0636897979797979797979999999999999999
9D7C80999A9AA09A9F9F9FA0A0A2A2A2A4A4A4A5A7A7A7A8
A8A8A8A8A8A8A8A8
B6B6B6B4B4B3B3B1B1B3B3B4B4B6B6B6B0B7AEBBB4AEAD6E
9A9DA2A7AAADAEAEA2A09F9C99969493979696938E898683
5B918B887F667980949494886B5254655260748590908B86
695548484F976C6B97979797979797979999999999999999
9D7C80999A9AA09A9F9F9FA0A0A2A2A2A2A4A4A5A5A7A7A7
A8A8A8A8A8A8A8A8
B6B4B4B4B3B3B1B1B1B1B3B3B4B4B4B6B1B9ADB9B3ADAD6F
AAAAAAAAA7A5A2A0A4A29F9A96918E8D90908E8B86807C79
609690908D7789909094907C5D4C576B717D90A0AAA8A29D
7F6F494C4F8D746B96969696969696969999999999999999
9D7C80999A9AA09A9F9F9FA0A0A2A2A2A2A2A4A4A5A5A5A7
A7A7A7A7A7A7A7A7
B4B4B3B3B1B1B1B0B0B1B1B1B3B3B4B4B3B9ADB7B1ADAE71
B6B6B4B1ADA7A29FABAAA5A09A9693908D8D8D8B89868380
578983868877898D8D90866B545263748D91979C9D9C9794
8D8548514F7F766096969696969696969999999999999999
9D7C80999A9AA09A9F9F9FA0A0A2A2A2A0A2A2A2A4A4A5A5
A7A7A7A7A7A7A7A7
B4B3B3B1B1B0B0B0B0B0B0B1B1B3B3B4B4BBABB6B0ABAE72
A5A5A7A7A5A4A09FA2A09C97938E8B898B8D8D8D8D8B8886
588980868D7D8D8E8B89775B526277809F9D9A9794908E8D
8D8E40514E71765594949494949494949999999999999999
9D7C80999A9AA09A9F9F9FA0A0A2A2A2A0A0A0A2A2A4A4A5
A5A5A5A5A5A5A5A5
B3B3B3B1B0B0B0AEAEB0B0B0B1B3B3B3B6BBABB4AEABB074
A8AAADAEB0B0AEAEAAA8A5A29D9A97968B8B8B8B89868382
5F8E8389918391918B83694F55768B8EA0A09F9D9994908E
83903855546F805894949494949494949999999999999999
9D7C80999A9AA09A9F9F9FA0A0A2A2A29FA0A0A0A2A4A4A4
A5A5A5A5A5A5A5A5
B3B3B1B1B0B0AEAEAEAEB0B0B1B1B3B3B7BBABB3ADABB076
A5A5A7A7A5A4A09FA09F9C99969391909393918E8B868280
58867C828B7D8B898D7F60495882999693969A9C9C96908B
8093385B5D768E6294949494949494949999999999999999
9D7C80999A9AA09A9F9F9FA0A0A2A2A29F9FA0A0A2A2A4A4
A5A5A5A5A5A5A5A5
B3B3B1B1B0B0AEAEB0B0B1B1B3B3B4B4B7B1B6B0A5B0A47A
9DA8ADA7A5AAABA7A7A5A29D9A9693919391908D8B888685
5D868E82888B85898589524E579494A79193979C9C907D6E
584346576983805D93939191939496979696979799999A9A
998363A7969CA29D9D9D9D9F9FA0A0A0A0A2A4A5A7A7A5A5
A5A5A5A5A5A5A5A5
B3B1B1B1B0AEAEAEB0B0B0B1B3B3B3B4B7B1B4B0A5B0A57A
9DA8ADA7A4AAABA7A7A5A29D9A9693919191908D89888685
5D858E82888B858988894E495794909D999A999386726054
514146576985825D9393919191949697969696979999999A
998363A7969CA29D9D9D9D9F9FA0A0A0A0A2A4A5A7A5A5A4
A5A5A5A5A5A5A5A5
B1B1B1B0B0AEAEADAEB0B0B1B1B3B3B3B6B0B4B0A7B0A77C
9DA8ADA7A4A8AAA7A7A5A29D9A96939191908E8D89888585
5B858E80888983888D88484457968E97999A96866F5A4B46
483E48556685835B93919190919394969496969797999999
998363A7969CA29D9D9D9D9F9FA0A0A09FA0A4A5A5A5A4A4
A5A5A5A5A5A5A5A5
B1B0B0B0AEAEADADAEAEB0B0B1B1B1B3B4AEB3AEA7B1A77D
9CA7ABA5A2A8AAA5A7A5A29D9A96939190908E8B88868583
5B858D80868983888B854343589A919793938D7A62514C4F
414049515F80825891919090909394969494969697979799
998363A7969CA29D9D9D9D9F9FA0A0A09FA0A2A4A5A5A4A2
A4A4A4A4A4A4A4A4
B0B0AEAEADADADABADAEAEAEB0B0B1B1B3ADB3AEA7B3A87F
9AA7ABA5A2A7A8A4A7A5A29D9A969391908E8D8B88858383
5A838B7F85888286868546445899939C938B7D69574F4F54
464B514C547A7F5491908E8E909193949394949496969797
998363A7969CA29D9D9D9D9F9FA0A0A09D9FA0A4A4A4A2A2
A4A4A4A4A4A4A4A4
B0AEAEADADABABABADADADAEAEB0B0B1B1ABB1AEA7B3AA80
9AA5AAA4A0A7A8A4A7A5A29D9A9693918E8E8B8986858382
5A828B7F8588828685894E484F8B889997866C5A51515454
5A60604E4C77805490908E8E8E9093949393939494969697
998363A7969CA29D9D9D9D9F9FA0A0A09D9FA0A2A4A2A2A0
A2A2A2A2A2A2A2A2
AEAEAEADABABABAAABADADADAEB0B0B0B0ABB1AEA7B4AB82
99A5AAA4A0A5A7A2A7A5A29D9A9693918E8D8B8986838282
5882897D8386808588935A4B41727289967A5B4F58666C69
747A72524B778358908E8E8D8E9091939193939394969696
998363A7969CA29D9D9D9D9F9FA0A0A09C9D9FA2A2A2A0A0
A2A2A2A2A2A2A2A2
AEAEADADABABAAAAABABADADAEAEB0B0AEAAB0AEA7B4AB83
99A4A8A2A0A5A7A2A7A5A29D9A9693918E8D8B8886838280
5882897D838680858B9A634B375F607C8E6F4F4E66828B88
868B7F574B79885D8E8E8D8D8E9091939191939394949696
998363A7969CA29D9D9D9D9F9FA0A0A09C9D9FA0A2A2A0A0
A2A2A2A2A2A2A2A2
B4B3B0ADABABABABADADAEAEB0B0B1B1ABADABA7AAADA291
8BA8ABA2AAA79DA79D9D9D9D9C99979690908D8986838080
60888D7C7F838088947D63575D6B76799D554B7C8E85888E
88887C57496E7D5A8D8D8E90919394949393939494969696
998B5F9D9DA09DA09F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F
9FA0A2A4A4A2A09F
B4B3B0ADABABABABADADADAEB0B0B0B1ABADABA7AAADA291
8BA8ABA2AAA79DA59F9F9F9F9D9A999690908D8986838080
60868B7C8285808697856F6872889AA49052518394888382
8D826E4C446E7D5B8D8D8E90919394949393939494969696
998B5F9D9DA09CA09F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F
9FA0A2A2A2A2A09F
B4B3B0ADABABABABABADADAEAEB0B0B0ABADABA7AAADA291
89A7AAA2AAA59DA5A0A0A2A09F9D9A9990908D8986838080
5F85897D85887F827D6F5F57627991A086545A8E9A8B7F77
86725B4346727F5B8B8D8D8E909193949393939494969696
978B5D9C9C9F9CA09F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F
9F9FA0A2A2A09F9F
B4B3B0ADABABABABABABADADAEAEAEB0ABADABA7AAADA291
89A7AAA0A8A59CA4A2A2A4A2A09F9C9A90908D8986838080
5D82887D88887A77635A4C414355718586585F8891837A6F
6E584B46547D835A8B8B8D8E909193939393939494969696
97895D9C9C9F9A9F9D9D9D9D9D9D9D9D9F9F9F9F9F9F9F9F
9D9FA0A0A0A09F9D
B4B3B0ADABABABABAAABABABADADAEAEABADABA7AAADA291
88A5A8A0A8A49CA4A2A2A4A2A09F9C9A90908D8986838080
5D82867D888671685757514643526F86865A556F726C6B63
4F4043546988855B89898B8D8E9091919393939494969696
96885B9A9A9D9A9F9D9D9D9D9D9D9D9D9F9F9F9F9F9F9F9F
9D9D9FA0A09F9D9D
B4B3B0ADABABABABAAAAAAABABADADAEABADABA7AAADA291
88A5A89FA7A49AA2A0A0A2A09F9D9A9990908D8986838080
5F80857C86826555414C524C46516F89855A4E585452574F
3E3748637689835F88898B8D8E9090919393939494969696
96885A9A9A9C999D9C9C9C9C9C9C9C9C9F9F9F9F9F9F9F9F
9C9D9F9F9F9F9D9C
B4B3B0ADABABABABA8AAAAAAABADADADABADABA7AAADA291
86A4A79FA7A29AA29F9F9F9F9D9A999690908D8986838080
6080837A857C5A464154605B4E526B85866054574B494C41
443E546C74807D638888898B8D8E90909393939494969696
94885A99999C999D9C9C9C9C9C9C9C9C9F9F9F9F9F9F9F9F
9C9C9D9F9F9D9C9C
B4B3B0ADABABABABA8A8AAAAABABADADABADABA7AAADA291
86A4A79FA5A299A29D9D9D9D9C99979690908D8986838080
6282837A8377523B667A887F6862768B8D6B6262524E4C3D
51495B6F6E7679668888898B8D8E90909393939494969696
94865A99999C999C9C9C9C9C9C9C9C9C9F9F9F9F9F9F9F9F
9A9C9D9F9F9D9C9A
B3AEAAA8ABADABAAAAAAABABADADAEAEAAAEADA7A8ABA597
74ADA4A0A297A7A29D9D9D9C9C9A9A9A94908B888885807C
627D807A7F6F554F838B886E525274968579665448434446
556B7169558D6C6F868888898D8E8E909091919396979799
94904C979A919F949A9A9A9A9A9A9A9A9C9C9C9C9C9C9C9C
9D9D9D9D9D9D9D9D
B1ADAAA8ABADABA8AAAAAAABADADADAEAAADADA7A8ABA497
72ABA4A0A497A5A09D9D9D9C9C9A9A9A94908B888885807C
607F837C80725A5571726954414969888E887D7163574C48
4F5B5B574986696E868888898D8E8E909091919396979799
94904C979A919F949A9A9A9A9A9A9A9A9C9C9C9C9C9C9C9C
9D9D9D9D9D9D9D9D
B1ADA8A8ABADABA8A8AAAAABABADADADA8ADABA7A7ABA497
6FA8A2A0A499A5A09D9D9D9C9C9A9A9A94908B888885807C
6080857C7D6E5857605B51433E4C667C939391897C69574C
4B4B444440826972868888898D8E8E909091919396979799
94904C979A919F949A9A9A9A9A9A9A9A9C9C9C9C9C9C9C9C
9D9D9D9D9D9D9D9D
B0ADA8A7AAABAAA7A8A8AAAAABABABADA8ABABA5A7AAA296
6BA5A0A2A599A59F9D9D9D9C9C9A9A9A94908B888885807C
638283746F5F4B4E4E48434149546268797A7C776E5F4F46
4C433A4040836E7F868888898D8E8E909091919396979799
94904C979A919F949A9A9A9A9A9A9A9A9C9C9C9C9C9C9C9C
9C9C9C9C9C9C9C9C
B0ABA7A7A8AAA8A7A7A8A8A8AAAAABABA7ABAAA5A5A8A296
66A2A0A2A79AA59D9D9D9D9C9C9A9A9A94908B888885807C
6B8580665A493B434343464F585B5A555554524E4944413E
493E3A4643806C83868888898D8E8E909091919396979799
94904C979A919F949A9A9A9A9A9A9A9A9C9C9C9C9C9C9C9C
9C9C9C9C9C9C9C9C
AEAAA5A5A8AAA8A5A7A7A7A8A8AAAAABA5AAAAA4A5A8A094
629F9FA4A89AA59D9D9D9D9C9C9A9A9A94908B888885807C
71897C5A4B3B3848555A62686B686058514C48434344494C
413E445549796382868888898D8E8E909091919396979799
94904C979A919F949A9A9A9A9A9A9A9A9C9C9C9C9C9C9C9C
9A9A9A9A9A9A9A9A
AEAAA5A5A7A8A7A5A5A7A7A7A8AAAAAAA5AAA8A4A4A8A094
5F9D9DA4AA9CA59C9D9D9D9C9C9A9A9A94908B888885807C
778B7A54443D445D6C6F726F68605F5F55524F4C4B4C4F51
40485B7158765D83868888898D8E8E909091919396979799
94904C979A919F949A9A9A9A9A9A9A9A9C9C9C9C9C9C9C9C
9A9A9A9A9A9A9A9A
AEAAA5A5A7A8A7A5A5A5A7A7A8A8AAAAA5AAA8A2A4A7A093
5D9C9DA4AA9CA59C9D9D9D9C9C9A9A9A94908B888885807C
7A8D7A52444452726C6E695D4E464C554C4C4B4946434140
44547186667A5F88868888898D8E8E909091919396979799
94904C979A919F949A9A9A9A9A9A9A9A9C9C9C9C9C9C9C9C
9A9A9A9A9A9A9A9A
A7A7A5A5A4A4A2A2A4A4A5A5A7A7A8A8ABA8A7A7A8A7A29D
549FA5A2A297A59C9D9D9C9C9A9A99999696938E88827C79
8272716E667274574C4E463B3E4F5858444B525758524B44
3A414E5B6972777A868688898B8D8E8E9394949696949493
96943D9D8D9C979499999999999999999999999999999999
9A9A9C9C9A999796
A7A5A5A5A4A2A2A2A4A4A4A5A7A7A7A8AAA8A5A7A8A7A29D
529FA5A2A297A59A9D9C9C9C9A9999999694938E88827D7A
857A7D76636560443B40434148545B5B5F656B6B62544941
4041464E57636C72868688898B8D8E8E9394949696949493
96943D9D8D9C979499999999999999999999999999999999
999A9A9C9A999796
A5A5A5A4A4A2A2A0A2A4A4A5A5A7A7A7AAA7A5A5A8A7A09C
529DA5A2A096A49A9C9C9C9A9A9999979494918E88837D7A
837F857757514C353E48515860696F74767A7D7462514643
494440414C6074808688898B8D8E8E909394949696949493
96943D9D8D9C979499999999999999999999999999999999
99999A9A9A999694
A5A4A4A4A2A2A0A0A2A2A4A4A5A5A5A7A8A7A4A5A7A5A09C
519DA4A0A096A4999C9A9A9A999997979393918E89837F7D
7D7C806E4B484E404F525A62666C7A887A797162524B4C51
4E443A3744607D918888898B8D8E90909394949696949493
96943D9D8D9C979497979797979797979797979797979797
97999A9A99979694
A4A4A2A2A0A0A09FA0A2A2A2A4A4A5A5A8A5A4A4A5A59F9A
519CA4A09F94A2999A9A9999979797969191908D8985807F
7D797C6B4E546860524B4B4F4E4F6682796B57484651626E
5B4F3E353E58768989898B8D8E9091919394949696949493
96943D9D8D9C979497979797979797979797979797979797
9797999999969493
A4A2A2A0A09F9F9FA0A0A0A2A2A4A4A5A7A5A2A4A5A49F9A
4F9CA29F9D94A2979A9999979796969690908E8D89868280
837C7D715D6B7C72524440433D3A557C7D62443B4B65777F
796955494B5D7483898B8B8D8E9091939394949696949493
96943D9D8D9C979496969696969696969696969696969696
9697979997969493
A2A2A2A09F9F9F9D9FA0A0A0A2A4A4A4A7A4A2A2A4A49D99
4F9AA29F9D93A09799999997969696948E8E8E8D89868382
857C7F7A6C74765F4E41434C443A547D85623E3E5A767D77
74695B52556577858B8B8D8E909193939394949696949493
96943D9D8D9C979496969696969696969696969696969696
9696979797949391
A2A2A0A09F9F9D9D9F9FA0A0A2A2A4A4A7A4A2A2A4A29D99
4F9AA09F9D93A09799999797969694948E8E8E8D89868382
82777D7D7171633E40374051493A4F7988623E43657D7663
4F4B44444F6274828B8B8D8E909193939394949696949493
96943D9D8D9C979496969696969696969696969696969696
9696979796949391
A2A09F9D9C9C9D9D9D9D9F9FA0A0A2A2A0A0A2A2A09F9D9C
43A2A094A09A9F9C9A9A9999979796969393908D89868383
7A7C7A7A7C7760444441768368463B74855D44657F583A4F
464B37404665947780868E91909091939393939393939393
9194448D9F94969394949494949494949494949494949494
9696979796949391
A2A09F9C9C9C9D9D9D9D9D9FA0A0A0A29FA0A0A2A09F9D9C
43A2A093A0999F9C9A999999979696969393908D89868383
7A7C7A777A765D43544E7A826649437C80664E5B6E523A4B
3E483D494B63937A80868E91909090939393939393939393
9094448D9F93969394949494949494949494949494949494
9496969796949391
A09F9D9C9A9C9C9D9C9D9D9F9FA0A0A09F9FA0A0A09F9C9A
41A09F93A0999F9A99999997979696949393908D89868383
7D7D797476715A405B547C7D634E497F7A72584E55493B46
34413B463E4E827480868D90908E90919393939393939393
9093448D9F93949194949494949494949494949494949494
9494969696949190
A09F9D9A9A9A9C9C9C9C9D9D9F9F9FA09D9FA0A09F9D9C9A
41A09F919F979D9A99979797969694949393908D89868383
7F7D7771726E583E4F4E77796657517D767C5F4143443E46
484E4146343D79777F858D908E8E8E919191919191919191
9093438B9D91949193939393939393939393939393939393
9394969694939190
9F9D9C9A99999A9C9A9C9C9C9D9D9F9F9D9D9F9F9F9C9A99
409F9D919F979D9997979696949494939393908D89868383
7F7D766F716E5A43434876796C655A7D767A5B3D4044434E
726B52513A3E7D887F858B8E8E8D8E909191919191919191
8E9141899D91939093939393939393939393939393939393
939394949491908E
9F9D9A9999999A9A9A9A9A9C9C9D9D9F9C9D9D9F9D9C9A99
409D9D909D969C9997969694949393939393908D89868383
7D7C746E7171604B444972716869607D7A6F4E404C4B485B
857151543E3E7A857D838B8E8D8B8D909090909090909090
8D9141899C90919091919191919191919191919191919191
919393949391908E
9D9C9A999799999A999A9A9A9C9D9D9D9C9C9D9D9D9A9997
3E9D9C909D969C9796969694939393919393908D89868383
7C7A726E727668524F4C68584F5A587682603E4860544E6B
7A624454494474767D83898D8D8B8D8E9090909090909090
8D9041889C90918E91919191919191919191919191919191
9191939393908E8D
9D9C9A999797999999999A9A9C9C9D9D9C9C9D9D9C9A9997
3E9D9C909C969A9796969494939391919393908D89868383
7A79726E74796B58574E5B4034464B6B8655344E6F5A5174
725A435F5B5479727D83898D8D8B8D8E9090909090909090
8D9040889A90918E91919191919191919191919191919191
9191939391908E8D
97979797979797979697999A9C9C9A9A9A9A9C9C9A999796
419A99919D9094978B8E90939496949491908E8B89868583
7D746C727C765F4946403A383E484E527C5A3E5169524868
7F3D5B634862777C7C82898D8B8B8D8E8D8D8D8D8D8D8D8D
93894390948D978890909090909090909090909090909090
919190908E8E8D8D
97979797979797979697999A9C9A9A99999A9A9C9A999796
419A97919D909497898B8E909193919190908E8B88868583
7A71696C6F654B343B3D4041444B555D6B55435769514665
68495F554B6872827C82898D8B8B8B8E8D8D8D8D8D8D8D8D
9389438E948D968890909090909090909090909090909090
919090908E8D8D8D
97979797979797979496999A9A9A999999999A9A9A999694
419997909D8E939688898D8E90908E8E908E8D8B88868383
7F776F6F6C5D4129384654575557636F66554046513E4069
445A6644527268837C82888B8B898B8D8D8D8D8D8D8D8D8D
9188418E938B968690909090909090909090909090909090
9090908E8E8D8D8B
9696969696969696949697999A9A999797999A9A99979694
409996909C8E93968B8D8E9090908E8D8E8E8D8986858382
7A76716F6B5B432F41576B6E635F697776654335372D4071
2F6C77496882627F7A80888B8989898D8D8D8D8D8D8D8D8D
9188418D938B94868E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E
908E8E8E8D8D8B8B
969696969696969693949699999997979797999999969493
4097968E9A8D9194909193939391908E8E8D8B8986838282
726F6E6E6B6251445D71838374696F7A837D665755444869
44828E638296697C7A8086898988898B8D8D8D8D8D8D8D8D
9086408D918994858E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E
8E8E8D8D8B8B8B89
949494949494949493949697999797969697979997969493
3E96948E9A8B9193939494949491908E8D8D898885838280
7D7A79797976716C88949F9C8E838388828E8D8E90725457
7F909C7F8B9C777D797F86898886888B8D8D8D8D8D8D8D8D
9086408B918893858D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8E8D8D8B8B898989
949494949494949491939497979796969696979797949391
3E96948D998B909393939393918E8D8B8D8B898885828080
86837F7C7C7F8386999C9D9C948E89887C8B8B919D855D52
BE8E938276897D79797F8588888688898D8D8D8D8D8D8D8D
8E853E8B908893838D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8D8B89898988
949494949494949491939496979796969696979796949391
3E96948D998B9093909191908E8B89888D8B89868582807F
7D7A726C6B717A80868382807F7C77727C7F6E6C807A605A
E48580775A717971797F8588888688898D8D8D8D8D8D8D8D
8E853E8B908893838D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8D8D8B8B89898888
909090909090909091919393949496969696949493939191
3B94938B97898E9190908E8E8D8D8B8B8B8B898886858383
807C746E6C6F7477827D79797A7A766F7C716C77857D5D3E
8383827C7676797D8283858688888686888889898B8B8D8D
8D86408B8D83938888888888888888888989898989898989
89898B8B89888685
909090909090909091919193949494969694949493919191
3B94918B97898E91908E8E8E8D8B8B8B8B8B898886858383
7D79726E6C71767A7D79747274726E697A74727A7F725238
777977767272797F8283858688868685888888898B8B8B8D
8D8640898B83918888888888888888888989898989898989
8889898B89888685
909090909090909090919193939494949494949393919190
3B93918997888D908E8E8E8D8D8B8B898B89888685838382
7D7A726E6E71777C7977767472716F6E7474777A76634935
7172747271747C82808285868686858586888889898B8B8B
8D8540898B83918688888888888888888989898989898989
8888898989888583
8E8E8E8E8E8E8E8E90909191939393949493939391919090
3A93908996888D908E8D8D8D8B8B89898989888685838282
827C746C696B6E71686B6C6C6C6C6F716B71777972624F43
696B6B6968696F768082838586868583868688888989898B
8B853E888982908686868686868686868888888888888888
8688898988868583
8E8E8E8E8E8E8E8E8E90909091919393939391919090908E
3A91908894868B8E8D8D8B8B898989888888868583828080
80796E635D5B5B5D555B626363656B716E71777C7A726862
6565635F5A5A5F637F808285858583838586868688888989
8B833E888982908586868686868686868888888888888888
8686888888858382
8D8D8D8D8D8D8D8D8E8E8E909091919393919190908E8E8E
38908E8894858B8D8D8B8B8989888888888686858382807F
7A74685D555254555F686F6F6969717A797472778085807C
7474716B6665686C7F808283858383828585858686888889
89833D8688808E8585858585858585858686868686868686
8586868886858382
8D8D8D8D8D8D8D8D8D8E8E8E90919191919191908E8E8E8D
38908E869385898D8B8B8B89888888868686858382807F7F
7C766E6560606365717A807A6E696F777D6E60657785837C
7D7F7D7A76767C807D7F8083838382828385858586888888
89823D8688808E8385858585858585858686868686868686
8585868686838280
8D8D8D8D8D8D8D8D8D8D8E8E90909191919190908E8E8D8D
38908E869385898D8B8B8989888886868686858382807F7F
837F777271747A7D727A7F7462575B637C634E51687A796F
7276767472767D837D7F8082838382828383858586868888
88823D86887F8E8385858585858585858686868686868686
8585868685838280
89898989898989898D8D8E8E9090919190909191908E8D8B
40888B8889828E838B8B8989888886868585838382828080
7D7D7C7A797776766F6F6E68605B5B5F7272727474767676
77777779797A7A7A7F7F8080828283838383838383838383
85864B7A85897D8883838383838383838383838383838383
8585868685838280
89898989898989898D8D8D8E909090918E909091908E8D8B
40888B8889828E838B898989888686868583838382808080
7D7D7C7A79777676767776716B66696C7272727474767676
77777779797A7A7A7F7F7F80828282838383838383838383
83854B7A85887D8883838383838383838383838383838383
8385858685838280
89898989898989898B8D8D8E8E9090908E8E9090908E8B89
40888B8889828E838989898888868685838383828280807F
7D7C7A797776767477797976716F72767272727474767676
77777779797A7A7A7D7F7F80808282828383838383838383
83854B7A83887D8883838383838383838383838383838383
838385858583807F
88888888888888888B8B8D8D8E8E8E908D8E90908E8D8B89
40888B8889828E8389888888868685858382828280807F7F
7C7C7A79777674746F7172716E6F72777272727474767676
77777779797A7A7A7D7D7F7F808080828282828282828282
8283497983867C8682828282828282828282828282828282
828385858382807F
8888888888888888898B8B8B8D8D8E8E8D8D8E8E8E8B8988
40888B8889828E838888868685858583828280807F7F7F7D
7A7A7977767472726C6F716F6E6E74797272727474767676
77777779797A7A7A7C7D7D7D7F7F80808282828282828282
8283487782867C8582828282828282828282828282828282
8282838383807F7D
86868686868686868989898B8B8D8D8E8B8D8D8E8D8B8988
40888B8889828E8388868685858383838280807F7F7D7D7D
7A79797776747271717476747172777C7272727474767676
77777779797A7A7A7C7C7C7D7D7F7F808080808080808080
8082487782857A8580808080808080808080808080808080
8082828382807F7D
8686868686868686888989898B8D8D8D8B8B8D8D8D898886
40888B8889828E8386868685838383828080807F7D7D7D7C
7979777674727171767779767272767A7272727474767676
77777779797A7A7A7A7C7C7C7D7F7F7F8080808080808080
8082487780857A8580808080808080808080808080808080
80808282827F7D7C
8686868686868686888889898B8B8D8D8B8B8D8D8B898886
40888B8889828E83868685858383828280807F7F7D7D7C7C
7979777674727171747676726F6E71767272727474767676
77777779797A7A7A7A7A7C7C7D7D7F7F8080808080808080
808246768085798380808080808080808080808080808080
80808282807F7D7C
8585858585858585888889898B8B8D8D8989898989898989
43838588897C8B8683838383838383838080807F7F7D7D7D
7A7A79797777767674747676777779797A777476797A7976
79797979797979797C7C7C7D7D7F7F7F8080808080808080
7F8046767F8379837F7F7F7F7F7F7F7F8080808080808080
7F808080807F7C7A
8585858585858585888888898B8B8B8D8989898989898989
43838588897C8B8683838383838383838080807F7F7D7D7D
7A7A7A797777777674767676777979797A777474777A7976
79797979797979797C7C7C7D7D7F7F7F8080808080808080
7F8046767F8379837F7F7F7F7F7F7F7F8080808080808080
7F808080807F7C7A
858585858585858586888889898B8B8B8989898989898989
43838588897C8B8683838383838383838080807F7F7D7D7D
7C7A7A7979777777767676777779797A7C77727276797977
79797979797979797C7C7C7D7D7F7F7F8080808080808080
7F8046767F8379837F7F7F7F7F7F7F7F8080808080808080
7F808080807F7C7A
8585858585858585868688888989898B8989898989898989
43838588897C8B8683838383838383838080807F7F7D7D7D
7C7C7A7A797979777677777779797A7A7D79727174797A79
7A7A7A7A7A7A7A7A7C7C7C7D7D7F7F7F8080808080808080
7F8046767F8379837F7F7F7F7F7F7F7F8080808080808080
7F808080807F7C7A
858585858585858585868686888889898989898989898989
43838588897C8B8683838383838383838080807F7F7D7D7D
7D7C7C7C7A7A7979777779797A7A7A7C8079716F72777A7A
7A7A7A7A7A7A7A7A7C7C7C7D7D7F7F7F8080808080808080
7F8046767F8379837F7F7F7F7F7F7F7F8080808080808080
7F808080807F7C7A
858585858585858585858586868888898989898989898989
43838588897C8B8683838383838383838080807F7F7D7D7D
7D7D7D7C7C7A7A797779797A7A7C7C7C827A716E71777C7D
7C7C7C7C7C7C7C7C7C7C7C7D7D7F7F7F8080808080808080
7F8046767F8379837F7F7F7F7F7F7F7F8080808080808080
7F808080807F7C7A
858585858585858583858585868888888989898989898989
43838588897C8B8683838383838383838080807F7F7D7D7D
7F7D7D7D7C7A7A7A7979797A7C7C7C7D837A6F6C6F767C7D
7C7C7C7C7C7C7C7C7C7C7C7D7D7F7F7F8080808080808080
7F8046767F8379837F7F7F7F7F7F7F7F8080808080808080
7F808080807F7C7A
858585858585858583838585868688888989898989898989
43838588897C8B8683838383838383838080807F7F7D7D7D
7F7F7D7D7C7C7A7A79797A7A7C7C7D7D837A6F6B6E767C7F
7C7C7C7C7C7C7C7C7C7C7C7D7D7F7F7F8080808080808080
7F8046767F8379837F7F7F7F7F7F7F7F8080808080808080
7F808080807F7C7A
838383858586868685858586868888888B8B8D8B89888583
40888B8889828E83838383838383838382828280807F7F7F
7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D827D797474797D82
7C7C7C7C7C7C7C7C7C7C7C7D7D7F7F7F7F7F7F7F7F7F7F7F
82805263857C85827F7F7F7F7F7F7F7F8080808080808080
8582808082807C77
838385858686888885858686888889898B8B8B8B89868382
3E86898689808E8285858585858585858383828280807F7F
7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F827F7A76767A7F82
7D7D7D7D7D7D7D7D7C7C7D7D7F7F80808080808080808080
83805265857D858280808080808080808282828282828282
8582808082827C77
8585868688888889868688888989898B89898B8988868382
3D85888588808D8085858585858585858583838382828080
7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F82807C7A7A7C8082
7D7D7D7D7D7D7D7D7D7D7F7F808080828080808080808080
83805265867D858380808080808080808282828282828282
8583808283827D79
8686888889898B8B888889898B8B8D8D898B8B8988868382
3D858885867F8B8086868686868686868686858583838282
8080808080808080808080808080808083827F7D7D7F8283
7F7F7F7F7F7F7F7F7F7F8080828283838282828282828282
83825466867F868382828282828282828383838383838383
8683828283837D79
888889898B8B8D8D89898B8B8D8D8E8E8D8D8D8D8B888583
3E85888588808D8089898989898989898888868685858383
838383838383838383838383838383838383838282838383
828282828282828280808282838385858585858585858585
85825566887F888585858585858585858686868686868686
8685828385837F7A
898B8B8B8D8D8E8E8B8D8D8D8E8E9090909090908E8B8886
40888B8889828E838B8B8B8B8B8B8B8B8989888886868685
858585858585858585858585858585858585868686868585
838383838383838382838383858586868686868686868686
868355688880888586868686868686868888888888888888
8885838386857F7A
8B8B8D8D8E8E90908D8D8E8E9090919193939393918E8B89
438B8D8B8D8591868B8B8B8B8B8B8B8B8B8B898988888686
858585858585858585858585858585858586888989888685
838383838383838383838585868688888686868686868686
868357688980898686868686868686868888888888888888
888683858685807C
8D8D8D8E8E9090908E8E8E90909191919494969493918E8D
448D908D8E8693888D8D8D8D8D8D8D8D8B8B8B8989888888
868686868686868686868686868686868588898B8B898885
858585858585858585858586868888888888888888888888
868357688980898688888888888888888989898989898989
898685858685807C
83888D8E8D8B8E918E8E8E90909191919090908E8E8D8D8D
4C8093898D8E8E998E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E
8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8E8E8D8D8B8B8B89
8B8B8B8B8B8B8B8B8B8B8B8D8E8E8E908D8D8D8D8D8D8D8D
8B8063658B9788868B8B8B8B8B8B8B8B8989898989898989
8D8D8B8986827F7C
888E93949391939693949494969697979696949493939391
54869C939797949D94939393919190909393939393939393
8686868686868686898989898989898991919190908E8E8E
858585858585858582828383858586868989898989898989
99896662839086888D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D
8E8E8E8B8885807F
8B909496949396999696979799999A9A9999979796969494
44798E868D8D85899696949391908E8D9090909090909090
949494949494949493939393939393938E8D8D8D8B8B8989
919191919191919191919393949496969494949494949494
978966628394909790909090909090909090909090909090
9191908E8B868380
898E93949391949696969697979999999797979696949494
5A8B9F9AA2A096979A999796949190909696969696969696
8D8D8D8D8D8D8D8D8E8E8E8E8E8E8E8E9999999797969696
8B8B8B8B8B8B8B8B888889898B8B8D8D8B8B8B8B8B8B8B8B
79725B5F8596919A91919191919191919393939393939393
949393918D898583
898E9394939194979697979799999A9A9999979796969694
5582918D96978B8B9696949391908E8E9696969696969696
91919191919191917C7C7C7C7C7C7C7C5A5A585857575555
4B4B4B4B4B4B4B4B41414343444446464F4F4F4F4F4F4F4F
666B60698B91868993939393939393939494949494949494
949493918E898683
888D9394919193969697979799999A9A9999979796969694
6088918896998E8E7C7C7C7C7C7C7C7D4F4F4F4F4F4F4F4F
5F5F5F5F5F5F5F5F7C7C7C7C7C7C7C7C8585838382828280
888888888888888889898B8B8D8D8E8E9393939393939393
828982869D99858393939393939393939494949494949494
949493918E898583
7F8388898886898B8D8D8E8E9090919190908E8E8D8D8B8B
27494C404F574F4F6E6F7172747779799393939393939393
8E8E8E8E8E8E8E8E888888888888888891919190908E8E8D
858585858585858590909091919393939090909090909090
979F9391A49C898B91919191919191919494949494949494
939391908D888582
71767C7C7A7A7C7F808080828283838583828280807F7F7F
607D7C6E7D8882837C7D808386898D8E8383838383838383
858585858585858589898989898989898D8D8D8B8B898989
89898989898989898989898B8B8D8D8D8D8D8D8D8D8D8D8D
8B90827D9190838D90909090909090909393939393939393
9191908E8B868380
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7F7E7F837D7F7D807F7F817F7E80817D8282827E84828181
7F7F7E807D82818181807E8081817F7E7D7E7F807F7E7F7F
817E7C7F7E7E837F8084838081807E7E81827F7F81818180
7D7F7F7F808081817F8180817D80807F7E7F7F7D827E7E7D
83808180817D83827B807E81838382847A7C7E7D7E7F8184
7E807F7E80807E80
81808081808081828283838382838380838182828281837F
8183818182808280838281818582837E8281818182828382
807E817F8082808180828382828184818183808082828280
828383828282818484838182838181828183818581838280
81807F7E7D7A7A79807E7E7C7C767876848181807E7C7E7D
82827F7F7F7E7D7F
81817E817E817F8181818181817F807F807E7E817E7F807E
81808180807F807F807F817F7F81807F7F80818182828081
7E7F7E7D80807F7E827F807F807F81807D7B7C7E7E7D7E7E
7F807F807E7E7F81817E7F807E807F7C827F818183828081
8180837F80807E7F85848485838485858483828281818382
8583858282848283
807F8180807F8281827E7C7F827E7E7E807E7F807F80817F
807F807E807F7D81807F7E81828081807F7F817F8080807E
81818182838180837F7E7D7D7F827F7F7F807F7E7F7D807F
8081827F8081828181818080807F807F8280818181838080
7F7F7F7F7D807D7E7D7E7F7D7F7F8282807D7B7D7F7F7F7F
7C7C7D7A7E7B7D7E
857F84818281828280807E7C7F827E7B8080807F7F80817C
8080817E7F818280817E81837E7F7F7E7F817E7E81807F7E
8183827F82828180817F7E807C7F7F7F848081827F82807F
838180838180838181807E808382827F8181808081817E80
7F7E7F82807F7D7C8383827E827F7E808080818182818285
817E817F85828383
8281837F7F8282817C7F7E7F807F7F7E837E818283807E81
838180807F8182827F817F807F807F7F8180807F80808080
817D80817F807F7F7F807E808081828281808180817F7F7F
7E7E7F7E7E817F817E7E7E7B7E7F7E7E7F818181817F7F80
807C7F7F7E818083858281817E7F7C7D7C7C7C7D7F7C7D7E
7D7D7C7A7E7E807F
8282817F7F8081827F7E7F7F807F7F7E8182828182818280
807F7D8081818180837F8380828081817E7F807F7E807F7F
7E8080818182817F83818180808282817F7F7F7E7E7E7D7F
7E7E7E7F7F7F817F807D7F7E7D807F7D7F7E808082808081
817F807F828082857C7D7E7E7F7D7E7E8585848483848281
8181808184838383
80827E7D7E80817D7F807F80827F817E807F81817F7E7F80
7B7D7E7E7D7F7D7E8180808081828283817F8181807F807F
83828082808280837F7F7E7F7E8081808082818381828181
8082838285838481817F8181828280827E7F7F80807F807F
84817F8082827E807E7E7F817E8486858180827E7E7D7B79
7D817E7D7F80807E
817F80818183818084808280838280817F7F807E7D808380
837F7E81817F81827F7D7F7D817D7C80827E81808080807F
7E807C7E817E7D7F7F7E7C7E7D7E7E817F807E7F7E817E7F
7F7E8180827F8081817F8081817F817E8182828182828081
84828081838182828181807F7E80807F8285828181808281
807F808080818181
808080808181807D8180828284827F8081817F7E807E7E7F
7F7D7D817F8180807F7F7F8083808081807F7D8081818281
81808183808181828280808183808281818283827F818082
7F828181838083827F7E817F808182828382818282808282
807F7E827F7F7F7E838081817E8080818082818081838082
8083808083838480
8080807E83807F7F827F81818281828180818081817F8281
80818080808081827F7E7F7F818081817F807F8181817F7F
7E80807F7E7E7F7F7F7F80808080807F7E807F7E81807F80
7F7E8080827E81807E817F817F828281817F817F80807E7D
807E807F807E7C7C80807E7F81818081818081817E7F8080
7F807E807E80807D
848280807F7F807C80817F81828182808282818283818082
8481828283808381817F80817F81827E7E7F7E8180808180
807F7E7F7E7F808182807F8181808183807E8080817F8181
7F81807F7F80808083817F7F808081817F838282807F7E7E
80808180818182817E818284828282817F7E807E7C7E7E7E
7E7E7B7D7E7D7F7F
8282818382828181817D807D81807F7E807E817E7E7F8082
818180828483828280828280828184828381828184858482
82838082817F817E7F7E8181838583838480828382808281
7E807F7D7E7F818381807F8081817E7C808381817E7F8181
7C827E7F83807F7E817F7D817F7E807F80817F7D7E818081
7F7F818280808381
8280818080817E7E807F817E8180817E83838080817F827F
7D807D7F807F7E7F807E7F7F807F807F7F7F7E7E7B80807E
7D7E7D7E807E7F7F817D7E7D7D7F7E7D8281818181807F7D
7C7E7E7D7D7D7F807A7C7E7E7E7E7E7D807E7D807E808080
7F808080818080828083807F81817F818381818081827F7F
7E817E7E8082817F
848080808081808080808181827F81808282817F8281827E
807E808080808080807E817E808281818182828384838484
838383828480828182828183828180828382818281828285
85828082838281818081807E807E7E7E8181808181828282
818181808182807F807F7F7E7E7F7F7E8181807F807D7E7F
808080808081807F
7F807E7E807F7F7E7E7F8080817E7F818181808080808280
80827E827E80808082818281837E808182807E7D7F807F81
817F7F807E81807F81817F828081818181807E7F8182807E
817C7F7F817E827F807F807E8181817E82807E7E80807F7E
828280827E807E7F7E7C7F7E7F7D80807E80807F807F827F
827F7F8180818381
807F808180828280817F8380838480828380818282818082
807D7B7D8180808282838082837F7D7D817F82807D7F817F
85807D7D7E838787777D7F8483817D7C858783818182807F
817F7D848A7F7775837F807E818181827D7D7F7D81807B7E
82808381807F807F7F807F807E7D7F7F817F818280838182
838281818082807D
83828284838381827F7E7E807E7D7E7D7F7F80807F82807E
83807F7E80808081818482828180817E8083808180848183
78777B8081817C728D8986838280807F7A7B7B7B7C7B7D7E
7F7A7679828089897C81847F807E7E818283818383848283
84817F808281808184858385818080828383817F827E7E7C
847E7F80827F7F7D
807E7F828082837F817F818181828080808380807F828181
8381807F7F7E7F7F7F807F827E7F7F7C817E7E7E7F7E7E7C
878D887C7C818386727475787A7F8083848484807D818086
8586837B737A7E79868584827E7D7D7B8281807F7D7D7D7C
7F7B7C7B7E7F7E7D7C7E7E7D7D7B7D7E7E80808183808282
8483838385858283
81817F7E80817F7E7F7E80827F8080807E7F7F7F817F807D
7C7E7D7D80827E7D7E7D7D7E7E807D7D80817F808080827F
7B72707E87867F79928C8782838180827A7B7C7C7C7C7F80
7B8387807F8887867F7E80807E7F7F7F7E817F8183817F7F
84808183838584857F828081828283857C8181808080807F
7C7D7D7C7D7D7F7D
838080827F817F7D80807F7F80807F808280807E807E7B7E
7E7B7E7D838382857E818382838684827F7E7E7D7C7D7E7F
89898B807C777A7D79787A7B7C8080847C81838683807F7F
7B7F867C7A7E8476818181858282858280807F8281838481
7F7D8081807F8081807D8182818181847B7F7E7D7F807E7F
8383828082828181
7C7C808180807F7E8080817F808181818684848584858382
828082838181817E817E7E7D7F7F7F807E7E7C7F83828282
7C807D7D7B807F838586838383807C7C808181847B7A7C7D
7984838082798085807F818181807F7E7E80817E7E7F7D7F
7E7D7E807D7D80807F7C7E7C7F7D807F8080817F807F807F
8183828285828382
83818383838482818A87848181817C7A7E7E7B7B7D7B7C79
7C7D7D7E7E82828085818082828382838481818281838380
7E828385838380777F8085807D7B838082838181867F7F81
8086867D8B79737F7E7F8080807F807E7F818080807D7E81
8180807F828182827C7E7F7E7E7E7F818082817E807F8080
81817F7F7F7F7E7F
84817E807C7D7C7A827F7F817F8082818082838484858282
8482828182807E7C847D7F8181808080828281827E827F71
7983828583797E82777D827D7981878481807E7E7D7E8480
7F837F758C857A7F81818283848182817E7F80807D817F80
7C7C7D7E7F7E807F827D81817F8080817F7D817D817E807E
817F7F7F7E80807F
8280818082828281827E81838183807F8282818281838380
82817F817C807E7B7E7F7E7F8280807F817D81807D78837D
7F7C808185897B7B7D7D7C847E798189857F82827F7E7981
7E887F7B867B7E7381807E8185808181817F82807E80817F
8080807B7E8485807E7F82817F7D7F8383817F7F817E7C7F
837F818282828082
838181808183818280807E7E7F7F827E827F817F7F828080
8182818080817E807E807E7F80808080818381857F7D8982
83807A807B878282837D847D7B7F81818385867A797A7F84
7987787A7D8586807D7D7C7E7F817F808282817F7D7E7E80
81828582838282788382828280818181807F817E807F7F7E
8082828181818181
81817D7F80817F7F8281817E818280818180807F81818181
817F7F7F7F81817F827E7F808283807E817F7F80807B8380
827D847A72817B7D7C7E7E81867F7E7F80807F8387848284
7D89837D7D8887847F7D7E7F80807E80808282807D7E7B7D
7D7F84807E827F7A8081808282818081807F7F817F807F7F
8180808180838180
7F82807F7E7E7F7F807E7F7F817F7E7D817E80808180807E
837F807F7E807E8082817E8081808180817D7D81807E827D
7C78828581888982828179836D83887E767F8B7C7E7F7C78
70798A8A7B827A7E83838783848586848584848485838683
7C7E7F7B7C828480827F80807E7F7F81807F7E7E7F807F7F
7D7F7F7F7F7F8280
817B807F81807F7F8180807E7F80817F817F8081837F817F
817E80817E7D817E827C7F7F80838281817C7E83837E867D
7F7C808376807A827E7F808382807D858C727B838B898680
858773907C81787F7E797C7A7A7A78797A78797A817F8184
8F8E857D7982868782808081817E8082817F807F83807F7F
7D7E7F808380837F
7F807F7F8281807F807E7E7F827F7E7D8080817F81818181
8381817F8081818083808082838383818079797E8181807A
808486848481828385817B777F7B808083807E7C7E7F8481
8386787B847C7F878B8D8C878884807B8F8D89898284837D
71698B81787F80807E7E7F807E7D7F80807F80807F80807D
7F7E7F7F8181807E
807F7D7F8481807F8080807F817F7F7F827E7F80817D8180
7F7F7E7F817F80828281828381838182817A7B818684847F
8181857F787C7E85789170838380837389857E79797C807F
7A837B78858280797578797C7B808283717675777A7E8184
8F857A847B807E7C7F8180827F7E7E7E80817F8180807F7E
7F807E82837E7F7F
807F8180828080807A7F82807F7F807E81807F828282817F
81817E807F83827F7F82817F7D7D7E77877D7C80807B787E
817F867285897D867C85867C888B7584797E7E8287847F7F
83877C7B7E7F7D8087848381827E7F7D8887878484807E7C
817C72858284827B838082827F80807F837F808280817F81
818081808183827F
828081808280817C818281808080807E857B847A80828274
86807D7E7D81808080817D7E80808484827F807F83818282
8082847A78858288777C7E7D8D7B837C797D81888686837E
7B897D7F887480818181827F82828181828380818180807F
7E897B827F807C81807E817F81818281818280827F7C8182
8180817D83818381
7D7F81807D7F7F7E7D8282807E81827D817E847A7C828281
7980828183838080868284818381808088868482827F817D
878382897F7F7A757F7E8380757F847D8887857F7A7B7B79
7A89808582748380807E7F80827F817E80807F8180807F83
80857A8082837D8280807F8280807E818280807E817F8280
807F8181817E8180
827E807D81807F7E7D7E817F7F7E7F7E847D837A7E828184
888987827F7D7D7A8180807F7F7F7F817C7C7B7C7D7F7D7C
807A807E807E8C8A7D8082887488877C8880767F83838587
797E8481827B7F7C807E7F807D807F7E807D7F7F80808180
7D837A827F807B827F818281818081818382827F817F7E80
7F807F7F7D7F807F
7F7D7F7F807F817D828080807F7F807E7F7C837C80838281
7E84827E7D828484827F8081828281848181808182828584
7D797B7D7D83817D7E8183737E8C85777687857C7D75797A
8D70827E81837C7B827D817F7E80817F7E7F7E7E807F807F
7B847D8281807C81818182838180808082808082817D7E80
7D80807F8182817D
817E7E7F8181807F7F8081807E7E7E7F817E867D7F827F84
787B7A7B7E8284847D797B817D807D7F838183817E818380
7F7E8684808B7C798281877386887E7A8884807D7D7F807D
8579807B7F7F7E827E7E807F837E81817B817F827F808181
7E817C8281817D8483808284837F82808080837E7F7F8280
7C827E80817E807F
828180817F8082817E7F8080807E7E80817B857D8082817F
808483828482848381828182858485868481817F7D7F7D7D
7F7E80837E887E7D7A82817C847A778B7F7D7E8183848387
817C847C827B828B7F7F808281817F817F7F828080807F80
7E807B8380817C837E80817E807C7F7F7F8080817D7F7F7E
8080827F8081827E
827F7F7F8181828280828282817F817F807B847D83817E82
7D817F7D7C7B7B7B7A817E7E7F7C7A7E8382817E817F807F
7F78857979857C7C81857A80827187857B7A817C7F7F827F
80798B7880847C86807E8080808181837E7F808182818180
7C817A8381817E838282828280807F8183808181807E8081
7F8080817F808280
827F808281808081818182827F828081817B847D82817D7F
7D84818181808384858384827F8282837F7D7F7D7F828080
817E898579847D817F897788837B7E7F84827E7F807E8182
85788D738780728080807F817F808182807F808182818080
7F85768180837F83837F807E807E7F7F7F8180828181817F
817E828182808181
817F7E81827F8182818180807E8080807F807F828980857D
84837D8480807D7F847F7F807F7F7E83807D828181817E80
817D7E867D7E787F84807C838283827584827F7B7C87897B
7D8882768F737E83817F81817F8181808381808181827E7F
827D8B7986807E808280807F80817E7F807E818082808081
8181808084808380
807E808084817E817F80807D7F7F807F7B7F7E7F857E847F
80817D80827C7E81817F818180807F8082807F7F8280807F
82807B85847E827A7E837F837E818484807D7D81897B787B
7D8481778B7680807F80817F8380817D81828081807E807D
7E7E877A85807D81828180827F80807F7F8180807F807F81
8281807E8082817F
82817F81838182828080807E8180818080827D80867E847E
80827D8282817F7F80828283807E8281828080808280817F
80807B7F827E82817F7E8186807F827F7E848087747E8584
8285817994758080807F7F828080817E807F8081807F7F7F
807D867A83837E818380818282807F7F8381817E807E7F83
8081807F8081807C
817F7F7F827F7F81807F7E7F7D80818180817F82857E8380
7D837E84837F7F8181808182848080828181818180807F80
807E7C85767D8381808185857C7B807E828188707A83837D
8586807A857C8182817F7F80837F7F807F817F817F808081
817F847883817E80817F8080808180828080807E827F8183
808380828081817E
828082818080807F817E80817C7F7F817C807D7D857C8585
7D857F8184817F81818182818280807E7E83817E82817F7F
7F7F7C8683767F7F83868084787E817C7E877A778084817C
847F7A7D7E8784857E81817E7F7E807E80817F7F827F7E7F
7E7D827A837F7F848180827F8180827F81837F80807F8181
7E7F82807F82807F
81817D808080818080807F7F807F818080847F7E847C8082
80827F84827F7D827D7E8080818281817F8183808081817E
82827D84827F827985828284806F8C807D86768186837C7B
7779757A7D8881827F7D807F817E7F7F807F81808180817F
7D807E7982807F7F8180817F8080808181808180807F7F81
807F7F7F7F81817E
80807E808081808280807E7F7F7E7F7F7F828080837C7F82
7F827F82817F7F837F8080818383817F828281807F83807E
84817B8481828582857D7D7F886E8D87847A7F887F757C8B
89888A807F7A808181808283818080828180818381818180
8080837A85817D7F807E807F807F7E808180807E807F7F7F
7F7E7E807E7F807E
827F7F82827F83827F8180827F80818081827F8085797F81
7C847E8182817F837D7F7F81808080808183838081818180
81807C817A8084818077808090777E7F817486877D837F7E
7E7584897C837B807F80828280838080828382818381817F
807E807A86817C817F7D817F7E807F7F82818181817E807F
807E808181817E7F
7E807F80828181827F7F7E7E807F817F80828286817E857A
857F7C82797F837F838181827F817E7E83807F7E81818481
7F7D7D86847685837D8A85797777838E7C8088708484807D
7F7F79847A8A82818180817E7F7D7F808081818481808180
807C8380817D7F7D7E7E80828083817F7F81818181828180
7F807E7F7D82817E
807E7F807F7E807F7E807E808081817E82828483827F847D
82807B817E7D847E828484818183817E828181808282827F
7D7F7F878181797D79847F838A807B727D8286847D7C8182
7A818B7D82807D7F8080807F817F807E7E80808182818181
80807F837D7E81807F7E807E817D7F7E7F8181827F7F8181
7F807E7E8081807F
7E7D7F817F7F81817E7E817E817F7F7E837E7F827F7D857D
80817D837A7E837D80817E80817F817E818081818183817F
80817885817E837F86887C7A75837E7885828383767F8281
7E87788382837F7F807E8080807F7F7F7F81838181818181
7F7E7C82817E7F7F807E7F7F7F7E7D7F817F7F7E827F7F81
8180827E8081827F
7E7F82818181818382807F7F7F7F7F7F817F8082807E837E
7C7E7C837C80847D80817F7E837E7F7E7F8081808181827F
81807C7C7C7D8589807C8185867C9084837F7D857E828889
7E767C8181808180817F8180827E7F7F80808080807F8080
7F827A817E7F827E808081837E807F807E7D7E7F8281807F
81827F8181807F80
807F808383828081847E81827D807E80827F8084837E837E
7B817D837D81857D7F80808082808180828181828081807F
83827F8279778C7B7B7B7E83857F8582837F80768A897C71
7D838478897D7F82827E8082837F80818180807F83808084
81817F7E827E807F807E7F7F817F7F7F818180807E828084
8082817F7F80837F
807E7F81827F7F7E7F7F8181807F808083828080807E847E
7E817E837F7F847F7F7F80817E7F817F7F7F7F7F7C818281
80827F837C7E887582827D7F837E8081827E857F7F7F7A7D
868B7E718A7C807F81808180838080808080807F817D7F80
80817C81817F817F7F8181807F817F82807E7F7E7F808080
808281818180817E
837E8081828281808180828282808080807F7F83807D837F
7D8380837C81857E8180828183838182857F7E7E7E808080
81847E838184897C847D7F837F7E87848380808084837E84
828677818282827E8281818183818080808080817F7F8081
84807C82827F827E7F817F8182808281818180827D818180
7F81817F8181827E
817B7D7E80807F818280807F827F7E7E7F808084817E837F
7A827F827F81837D7F83818083818180827F7F818082827D
81837F7F7D877D857A847E838771897D7B8B77797F7F7C86
7A7F7C8E8080827F817E82807F807F807D807F8080818080
80807D84807F827F7E807F80807F7E817D7E7F7E807F8180
818181808081817E
807F8081807F7F80817E80807F7F7B7F837F80818280827B
867A80817F857E7E847F80818482807D7D807E7F807F827E
80857E83788A7582837C7988897B82787D8C7E7F85818181
7A718A8A7879867E8182807F828081807E80807F807F8082
8678868381847C8381808180827F7F81827E7F80817D817F
8081828081817E80
7E7E8182807E7F80817F80817E7F7E7F7E807F817F7E817C
827A7F837C877C7E817E81808181827E7F7F807E807F8082
80857F827E7F72928C89807B838182837C81898272787C84
94917773817A86818182818280808080808181807F7E7F82
7F7C82827F857A827E8180807F808081807E7E7F827E8283
807E81808080807E
81808180817E7F7F8081808181807F7F827D7F81827E8081
7C7F7F827D847C8081807F8180807F808080817F7F7F7F81
85837D83818B727F74757B84867E808678797881858A8C85
7E7C7F81867D86808281838280817F80828081807E817F7E
837E808380857C848181807E7F7E8180817E7F8182808182
807F807E81807F7E
807D82837D80808181817F8081817F80817F7F83807F8280
7D7F807F7D857D7F7F8080808080817E8182818081808181
83857B7E8B867A797C8283847E7A83798A86847E7273797E
7A8187828678817C81828182807E7F80808181807D837D80
837E7F8380847C817E7F807F7D80807F8080807E80828080
817F80807E81807D
7E7E8381827F82828382808084828081837D7F83837F8184
7E827F7F7D857C81817F80808481817D828280827F7E7D80
837E807B727D84808487807A777A84808087807E83838283
7F85887F817B7C7D82817F81838180817F837F827D807E7D
82807E837C837A817E7F80807F828081817F7E8180808281
7F807E7F80807E7E
7F7F7F827E7F80817F7F808182817F7F84808082817F8381
808381807A837980828280807F818080808382807D7F7E82
817D83817C86877D77767881878F807D7D85828484837E7C
838481757F807D82817F807F837E80807D8180807F818181
81827D817F847B83817F7E7F807E8080827E7D8083808080
8181828181837F7F
80807F808180807F8280808282807E81817D8080827C8284
8082837F7A847D8080817D818081817F808281817D7E7E81
807A83857D8480737986888784777F7A7D7E7E7D807E7B76
827F787590817C8283808182807F7F7E82828383817F8180
817F7E817E847B81807F7F817E807F817D7F7D7F7F807F7E
7E8280818182817F
7E7C7F80807F7E7F81808081817F8080837D7D84817F8185
8187837D7B827B82807F7F807F80807F82818280807B7E80
80787E877B828980878678727C81888081827F8182858284
80777C7D8882787F807D82827F807F808181828081817F80
82837B827E8479817D7F7E80808081807F7F7F7E7E807F7D
81818180827D7F7F
81807F807D807F80827F81827F8282817F7E8082807F817E
83847C7F80857C818080807E827E807E827F7F7E80828081
7C8A89747B837C7C7C7F81868579808087857B787A877C81
85817A788E816D89817E807F7F7E8081807F7F7F867F8082
8280847E87807F83817F81828280817D7E81808080808282
7F7F807F7E818381
807F7F7F80807F82807E81818280807E7E7F81807F7D7F7B
80837C7D7C847B817E7F7E7E7F807E7D81807E7F7E818280
7C878083867E8879868281817E787D7F797B8088927F7B82
82817E7974877B8C808182827E7F81827F7F818082838182
7D80857C897D7F837E7E7F80817F807F807F7F807E817F80
81817D7F8080807E
817D7C7F8280808182807F807F7F7F7F7F7F7F827E808180
80837B7F7F857E82807E7E7F7F807E7E7F7D807E7D81817F
7F7E7C8084768488837E7A787D827983868480847A7A807F
7D7D80827D807D838081807F7F8081827E817E7E82817F81
7F7F857C847E7F837F7E7E7F81807F7F7E7E7F7F7D808181
80807C7F7F82817F
827D7F80807E807E807F807F7F81817D817F80817F808180
7F857D7F7D837982807E808080807F7E81807F7F7F80807F
81857B877D7D82807885867C79877F7A83778886787F847E
787D858880817D7780807E817E818080807F8180817F8281
7F7F817B877C80817F7F7D80807F8180807F828180818181
817D7E7E7E81827D
848181808382817F827D8382837E8081807E8081817F8382
7F857D807D857E83808181818280817E817D81828080817F
82877F847F75848290807B7B7A7C8A7F7F7A777F7F7D8F7E
897681868682867B7E82807E817E7F81827F817F80828081
7E7D847E877E8182827F7F807F827F80817D82807E7F8080
817F80817E80807F
837C7F8080817F827E818280817F80807F7E817F807F8383
7D837D807E857D83807F818182828281818184807D7F7F7D
80807E81887D7D80747F838184887B84828281877E7F857C
7D817B7B7C8185807C7E80807F818080837F81807E828083
7E7D847D857C7F80817D7F807F7F817F8082818180828181
7D82807E81818080
817F7F7F80807F827F7F80807F7F8181808282817F7E8383
7D847C8081857E8280817D8180817F7E838282828082807D
7D817D7D867B7F7A7681807B80867B807C83858575858082
81848686737B867E7D7E7E7F7F7F7F7F81817F7F7F807F81
8280827B857D8080827D7F807F80808081817F8381828180
80807E807F808380
8081807F8281817D808181827D817F7F8180827F7D7E8381
79837E8080857D827F828081817E7F7F8382818283817F7F
7E837F7D8684847E8089867C7E877B807B818581857B8078
767A7D808E7A877E7D7B8080817F81807E808080817E8183
8080837B867C7F828081827E807F818282808180807E7E80
7E7F7F7E82808081
827D7E7D8381808180827F81827F838084807F7E81807F7F
837C7D837C817D7E817F817F7E7E80817E7F81838480817F
8481807D7F8188797F857E79817D877D7A8680727F8E8776
7F79877F7E8A72877F81807E817E7F80807E7F7E82818183
827F7D847C7E7F827E818080818082827F7F80808183817F
7E817F7D817F817D
818080818081817F7E7E80817F8281818380827E7F7F807E
7F7D7E877D837E7D807F807F7C827F7E807E7F7F8281807E
838180787F81807E897C827A8D7C827F7B827A8C7A798579
837C817C7A84718480817F7C7F7E807D7F7E827E7E808281
827D7E8779827E828081807F828180818081808181818080
7F81807E817F8080
807F7F7F8081817F8181818080807E7F81817E808081827F
817D7E857D817C81817F807F817F7F8081817F7E82838380
817F81817A8181878D777F798C7A837E817B7793747E847E
867F827D83847A888381807E80817F7F7F81808080808081
81817F867A817F8280807F7F80808080817D808181807E80
80807F7F80808281
7E7E7F8080818081818280808280808082807E7D7D7F817F
7F7F7C867C817E7F7F82828080807F7E807E7E817E828181
807E818080827E7F7B7C828084728C7E847383837E80817B
7A787F7D8987838280817F7D7E80817E7E81828180818081
827C7E867D837F837E7E8180817F7F828380818081808180
7F807F7C7D81817F
80807D8281807D7E8180808081838380817E807F807F8181
86837D867B827E808082828281827E818081808180808082
807E8183848489797E8184807473937D857F8181827E7F80
7986847485847E7B8185807E807F807F8080818181818181
8282808679828182817F7F81807D808081817D81807F8080
837E818080828282
807F8080838182807F8380818182837C807E7F7F81828080
827F7E857E827F82808181838181807E817F7E80827F807F
807E818086848B767D7D85827A858E7B7C867A83787E7C88
788584798084807A82847F7D83817F7F7F7F808081828282
857F7F877C8381828181838181808181828081807F82827F
8082807F81818180
7F7E7E7E82807F7F8280808180807F807E8081827F80817F
817E7E857D817C7C807E82818183817F7D7F817F82808080
827E82807C7E888576838288817476817A88847C7C8A7687
76877C847A837F84758380817F818182827F82818281817E
7D7D80867B837F807E808080807F7F80827F7F807E808180
7F81807F7F818080
7F7E7D827F818180817F7E7E807D7D807D7F7F8181818180
807E7E867B7F7F7F7E7F8081847E8280807E7F7F7F80807E
817F83807D76857988847383897E7D7C7989877A8285747F
827D86856D807E8573827F7D80818081817D807E82807E7E
807D81867A817E8181807F7F7E82807F7F817E7F817D8180
817F7F7E8082817E
817F818181808281817D807E818082807F82808182808181
81827C857985837D828081857F807C7F8180837F7E7F7E7F
7E8085807A7D80797C808686837C7A8B7E7E848186887A86
798383797B7E80807E827F7F807F837E8381838081827F80
7C807F8080827B858181807F858382838381817E82828080
827F81817F848080
807E807F7F808180807F80807E80818181827F7F807F7F80
7F7F7F857A85817D7F8180838381817F8180807E827F8180
8382848281837685818181807F7C758987837E737E7F7C87
827D8C847687807B7B81807F8280817F7F7F82838082807F
7C817C837E837B86807E817F7F7F7F807F80818082808280
8081807F8182817F
827D808081808081817F7F80817F828083807E7E8080807D
807C7E837B85827D82847F82848282818181817F8180807F
7C7F827980817A8D857B78818D866D82838A7F7C77847F81
857588847F7A867B7D7F80808081807E817F80818380807F
7A847D817D837A837F807E7E7F7E817F8080807F7E818281
7E7F7E7F807F7F80
82817F7F81827F7F817F80808180818383807F7E80818181
7F8080837C87837E847E7F808481818382807F8082828180
827F817E7D7E7A89848A7F82897B807E7D897F8B878B7F7E
8A6F7D7B8776887C7B827F7F8280807F817F818182818281
81827D817F837B847E8080807F808180828080827F828282
7F7E808082808080
8181817F827E817F8281827E847F7F8384817F827E7F8181
7F807E817A858080837E7D7F81817F827F7E7F80807E827E
837F828182747C7F808278747989857E777F73757C7E7C83
808374957E708E807780807D807F7F80827F808381808281
7E857D837F847B837F7D7F7F807F7F7D7F818082807F807D
8180807E7F7F807D
82808280817F827E7F817F807D8280838380818082808281
80827D827B868380837F7F7E7F818080807F80807F808181
817D7F7E82858A7C7D8C92857E85878186818383A7747D82
798578887D7188837A867E7C8182827F807F81817E80817F
7F847F827C837A847E807F8083817F80817E82817F807F81
807F82817F838080
80807F8081817E808281807F81818181808180827F828381
817E7F857B85827F807D7F80807F81817F7F807F8281817D
7D7A7F8181817E7D7C787B81817A7C7B847C7B786874907B
858C75808079817A8583807F808182808180828081817F80
7E837E7E7D837A85817E808182807F817F7E7F7F80818280
807F818082817E7E
7F7F7D7D7E7F7E7D82807F81807F81807F83817E81827F81
7F7E7E837B83807E7F807F7E818181827F7E7F8082838280
817F838584838283897D7D7E7F81838781798A8C81858D76
74807F83938581818482807E7F82807F7D80808080808080
7F8480807C817B85807F7F7F817F7F80817C7F7F7F807F80
81808080817F807C
8282828180838083817F81817F82817E8281808282818281
7E837D867D86817F7E7F7F83828080817F80807E807F807D
7F7F8084878384828881817F7C8181857F8486837A7F8483
87797B7F847F827C8082817F83818381818080807E82817E
818381807E86788081838182818182818081808181808381
827F7F8280828185
81808180807E7E80807E7F81817F8181807D818080818280
817E7E847C828180808082808081807E7F807F80807F7F7D
8281818282807E7B7C7F8281808086887D80828078837F86
79837F838382807F807F7F7F81827F81808181807F7E7E80
7D83807E7D847B8180818182807E81807F80807F7F81817F
7D837F7F7F7E8081
8280807F7F7E7F82807F817F817F8080837F7F8082817F80
7D7F7D847C84837E7F807F827D8182807F7F828181807F7F
828381807F7D7D79797C7F808082818280807F7D80877D89
7D84838183847E7E8081807E81808180818280827F81807F
7F837E7F7F83798180817F81828181807F7E7E807E82807E
7F817E7D81818281
8081817F827F7F827E7F807F807F80808080807F837F8080
827E7F827B84827E7D80807E828182808280817E8280817C
7F8081828181807F848082827F807F7E817D7B798087767F
7981807E7F7B798581817E817D7F81817E7F8280807F7E7F
7D8481807F857A81817F7E807F817F7F837F7E8182817F82
80817F7C8282807F
8281807B817E80817F7D808081827E8184817E81837F7D80
83817D847D81827F7E7E8280807E81827E7E807F82818080
7B828381837F8382868580828185817D8480807A7F818285
847E7E7D7E7F7E8981828081807F827E807F81808082817F
7C817E827F837B81837F807F80818281807E7F7F7E7F7E7F
837D7F807D818180
82808281818381817E7F7F7F8181828081817F827F82817C
837F7D817A84807F7C7E8081818182827F817F807F818081
81857F7A7B7C7B7B7B79757A80827C7A7A818383847E7E7E
82817E807E838386817F807F807F807F80818180807F8181
7D82827F80867C80828182808180818280827F8081828282
808181807F83817F
82808182818381818281818280807F7F7F7F80808380807F
827E7C847886818080827F8081807E80807D80808081807E
81847B7F8386888E848883858A81778676838377827D7B7D
7E7C7E7F8285818081817F80807F8082827F818280807F7F
808181807E857A8281827F80808180817F7F80817E82807F
83827E8080828281
7F7F7E807F7E7E807D828080827F8181807F8180807F817E
817D7E827983807D807E8180807F80807F7D7F807F7F7F7F
7B7D8183837F7C7B807B788088777C907F8A847B847E7F82
8482828283828179807E817D7D8080808580808181807D7E
7E81807C7C84797F7F807F7F80807F817D7F7E807E7E807F
7E80807F8080817F
83818181818083808181818081827F7E8381807E837F8182
7C81808283847D827E7F7F7F807F817E807F7F7D807E807F
818080827F817F828483858A7F6F7D8674777D8581808083
7F8082817E8081817F807E80827F81818382828085828382
827C7986807D857F837E80838181828184818082827E8183
8082807D8082827F
8081807F80818181807F807F8181807F817E7D7F7E7F807B
7B817F807E847D827E7E7E7F7E807F7E7F80807D807F7F7E
807C7D7E7F7E7E7D807B7F837D8B89868383827F827F807F
7E808080827E8181807F827F7F8181807D818183807F8080
7F807783827C827C7F7E7F80807F7F7F8280808180827F80
827F7E7F7F808080
83818280817F8180807D8181818080828180807E7F7E7E80
7D7F7F8181817D847F7E7F8081818083807F7E807F7F7E7F
7F80807E827F7F807F7C7D7D8181807C7F80807F80808182
7F7F82808280808180807E807F7F81808082818182828180
7F807983817D857E8080807E8080807F7F807F7F7E7F8181
7F817D807E818180
80807F807F8080807F7E807E7F807E7D7F807E7F7F808081
7F817F817D847D828081807E848082808181817F7E81807F
807F7D7E7E7E7D80817F7F8082837F7D817E8181827F817E
7E7F7F7E7F7F7F81807F807F817F80807F7F807F8081817F
81817B83807D847C807F7E817D7E81817F81808182818183
80807E808180807F
8082828184817F82828281827D7F7F8280817F8180808184
7F8181827E847D8481818083827E7E817F80837F7D817F81
807D818081837F81828080838281807A838280807F808080
817E8080827C7D7D7F7F7F8180817E828081807F8282837F
817E7E868280867E8681807D808080818080807F7F807F7F
807F7E7F7E81817F
7E7F80808080808080817E7C7F7F817F808180807F7F807F
7E7F7D817E847E82817E80817F81817E808181807D807F7E
817E807F8082808180807F7F81817F798380828082808182
817E807F807D807E828081808080807F82807F8082808081
81807B817F7D837D82817F807D7E7E808180818180818080
8281817E82807F7C
7F82818082808280807F80817E7F807F808081817F828081
80807F817D837A837E807E7F8180807F827F80817F817E7F
827D827D81847E817E7F7E7D81827F7C8181828182828180
828181807F7F8180828281807F807F7E7D817F80807F817F
81817D83817E857E8180817E7D7E7D7E807D807F8180817F
80817F7F7F838281
7C8180807F8180807E7F808082817E827E8181807F7F7E80
82807C7F7B837A837F7E81827F8080818181817E8280817E
807F808382838182818180817F83828080818080807F7E80
7F81817D7E7D7E81807E7E817F817F80807E80827F7F7F81
80827F817D7D8580807F81807F7E7E7F817C7F807F818081
827F7F7F827F807F
8081808180817F807E7F7F808181807E858083818280807F
7E817F7E7E867E807F8181817E7D807C82827E7E8180817F
7F7D8081817F7F7D7E807C817F7D7F807D81837D7F7F7D81
827E81817E7F81827E7F827F807F80827D807F7F81808080
7F818183817D857A83807F7F7E7C817F807F7F7D81807F80
8381817E8083817F
7D807F828283818180818080817D7F7E8081818182818080
8182807F7F867C7E81807F807E81817F808280828081807E
817F7E7E807E8081827F7F83807E7E80807E82827F7E7F81
807D7F7D817F81817E807E808081808182807F8282828280
8280807E837E847E81808080808081807E81808380817F80
80828180807F837E
7D82818181808182827E817C807E7E7F7F8181817E80817D
7F7F82807A847A7D817F807F8181827F7F8181818083807E
7F80827E7F82838080807F7F817F7F7F7E82838381817F82
7F7F807F807F807F7E7F8080817F7F7F817F7F80807F817E
7E7F807E807E837D80817E808080818080807F808180807F
8080818080808382
7F828180828082828281827F8280817F807F808281818181
7F81817E7C857B7F827F82808082827E83817F82817F807F
8080807F807E807F807F80817E807D7F7D82828281807F81
7E7E7E807F7E80808081827F807F82817F8080807F827F80
8180817F817D847C8181808183817F817F7F7E817E828180
817F81807F7F827F
7F7F8081827E818180808181808281807F7F817F80817F80
7F7F80807C867D80827F82837F818281848282838181817F
828180817F7F80827E82807F837E807D7E81808181828480
8080828280807F80827F7F80807F7F807F7E7E8180807F7F
8380827D817E847D838181808182838082837F7F81807F80
83827F807E82827F
8182817F818281827F818083828281808180817E83807F7D
80807F817F867C7F81808281817E817D8080818080817F7F
817F7E817D80807F80818280818281837E817F7F807F817F
7F81807F827F7F7C8080818081818080807F81818082807E
8180807C827E867D8380807F80838081827F807E807F8180
817F7D7E7E7F807E
7E8082808081807E807F7F827F808181847E7F817F7F807D
7E81817F7C867D7E838180808181807F8281818182828081
8081807F80808080817F8180808181817C7F7D7E807F817F
817E817E8180807D7F807F7E807E808080807F817F808081
7D80827E817E867E7F818181808081807F807F8081808180
817F807E7F80807E
7D807F82828180807E8180817E81818082807F828180807D
818082807E867B7F807E7F8281817D7E807F807F7F7E8081
8080807E817E81827F7F7E817F7F81817D817D7F8081817F
807F8081807E807F7E7F807F83808082807F807F7F817F7F
8281827D7F7F857C8080807E828080807E807F7F80817F7F
81807F807F81817F
7E8083807F7F7E7E80818181847F82827E7E7E8082818080
857C7B807E837A817E80807F83817F7E808382817F7E8181
827D80807D7E7E807D817F80807F81838281807C8280827E
81807E7E827D7E7D8180808080807F81807F828181838180
7F807E847B847E7C82807F8180848081808181827D808080
817C81807E7E8281
7E81817E80807F7F7E807F818081808280807E81817F8080
847E7E807F857B82817E7F817F80817E807E817E80807F80
817E80807F7E7E7F7F7D7F7E807F81807F8281828284807C
837F7F7F7F7F7F7F818182808380807F8180818181808182
80817E847A847D7E7F7F807F7F807E7F807F7E818180807F
7D80807F807F8382
7E81807F807F817F818082818080828181838081827F817F
828080837F837A847F838280818182807F8081808180817E
82807F7F81807F7F807F8080808280807F8084828384807E
7D7F7F8080808180828180827E8182808180818182818080
7F807E867D817D7F7F817F817E7F81807F7F7F8081808080
7E7F81817F808282
8081818182807E7D8181808180828081848181827E7F8080
807F7F8380857D837F8180817F81817E7F7E81807F818081
8283817E8180807F827F7F7D837F80807F838383817F817D
7F80817F808280817F8283807F8080808080808080828081
807F7F837C817E7D807F817F818081828280808181818181
7F81818280808383
8184807F8182807D8281808381808182818080837E808080
7F827F8081877C83827E82817D807E7E8180808281808180
7E807F7E817D8080817D817D7D817F7E808181817F7F807F
7E807F80817F807E7F8081837F818182807D7F8181808182
7C847F847D837E7C7F7F807E807F80827C81817F7F7F8080
8281827F827F7F81
7D827D807B7F807E7F7F7F807F80807E7F817D807D808080
827E7E817E847E837E817E807E7F7F7E7C7F818082807F83
7F808081807E7F7D7E80807B80807E8080807F7F7E80807F
7E807F7F7E7D818082807E807F807E7F7F807F7E7D7F7D80
80807E7F81827D807C7D7F817F7F807C7F7F7E7E7D7E7F7F
808081837E808180
80807E807F817D7F81817E81828280807F807F7D80818180
817D7E807E847D837E818180817E7F7E7E7D827F7F81817E
828080828080807F80817F817F808182827F807E7E7F8181
808282807E81808281808180807F7E7F7F81827E817E7F82
7F8180787F837D7E817F8181818081808180817F82808080
818182807F80807E
7F7F8181807F7F7F7F807F80827F7F807E7F7F7D80808182
847B7D8180847D837E8180807F7F807D8381828081828181
7F818080827F82828180807F818081828480807E7F7F8181
82828181808080807D80807F827F80808081818181808180
81838576818580807F80818280828183817F818081807F80
7E8383828181817E
818683828481817D7F828184857C82828282827F82828383
82847E86818181798180817F7F807F7F7F827E7E7F827F7F
7F817E7D7C7F7F7C817C7D7F807F81818080808080817F7F
7F7D7F7C81807E7D7D7F7F7F807E7F7C818181807F7E7E80
818782798378828180808180827F808080817F8180808280
807F80818181817F
80817D7D80807E7E7E7E7E7F807D807F7D80808081808281
7F7C797F7B7C7D787F7E7F7E817F817F817E7E817F7D7C7B
838583838384828382808181858282827C7E7D817E7F7F7C
848380818084837F82848383838384838281838384828284
79828576887C828181807F807E818280828081828080807E
7F807E828180827F
82817F7D80807F7D807E7F7E7F7E7F807F7F80817D7E7F80
87898188858489857E7E7E7E7F828383827F81828081807F
7E7C7C7B7A7B7C7C7C7D7C7E7C7F7F7D8280818282818383
7E7D7D7C7D7D7D7C7D7A7B7E7D7B7D7A7B7E7C7D7D7E7D7D
7A8388748A7C7E7981807F7E7F7E7E7F81817E80807F7F80
7E7E7F818081817E
8181817F7F81807E7F7E7F7E827F8182828081838083817F
7D7D797D7778807F7C7C7E7E7F808380827B807E7F7E807E
85828383848182837F80838182828283787C7C7C7C7C7B7B
8181817F7E8181808382838482818281818284818181807F
898C81778B7C7F777D7F8080807E817E7F7F807F81807E80
7E8080807E80817E
7F817F8180848180807E7F7E7F7F8180807F817F7F807E82
7F8381847D8087867F7F7F8183858685817E807F7E81817F
7E817F807D7C7C7B898684817F807B768A848680827E7D7B
8681807F7D7C7F7D84818282808180817E7F7F7C7D817F82
75727192897E86837C7E807E7C7C807D7F807F817E828081
837F828084817F80
7D807E7C80817F807E7E7E7D7D817F7F807F7F807E7F7E7E
7C7C82847C7A7F7D868381827F7875718B85848681828081
797B7E7F8387888B787C7C7D7E808483807E7F8182818082
7B7E7E7E7D7D7E7E807C7F7F807E7E7E7B7D7B7E7E7D7D7F
888588857A7C89887E818181818081808481828280818182
818281817E81827D
8284807F84848080807F807E8082817E8180808181817F80
8E787D86817D8389797A7C818784878A7A797B7C7B7C7E7B
807F807E7F7D7E7F83858384858486847E80808082807F81
84868684858584837D7F7F7E7F7D7E7F7F82808181808182
7C767E7B7379848381818182818181817F8080808080807F
8180828280818080
81848181828183817F827F828280827E8183818280828283
81798289817A7E8082858480807C7D7B8381828380858382
8280818281807F80807D7E7E807F817E7F7E7C8182808281
7F7F7F7F7C7F7E7F827E7E7F817D7E7F7F807F807F818081
817F85877D7E847F7D7E7F7E7E8280807F7F7E7F7C7E807D
807F7F7B807F807E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  ImageSize->{298.75, 142.25},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004Z0000SQ000`40n007h00Ooooo:ooo003oool[
ool00?ooob_oo`00oooo:ooo0007oon8000<oon80007ool000Ooo`03003ooooo08Coo`03003ooooo
00[oo`03003ooooo08Coo`03003ooooo00Goo`001ooo00<00?ooool0Q?oo00<00?ooool02_oo00<0
0?ooool0Q?oo00<00?ooool01Ooo0007ool00`00ooooo`02mkh2oml01?ooomoooooO2?oo00?ogoON
oml02_Nn00[gW_NnmikgW^nMmik_OONNkgggWP;_O@;_G@06iec_GNMLkegW?>mM1>Ll00[W7>Llga_W
7=lKiacO6nLLg__W70;Nn`04e][NfmJjg]/4e[X2eYX00ljIeY[>N@0;cWT01<jIeY[>VMJJ1<ii00G>
FLiicWWFV]Jj00;Nf`08g__W7>Llicc_GNmmmkkggQCoo`03003ooooo00[oo`05003oooooQ11kk`02
Q10038?`Nnn3l7__Q11kkh@@Nnn447__Q11kk`>44003Nnn4<8@@00>44004Nnn447__Po04Q1000g__
Q11kk`03Q1002G__Po1kkh@@Nnn447__Q11kk`03Q1000g__Q11kk`03Q1000g__Q3244003Q1001G__
Q12448@@Nnl01H@@00Ekkh@@Nnn447__00>4400<Nnn447__Q11kkh@@Nnn447__Q11kkh?`0X@@00=k
kh?`Q10018@@00J3l8@@Q11kch@@Nnl2Q10018@`Q12448@@0W__00B447__Q11kk`>44007Nnn447__
Q11kkh@@Nnl00_oo00<00?ooool01Ooo0007ool01000ooooooNn0_ON3ooo00[gg_oommkogoNnomog
__oOmkkggPCg_P04kiggW^nMmih2kid04^mmkig_GNmmkeg_ONMLkggWG>mMicc_ONmMkggWG>mMiec_
G@;W?00<iacW?=lKiacO6nLLg__W?=lKiacO6nLL1=kk013Ff]kke][NfmKJg]_F^]kKe[[NfmJjg]_F
^]kKe[[FfP;F^P0AeY[F^/jIeY[>VMJJcYWFV]Jje][F^]kKe][>VLiieY[>V@02e[X01=kKe][NnlIH
0/ii0/jI00KFV/jIe[[>NMJJcYT2e[X00mKJe[[FfP02ool00`00ooooo`0:ool03000ooooog__Q11k
kh@@Nnn447__Q11l3`>44003O0n448@@00>44003O0n447`?00>44007Nnn447__Q11l3h@@O0l00h@@
00=kkh@@Q1000X@@01Ykkg`?Q11kkh@@O0n447`?Q11l3h@@Nnn447__Q11l3h@@Nnn447`?Q11l3h@@
Nnn4<7__0h@@00Ekkh@@O0n447__00>44003O0n447`?00:44008Q32448@@O0n447__Q11l3`N44004
Nnn447__Q102Nnl017?>NlmccX@@17__00Akcg>^Ljic[P:44003Nnn447__00=kk`04O0n447__Q103
Nnl018@@ooooo`001ooo0007ool00`00ooooo`02omlGool01ooOoooogooommkogoON00Gg_P08mikg
_^nMmik_OONNkgggWPG_O@03mik_OONN00;_O@08keg_ONMLkegWG>mMicc_G@;W?006iec_GNMLkegW
G>mM0^Ll023W7>LliacW7=lKiacO6nLLga_W7=lKiacO6nLLga_W7=kKg__Nfmkke][NfmKJg]_F^]kK
e[[NfmKJg]_Ff]kK2Lii00SFV/iieY[>NMJJcYWFV/jI0/ii00?FV]Jje[X00]Jj00CFV_ooool000co
o`03003ooooo00f44005Nnn447__Q11kk`03Q1003g__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11k
k`03Q1000g__Q11kk`05Q1002G__Q11kkh@@Nnn3l7__Q11kk`03Q1000g__Q11kk`03Q103Nnl038@@
Nnn3l7__Q11kkh@@Nnn447__Q11kk`>44004Nnn447__Q102Nnl6Q1000g__Q1244003Q10017__Q11k
kh@@0X@`00J448@`Q324<8@@S342Q305Q1001H@`Q12<<H@@S3401H@@0_oo00<00?ooool01Ooo0007
ool01@00ooooooNnoml05_oo00cgg_oommkogoNnomog__ONmkkgg_Nnmmh2mkh02_NNmkk_WONNkigg
W^nMmik_ONnM0^mm013_GNmmiec_GNMLkegW?>mmkeg_ONMLkggWG>mMiec_G@CW?006iacW?=lKiacN
nnLL4=kk00[Ff]kke][NfmKJg]_Ff]kKe[[FfP;F^P0@eY[>VLiicYW>NMJJcYWFV/jIeY[Ff]kKe][N
fmJje]X2e[X3g_/00nLLga_W7002g_/2ool00`00ooooo`0:ool04000ooooog__Q11kkh@@Nnn447`?
Q11l3g__Nln447`?1W__00N447__Q11kkh@@Nnn44003Nnl06X@@Nnn447__Q11kkh@@O0n447__Q11k
kh@@Nnn447__Q11kkh@@Nnn447__Q11l3h@@Nnl3Q103Nnl088@@O0n447__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl3Q10017__Q11kkh@@2g__00>4
47`?Q1000W__00Mkcg__Nnn447__Q11kc`02Nnl00g_?Nnmkk`02Nnl2ool00`00ooooo`05ool000Oo
o`05003ooooomkkggP0Gool01?ONomogg_oO0oNn00GogoONomog__oO00Sg_P;gWP03kiggW^mm00?_
O@06keg_ONMLkeg_OONN0^mm00C_GNmmiec_G@CW?0;W7004ga_W7=kkia`4g_/00mkKg__Nn`09g_/0
1MkKg__NfmkKe]X00mkK0]Jj0]JJ00G>NMJJcUW>NLiI00;>N@;F^P07g]_Ff]kke][NfmJjg]/00mJj
00?NnmkKg_/00]kk00?Nfmkke]X00_oo00<00?ooool02_oo00H00?oooon<<G__Q306Q1000g__Q11k
k`03Q1003G_?Q11kkh@@Nnn447__Q11kkh@@Nnn447__00>44003Nnn447__00>44003Nnn447__00>4
4005Nnn447__Q11kk`02Q1000h@`Q1244006Q1001G__Q11kkh@@Nnl01H@@00=kkh@@Nnl00h@@00=k
kh@`Q1001H@@00=kkh@@Q1001H@@00akkh@@Q12447__Q11kkh@@Nnn447__Q102Nnl02h@@Q32448@@
Nnn447__Q11kkh@@Nnl01H@@00V4<8@@Nnn447__S36448@`Q1000_oo00<00?ooool01Ooo0007ool0
1000ooooooNn0_ON4ooo00Kgg_oOmkkogoNnmmh5mkh00ooOmkkggP02mkh01_NNmkkg__Nnmikg_P;g
WP08kiggW^nMmik_WONNkgg_W@C_O@06iec_ONMLkegW?>mM1>Ll00SW7>Llga_W?=lKiacNnnLL1Mkk
00OW7=kkiacNnnLLg__W7002g_/02=KJg]_Ff]kKe[[Ff]Jje]X2e[X2eYX2cYT00liicYW>N@02eYX2
e[X2g_/02NLLga_W7=lKiacO6nLLga_W7003ic`01NmMiccW?=lKia`00_oo00<00?ooool02_oo00@0
0?ooooml3`>4400:Nnn447`?Q11kch@@Nnn447__Q102Nnl00h@@Nnmkk`03Q10097__Q12448@@Nnn4
47__Q11l3h@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn4
40=kk`0;Q11kkh@@O0n447__Q11kkh@@Nnn44003Nnl01H@@Nnmkkg__Q10017__00=kcg__Nnl00W__
00^447__Q11kkh@@Nnn447__Q11kch@@00=kk`:4400<Q31l3h@@Nnn447__Q11kcg__Nlmkkg_?1g__
0W_?0g__00B44?ooool000Ooo`001ooo00<00?ooool00_oO4ooo00cogoooomoooooOoooogooommko
goONoml6mkh00oNNmkkg_P03mkh2mih01^nMmik_WONNkgggWPC_O@04iec_GNMLked8ic`2ia`01=lK
iacO6nLL1=kk00[Nfmkkg__W7=kkiacNnnLLg__W70;Nn`08g]_NnmkKg__Ff]kKe[[Nf`KF^PGNn`04
iacNnnLLga/4e[X2g]/2g_/01NLLg__W7=lKia`00]kK00CF^_ooool000coo`03003ooooo00>44003
Nnn447__00>44007Nnn447__Q11kkh@@Nnl01h@@00Ekkh@@Nnn3l7__00>44007Nnn4<7__Q31kkh@@
Nnl00h@@00]kkh@@Nnn447__Q11kkh@@Nnn447__00V4400ANnn448@@Q11kkh@@Nnn447__Q11kkh@@
Nnn447__Q11kk`03Q1002g__Po1kkh@@Nnn447__Po1kkh@@Nnl00h@@00Ekkh@@Q12447__00B4400;
S35kkh?`Nnn447__Q11kkh@@Nnn<<@02Q3000h@@Q3244006Q10018@`Q124<8@@0_oo00<00?ooool0
1Ooo0007ool01000ooooooON7Ooo00?gg_oomkh00oNn0_NN00S_WONNmikgW^nMmik_WONN0^nM0^mm
00CWG>mMiec_G@CW?00:iacW?>LLiccO6nLLga_W7=kkia`5g_/04=kKe][NfmJjg]_F^]KJe[[NnmKJ
g__Ff]kke][NnmKJ1Mkk00_Ff]kke][Ff]Jje][F^]KJe[[NfmJj00CNn`06g]_F^]JjeY[F^]KJ0]kk
00WW7=lKiccW?>mMg__W7=lKia`00]kk00GFf]kKooooo`0000coo`05003oooooNnn44003Nnl02H@@
Nnmkkg__Q11kkh@@O0n44003Nnl00h@@Nnn44003Nnl00h@@Nlmkk`03Nnl06X@@Nnmkkg__Q11kkh@@
Nnn447`?Q11kkh@@Nnn447__Q11kkh@@Nnn447`?Q11l3h@@O0l3Q105Nnl018@@Nnn447`?0h@@01=l
3h@@Nnn447`?Q11l3h@`Q124<7__Q11kkh@@Nnn447`?Q11l3`02Nnl038@@Nnn447__Q11kkh@`Nnn4
47__Q11l3`Ikk`03Q11kkh@`00:4<003Nnn447`?00=kk`9kc`03Nnn447__009kk`03Q11kkg__00;o
o`03003ooooo00Goo`001ooo00<00?ooool05ooo00[ogoooomooooONomog__oOmkkoo`;og`03mmko
goNn00?g_P;gWP03kiggW^mm00?_O@0>keg_ONmMkegWG>mMiec_GNMLkegWG>mMicc_G@KW?0;W7006
ga_W7=lKiacNnnLL0]kk01WNfmkkg]_NnmkKg__Nfmkkg]_NnmkKg__Nfmkkg]_NnmkKg__Ff]kKe][N
fmKJg]_FfP02g]/02=kkg]_NnmkKg__Nfmkkg]/4e[X01]kKe][NfmKJg__Nf`GNn`04g]_ooooo000<
ool01@00oooooh@@Nnl01H@@00Ikkh@`Nnn447__Q304Q1002G__Q11kkh?`Nnn4<7__Q31kk`03Q100
27__Q12448@@Nnn447__Q103Nnl038@@Nnn447__Q11kkh@@Nnn447__Q11kk`>4400CNnn447__Q11k
kh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl01H@@00Ekkh@@Q12447__00^44005Nnn448@@Q11k
k`09Q1001g__Q11kkh@@Nnn448@`00>44007Nnn448@@Q11kkh@@Nnl018@@0_oo00<00?ooool01Ooo
0007ool00`00ooooo`0Fool02?ONomogg_oOmkkogoNnmmh3mkh00ooOmkkggP04mkh2mih01>nMmik_
WNnM0^mm00SWG>mmiec_ONMLkegW?>mM1>Ll00KW7>Llga_W?=lKia`6g_/08=KJg__Ff]kKe][NfmJj
e][F^]kke][NnmKJg__Ff]kke][NnmKJg__Ff]kke][NnmKJg__Ff]kke][NnmKJg_/2e]X02=Jje][F
^]KJe[[Ff]Jje]X3e[X01]KJe[[NfmKJg]_FfPGNn`05e][Nnoooool0000<ool02@00ooooog__Q11k
kh@@Nnn44003Nnl00h@@O0n44002Q10017__Q11kkh@@1G__00b447__Nnmkkh@@Nnn447__Q11kkh@@
Nnl3Q1003G__Q11kkh@@Nnn447__Q11kkh@@Nnn447__00>4400/Nnn447`?Q11kkh@@Nnn447__Q11k
kh@@O0n447`?Q11kkh@@O0n447`?Q11kkh@@Nnn447`?Q11kkh@@Nnn447__Q11l3h@@O0n447`?Q11k
kh@@O0n4409kk`0IO0n447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@
Nnl01H@@0_oo00<00?ooool01Ooo0007ool00`00ooooo`0Eool01_oOooogg_oOmmkog`Gg_P03omog
__Nn00Cg_P04mikg__NNmkh2mih00nmmmik_O@03kgd2ked01>MLkegWG>mM0^Ll00[W7>Llga_W7=lK
iacO6nLLg__W70;Nn`09g]_NnmkKg__Nfmkke][NfmJj00;Nf`0Gg__Nfmkkg]_NnmkKg__Nfmkkg]_N
nmkKg__Nfmkkg]_NnmkKg__Nfmkkg]_Nn`09e[X02=kKe[[NfmKJg__Nfmkkg]/2g_/00nLLg__W7002
g_/01=kKooooo`003?oo00d00?oooon447__Q11kkh@`Nnn447__Q11kk`0;Q1000g__Q1244003Q100
0g__Q11kk`03Q1001G__Q11kkh@@Nnl00h@@00=kkh@@Q1000h@@01Ekkh@@Nnn447__Q11kkh@@Nnn4
47__Q11kkh@@Nnn447__Q11kkh@@Nnl00h@@00Ekkh@@Nnn447__00F44005Nnn447__Q11kk`07Q100
2W__Q11kkh?`Nnn447__Q11kkh@@0g__00B447__Q11kk`F4400?Nnn448@@Q11kkh@@Nnn447__Q11k
kh@@Nnn447__00;oo`03003ooooo00Goo`001ooo00@00?oooooggPooo`0:mmkoooooooogg_oOmkkg
g_Nnmmh2mkh00oNNmkk_W@02mih02oNnmikgW^nMmik_WONNkiggW^nMmih00^mm00S_GNmmiec_ONML
kegWG>mM1>Ll00cO6nLlga_W7=kkiacNnnLlga_W7=lKia`8g_/08mKJg__Ff]kKe][NfmKJg]_Ff]kK
e][NfmJjg]_F^]kKe[[NfmJjeY[>VMJJcYWFV/jIeY[>VMJjeY[F^]JJe[[FV]JjeYX00]Jj00SNfmJj
g]_Ff]kke][NnmKJ1mkk0_oo00<00?ooool02_oo00<00?ooool00X@@00Akkh@@Nnn440=kk`0:Q11k
kh@@O0n447`?Q11l3h@@Nnl3Q1001G__Q12448@@O0l01H@@00Mkkh@@Nnn447__Q11l3`02Nnl02H@@
Nnn447__Q11kkh@@Nnn44005Nnl028@@Nnn447__Q11kkh@@Nnl3Q1005g__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl00h@@00=l3h@@Nnl00W__00N447__Q11kkh@@Nnn4
4003Nnl01h@@O0n4<7`?Q11l3h@@00Akk`03Nlmkkg__00=kk`03Nlmkkg__009kk`04Q13ooooo0007
ool000Ooo`07003ooooooooogooooml03Ooo00KogoooomooooONoml6mkh2mih03>nMmik_WONNkggg
W^mmmik_OONNkgggWP;_O@;_G@06iec_GNMLkegWG>mM1>Ll00[W7>Llga_W7=lKiacNnnLLg__W70CN
n`0Rg]_Nnmkkg__Nfmkkg]_NnmKJg]_Ff]kKe][NfmKJg]_Ff]kKeY[F^]JJe[[FV]JjeY[F^/jIeY[>
VMJJcYWFV/jIeYX9e[X02]kKe[[NfmKJg__Nfmkkg]_NnmkK1Mkk00CNfoooool000coo`03003ooooo
00V4400=Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl01X@@00>4<8@@Q10018@@00Ikkh@@Q124<8@@
Q303Q102Q3001X`aQ12448@@Q31kk`F44003Nnn448@@00:44003S36448@`00>44003Q32448@@00:4
4005Nnn447__Po1kk`02Q10018@`Q12447__0h@@0g__00B4<8@@Q11kk`>44003Nnn447__00>44006
Nnn448@@Q11kkh?`0X@@00=kkh@@Nnl00h@@00=kkh@@Q1000h@@00Mkkh@@Q12447__Q3244002ool0
0`00ooooo`05ool000Ooo`08003ooooommkogoONoooggP?oo`0>mmkoooONooogg_oommkoooNnomog
g_oOmkkggP;g_P;gWP08kiggW^nMmik_ONnMkgg_W@;_O@0:keg_ONMLkgg_GNmmiec_ONMLked2ic`0
2=lKiccO6nLlga_W7=kkia`6g_/00mKJg__FfP03e[X2eYX01<jIeY[>VMJj0]JJ02O>VMJJcYW>VLii
e[[FV]JjeY[F^]JJe[[FV/jIcWW>VLiicYW>NLjIcWWFV/jIeY[>VMJJcYWFV/jIe[[FV]JjeY[F^]JJ
e[[FV]JjeYX00]Jj00gFf]Jjg]_F^]kKe[[NfmJjg]_Ff]kKe[[FfP02ool00`00ooooo`0:ool02@00
ooooog`?Q11kkh@@Nnn44003Nnl01H@@Nnmkkg__Q1000W__0X@@00ikkh@@Nnn447`?Q11kkh@@Nnn4
47__Q11kkh@@0g__00N447__Q11kkh@@Nnn44002Nnl017_?Q11kkh@@1G__00F447__Q11kkh@@00Mk
k`07Q11kkh@@Nnn447__Q1001g__00B447__Nlmkc`Ikk`03Q11kkg__00=kk`0:Q11kkh@@Nnn447__
Q11kkh@@O0l3Q1001G__Q11kkh@@Nnl00h@@00Qkkh@@Nnn447__Q11kkh@@0g__00>447__Q1000_oo
00<00?ooool01Ooo0007ool00`00ooooo`02oml00oooomooo`04ool01_oOoooogoooomooo`;og`04
mkkogoONoml2mkh02_NNmkkgW_NNkiggW^mmmik_OONN1>mm00KWG>mMiec_GNMLked2ic`2ia`01]lK
iacO6nLLg__W70;Nn`06g]_NnmKJg]_F^]kK1=Jj00C>VMJJcYWFVPG>N@03eY[>NLii00C>N@0ScYWF
V/jIeY[>VMJJcYWFV/iieY[>NMJJcWWFV/iieY[>VMJJcYWFV/jIeY[>VMJJcYWFV/jIeY[>VMJJcYWF
V/jIe[[FVP0:e[X01=kKe[[F^]Jj0_oo00<00?ooool02_oo00L00?oooon4<7__Q11kk`03Q1000g__
Q11kk`03Q1000g__Q11kk`03Q1004G__Q12448@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl028@@
00N4<8@@Q32448@`Q124<009Q10018@`Q12447__28@@00B<<H@`Q11kk`F44007Nnn447__Q11kkh@@
Nnl00h@@00=kkh@@Q1002H@@00]kkh@@Nnn447__Q11kkh@@Nnn447__00>44009Nnn447__Q11kkh@@
Nnn447__00>44004Nnoooooo0007ool000Ooo`08003ooooomkkogoONomoggP?oo`0<mmkoooONooog
g_oommkoooNnmmkg__ON0_Nn00C_WONNkiggWP;_W@C_O@08keg_ONMLkggWG>mMicc_G@;W?004ga_W
?=lKia`6g_/06=KJg__Ff]kKe][FV/jIeY[>VMJJcWW>VLiieY[>VMJJcYWFV/iicYW>NMJJcYWFVP;>
V@_>N@0@eY[>VMJJcYWFV/jIeY[>VLiIaUS>FLIHcUW6F<iIaUP9cWT02LjIeY[>VMJJcYWF^]JJe[[>
V@02eYX3e[X01LjIeY[ooooo00003?oo00D00?oooomkkh@@00=kk`07Q11kkg__Nnn447__Q1000g__
01B447__Q11kkh@@Nnn447`?Q11kkh@@Nnn447__Q11kkh@@O0n447`?0X@@0W__00>447`?Q1000g__
00N447__Q11kkh@@Nnn44003Nnl02h@@Nnn447__Q11l3h@@Nnn447__Q1000g__01F447`?Q11kkh@@
Nln447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q1000g__00R447__Q11kkh@@O0n447`?1G__00=k
cg__Nnl017__00j447__Q11kkh@@Nnn447`?Q11l3h@@Nnn447__0h@@0_oo00<00?ooool01Ooo0007
ool01P00oooooooommkog`Kg_P0:mikg__NNmkkgW_Nnmikg_^nMmih2kgd00nmMkggWG004kgd00nmM
iecW?002ia`00mlKiccW7002ic`02NmMiccW7=lKiacO6nLLg__W7002g_/04MJjg]_Nfmkke[[>NLHh
aQSNfmJjcWW>FLHhcUW>NMJJ_QL00/HH00?>FLHhcUT00/Hh00Rn5liIaSRmekFfaSSFV]kK2LHh00O>
FLHhcUW6><iIaSS>F@09aQP00lHhaQS6>003aSP00liIaSS>F@03cUT00liicUW>N@05cWT01=JJcWW>
NLiI0_oo00<00?ooool02_oo00D00?oooon447__00F44006Nnn447__Q31kkh@`0h@@00>4<7__Q100
1X@@0g__00>447__Q1001H@@00Z4<7__Po1kkh@@Nnn447__Po1kk`>44005Q32447__Po1kk`02Q300
1HaALjj3l7__Q3000X@@0W__00>4<8aAQ1000h@@00Ykkh@@Q12447__Q32<DH@@Ljik[`:44003Nnn4
48@@00>44004Nnn3l7__Po02Q1000g_?Q1244003Q1003g__Q11kkh@@Nnn447__Q11kkh@@Nnn447__
Q11kk`06Q1000h@`Q1244004Q10017__ooooo`001ooo0007ool01@00ooooonnMmih00^mm00k_GNmm
kgg_OONNmkkgW_Nnmikg__NNmkk_ONnM0^mm00GWG>mMicc_GMlK00GW?003ga_W7=kk00ONn`04e][N
fmJjg]/2e[X02<jIeY[>VMkke[[>VLHH_OL2]KH01[FFNnmc[W>>HbaS30=Jj`0@JbeS;6]=Jde[KF]=
JfeSC6]=JfecSV^=NnnDTZDdYE@8_OL03kgG]KJmekFf_MNe][gG]KJmekFf_MNe][gG]KJme`07]KH0
4kgG]MJmekFf_MNe][gG]MJmmkgG_ON]MKFF[IFeUZfE]IJ]MKFF00;oo`03003ooooo00[oo`03003o
oooo00:44006O0n4<8@@Q11kkh@@0g__00>447__Nnl00g__00F447__Q11kkh@@009kk`:440=kk`09
Q11kkh@@Nnn4<7`?Q11kkh@@00=kk`05Q11kkh@@Nnn4<003Q1001G_?Ljikkg__Q1000W__00A[SHaa
Q324<0:44003Nnn447__009kc`04Nnmkcg__Nll2Nnl028@@Llic[W?>Q11kkhaAQ302Nnl00h@`Nnn4
4003Nnl8Q10048@`Nnn447__Q11kkh@@Nnn4<8@@Q32448@`Nnn447__0h@@00=kkh@@O0l00g__00J4
47__Nnn447`?Q102Nnl2ool00`00ooooo`05ool000Ooo`03003ooooo00?g_P0@kiggW^mmmik_WONN
kiggW^nMmik_WONNkiggW^mmmih2kgd00nMLkegW?002ia`3ic`01]lKiacNnmkkg]_Nn`CF^P04cYW>
NLiIcUT2aSP2aQP01[gG_ONLliBbNnm[K@=S3003Jdf4<8`a00:44005Nlmc[W>>Lhi[C@02Jfd00g>>
JfecSP03Jfd2Lhh03G__U9:]EKGFaQR]MKEf[GFeMZee]GJ]MKEf00RU=00=W?>U59ccYABLljDDW?>U
5:Dd[EFU=:eEYC@01:eE00>]MJeE[GD00jee00NeMZee[EF]EJee[EF]M@02[ED01:Ddooooo`003?oo
00D00?oooon447__00B44004Q31kkh@@Nnl5Q1001G__Q12448@@Nnl018@@00Z4<8@@Q11kkh@@Nnn4
47__Q11kk`>4400:Nnn447__Q11kkh@@Nnn447__Q102Nnl00h@`U7:4<002Nnl2Q10018`aLhic[W>^
0W_?00F447__Q32448@`00:44009Nnn447__S364<8`aQ11kkg>>009kk`03Nln4<8`a00:44004Nnn3
l7__Nnl2Q10017__Q11kkh?`1g__00j447__Po1kkh@@Nnn447__Po1kch?`Nnn447__0X@@00Z4<7__
Q12448@`Q124<8@@S364<0:440;oo`03003ooooo00Goo`001ooo00<00?ooool00_Nn0_NN00k_WONN
kiggW^mmkig_ONnMkgg_WNmmkig_ONnM0^mm00CWG>mMicc_G@CW?0;Nn`06e[[Ff]JJeY[>NLiI0/Hh
00Rn5lHH]KJe]Zee]IJ]MJeE0ZDD00FLljDdW=><DG?>009c[P05Nnn445[[F^]S3002Hb`2H``00e[[
Jde[C@02Jfd04g>>Jfe[KF]]Lji[CF/]Jhf448aAU9:D/YccW=>LlicCW?>Ldicc00:Ld`06U;:LdiBb
W=>D/YcC0YBb00VDTYBbU9:D/YBBU;:DTYccW=<019cc00JU59ccYABUE:eEYE@2[ED02jee[EF]MJee
]IJ]UKFF[IFeUZee]IH00_oo00<00?ooool02_oo00D00?oooomkkh@@00=kk`03Q11kkg__00=kk`0;
Q11kkh@@Nnn447__Q11kkh@@Nnn44002Nnl00g_?Nnmkk`02Nnl00h@@Nnmkk`05Nnl02h@@Nnmkkg__
Q11kkh@@Nnn447__Q1000W__00m[SG>>Nnn<<H@`Q11ccYBBS56<<G`?Q11kkh@@O0l00W_?00Ekkg_?
Nnmkch@@009kk`0:Q12<<G__Q124<8`aQ32447__Q103Nnl038@@Nnmkkg__Q11kkh@@Nnn447__Q31k
k`B44008Q32448@@O0n447__Q11l3`:4400:Q31kch@@Nnn447__Q11kkh@@Nll7Nnl2ool00`00oooo
o`05ool000Ooo`06003ooooomkk_WONN0nmm00WgW^mmmik_OONNkgggW^mmmih00^mm0^mM00KWG>mM
iccW?>LLic`2ia`01=kKe[[>NLiI0/HH0[gG00Je][FF[GF]EJDdYA@3W?<01IcCU9:DTXaaU7800W__
0W>^00McSW_?Nnn449BBU;:DdP02W?<01:DDW?>LljeE0Zee01beUZfE]IJ]MKFF]KJ]EIccYCB]EJDd
YAB]EIBbW=>D/YcCU;:LdiBbW=>DdYcCU=:LdiCBW=>DdPVLd`>Ll`04YABLljDDW?<2YA@00jee[EF]
M@03[GD01;Ef[GF]EJeE0Zee00BeMZee[GF]E@;oo`03003ooooo00[oo`05003oooooQ31kk`05Q100
3W__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q103Nnl01H@@Nln447__Q3000X@@00F4<8@@Q124<8@@
00>4<0:44003Nnn447__009kk`03Po1kkh@@00><D@05Q11kkg_?Nln3l003Nll2Nnl018@@Nnn4<7__
0X@@00Z<<H@@Q11kkh@@Nln448@`Nnmkc`:44005Nln448@@Q12<<@02Q1001H@`Q11kkh@@Nnl00X@@
00j4<8@@Q11kkh?`Nnn447__Q11kkh@@Nnn3l7__1X@@0W__00N447__Q11kkh@@Nnn4<002Q1000g__
Q1244002Q102ool00`00ooooo`05ool000Ooo`05003oooookiggWP02kgd03>mMkgg_GNmmicc_GNLl
kegW?>mMicc_G@;Nn`04e][NfmJje]X2e[X01/jIeY[>FLHh_ONe]P:]M@:U=004WA>LliCBU;84U980
1HaaU9:<DHaAQ3000X@@0Xaa00NDTYBbW?>LljDdYAB]E@04YC@2YA@01IdCW=>DdYccW=<00icc012L
diccS76<LIBBS75ccW__S56LlicCW?>LdiccW=>Ll`:Ld`0CU=:LdiCBW=>DdYcCU=:LlicCW?>Ldicc
W=>LlicCYABLljDDWA<00ZDD00RU=:DDYCBU=:eEYEB]EJED0ZeE00N]MJDd[EFUE:eEYEB]E@02YC@2
ool00`00ooooo`0:ool01000ooooog_?0W__00>447__Q1000g__00N447__Q11kkh@@Nnn44002Q300
18@@Q32448@`0X@@00Il3h@@O0n447__Q107Nnl00h@@Nnn44002Nnl01g_?Q12448@@O0n447`?00Ik
k`:440:4<0>4409kk`03Nln447__00:44005NnmccW__Nnmkc`02Q1000g__Q11ccP03Q1001W__Q11k
kh@@Nnn440=kk`03Q11kkg__00Ukk`04Q11kkh@@Nll6Nnl038@@Nnn447__Q11kkh@@Nnn447__Q11l
3`F440;oo`03003ooooo00Goo`001ooo00@00?oooooW?0;W700@g__W7=kkiacO6mJJcYWFV/jIeY[>
VMJJcYW>FLHhcUT2aSP2aQP01;hG_ONmekgg0[Ff00B]MJeEYCBLl`:Ld`:D/P04S76DLXaaU782S742
S5401h@`S364<8`aS76DTXaa00:DTP05W=>DdYccS76DLP02S5402X@`S56<LIAbS76DLYBBU;:DTYBb
0YBB022<LH`aS56DTW__H`aS;8@`W=>LlicCW?>LdiccW=>LlicCW?>LdiccW=>LlicCW?>D/YcCU;:L
diBbW=>D/YcC1JDD1:Dd00>]EJDd[ED00jeE00N]MJeE[GF]MKEf[GFeUP02[GD01:eEooooo`003?oo
00P00?oooon4<8@@Q32448@`0h@@00><DH@`Q3000h@@00=kkg_?Q1000W__00Ekch?`Nlmkkg_?009k
k`03Po1kkh@@00:44003Nnn<<H@@00J44003Q32448@@00>44004Q32448@@Nnl2Q1002H`aQ124<7__
Nlmkkh@@Q3244002Nnl3Q1007X@`Q12448@`Q11kkh@@Nnn<<H@`Po2<DG_?Lhj447__Q11kkh@@Nnn4
47__Q11kkh@@Nnn447__Po1kk`>44003Nnn448@@00>44007Nnn447__Q11kkh@@Nnl01H@@00Ekkh@@
Nnn447__00>44005Nnn447__Q11kk`02ool00`00ooooo`05ool000Ooo`03003ooooo00;6>003aQS6
>;hG00;66009aSRe][gG]KJmekFf_MNe][gG00Be]P08[IFeUZee]IJ]MKFF[GFeUP:]M@:]E@:Ll`:L
d`:D/P:DTPJ<D@07Q32<DH@`S764<8@@Nnl00W_?0h@@0W__00Akch@@Q32DTP>D/P05W;>D/YcCU;:L
d`02U;805haaW;>DdW__DZYS38@@W;>D/YbcU;:L/iBbW;>D/YcCU=:LdiCBW=>DdYcCU=802Ycc00BU
59ccYABM4`:U500:YCBUE:eEYEB]EJED[GF]EJeeYE@2[GD00kFF[GF]M@02[ED2ool00`00ooooo`0:
ool00`00ooooo`02Q10017__Q11kcg__0W_?00Ul3h@@Nnn447__Q11l3h@@Nnl00X@@00B4<8@@Q31l
3`>44004O0n447`?Q102Nnl04X@@Nnmkkh@@Nnn447__Q11l3h@@Nnn447__Q11l3h@@Jhekc`B4400:
Llikkg`?Nlmkkh@@Nnmkcg__S342Q105Nnl00h@`Nnn44002Q1001g>^S76447_?Nnn447__00:44003
Q31kkh@@00=kk`05Q11kkg__Nnn44002Nnl027_?Nnmkkh@@Nnn447__Q103Nnl01H@@Nnn447__Q100
2G__00N447__Q11kkh@@Nnn44002ool00`00ooooo`05ool000Ooo`06003ooooo_ONmekgg0[gG00Ne
e[gG]KJmekFf_MNeeP02_ML01Kgg_MNmmkgG_OL00[gG0[Ff00BeU[Ff]IJe]P:eUP:]M@:]E@06YCBU
59cCW=>D/Ybc0YBb01>DTYAbS76DLYBBU;:446]=NnnDTW>^Q124<7>>Q32L/g__Q32<D@02U;800ibc
U9:D/P02W?<03YCBW;>DdYccYAB]EIccU7:LdiccU99c[U[;U984W?<2W=<01YCBW=>LljDDW?>U50FL
l`07W=>DdZDDW?>LdiBbYA@00icc00>U59ccYC@00jDd00J]EJDd[EF]EJee[ED2[GD8[ED2ool00`00
ooooo`0:ool01`00oooooh@@Nnn447__00F44003Nnn448@@00>44003Nnn448@@00B44003Q31kkh@@
00>4409kk`0CQ11kch@@Nnn447__Q11kkh@@Nnn447__Q11kkh?`Llikch@@Po000g__00B448@`S55k
c`9kk`08Po1kkh@`Nnmkch@@S564<0>44006Nnn447_?Q11kkhaA0W__00B4<7__Nnmc[P:44003Nnn4
48@`00N44006Nnn448@@Q11kkh@@0g__0X@`00B447__Q11kk`>44004Nnn448@@Q302Q1000g__Q11k
k`02Nnl00h@`Nnn44005Q102ool00`00ooooo`05ool000Ooo`03003ooooo00:me`03]MJmekFf00Je
]P09_MNe][gG]MJmekGF_MNee[gG00:e]P06[IFeUZfE]IJ]UKFF0Zee00BUE:eEYCBU=0:Ll`04U;:L
/iBbU;82S7400h@`S564<002S7403g__Hbac[XaaQ12<DIBbNnn<LIBbW?>LdjDDW?>U5002W=<04IBb
U9:D/ZDDYCB]EJDDW?>D/ZDdU;:U=9ccU;9[SE9ZNnl00icc00BLdiccW=>Ll`>Ld`05W?>LdiccW?>U
5002W?<3U;801YccU=:LljDdW?>Ld`:Ll`:U500CYCBU5:DdYCB]EJDd[EFUE:eEYEB]MJED[EFUE:eE
YEB]EJED[ED00_oo00<00?ooool02_oo00<00?ooool00X@@00Qkkh@@Nnn447__Q11kkh@@0g__01n4
47`?Nnml3h@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn4
<003Nnl01HaAO0n447__Nll00W__00J4<8@@O0n447__Q303Nnl028@@Nnn448@@Q31ccW_?Llh2Q100
1g_?Q31kcg?>Nnn448@`00Ekk`07Q11kkh@@Nnn447`?Q1001G__01>447`?Q31l3h@@O0n447>^Q11l
3h@@O0n447__Q11kkh@@Nnn44003Nnl02h@@Nnmkkg__Q11l3h@@Nnn447__Q1000_oo00<00?ooool0
1Ooo0007ool03`00oooookgg_MNmmkGF_MNe][gG]KJmekFf_MNeeP02_ML01Kgg_MNmekgG_OL00[gG
0[Ff00B]UKFF]IJe]P:eUP:]M@04[EFU=:DDYA@2W=<00iBbW;>D/P03U983S7402YBBNnmcSW>>W;><
DIcCYABDLYBb0icc00BLdiccW?>U50:Ll`06W=>LlicCW=>DTYAb0X@@00RLdiAbW?>LliCBNlm:JG_?
19cc00BLdiccW=>Ll`>Ld`:Ll`BU5007W=>D/YccW?>Ldicc[ED00icc00>U59ccYC@00jDd00>]EJDd
[ED00jeE00>]MJeE[ED01jeE0_oo00<00?ooool02_oo00<00?ooool00X@@00>3l7__Q1000X@@00Ek
kh@@Q12447__00F44003Nnn447__00F44003Nnn447__00>44005Nnn447__Q11kk`03Q10027__Q11k
kh@@Nnn447_?Nnl3Q1004X?`Q11kkg>>Q11kch?`Nnn447__Q124<8@@Nnn447__Q11kk`>4<008Q124
<7__S56448?`Nnn<D@:4<009Nnn3l7__Q11kkh@@Nnn447__00>44005Nnn447_?Po1kk`03Q1000g__
Q11kk`02Nnl9Q1002G__Q12448@@Nnn447__Q11kk`05Q10017__ooooo`001ooo0007ool01`00oooo
okGF_MNe][gG00Ne]P09_MNe][gG]MJmekFf_MNe][gG00:e]P06[IFeUZee]IJ]MKFF0Zee00JUE:eE
YABU59ccW=<2U;8019BBU;:DTYBb0YBB02V<DHaaS56446^=LjjDdXaAS76L/h@`U9:<LH@@Nlmkkh@@
U9:LdiccW=>]EICBQ11[KF</F^]S;6=<Lji[KH@`S76Ldh@`F^]ccYBBS76DTXaa00BDTPFD/P0=U9:D
/YBBYABLdiccYABU=9CBW;>DdYccW=<00Ycc0ZDD00>U=:DDYC@00jDd00f]EJED[EFUE:eEYEB]EJED
[EFUE:eEYEB]E@02ool00`00ooooo`0:ool01`00ooooog__Q11kkh@@00=kk`07Q11kkg__Nnn447__
Q1001G__00>447__Q1000W__0X@@00ikkh@@Nnn447__Q11l3h@@Nnn447__Q11kkh@@0g__00F447__
Nnmkkh@@009kk`0CLjj448@@Q124<8aAO0n447__Nln446]]Q12<DG__LjikkhaANll00g__00Uc[W>>
Llj<DHA@Nnml3g_?Nnl00X@@00j<<H@@Q32448@`Q124<8@@Q32448@`Q124<8@@0W__016447_?Nnml
3h@`Nnn447__Q11kkh@@Nnn447__Q11kkh@@00=kk`0;Q11kkh@@Nnn447__Q11kkh@@O0n44002ool0
0`00ooooo`05ool000Ooo`0?003ooooo_MNee[gG]KJm]kFf_KNeU[gG]KJmekGF00:me`07_ONmekgG
]MJmekFf_KL00[FF00R]MKFF[IFeUZee]GJ]MJeE0ZDd00JU59ccW=>L/iBBU;85U9802haAQ32<<G__
Lji[KIBbNlmcSW>^Jdd00W_?0g>>00f449BBYABLlicCS76446]=F/]:JE::DZYRk002F//01f]]NnnD
/YAbH`akcicc00:U5004YCBU5:DdYC@3[ED2YC@01iccYABLdicCQ12<<IBB00:U=003W?>DTYBb00>L
l`03YABLljDd00FU=004[EFU=:eEYC@:[ED2ool00`00ooooo`0:ool05@00oooooh@@Nln447__Q11k
kh@@Nnn447__Q11kkh@@Nnn447__Q11kk`02Q1001X@`Nnn447__Q11kk`>44007Nnn447__Q11kkh@@
Nnl01H@@00Qkkh@@Q124<7__Q124<8?`0g__00V4<7>^Q11kch@@Nnn447__Q3000X@@00Ikkh`aS55c
[W_?Q302S54038@`Q124<8aALhjDTW__Q11ccX@@Nnmkc`9kk`03Nlmkkg?>00Akc`0=Nnn448@@Q124
<8aaU7:4<8?`Nln448@`S5400X@@00Ekkh@@Q12447__00>4400?Nnn447__Q31kkh@@Nnn3l7__Q11k
kh@`Nnn4<7__00;oo`03003ooooo00Goo`001ooo00<00?ooool01[Ff00>eU[Ff]KH00[Ff00FmekFf
_MNee[gG00Fe]P09]IJ]MJee[GFeUZee]IJ]MJeE00:U=0:U50:Ld`:D/P>DTP03W=>D/YcC00:<D@:4
<00DNnmS;8aAJfeJbe[[DZY[;E[[Q31kkh@@S56LlidCW=><DE[;F^]S309S;007F^]Jbe:ZF/]BRV/]
Jfd00XaA00AJbf<<Q11kk`:440:4<003S564<6</009S309Jj`=BZP0:Jbe[CH@@U=:U=9cCW;>D/Ycc
W=<2W?<2YA@01ZDdYABU=:DDYCBU50:U=00;[EFU=:eEYEB]EJED[EFUE:eEYEB]E@02ool00`00oooo
o`0:ool02`00ooooog__Q11kkh@@O0n447__Q1000g__00>447`?Q1000g__00J447__Q11kkh@@Nnl3
Q1001G__Q11kkh@@Nnl00h@@00=kkh@@Q1000h@@00=kkg_?Llh00W__00B447__Q11ccP:44004Q324
48@`Nnl2Q1002H@`Nnmkkg>^Q11kch@@Nnn44002Nnl01g_?Nnmkkh@`Nnn448@`009kc`04Q31kch@@
Q302S5400haaQ32<D@02Q1001G_?U7:<DHaAQ3000h@@00Qkkg>>Hdb<DG__Nlmkkh@@1G__00^447__
Nnmkkh@@Nnn447__Q11kkh@@00Ekk`03Q11kkh@@009kk`;oo`03003ooooo00Goo`001ooo00H00?oo
oonmekFf_ML2]KH01kFF]KJeU[gG]KJmekGF00:me`05_ONmekfg]KJme`02]KH2]IH01:ee]GJ]MKFF
0Zee0ZeE00RU=:DDW?>LliCBW;>DTYBb0YBB00JD/YbcU;:<DG__Q102Nnl00e[[U79cSP02Hb`03V<<
JfeS38@`Q11kkhaaU=:Ldh@@LhiBRU[;H``2Jdd03V/]F^]Jje[;FZ]S36</Q32<LE[;F^]BRUZ[DZX2
F//2F^/02F<<Q124<8@@S364<8`aQ32<<@02Ljh00g__U;:Ll`02W=<01ZDDW?>LliccYABLl`RU=004
[EFU=:eEYC@8[ED2ool00`00ooooo`0:ool02000oooooh@@Nnn3l7__Q302Q1005g__Q11kkh@@Nnn4
47__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl02h@@00Ikcg__Q12<<H@@Q304Q1000h@`
Q11ccP02Nnl01H`aLljDTV^=Q3000h@@00Ac[XaAS35kk`9kc`9kk`03Q11kch@`009kc`05Q32447__
Nlmc[P02Nll027__Nln448@@Q31cSW_?Ljh2Nll2Q1001h@`S76<<G_?Q31kch@@00=kk`F44003Nnn4
47__00F44005Nnn447__Q11kk`02Q10018@`Nnn447__0_oo00<00?ooool01Ooo0007ool00`00oooo
o`04]KH01;FF]KJ]UKFF0kFf00FmekFf_MNee[gG00Be]P:eUPJ]M@:]E@:U=004WA>U59cCW;<2U980
7XaaU99ccX@@O0n447>>Jfe[CF]]HdaS39BBQ11c[W_?Ljikkf=<JfeSC6]]Llj<DH@`LhiBZV]=HbaS
309Jb`05DZYJje[[F/]:R@02F^/018@@S75S35[[0Xaa0YBB0YBb0YcC0XaA0YBB00jL/iCBW?>Llibc
S76DTYBbW=>D/YcCYABLlicC0Ycc0ZDD00JU=:DDYCBU5:DdYA@4YC@02JeEYEB]EJED[EFUE:eEYEB]
E@02ool00`00ooooo`0:ool04@00ooooog__Q11kkh@@O0n447__Q11ccX@@O0n447__Q1000g__01>4
47__Q11l3h@@Nnn447__Q11kkh@@Nnn447`?Q11kkh@@Nnn44003Nnl01G_?Q31kkg_?Q1000W__0W_?
00Ekkh@@Nnn4<6^=00:4<006Nnn4<7__Q124<7_?0XaA00=c[X@@Nll00W__00Ul3h`aQ12447__Q124
<7__Nll017__00f<<H@@Q11kkh@@Nnn447__S564<8`aQ124<002Nnl017_?Q11kcg>>18@@00Ukch@@
Nnn447`?Q11kkh@@Nnl00h@@00ikkh@@Nnn447__Q11kkh@@Nnn447__Q11l3h@@0_oo00<00?ooool0
1Ooo0007ool01P00oooookgG]KJm]`:e]P0@]IJe][FF]KJeU[Ff]IJm]kFf_MNe]Zee]KJeM[gg_KL2
[GD01V]=H^aJbe[[DZYBRP9:B@03@PQ:BDY9009:B@04BVU:BDYYBTT2F^/016</H`a[CF]=0V]]01]c
SU::S56447__Hda:JE[;JbfLdiBbU9:Ldh@`JdeJbf/]JdeS;5[[F/]BZUZ[F/]Jjf</BTT00U:Z01EJ
bjeEH`a[CIBbW=>D/YcCU;:LdiBbW=>DdYcCU=:LdiCBW=>DdYcCW?<00W__0icC00NLlicCW?>U59cc
YABLl`04YA@04:DdYABU=:Dd[EFU=:eEYCB]EJDd[EFU=:eEYCB]EJDd0_oo00<00?ooool02_oo00/0
0?oooon447__Q11kkh@@Nnn447__00>44009Nnn447__Q11kkh`aNln4<7_?00>44006Ljj<<G__Po1k
kh?`0X@@00Qkkh@@Q123l7__Q11kkh@`0X@@00Akkh@@Nnn4<0B44009Nnn448@@NnmccX`aQ12<DG>^
009kk`0;Po2<LG__Q11kkg_?Po2448aAQ32<<@02Q1001g_?S55kkh@@Q31c[W__00Z44003Q31kkh@@
00:4400?Nnn447__S55kch@@Nnn447__Q11kkh@@Nnn447__00V4400;Nnn448@@Q11kkh@@Nnn4<8@@
Q3244002ool00`00ooooo`05ool000Ooo`03003ooooo00Be]P:eUP05[IFeUZfE]IJ]U@05]KH02Jee
]KJ]MKgg]KJ]MJEDJffD/P02W=<01jDDWA>U59dCYABD/YcC00BD/P:DTP03Q124<8@`00F4<00OQ11B
RX@`Q11ccV]]BVUS36=<W=>DTYBbU99kke[[F/]S;5::DZYJjf<<JbeS;6/]HbaS3498DVY:BE::W?<0
0V</01RL/iBbW;>D/YbcU;:L/iBbW=>D/YcCU;:LdiBbW=>D/YccNln449BbW=>DdZDDU=84W?<01:DD
W?>U59dC0ZDD00>U=:DDYC@00jDd00V]EJDd[EFU=:eEYCB]EJDd[ED00_oo00<00?ooool02_oo00T0
0?oooomkkh@@Nnn447__Q1000g__00J447`?Q11kkh@@O0l3Nnl02H@@Nlmkch@@O0n447?>Q11l3`03
Q1000g__Q124<005Q10017__Q124<8@`0X@@00Il3h@@Nnn447__S342Q1003X@`Q11kkg_?Ljj447__
Q11kkg>^Nnn4<7__S542Q3001g__Nlmkcg__Llikch@`00>4400ALhj447__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q11kk`04Q1004G_?Nnn448@@Nnml3h@@Nnn447__Q11kkh@@Nnn447`?Q1000g__00N4
47`?Q11kkh@@Nnn44003Nnl018@@ooooo`001ooo0007ool02`00oooookfg]KJm]kFF]KJeU[Ff[ID0
0[FF00^e][FF]KJe][fg]KJeU[Ff]GJmekFf00:]M@0<JffLdiccYABU=:eE[GFeMZeeYABLljDD0YcC
0YBb00BDTYcCU;:L/`:D/P06S76<DH@`Q31JbiBB0XaA00Ukkf]=Nln449BBU;:DTXaAJdd00U:Z00][
;E::H`ac[X`aS76DTXaAS35[CEZ[009:B@0EBVVLdf]]JffD/YcCU;:LdiBbW=>D/YcCU=:LdiCBW=>D
dYcCU=:Ldicc009kk`>Ld`07W?>LdiccYABLljDDW?<01ZDD1:Dd00Z]EJDd[EFU=:eEYCB]EJDd[EFU
=0;oo`03003ooooo00[oo`0G003oooooQ11kkh@@Nnn447__Q11kkh?`Nnn447__Q11kkh@@Nnn4<7__
Q31kc`04Q103S542Q1002G__Po1kch@@Nnn447__Q11kk`02Q104Nnl00h?`Nnn44005Nnl00h@@Nnn4
4002S5402g__Q12448aALjj<DH@`Nnn4<8@@Ljh00X@@0X@`00><DG_?Q1000h@@17__00b447__Q11k
kh@@Nnn447__Po1kkh@@Nnl3Q1002G__Q31kch@@Nnn447_?Q11kk`05Q10017__Q12448@`0X@@00ek
kh@@Nnn447__Q11kkh@@Nnn3l7__Q11kk`02ool00`00ooooo`05ool000Ooo`03003ooooo00:e]P09
]IJe]ZfE]IJ]MKFF[GFeUZfE00:eUP0?]KJeU[Ff[GFmejeE_MN]UJee[EEcSZED[EFUE:eE00:U=008
WA>U5:DDYABLlicCU;:DTP><L@05U9:<LHaaS564<002Nnl017?>H`bD/YBB0Xaa00=c[XaAS7400iBB
00mkce[[BTUJbf]=LhikkiBBW?>]EJDdYABLdh@@Jfd00TY900ABRXaALji[C@RD/P0@W=>D/YcCU;:L
diBbW=>D/YccNln449BbW=>DdZDDU=84W?<01ZDDW?>U59dCYABM4`:U5004YCBU5:DdYA@9YC@2ool0
0`00ooooo`0:ool00`00ooooo`03Nnl00h@@Nnn44002Nnl01W`?Q11kkh@@Nnn440Akk`09Q11kkg__
Q11l3h@@Nnn4<7`?009kk`:4400DQ31l3h@@Nnn447`?Q11kkh@`Nnn447__Q11l3h@@O0n4<8@@Nnmc
cP=kk`:440=kk`05Q11cSW__S564<002Ljh2Q3002G_?Nnmc[W_?Llj<LF]]Q11kk`02Q1001G__Nln4
47__Q1000g__00>447__Nnl00g__00>447__Q1000W__00B447__O0n440=kk`0=Q11kkh@@O0n447__
Q11kkh@@O0n447__Q1000g__00N447__Q11kkh@@Nnn44002Nnl2ool00`00ooooo`05ool000Ooo`06
003ooooo]KJeU[Ff0[FF01B]UKFF[GFeUZfE]IJ]UKFf]IJe][FF]KJeeZee]KJeUZee]GIcS[fg0[Ff
00Z]UJeeYCBU59cc[GF]EJDdW?>Ld`:D/P04S76DLXaaU782S74048aAS36448@@DZZ<DH@@S364<7_?
S56DLXaaU9:4<6]]0U:Z00ES37>^S76DTYBb00>Ll`:D/P0IS76<<DY9DXY:JH@@LjiS39BbW;>D/Ybc
U;:L/iBbW;>DdYcCU=:LdiCBW=>DdYcCW?<00W__0icC00NLlicCW?>U59ccYABLl`08YA@03:DdYABU
=:Dd[EFU=:eEYCB]EJDd[EFU=0;oo`03003ooooo00[oo`07003oooooQ11kkh@@Nnl00h@@00ekkh@@
Nnn447__Q11kkh@@Nnn447__S35kk`04Q102Nll04G__Nln448@@Q32448?`Nlmkkh@@Po1kkh?`Nnn4
<8@@Q3001X@@00Qkkh@@Q324<7__S75kkg_?0X@@00B4<7>^Q32<D@9kk`:4<008Nnn3l7__Q11kkh?`
Q31kc`=kk`06Q11kkh@@Nnn447__1H@@00Ekch@@Nnn447__00>44003Nnn447__00>44005Nnn4<8@@
Q11kk`02Q1002h@`Nnn447__Q11kkh@`Nnn447__Q1000W__0X@@00Ekkh@@Nnn447__00;oo`03003o
oooo00Goo`001ooo00<00?ooool00[FF01N]UKFF[GFeUZee]IJ]MKFF[GFeUZee]IJ]UKFf]IJmejED
]KJ]MJeE[GEcSZDD00>U=00:YABU=9ccW?>M4jDDW=>L/iBBS743S5401HaaS56<LHaAS7400XaA00N4
<5[;Q32448@`S75kk`02S7402HaAQ31kce[;DXYS37_?NnnLl`02W=<2U;82S7408HaAS76<LD88BXUB
JV^=LjiBZYBbU9:D/YBBU;:DTYBbU9:LdiBbW=>D/YcCU;:LdiBbW?=kch@@U;:LdiCBYABDdP04W?<0
5JDDW?>U59dCYABLljDDW?>U59dCYCBU5:DdYABU=:DDYCBU5:DdYABU=002ool00`00ooooo`0:ool0
3`00ooooog`?Q11kkh@@Nnn447`?Q11kkh@@Nnn44003Nnl018@@Nnmkkh@@0W__00F447__Q11kkh@`
00J44003Nnn447__00:44003Q32448@`00:44004Nnn447__Q103Nnl01X@@Nnn448@@Nnn4<09kk`09
Nlml3h@@Nln4<7?>Nln<DH@@00=kk`>4400HQ32447_?Q31kch@@Nln448aAQ11kkh@@O0n447__Q11k
kh@@Nnn447__Q11kkh@@17__0X@@0W__00B447__Nnn440Ekk`07Q11kkh@@Nnn447__Q1000g__00N4
47`?Q11kkh@@O0mkk`02ool00`00ooooo`05ool000Ooo`0?003ooooo]KJeU[Ff[IFeUZee]IJ]MKEf
[GFeUZee00:eUP0:]KJeU[fg_MN]MKFF]GJ]EKFFLjh2[ED2[GD01KFF[GFeMZee[ED00ZDd00bU59cc
W=>LdiBbS76<DHaaS56<LHaAS342Q1001U[[U7:448aAU9:4<0:DTP0:S564<6]=DXYBZW_?S56DLYcc
YA@2W?<07ICBU;:<LIAbQ12DTSW7FZ]BZW>>NnmJbiBBU;:DTYBbU9:D/YBBU;:DdYcCU=:LdiCBW=>D
dYcCW?<00W__0icC00NLlicCW?>U59ccYABLl`05YA@00iccYABLl`02YA@00jDdYABU=007YC@2ool0
0`00ooooo`0:ool01`00oooooh@@Nnn447__00V44008Nnn447__Q11kch@`Nnn4<0>44003Po2448@@
009kk`04Nlmkkg_?Nnl2Q1000g__Q11kk`02Nnl038@`Q12447__Q11kkh@@Nnn447__Nln4<09kc`06
S35kkg__Q12<<G_?0X@@00IcSX@`S35kcg__Q102Nnl3Q1003G__Nln<DG_?Nnn4<7__S35kkh@@Nnn4
47__00:44004Q31kkh@@Nnl5Q10017__Q11kch@`0X@@00=kkh@`Q1001H@@00Ekkh@@Q124<7__00>4
4005Nnn448@@Q11kk`03Q1000g__Q11kk`02ool00`00ooooo`05ool000Ooo`09003ooooo[IFeUZee
]IJ]MKFF00F]M@09]IJ]MKFF[IFeU[Ff_MNUE;FF00:]E@03[GEc[ZDD00>U=003YABU=9cc00>Ll`:L
d`03U;:DTXaa00>DTP0IS76DTXaaS564<8@@NnmJbh@`Nnml3haANnn<DH@`S75kkf<<@TQJbg`?W=>D
/YBBU;800YcC02BLliBbU9:<DH@@U98iae[;F^]c[XaaH`bD/YBBU;:DTYBbU9:D/YBBW=>D/YcCU;:L
diBbW=>D/YccNln449BbW=>DdZDDU=84W?<01JDDW?>U59dCYA@00icc00fU59dCYABU5:DdYABU=:DD
YCBU5:DdYABU=002ool00`00ooooo`0:ool04`00ooooog`?Q11kkh@@Nnn447__Q11kkh@@O0n447__
Q11kkh@@009kk`0;Q11kkg`?Q11kkh@@Nnn4<7__Q11kk`02Q1000h@`Q1244002Q10017__Q11l3h@@
1G__00Z447`?Q11kkh@@Nnn<DH@@Nln4409kk`06Q124<7_?Q32447_?0W__0224<7`?Nnmkkh@@Nnn4
47`?Q31c[XaaLhj<<G__Lhikkh@@Nnn447__Q11kkh@@O0n447__Q11kkh@@Nnn447__0X@@00=c[W__
Q10018@@00=kkh@@Nnl017__00V447__Q11kkh@@Nnn447__Q1000W__00Il3h@@O0n447__Q102ool0
0`00ooooo`05ool000Ooo`04003ooooo]KH2]IH06:fE]IJ]MKEf[GFeUZee]IJ]UKFf]IJe][FF_MN]
UKfg[GFU=:eeYCAkciccYCB]M@:U=008[EF]MJDd[EFU=:DDW?>Ld`:D/P06U9:D/YBBU9:<LIAb0XaA
00b4<8`aF^^<<HaaQ124<8aaQ32<DH@`S542DXX01E:ZU;:DTZeEU9800YBb00JLlicCU99kkg>>F//2
@RP01e[;Jdf4<7__H^bDTYBb00>DTP:D/P06W=>D/YbcU;:LdiCB0icC00NDdX@`H`b]EIBbW?>U5006
W?<01:DDW?>U59cc0ZDD0ZDd00>]EJDdYC@02JDd0_oo00<00?ooool02_oo00D00?oooon447__00>4
4003Nnn448@@00>44007Nnn447__Q11kkh@@Nnl00X@@00N<DG__S35kkh@`Q123l002Q1002G__Po1k
kh@`Nnn447__Q11kk`03Q1000g__Q1244003Q1002G__Q12448?`Nnn<<G__Q11ccP03Q1001W__Q324
48@`Q11k[`:440=kk`:<D@9kk`07S56447_?S75c[W__Q30018@@00=kkh@@Q1000h@@00Ekkh@@Q124
47__00:44006Po2<DG_?Q32447__0h@@00=kkh@@Nnl00h@@00Mkkh@@Nnn447__Q11kk`05Q1001G__
Q31kkh@`Nnl00_oo00<00?ooool01Ooo0007ool01`00ooooojfE]IJ]MKFF00F]M@06]IJ]MKFF[IFe
UZfE0[Ff0kFF00FU5;FFYAAkcicC00:]E@04YCBU5:eEYE@3YC@019dCW?>DdYBb0YBB00B<LIBBS76D
TP:<D@:4<005Q11Jjh@@S75l3`02S542Q3001HaAQ31BJT98F//00YBB0YcC00JDdYcCU9:4<6^=H``2
DXX013X7BRUBZV]=0X@@00EJjiBBU9:DTXaa00:DTPJD/P0@W=>D/YcCU=:Ldh@@HbbU=9BbW=>U59cC
W?>LdiccW=<2W?<01:DDW?>U59cc0ZDD0jDd00ZU5:DdYABU=:DDYCBU5:DdYABU=0;oo`03003ooooo
00[oo`03003ooooo00=kk`>44004Nnn447__Q103Nnl01X@@Nnn447_?Q11kk`:44008Nnn448@@Nnn4
47__Q11l3`9kk`0CQ11kkh@@Nnn447__Q11kkh@@O0n447__Q11l3h@@Nnn447__Q1000W__00J448@`
Nnn447?>Nnl3Q102Nnl00h@`Q1244003Nnl01HaANlmkcg_?Nnl00X@@01Ac[XaALjj447__Q11kkh@@
Nnn447__Q11kkh@@O0n447__Q11kkh@@0g__00><<G?>Q3000g__01>447__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q11kkh@@O0n44003Nnl00h@@Nnn44002ool00`00ooooo`05ool000Ooo`0?003ooooo
]IJ]UKFF[GFeUZee]GJ]MKEf[GFeUZfE00:eUP0=]KJeU[fg[GFe]Zee[EF]MJeENnnLljDd[GD00jDd
00N]EJDd[EFU=:DDW?>Ld`02U;82U98018aaU7:<LIAb0XaA01R4<8`aF/^<<HaaQ124<8aAQ12<DHaa
S55:BDXYDZZL/haaW=>DdYcCU;:<<F]]F^/3BTT01d88BTUJZf</S36445[[00FDTP0BU;:DTYbcU9:L
/iBbW=>D/YcCU=:LdiCBQ31S3:eEU;:LljDD1Ycc00JU59ccYABLljDDW?<5YC@00jDDYCBU=006YC@2
ool00`00ooooo`0:ool00`00ooooo`04Q1000h@`Q1244002Q1001g__Q11kkh@@Nnn447__00:44006
Po1kkh`aNnn4<7__0X@@00>3l8@@Q1000X@@00=kkh@@Q1000h@@00Ukkh@@Q12447__Q11kkh@@Nnl0
0h@@00=kkh@@Nll01H@@00Ekkh@@Q12<<G__00>44006Nnn4<7__S55c[X@@0X@`00f448`aQ11kciBB
Njmkkh@@Nnn447__Q11kk`03Q1003g__Q11kkh@@Nnn447__Q11kkh?`Q31kkh@@Q31kk`03Q10027__
Q12448@@Nnn447__Q302Q1000g__Q11kk`05Q1001G__Q12448@@Nnl00_oo00<00?ooool01Ooo0007
ool01`00ooooojee]IJ]MKFF00:]M@03[EF]MJee00:]M@04]IJ]MKFF[GD2]IH03Zee[IF]MJDd]IJU
=7__W=>U=:EDYCBM4jeEYE@3YC@019dCW?>DdYBb0YBB00B<LIBBS76<L@:<D@:4<005Q11Jjh@@S75k
k`02Q3002X@@Q32<DH@@@RQ225[;U=:DTYBb0YBB00B<LG?>H`a:R@9:J@0<@PPiidY9BXUS37__Q11B
ZYBBS76DTXaa0YBB0iBb01>DTYBbU;:L/iBbW;>D/YcCQ11S;:DdU;:LdjDDW=>LlicCW?>Ld`02W?<0
2JDDW?>U59ccYABM4jDdYABU=003YA@01jDdYABU=:DDYCBU5:Dd00;oo`03003ooooo00[oo`0F003o
ooooNnn447__Q11l3h@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl2Q1001g__Q12447__Q11kkh@`
00:44005Nnn447__Q11kk`03Q10037__Q11kkh@@Nnn447__Q11kkh@@Nnn4409kk`0BQ11c[W__Q11k
kh@@Nnn4<8@@Nnmkch@@Nnn447__S55[KG_?0X@@01ikkh@`Q32447?>Q31kch@@O0n447__Q11kkh@@
Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn4<7>^Q103Nnl02h@@Nnn447__Q11kkh@@Nnn447__Q100
0W__00Yl3h@@Nnn447__Q11kkh@@Nnn4409kk`;oo`03003ooooo00Goo`001ooo00H00?ooooneUZee
]GH4[GD07ZeE[GF]MKEf[GFeUZee]IJ]UKFf[GFe]Zee[EFeUZeENnnLdjDd[GFU=:DDYCB]EJDD[EFU
=:DDW?>Ld`:D/P:DTP0US76DLXaaS764<8`aQ124<5[;Q32<DH@@Q32<DH@@S364<8`a@RQ::E[;W=>D
TYccU9:<LG__JdeBZU::BVUJZd8XBVUBRU9ZDZX00W__00IJZiBBU9:<LIAbS742U98019BbU9:D/YBB
0YBb00ZL/iBbW=>DdX@`H`b]EIBbW?>U50JLl`03YABLljDD00>Ll`:U500<YCBU5:DDYABU=:DDYCBU
5:DdYABU=:DD0_oo00<00?ooool02_oo00D00?oooon447__00>44005Nnn447__Q11kk`02Q102Nnl2
Q102Nnl028?`Nnn<<G__S364<8?`Q302Q1000h@`Q1244006Q1000g__Q11kk`03Q1003G__Q12448@@
Nnn447__Q11kkh`aQ11kcg__00:44004S35kkh@`Llh2Q102Nnl01haANlmkcg__Q32447__00:44007
Nln3l7__S56448`aNnl00h@@00Mkkh@@Nnn447__Q11kk`03Q1001W__Q11kkh?`Q11kk`:4400;Nnn4
<8@@Q11kkh@@Nnn447__Q11kk`03Q1000g__Q11kk`03Q1000g__Q11kk`03Q10017__ooooo`001ooo
0007ool00`00ooooo`04[GD2[ED01JED[EF]EJee[ED00Zee00FeUZee]IJ]MJeE00:]M@09YCBeUZED
Q12DdZDdYEBU=9cc00FU=004WA>LliCBU;82U982S742S542Q302Q1001G`?F/]l3haANnl00X@`00N4
48@`Q324<59Z@RQBRP02S54039BbW;>4<6]]F/]BRTZ9DZYBRU[;F^]S309:J@04Ljj445::U985S746
U984U;8039cCQ11S;:DdU;:LdjDDW=>LlicCW?>Ld`:Ll`04YABLljDDW=<2W?<3YA@02YdCYABM4jDD
WA>U59dCYABM4jDD0_oo00<00?ooool02_oo01D00?oooomkkh@@Nnn447__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q3000W__00b447__Nnn447__Q11kkh@`O0n447__Q103Nnl01X@@Nnn447__Q11kk`>4
4008Nnn447__Q11kkh@@O0mkk`:44005Nnn447?>Q31l3`03Q1002V]]S75kkg__Q31c[W__Q32447__
0W_?01IccW>^Llikkh@`Q11l3h@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn440Akk`0LLlj447__
Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q102Nnl2ool00`00
ooooo`05ool000Ooo`06003ooooo]GJ]MKEf0Zee00>]EJee[ED01:ee00neMZee]IJ]MKFF[EFeUZee
[EFeUZeeQ12LdjDd[ED00ZDD00RU=:eEYAB]EJDdYABLlicC0YBb00BDTYAbS76<L@:<D@:4<0:4400U
F/^448aAPo2448`aNnn<<H@`U;9JbdYY@PQc[W>>S56D/W__F/]BRU[;Jde[KF]=Ljikkg>>DZY:BG_?
Q11JbhaaU7:<LIAbS7400YBB012D/YBBU;:DTYBbU9:L/iBbW;>DdX@`H`b]EIBbW?>U50JLl`03YABL
ljDD00>Ll`FU5003W?>U5:DD00JU50;oo`03003ooooo00[oo`07003oooooQ11kkh@@Nnl01H@@00Mk
kh@@Nnn447__Q11kk`03Q1000g__Q31kk`07Q1001G__Q12448@@Nnl00X@@00B4<8@@Q11kk`>44005
Nnn448@@Q31kk`03Q1003g_?Q32448@@Q32448@`Po1kkh@@Q31cSXaaS5644002Nnl01HaANnmk[g__
S7400haA00B447__Nnmkk`B44004Q32448@@Nnl4Q1000h@`Q1244002Q1008G__Q12447__Q32447__
Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kk`02ool00`00
ooooo`05ool000Ooo`03003ooooo00:]M@07[EF]MJED[EFUE:eEYE@00ZeE1:ee00>eUZee[ED00Zee
00FU=;FfYEB449Bb00:U=005YABLljDdYCBU5002YC@019dCW?>DdYBb0YBB0Xaa0XaA0X@`0X@@00Mk
ke[;O0n<DG__Q124<002Q1003haAU=9S;4Y9>LMJjf<<Nln<LF]]DXY:JF/]O0n<D@02Q3001haAQ11B
ZTYYLlj<DE[[00><L@03S56<LHaa00>DTP05S76DTYBBU;:DTP02U;8039cCQ11S;:DdU;:LdjDDW=>L
licCW?>Ld`:Ll`04YABLljDDW=<2W?<03JDDWA>U59ccYABM4jDDWA>U59dCYABM4jDD00;oo`03003o
oooo00[oo`08003oooooO0n447__Q11l3`>4400;Nnn447__Q11kkh@@Nnn447__Q11kk`02Q10057_?
Nnn447_?Q31kkh@@O0n447__Q11kkh@@Nnn447__Q11kkh@@Nnl3Q1001W__Q11kkh@@Nnn440=kk`0:
Nlmkkh@`Nnn447>^Q11kkiBBLjh2Nnl01H@@Lhj4<8@`Nnl00X@@0W__00Ec[X@`Q31kkh@@009kk`04
Q11kkh@@O0l3Q1003W__Q12448@@Nnn447__Q11kkh@@Nnn447?>Q303Nnl03H@@Nnmkkg__Q11kkh@@
Nnn447`?Q11kkh@@00=kk`09Q11kkg__Nnn447__Q11kkh@@00;oo`03003ooooo00Goo`001ooo00@0
0?oooone]P:eUP:]M@03[EF]MJeE00:]M@06]GJ]MKFF[GFeUZfE0jee00fU=:eE[GFU59BBS76U=:ee
YAB]EJDdW?>U=005W?<029CBW=>D/YBBS76DLXaaS542Q3001G__Q11S38aAS7400W__01j4<7__S56D
TX?`H`aJbe[[Jfec[W_?W?=JZdY9Nnn<LH`aQ32DLX@`S55kke[;BTUcSW__F^^<LIAbS742U9803YBb
U9:D/YBBU;:DTYBbU9:L/iBbW;>DdXaaF^/2W?<05ZDDW?>U59ccYABLljDDW?>U59ccYABLljDDW?>U
59ccYABLljDDW?>U59cc0ZDD00BU=:DDYABLl`;oo`03003ooooo00[oo`07003oooooQ11kkh@@Nnl0
1H@@00Mkkh@@Nnn447__Q11kk`03Q1001X@`Q11kkh`aNln<<@9kk`06Q11kcg__Q31kkh@`1X@@00Ek
kh@`Nnn447__00F44006Nnn3l7__S36447_?0X@`01IkkhaAQ31kcg>^Nln449AbNnn448@`Lhj448@`
Nnn3l7__Q11kch@`Nln<D@J44005Nnn3l7__Q11kk`02Q1000h@`Q1244002Q102Nnl3Q1001X?`Nnn3
l7__Q11kk`F44003Nnn448@@00F44006Nnn447__Q11kkh?`0X@@00Akkoooool000Ooo`001ooo00<0
0?ooool00[FF0Zee00>UE:eEYE@00ZeE01N]MJeE[GF]MKFF[GFeUZED[GFUE:DdYEB]MIdCU9:<DJeE
YEBU5:EDYCBLdjDd00BLl`:Ld`:D/P04S76DTXaAS742Q302Q1001G__H`b4<8aANll00h@@00Z4<9bc
Q11cSV</Lhj4<9cCYABDTP9BRP0?Q12D/X@`Q11l3haaO0m[KDY9@RQ[KG__F/^<LHaA00:<L@:DTP03
U;:DTYBB00>DTPBD/P04W=><DF<<W=<FW?<01JDDWA>U59dCYA@00Ycc0_oo00<00?ooool02_oo00<0
0?ooool00g__00^447__Nnmkkh@@Nnn447__Q11kkh@@009kk`05O0n448@@Q11l3`02Q1001G__O0n4
47_?Q1000W__00B447__O0n4<0:4400<Nnn447__Nnml3h@@Nnn447`?Q11l3h@@0g__00N448@`Q11k
kg_?Nnmkc`03Q1004HaANnmkkf^=Nnml3h@`Q11kkg_?Q11l3g_?Nnn<DG__Q1000g__00N447__Q11k
kh@@Nnn44003Nnl028@@Nnn447__Q11kkh@@Nnl2Q102Nnl00h@@Nnn44009Nnl02H@@Nnn447__Q11k
kh@@Nnn44003Nnl00h@@Nnn44002ool00`00ooooo`05ool000Ooo`04003ooooo]KH2]IH2[GD00jeE
[GF]E@04[GD00kEf[GFeUP04[GD06ZDd[EF]MJDDU9:<DJDd[EFU5:eEYCBLljDdYABLljDDW?>U59cc
W=>DdYBBS76DLXaaS542Q3007G__Q11Jjh`aS563l8@`S55kkh@@NnmcSU[[F/]S37_?U9:U58@`FZ]J
biAbW=><LG__Nln4<7>^F//00T8X00Qc[W__F^^<DIAbS76DLXaa0YBB02BD/YBBU;:DTYBbU9:L/iBb
W;>D/XaaF^^LlicCYABLdjDDW?>U59ccYABLljDDW?>U59ccYABLljDDW?>U59ccYABLljDDW?<3YA@0
0iccYABLl`02ool00`00ooooo`0:ool01@00oooooh@@Nnl00h@@00ekkh@@Q12447__Q11kkh@@Nnn4
47__Q31kk`03Q1000g__S35kk`02Q1001X?`Q11kkg__Q31kk`>44007Nnn447__Q11kkh@@Nnl018@@
00N4<8@@Q11kkh@@Llj<<@04Q1002H@`S55kkg__Ljj4<7__Nln4<002Q1000h@`Ljj44002Q1004G__
S55ccX@`Q124<7__Q11kkh@@Nnn447__Q11kkh@@Nnl01h@@00=kkh@@Nnl00h@@015kkh@@Nnn447__
Q11kkh@@Nnn3l7__Q11kkh@@Nnn447__00>44003Nnn447__00>44004Nnoooooo0007ool000Ooo`03
003ooooo00:eUP:]M@05YEB]EJED[EFUE002[ED4[GD03KFFYEB]MJEDYCBUE:eeWA>DTX@`YCBUE:DD
00:U=003W=>U=9dC00>U50:Ll`:Ld`04S76DTXaAS742Q302Q10067__F^]l3haANnn<DH@`Nlmc[V</
F/]:JCX7@RQBZW>>Q124<5:ZH`b4<9BBQ11kc`9[K@07DZY:JD8XDZYkkh@@F//00XaA0Xaa00>DTXaa
U9801IBB19Bb00BL/h@`F^^Ld`:Ll`0:W=>LliccW=>LlicCW?>LdiccW=<9W?<01YcCW?>LljDDW?>U
50:Ll`;oo`03003ooooo00[oo`0G003oooooNnn447`?Q11kkh@@Nnn447`?Q11kkh@@Nnn447__Q11k
kh@@Nnn44002Nnl01h@@Nnmkcg__Nln447_?00:4409kk`04Q11kkg__Q104Nnl02H@@Nnn447__Q11k
kh@@Nnn44002Nnl00g_?Nnmkk`02Q3001h@@Nln448@@Q31kciBB00:4409kk`07Q11kkg`?S564<7__
Ljh00W__01N447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11l3g_?00=kk`0;
Q11kkh@@Nnn447__Q11kkh@@Nnn44003Nnl03H@@O0n447__Q11kkh@@Nnn447__Q11kkh@@00;oo`03
003ooooo00Goo`001ooo00@00?oooone]P:eUP:]M@03[EF]MJeE00:]E@05[GF]EJee[GFeMP04[GD0
3:Dd[EF]MJDDU9:<DJDd[EFLljeEYABLl`>U5003YCBU5:DD00:Ll`06W=>DTXaaU7:<LHaA0X@`01Ek
kh@@F^^448@`Po24<8`aLhi[CE:ZF/]BRTY9@PQBZV]]S364<5[[DZX00W>>00A[KF]=Hba:J@922005
FZ][CHaAQ31Jj`03S5400iAbS76DTP03U9802YBbU9:D/YBBW;>D/YbcU;:<DE[;0YcC00>LlicCYA@0
2Icc00NU59ccYABLljDDW?>U5003W?<00jDDW?>U5003W?<2ool00`00ooooo`0:ool01@00oooooh@@
Nnl00X@@00J4<8@@Q12448@`Nnl2Q1001X?`Nnn447__Q11kk`:44003Q31kkh@`009kk`0?Q123l8@@
Po2448`aNnn447__Q11kkh@@Nnn447__00N44006Nnn448@@Q11kkh@@0W_?00><DG__Nll00W__0X@`
00>448@`Q1000X@@00ekkg_?S56<DG__Lhikkh@`Q11kchaAPo1kk`03Q1001G__Q12448@@Nnl00h@@
00Ikkh@@Q12447__Q302Q1003g__Q12448@@Nnn447__Q11kkh@@Nnn447__Q11kk`03Q1000g__Q124
4005Q1001G__Q11kkh@`Nnl00_oo00<00?ooool01Ooo0007ool00`00ooooo`02]IH2[GD05JED[EFU
E:eEYEB]EJED[EFUE:ee[EF]MJED[GFUE:DdYEB]MIdCU9:4<002YC@02IccYCBU=9CBYABLljDDWA>U
5002W?<01YCBW=><LIBBS56<L@:4<0:4400@NnmS37__Q31kch@`O0mS;5:Z@PQ:BE::BTU::DZ9Lhh2
Q3004E[;DVYBZU:ZDXYJbdYY@NPaYTY9H`ac[X@`Q11JjhaAQ3000XaA0Xaa00>DTXaaU9800iBB1IBb
00>4<5[;U=8019cC00RLlicCW?>LdiccW=>LlicC2Icc00>LdiccW?<00icc00FLdiccooooo`0000co
o`03003ooooo00=kk`03Q11l3h@@00=kk`06Q11kkh@@Nnn447__0h@@00Ekkh@@Nnmkkh@@009kk`04
Q11kkh@@Nnl3Q1004g__Q11kkh@@Nnn447__Q11kkh@@Nnn447_?Q11kkh@@Nnn447`?00:4409kk`04
S55c[X@@O0l2Nnl09H@@Nnn447__Q11kkh@`Nnn447__Nlmkkh@`S55kkf^=S55kch@@Nnn447__Q11k
kh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@00=kk`0=Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q100
1G__00V447__Q11kkh@@Nnn447__Q1000W__0_oo00<00?ooool01Ooo0007ool01000oooookFf0[FF
0Zee00>]EJee[ED01:eE1jee00bU=:eE[GFU59BBS36U5:eEW?>]EJDDW=<2YA@019ccYABLlicc0YcC
00JD/YBBS76DLXaaS542Q3000g__Q11S3002Q1004G__Q31kke[;BTU225Z[H`aJjdYYDZY[CH`aQ31S
35:ZF//00TY900]:JD88@RQ225:ZJfec[X@@NnmS;8@`00:<D@:<L@0SU7:<LIBBU9:D/YBBU;:DTYbc
U;:L/iBBS55JbicCU=:LliCBW?>LdiccW=>LlicCW?>LdiccW=>U59ccYABLljDDW?>U5002W?<019cC
W?>LljDD0Ycc00BLdoooool000coo`05003oooooQ31kk`05Q1000g__Q11kk`03Q1001G__Q11kkh@@
Nnl00h@@00Akkh@`Nnn3l0>44006Nnn448`aNnn447__0X@@00b4<8@@Q12448`aNnn447__Q11kkh@@
Nnl2Q1003H@`Nnn4<8@@Q32<DG__Q123l7__Q31kkh@@00:4<0:44009Nnn448@@Q31kkh@`Q12<<G>^
00^44009Nnn447__Q11kkh@@Nnn447__00>44003Nnn448@@00>44003Nnn448@@00>44003Nnn448@@
00B44004Po2448@@Nnl3Q1001G__Q12448@@Nnl00_oo00<00?ooool01Ooo0007ool00`00ooooo`02
]IH2[GD02JED[EFUE:eEYCB]EJED[EFUE002[ED02ZeeYEB]MJEDYCBUE:eeWA>DTX@`0ZDd00VLljDD
YABD/ZDDW=>LlicCW?<00YcC0YBb00B<LIBBS56<L@:4<0:4400CNnmS37`?Q11ccX@@LjiBRSW7Jbec
cXaANnm[CF<<Ljj<DHaaJdd00V<<00MBRTYYBVTiie::@TQJj`02Jfd01G>^NlmS;8aAQ3000XaA0Xaa
00>DTXaaU9800iBB1IBb00>4<5[;U;8019cC00RLlicCW?>LdiccW=>LlicC2Icc00>DdYccW=<00icc
0YcC0_oo00<00?ooool02_oo00<00?ooool01G__00V447__Q11l3h@@Nnn447`?Q1000g__00>447__
Q3000W__0X@@00EccX@@Nnn447__00:4409kk`03Q11kkh@@00:4400;Nnn447`?Q11kkh@@Nnn447`?
Q11kk`03Q102Nnl02X@`Nnn447_?Q11kkh@@S35[SHaA0W__00B<DG_?Llj4409kk`0@Q31kcg__Nnn<
LH@@Nnn447__Q11kkh@@Nnn447__Q103Nnl01h@@Nnn447__Q11kkh@@009kk`:44003Nnn447__009k
k`07Q11kkh@@Nnn447__Q1001G__00V447__Q11kkh@@Nnn447__Q1000W__0_oo00<00?ooool01Ooo
0007ool01`00oooookFf[GF]EJDd00>]M@>]E@07[GF]EJee[GFeMZee[ED00Zee00fU=:eE[EFU=9Bb
Ljj]MJDdW?>U59Bb[EFU5003W?<00icCW?>Ld`02W=<00iBbS76<L@02S5401X@`S35kkg__H`b3l0=k
k`0@LhiBZU::Q12<LH@`LhiBRU:ZLjjL/h@`NlmS;5Z[BTT2@RP04TY9DZY[KG>>JdeBZYAbJfecSX@`
S564<8aAS76DLXaaU9:<L@:DTP:D/P03W=>D/YcC00:DTP06BVVLdicCU9:LliBb2IcC00RLlicCW?>L
diccW=>LlicC29cc0_oo00<00?ooool02_oo00D00?oooon447__00>44008Nnn447__Q11kkh@@Nnn4
40=kk`03Q31kkh@@00:44005Nnn447_?S35kc`03Q1001H@`Q11kkh@`Nnl00X@@00Z4<8@@Q11kkh?`
Nnn447__Q11kk`>44007Nnn<<G__Q31ccXaALjh00X@@00akkg_?S56<DG__Q11kcg__S75kkh@@Q303
Q1001g_?Lhj<DHaALlikch@`00>44003Nnn448@@00>4400:Nnn447__Q11kkh@@Nnn448@`Nll2Q300
18@@Q31kkh@`0X@@00Ekkh@@Nnn447__00>44007Nnn447__Q11kkh@@Nnl00h@@00Ekkh@@Q12447__
00;oo`03003ooooo00Goo`001ooo00<00?ooool00Zee00VUE:eEYEB]MJED[EFUE:eEYE@00ZeE00J]
MJeE[GFUE:ee[ED2YC@01JeEYABL/f^=[ED00jDD00NL/jDDYABLdiccW=>Ll`02W=<019CBW=>DTYBB
0XaA02F4<8aAQ12447_?H`akkh@@Nln446^=F/]BZW>>Jhe[CE::@PQ2B6]=Q32<LH@`Nnm[SF</DZY:
JD8XDXYJbe[[DZY:BH@`Jde[K@02Q3000haAQ32<L@03S74019BBS76DTYBB0YBb01:L/iBbU;:<LDYY
U;:LdhaaW?>DTYcCU=:LdiCBW=>DdYcCU=82W=<03iccW=>LlicCW?>LdiccW=>LlicCW?>LdiccW=>L
l`02ool00`00ooooo`0:ool00`00ooooo`03Nnl04H@@Nnmkkg__Q11kkh@@Nnn447__Q11kkh@@Nnn4
47__Q10017__00Ml3g_?Nnn447_?S35kc`04Nnl018@@Nnn447`?0W__00R447__Nnmkkh@@Nnn447`?
0h@@00]l3g__NnmcSXbAS764<8@@Nln447__00:4409kk`0RS55l3g>>Ljikkh@@U;:<LG_?Lhj447?>
Q31kkh@@O0n447`?Q11kkh@@Nnn447__Q11kkh@@Nnn447`?Q11kch@@O0l2Q1002g_?O0mkkg__Q11k
kh@@Nnn447__Q1000g__00F447`?Nnml3h@@00=kk`03Q11kkh@@009kk`;oo`03003ooooo00Goo`00
1ooo00L00?ooooneUZee[EFU=003[GD00jDd[EF]E@02[ED4[GD01:eE[GF]MJDd0ZeE00VU=9BbLhjU
=:DDW?>U=9CBYC@019cc00>LdiccW=<00YcC00>D/XaaS7400XaA00N4<8`aNnmkkf<<Q124<002Nnl0
97>>F/]Jbf<<F^]BRT8X>NMBJV</NnnDTYBbU9:<DG__JdeBZU9ZBTU:JD8XBRU228@@Jdec[X@`S564
<8aAS76DLXaaU9:<L@:DTP:D/P03W=>D/YcC00:DTP06BVVLdicCU9:LliBb2IcC00RLlicCW?>Ldicc
W=>LlicC29cc0_oo00<00?ooool02_oo00/00?oooon447__Q11kkh@@Nnn447__00F44005Nnn447__
Q11kk`03Q1000g__Q1244002Nnl2Q1001X?`Q11kkg__Q11kk`>4400<Nnn447__Q11kkh@@Nnn447__
Q11kkh@@0X@`00Ukkh@`Q12<LG>>Q11c[W^_Nll00X@`00R447__S35ccW_?Llj448@`0XaA00R<<G__
Nnmkkh@@Q323l8@`1H@@00=kkh@@Nnl01H@@00=kkh@@Nnl00h@@00Ikkh@`Nnn<<G__Q304Q1001g__
Q11kkh@@Nnn447__00>4400;Nnn448@@Q11kkh@@Nnn447__Q11kk`02ool00`00ooooo`05ool000Oo
o`03003ooooo00:]M@:U=003YEB]EJED00:U=00:[EFUE:eEYEB]EJED[GFU=:eEYE@2YC@01ZeEWA>D
/V]=YCBLl`:U5007W=>U59ccW=>LlicCW?<00YcC00BDdYcCU9:DTP:<D@08Q32<DH@@Q11kcf</O0n4
409cSP04F^]:JDYYDVX2@RP05CX7BTUBRV<<Hbakcg?>Nnmc[V]]F^]BRT8XBVU223W7>NM228@@Jfek
k`02Q3000haAQ32<L@03S74019BBS76DTYBB0YBb01:L/iBbU;:<LDYYU;:LdhaaW?>DTYcCU=:LdiCB
W=>DdYcCU=82W=<03iccW=>LlicCW?>LdiccW=>LlicCW?>LdiccW=>Ll`02ool00`00ooooo`0:ool0
0`00ooooo`02Nnl097`?Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11l3h@@Nnn4
47__Q11kkh@`Nnn447__Q11kkh@@Nnn440=kk`08Q11kkh@@Nnn447__Q11kk`:4409kk`06S564<7_?
Llikkg`?0X@@00Ekkg?>Q11ccXaA00:4<00HNnmcSW>>Nlmkkg_?Nnn<<G`?Q31c[X@@Nln447`?Q11l
3h@@Nnn447__Q11kkh@@0W__00F447__Nnn447__00B440Akk`09Q11kkh@@Nnn447__Q11kkh@@00=k
k`09Q11kkh@@Nnn447__Q11kkh@@009kk`;oo`03003ooooo00Goo`001ooo00@00?ooooneUP:]E@09
YCB]EJeE[EFU=:eEYCB]EJDd00:]E@03[GF]EJeE00:]E@>U=003YABD/V]=00>U5003[EFLdjDd00BL
l`03W=>LlicC00:Ld`03U;:<LHaa00:<D@0=Q32<<G__Nnm[CH`aNnm[CE[;BTTiad8X@PP00T8X00MB
RU[;F^]JbeZ[DZYJZ`02DXX02dY9BRU22488BTU223W7BTU228@@Jfd00X@`00R<DH@`S56<LIAbS76D
TXaa0YBB0YBb00>LdiBbW=<00YBB00I:JIcCW=>DTYccU;89W=<049ccW=>LlicCW?>LdiccW=>LlicC
W?>LdiccW=>LlicC0_oo00<00?ooool02_oo00H00?oooon447__Q302Q10017__Q12448@`0X@@00=k
kh@`Q1000X@@00J4<7__Q12448@`Nnl5Q10017__Po24<7__0X@@00Akkh@@Nnn4<0:44003Nnn448@@
00>44003Nnn447__00>4409kk`03Lhj3l8@@00:44005S55kkg__Ljikk`02Q1000g__S55kk`02Q100
1X@`Q124<7__S364<0:4409kk`04Po2448@@Nnl3Q1002W__Q11kkh@`Nnn447__Q11kkh?`0X@@00]k
kh@`Nnn4<7_?Q11kkh@@Nnn447__00F44005Nnn448@@Q11kk`03Q1001g__Q11kkh@@Nnn447__00;o
o`03003ooooo00Goo`001ooo00H00?oooon]MJeEYA@2YC@00jeEYCBU=003YC@03ZeEYCB]EJED[EFU
5:eEYEBU=:DD[EFLliBbH``2W?<2YC@01icCYABLlicCW?>Ldicc00:Ld`04U=:LdiBBU982S5402X@`
S56448@@NlmcSX@`NnmJbdYY0SW700Y2:5:ZF/]S36</JfeS;6<<DZYBRP9:B@03@PQ2:488009:B@08
@PPiid8XDZY:BG?>Hbal3`:4<003S564<8aa00><L@04U9:<LIBBU982U;804YbcU;:D/XaaBVVD/YcC
S76LliBBW=>DdYcCU=:LdiCBW=>DdP:Ld`0?W?>LdiccW=>LlicCW?>DdYcCU=:LdiCBW=>DdYcC00;o
o`03003ooooo00[oo`0B003oooooNnn447__Q11kkh@@Nnn447__Q11kkh@@O0n447__0h@@00=kkh@@
Nnl00h@@01Ikkh@@Nnn447?>Q11ccX@@O0n447__Q11kkh@@Nnn447__Q11l3h@@Nnn4409kk`04O0n4
47__Q102Nnl02X@`S35kkg_?Ljikcg__S36<LH@@0W__0h@@00B4<8@@Nnmkc`>4400<Ljj447__Nnml
3h@@Nnn447__Q11kkh@@0g__00R447__Q11kkh@@Nnn447`?0W__0X@@00Mkkh@@Q11kkh@@Nnn44003
Nnl018@@O0mkkg__0h@@00Ykkh@@Nnn447`?Q11kkh@@Nnn440;oo`03003ooooo00Goo`001ooo00D0
0?ooooneMZeE00:U=003[EFU=:eE00>U=003[EFU=:eE00>]E@04YCB]EJeEYA@2YC@00jDDU99S3002
W?<01JDD[EFLdjDdW=<00icc00>LdiccW=<00YcC00>D/XaaS7400XaA00f4<8`aNnmkkg>^S75kceZ[
@RQ1j48XH^a[K@03Lhh016=<H`aJjf<<0U:Z00e:JE9ZBTUBJTYYDXY224Y9F/]cSU[;NlmJj`02Q300
28aAQ32<DHaaU7:<LIBBS742U982U;800icCU;:Ld`02U9801TYYW=>LdiBBW?>D/PVLd`07W?>Ldicc
W=>LlicCW?<02IcC0_oo00<00?ooool02_oo00d00?oooon447__Q11kkh@@Nnn447__Q11kk`03Q100
2G__Q12448@@Nnn447__Q11kk`04Q1001X@`Nnmkkh@@Po1kk`:44003Po2448@@00:44003Nnn448@@
00:44005Po1kkh@@Nnn44002Nnl038@@S35kkh@`Nnmc[W_?S364<8aAQ11kc`=kk`05Q11kkh?`Nnn4
4002Nll2Q1001G?>Njn<LH@@Nnl01H@@00=kkh@@Nnl018@@00>4<8@@Q10018@@00Ukkh@@Nnn4<7_?
Q11kkh@@Nnl00h@@00]kkh@@Q123l7__Po1kkh@@Nnn447__00N44004Nnoooooo0007ool000Ooo`06
003ooooo[GF]EJDD0ZDd00B]EJDdYCBU50BU=006[EFUE:eEYAB]EJDd0ZDD00nU=9ccU99JjiccW=>U
=:EDW?>U59ccW=>LlicCW?<00YcC00BDdYcCU9:DTP:<D@04Q32<DH@@Q102Nll01haANlmBRT8X@PQB
RV^=009[K@0;JdeJje9Z@RQ:JE:ZBVU:BDYY@TQ::@02@PP023WW@RQBRW>>Q31[;G?>H``3Q3000haA
Q32<L@03S74019BBS76DTYBB0YBb01:L/iBbU;:<LDYYU;:LdhaaW?>DTYcCU=:LdiCBW=>DdYcCU=82
W=<03iccW=>LlicCW?>LdiccU=:LdiCBW=>DdYcCU=:Ld`02ool00`00ooooo`0:ool00`00ooooo`03
Nnl038@@Nnn447__Q11kkh@@Nnn447__Q11kk`:4409kk`0IQ31kkh@@Nnn4<7__S36447__Nln447_?
Q11kkh@@Nnn447__Q11kkh@@O0n447`?Q1000W__00mkcg__Nnn447>^Nnn4<7__O0n<DG__S364<7_?
Jhd00W__00J<DG__Q11l3h@@Nnl5Q1005g>^NnmkkhaAO0mkcg__Q11kkh@@O0n447__Q11kkh@@Nnn4
47__Q11kkh@@Nnl00X@@00Ekkg`?Nnn447_?00=kk`09Q11kkh@@Nnn447__Q11kkh@@00=kk`08Q11k
kg__Nnn447__Q11l3`9kk`04Q13ooooo0007ool000Ooo`04003ooooo[ED4YC@3YA@04jDdYABU=:Dd
[EFU=:eEYCB]MJDd[EFU=:eEYCBU59ccFZ^LljDd00:U5003U;:U=9cC00>Ll`BLd`0<U=:L/iBbU;:D
TYAbQ32447__Nln447>^0W>>00MS;7>^LjiJbdYYDXY2:002>NL01U::F/]Jbd8XBVUBRP9Jb`08DZY:
BDXY>LM224YYF^][C@9c[P04Nnn4<8`aQ302S5401iAbS76DLYBBU;:DTYbc00:D/P08U9:D/YBbU;8i
iiccS76Ll`:D/P0AU=:LdiCBW=>DdYcCU=:LdiCBW=>DdYcCU=:LdiCBW=>DdP02W=<01YccW=>LdiCB
W=>D/P;oo`03003ooooo00[oo`0=003oooooQ11kkh@@Nnn3l7__Q11kkh@@Nnl01h@@00Ukkh@@Q124
47__Q11kkh@`Q1000W__00>448@`Nnl00X@@00]kkh@@Nnn447__Q11kkh@@Nnn447__00>44003Nnn4
47__00:<D@03Ljikch@`00=kk`:44007S364<7_?Nnn448@`S3400g_?00F<DG__Q124<8@@009kc`04
S76446]]S542Q1003G__Q11kkh@@Nnn447__Q11kkh@@Q32447__00F44004Q32447__Q302Q1001g__
Q12448@@Nnn447__00>44003Nnn447__00>44003Nnn447__00:44005Q3244?ooool00007ool000Oo
o`03003ooooo00:U=005YABU=:DDYABM4`02YA@00jDdYABU=003YC@01:eEYEB]EJDD0jDd00BM4icc
DXZLl`:U5003WA>L/jDD00:Ld`07W?>LdiccU=:LdiBbW=<00YBb0YBB00V<LHaAO0mkkg?>Q31ccW__
Ljh00V</01YS3488>NLiid8X>PM:BE::F^]Jbf<<Hba[KF]=H`aBRTY9>PM223X7BRU:JE[;H`a[KF^=
0X@`00B<DH@`S56<D@:<L@:DTP>D/P0RU9:D/YBBU;:DTSWWW=><LIcCW;>DTYcCU;:LdiBbW=>D/YcC
U;:LdiBbW=>D/YcCU;:LdiBbW=>D/YcCU=:LliCBW=<2U;82ool00`00ooooo`0:ool02`00ooooog__
Q11kkh@@Nnn447__Q1000g__00>447`?Q1000g__00>447__Q1001G__00V447_?Nnmkch@`Nln447__
Q1000g__00^447__Nnmkkh@@Nnn447__Q11kkh@@009kk`0:Q32448@@Q31kkhaALlj4<7`?Q102Nnl0
0g>^Nnmkk`02Nll00h@@Q32DTP02Nnl03G`?Q11kkg__Llic[X@`Nnn<DH@@Nnn447`?009kk`06Q11l
3h@@Nnn447__0h@@00Ml3g__Nnn4<7_?S55kk`02Q104Nnl04h@@Nnn447__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q11kkh@@009kk`;oo`03003ooooo00Goo`001ooo00<00?ooool00jDd00FU5:DdYABU
59cc00:U50BU=003[EFU=:eE00>U=007[EFU=:DDW==BZYccYC@00ZDD00JD/ZDdW=>LlicCW?<2W=<0
19CBW=>D/YBb0iBB00>DLX@`Q3000W__0X@@00f4<7_?DZYBRTYY>JLiidY9DXYJbf<<Jde[K@02Ljh2
Nnl00g>^H`aBRP02@RP02DY9BRU22488BVUS37>^Q124<002S542S7401iAbS76DTYBBU;:DTYbc00:D
/P08U9:D/YBbU;8iiiccS76Ll`:D/P0CU=:LdiCBW=>DdYcCU=:LdiCBW=>DdYcCU=:LdiCBW=>DdYcC
U=800icC00>DdYbcU9800_oo00<00?ooool02_oo00@00?oooon440=kk`03Q11kkh@@00:44009Nnn4
47__Q11kkh@@Nnn447__00>44003Nnn447__00:4409kk`03Q124<8@@00:4400<Nnn447__Q11kkh@@
Nnn447__Q11kkh?`18@@00=kkh@@Nnl00X@@00=kch@@S5400X@@0W_?00=kkh@@Nll00h@`00=kkh@`
Nll00W__00j447__Po1kkh@@Nnn447__Q31kkh@@Nnn447__0h@@00=kkh@@Nnl00h@@00Ikkh@@Nnn4
48@`Nnl2Q1004G__Q31kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh?`Nnl00h@@0g__0h@@00Akkooo
ool000Ooo`001ooo00`00?oooonU5:DdYABU=9dCYABLljDDWA<2YA@01:DdYABU=:DD0jDd00BU5:Dd
YCBU=0:Ll`07BXVLljDDYABLliBbYA@00icC00JDdYcCU;:LdiBbW;<2U98018aaU9:<LHaA0X@@0W__
00Mkch@@Jfe:JD8XDVXii`02DXX065[;H`a[;F]=Nln4<7_?LlicSV<<DXY:BDYYBXUBJT88>LLaYT8X
F^]kkhaaS564<0:<D@:<L@04U9:<LIBBU983U;808YBBU;:DTYBbU98iiicCS76LdibcU9:L/iBbW;>D
/YbcU;:L/iBbW;>D/YbcU;:L/iBbW;>D/YbcU;:LdiCBW=>D/Ybc0YBb0_oo00<00?ooool02_oo00@0
0?ooooml3`9kk`03Q11kkg__00=kk`05Q11kkh@@Nnn44003Nnl03h@@Nnn447__Q11kkh@@Nnn4<7__
Q11kkh@@Llj44003Nnl00h@@Nnn44003Nnl028@@Nnn447__Q11kkh@@Nnl2Q1002G__Q31kkg__Q11k
kg_?Q124<002Nll03H@`Q11ccX@@Ljj<DH@`Nlmkkh@`Nnmkcg__00:4<005Q11kkg__Ljj44005Nnl0
8h@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nln<<G_?Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11l
3h@@Nnn447__Q1001G__00>447`?Nnl00_oo00<00?ooool01Ooo0007ool01000ooooojDd1:DD00>L
ljDDW?<01:DD00FU=:DDYCBU=:eE00:U=00=YABU=:DdYABLde::W=>U=9ccYABDTZDDU=800icC00FD
dYcCU;:LdiBb00>DTP0US76DLXaAS35kkh@@Nnmkcg__Jfe:JEZ[HdaS35::BVU:BE::BVUBRV</Q11k
cf]]DZY:BD8XDXYS37>>F/]BRSWW>JLiie[;Ljh018aA00>DLXaaU9800iBB00>D/YBBW;<00YBb00RD
TYBbU;:D/SWWW?><LIcc0iBb01FLdiBbW=>D/YcCU;:LdiBbW=>D/YcCU;:LdiBbW=>D/YcCU;:LdiCB
W=<00YBb00BDT_ooool000coo`04003oooooQ302Q1002g__Q32448@@Nnn447__Q32448@`Nnl00h@@
00Ikkh@@Q12447__Q302Q1001H@`Po1kkh?`Q3001h@@00Ekkh@@Nnn447__00>44003Nnn448@@00:4
4005S55kkh@`Nnmk[`02Q10028aaQ11kcg__NlmkkhaAQ102Nnl03G>^Q11kkh?`S76448aANln448`a
Q32448@`009kk`03Q11kkh@@00:44003Nnn448@@00>44006Nnn447__Q11kkh?`0X@@00>4<8@@Q100
0h@@00=kkh@@Nnl00h@@00]kkh@@Nnn447__Q11kkh@@Nnn447__00>44003Nnn447__00;oo`03003o
oooo00Goo`001ooo00<00?ooool00ZDD00>M4jDDW?<019cc00JU59ccYABM4jDdYA@3YC@04YdCYCBU
5:DdW?>LddYYW?>M4iccW=>D/YdCW;>DdYcCU;:L/`BD/P04S76DTXaaS742S54038@`Q11kkh@@Nlmk
kf^=F^][CG__JheBRP=2200D>NLiae:ZNlmkkf<<@RPiadYYHbakcg__NlmSC5:Z@TQ:JE[[Ljj440B<
D@:<L@BDTP>D/P0;U9:D/YBBU;:DTSWWW=><LIcCW;>DTP0BU;800ibcU;:Ld`02U;82U982ool00`00
ooooo`0:ool01000oooooh@@0W__00f447__Q11kkh@@Nnn447`?Q11kkh@@Nnn44003Nnl00h@@Nnn4
4002Q1004G__Q11kkh@@Nnn4<7__Q11kkh@@Nnn447`?Q11l3h@@Nnl00h@@00Ikkh@@Nnn447__Q103
Nnl028aANnmkkg__Ljikkh@@Nnl2Q3001W__Q12447`?Q124<09kk`03Q31kcg__009kk`04Nlmkkg__
Q303Nnl02H@@Nnn447__Q11kkh@@Nnn44002Nnl00g`?Q1244002Nnl01h@`Nnn4<7_?Q11kkh@@00=k
k`0?Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@00=kk`03Q11kkh@@00;oo`03003ooooo00Go
o`001ooo00<00?ooool00jDD00VLljDDW?>U59ccYABLljDDW?<00ZDD00>U=:DD[ED00jDD00NU=:DD
W?>DdU::W=>U5002W?<04YBBYABD/YcCU=:LdiBbW;>D/YbcU9:DLXaaU7:<LIAbS56<<@:44005Q31k
kg__Nnm[K@02Ljh056<<BVU22488DVY2:3WWDZZ3l8@`Hb`iid88F/]kcg__Nlmc[V]=F//2DZX016/]
Ljj<<HaA0Xaa00VDLXaaU9:DTYBbU9:D/YBBW;<00YBb00RDTYBbU;:D/SWWW?><LIcc0iBb01RL/iBb
W;>D/YbcU;:L/iBbW;>D/YbcU;:L/iBbW;>D/YbcU;:LdiBbW=>DTYBbU982ool00`00ooooo`0:ool0
2@00oooooh@@Nnn447__Q11kk`03Q1001G__Q11kkh@@Nnl01h@@00Ekkh@`Q123l8@@009kk`03Q124
<8@@00>44003Po2448@@00:44003Nnn4<8@@00F44007Nnn3l7__Q11kkh?`Q3000g__00=c[X@@Nnl0
0W__00B<<G_?Q11kk`:4<004S35c[X`aNnl2Q102Q30038`aLhikkh@`Q11kkh@@Nnn447__Q11kk`>4
4005Nnn447__Q11kk`04Q10017__Q323l7__0X@@00R3l7__Q11kkh@@Nnn447__1h@@00Ukkh@@Nnn4
47__Q11kkh@`Nnl00_oo00<00?ooool01Ooo0007ool01`00oooooidCYABLljDD00:Ll`03W=>Llicc
00:Ll`04YABM4jDDYA@3YC@019dCYABU5:DD0YcC00a:JIcCW?>LlicCU9:LlibcU;:LdiBbW;<2U;80
0iBBU;:<L@03S742S5401H@`Q11l3h@@Ljh00W__01acSV^=Hb`iid88<JI224Z9BTTiae::Llj<DF<<
@NQ226</Nnmc[V<<DXY:BD8X@PQBRV<<Ljil3`:<D@:<L@03U9:<LIBB00>DTP>D/P0;U9:D/YBBU;:D
TSWWW=><LIcCW;>DTP0DU;800ibcU;:D/P02U982ool00`00ooooo`0:ool02@00ooooog__Q11kkh@@
O0n44003Nnl02h@@Nnn447__Q11kkh@@Nnn447`?Q1000W__0X@@00accX@@Nnn447__Q31kkh@@Nnn4
47__Q103Nnl3Q1001W__Q12448@@Nnn4409kk`:44006Nnn4<8@@Q31kkh@@0X@`00=kcg__Q30017__
00F4<7__Q31kch@@009c[P06Llikkg__S75ccX`a0W__00Ikch@@Nnn447__Q103Nnl018@@Nnn447__
0h@@00]kkh@@Nln4<7_?Q11l3h@@Nnn447`?009kk`07Q11kkh@@O0n447__Q1000g__00>447__Q100
0W__00Al3h@@Nnn440;oo`03003ooooo00Goo`001ooo00H00?oooonU59ccYA@2W?<00icCW?>Ll`02
W?<01:DDW?>U59cc0jDD00BLljDDYABU50:Ll`08W==2::DDYABDTZDDW=>U50BLd`04U=:LdiBbW;<2
U;82U9802HaaU7:<DH`aQ124<7_?Nnmkc`02Nnl087_?H`a::D8X@PQc[X@`Hda:BCW7Ljj4<6;/@RQ[
;G__F//iae::@RQ:JC6V@PQ2:6/]U99kcg__S36<LIBBS742U9803YBbU9:D/YBBU;:DTYBbU9:D/YBB
U;92:9AbW?<3U;806IBBU;:DTYBbU9:D/YBBU;:DTYBbU9:D/YBBU;:DTYBbU9:L/iBbW=>D/YbcU9:D
/YBB00;oo`03003ooooo00[oo`08003oooooQ11kkh@@Nnn4<0R4400INnn4<7__Q31kkh@@Nnn447__
Q11kkh@`Nnn3l8@@Nnn448?`Nnn447__Q11kkh@@Nnl00h@@00Ekkh@@Q124<7__00F4400QNnn3l7__
Q124<7_?Nnn<<G__Nln448?`Q323l7_?S35kkg>^NnnDLX@`Nlmkkg_?Q32447__S55cSXaANnn447__
00>44005Nnn447__Q11kk`04Q1002X@`Q12447__Q31kkh@@Nnn447__0h@@00=kkh@@Nnl00h@@00=k
kh@@Nnl00h@@00Ukkh@@Q12447__Q11kkh@@Nnl00_oo00<00?ooool01Ooo0007ool01@00oooooidC
YA@00Ycc00NLdiccW=>LlicCW?>Ld`02W?<01jDDW?>U59ccYABLljDD00:Ll`08W=>Lld88YABLliBB
W?>Ld`:Ll`04U=:LdiBbW=<4U;82U9801HaaU9:<DHaAQ3000X@@0g_?01mc[W_?LjiJjd88DZY:JG_?
O0m[;D98@RQkch@@HbaBJU[;JfeBRSW7BTU1j48X>NM2B4YYH`bDTW?>Q124<002S7400iBBS76DTP0;
U980648XS56LliBBU;:DTYBbU9:D/YBBU;:DTYBbU9:D/YBBU;:DTYBbU9:D/YBBU;:DTP:D/P03W;>D
/YBb00:DTP;oo`03003ooooo00[oo`0;003oooooNnn447__Q11kkh@@Nnn44003Nnl018@@Nnn447__
0h@@00Al3g__Nnn440Ekk`03S35kkh@@00=kk`05Q11kkh@@Nln44005Nnl05H@@O0n447__Q11kkh@@
Nnn447>^Q11kkh@@Nnn<DG_?Q11ccXaaNln44002Nnl02W`?Nln<DG_?Llj4<7?>Q11kch@@0W_?00j4
47>>Q12447__Q11kch@@Nnn447__Q11kkh@@0g__00>447__Q1000W__01R4<7_?O0mkkg`?Q11kkh@@
Nnn447`?Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q103Nnl00h@@Nnn44002ool00`00ooooo`05ool0
00Ooo`04003oooooYA@2W?<3W=<6W?<02JDDW?>U59ccYABLljDDW?>U5002W?<029cC@PRLljDDU9:U
59CBYA@2W=<029CBW=>D/YcCU;:L/iBBU;82U9802HaaU7:<DH`aQ124<7__Po1kc`02Ljh08W>>F/]2
25[;FZ]kkh?`H`aBRTY9Q11kcg>^F/]BRU:ZBTTiadY9<JI223W7BTTiie::Q11c[W__S36<LIBBS76D
LXaa0YBB00fD/YBBU;:DTYBbU9:D/XaaU;92:9AbW?>D/P03U9805IBbU9:D/YBBU;:DTYBbU9:D/YBB
U;:DTYBbU9:D/YBBU;:DTYbcU;:L/`02U98018aaooooo`003?oo00L00?oooon447__Q11kk`03Q100
2G__Q12448@@Nnn447__Q11kk`03Q10037__Q12448@@Nnn447__Q124<8?`Q11kk`:44007Nnn447__
Q11kkh@@Nnl00h@@00Akkh@@Q124<0J4400:Nln448@@S56<LG_?NnmkchaANnl3Q10017__LjjD/W>^
0h@@00R4<8@@Q123l8@@Q31kchaA0X@@00ekkh@@Nnn447__Q11kkh@@Nnn447__Q11kk`03Q1004G__
S35kch@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl00h@@00Ukkh@@Nnn447__Q11kkh@@Nnl00X@@
0_oo00<00?ooool01Ooo0007ool00`00ooooo`02W?<2W=<01iCBW=>LdiccW=>LlicC00BLl`05YABL
diccW?>U5002W?<2W=<01SX7YABLliBBW?>L/`:Ld`04U;:L/iBbW;<2U;801YBBU;:DTYBBS76DTP:<
D@0SQ32448@@Q11kkg_?JhecSV]]F//iie::BVUkcg?>JbeBZU::Nnmc[W_?H``j1d8X@PQ1j48XBTU:
JD88@RPaYSWWNlmc[P02Q106S74029BBS76DTXaaU9:<LIBBS742U9801T8XS56LlhaaU;:<LA:DTP>D
/P:DTP05S76DT_ooool0000<ool00`00ooooo`03Nnl03h@@Nnn447__Q11kkh@@Nnn447`?Q11kkh@@
O0n44003Nnl04H@@Nnn447__Q11kch@`Nln447__Q11kkh@@O0n447__Q1001G__00b447__Q11l3h@@
Nnn447__Q11kkh@@O0l3Nnl02G_?Q11kkh@`Jhf<LG__Q31cSP02Q102Nnl03H@@Nlmkcg>^Q11kkhaA
Q32447`?Q11kkh@@00=kk`0?Q11kkg__Nnn447__Q11kkh@@Nnn447_?Nnn4<7__00>440Akk`04Q11k
kh@@Nnl3Q10027__Q11kkh@@Nnn447__Q103Nnl00h@@Nnn44002ool00`00ooooo`05ool000Ooo`04
003oooooYA@2W?<2W=<00iCBW=>Ld`02W=<01IccW=>LliccYA@00icc00>U59ccYA@00YcC00bDdT88
W?>LliBBYABD/YccU=:LdiBbW;<2U;8019BBU;:DTYBb0YBB00V<LIAbS56<<H@@Q31kkh?`Ljh00g>>
01AJbd8X@PQ:BG>^Nlm[KF/]F/^3l7>^NnmJbd7X@PQ::D88DXYcSV]]0U::00/iad88Nnn<DG__S36<
DIAbS76DLXaa00VDTP05S76DTT88S56Ll`04U9805IBbU9:D/YBBU;:DTYBbU9:D/YBBU;:DTYBbU9:D
/YBBU;:DTYBbU9:D/P02U98018aaooooo`003?oo00H00?oooon447__Po02Q1001g__Po1kkh@@Nnn4
47__00:44008Q31kkh@@Nnn447__Q11kk`:44005S36448?`Q31kk`02Q1000g__Q124400;Q1001G__
Q11kkh@@Nnl00X@@00J4<8@@Q32<DG_?Nnl3Q102Ljh00iBBPo24<005Q1001W__Q11kch`aQ11c[P:4
<09kk`09Q12<<G__Q11kkh@@Nnn447__00V44003Nnn<<G_?00F44007Nnn448@@Q11kkh@@Nnl00X@@
00Z3l8@@Q11kkh@@Nnn4<7__Q11kk`B440;oo`03003ooooo00Goo`001ooo00<00?ooool00Ycc01bD
dYcCU;:LdiCBW=>DdYcCU=:LlicCW?>LdiccW=>LlicCW?>LdiccU=:LdcWWW?>LdiBBW=>D/P:Ld`BD
/PJDTP05S76DTXaAS564<002Q1005G__Nlmc[V]]Lhi[SF<<BTU2:498Lhi[SF]=HdaS37__Nlm[KE9Z
>NM:J@02BTT00e[;Q31[S@02DXX01d7X>NMkch@@Nnn448aA00:<L@0:S56<LHaaU9:<LIBBS76DTXaa
U983S7406488Q32LlhaaU9:<LIBBS76DTXaaU9:<LIBBS76DTXaaU9:<LIBBS76DTXaaU9:<L@:DTP03
U;:DTYBB00:<L@;oo`03003ooooo00[oo`06003oooooNnn447__0h@@00Ml3h@@Nnn447__Q11kk`02
Q104Nnl04h@@Nnn447__Q11l3h@@Nnn4<7__Q11kkh@@Nnn447__Q11kkh@@00=kk`0@Q11kkh@@O0n4
47__Q11kkh@@Nnn447__Q32448aALjh2Nnl02h@`O0mkch@@S75kcg__Q31kch@@Nll00W__00F4<7_?
Q124<7?>00>4400FLlj448@@Q11kkh@@Nnn447__Q11kkh@@Nnn447`?Q11l3h@`Nnn448@`Nnl2Q100
0g`?Q11kk`03Q10057__Q11kkh@@O0n447__Q11kkh@@O0n447__Q11kkh@@Nnn447__Q102ool00`00
ooooo`05ool000Ooo`04003oooooW?<2W=<00iCBW=>DdP06W=<5W?<019cCW?>Llicc0YcC01:D/T88
W?>LlhaaW?>D/YccU;:L/iBbW;>DTYBbU9:D/YBBU;82U9801XaaU7:<DH`aQ124<09kk`=cSP0ONlmS
C5:ZBVUBJV=<F/]:JE[[F/]kch@@H``iidY9H`aJZdYYJfekcf</@RQJZdY9BRUc[W_?Nnn4<8aAU780
0haa00jDLXaaU9:<LIBBS76DTXaaU9:<LIBB@PR<DIcC0YBB00>DLYBBU9804IBB00JD/YBBU;:<LIAb
S742ool00`00ooooo`0:ool03@00oooooh@@Nnn447__Q11kkh@@Nnn447__00>44005Nnn447__Q11k
k`03Q1002G__Q11kkh@@Nnn448@`Po244002Nnl00h@@Nnn44004Q1002G__Po1kkh@@Nnn447__Q11k
k`05Q1002G__Q124<8`aLjj4<8@@S5644002Ljh018@@Nln<DH@@0W__012<DG>^S55c[XaANnn4<7_?
Q31kkh@`Ljj4<7__Q11kk`^4400INnn3l7__S35kch@`Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn4
47__Q11kkh@@Nnl00h@@00Ekkh@@Q12447__00;oo`03003ooooo00Goo`001ooo00h00?oooonLdicc
U=:LdiBbW;>D/YcCU;:LdiCB0YcC00NLlicCW?>LdiccW=>Ll`02W=<02YBbW;<iiiccW=>DTYcCU;:D
dYbc0YBb00FDTYBbU9:DTXaa00>DTP05S76DTXaAS564<002Q1005g_?LlicSV]]LjiccV]]DZYJbdYY
F^/iic6V@RQ:JF]=Q31BZS6VBVUcSU[;DXX00W>>00UJbd8XF^]Jje::Nlm[SG__Q1000XaA00^<LHaA
S76<LIBBS76DTXaaU9:<LIBB00><L@0H@PR4<9cCS76DTXaaU9:<LIBBS76DTXaaU9:<LIBBS76DTXaa
U9:<LIBBS76DTXaa0iBB00B<LIBBS76<L@;oo`03003ooooo00[oo`03003ooooo00=kk`07Q11kkh@@
Nnn447__Q1001G__00V447__Q11kkh@@Nnn447__Q1000g__00R4<7_?Q11kkh@@Nnn447__0X@@00=k
kg`?Q1000g__00V447__Q11kkh@@Nnn447__Q1000W__00Qc[X@`Llj<DH@@Ljj448aA0W__0W_?00>4
<8`aLlh00X@@00Mc[W__Q11kkh@`Q11[K@02Nnl03X@@Ljil3h@@Nnn447__Q11kkh@@Nnn447__Q103
Nnl01H@@Nnn448@`Nll00g__00f447__Q11kkh@@Nnn447__Q11kkh@@Nnn44003Nnl00h@@Nnn44003
Nnl00h@@Nnmkk`02ool00`00ooooo`05ool000Ooo`0=003oooooW=>D/YcCU;:LdiBbW=>D/YbcU;80
0YcC00>LlicCW=<00icC00NLlicCW=>DdYcCU;922002W=<00iBBW?><L@02U;82S742U983U;82U980
1XaaU7:<LHaaS56<<@:4<00:Nnmc[V]]Ljikkg_?F^]:BD8X@PP2>LL04cWWBTU:JE:ZNnmJjcWWDXY[
CE:ZBTU[CG__@NQJbf</BTUS;7>^009kk`04Q12<DIAbS542S74039AbS76DLXaaU7:<LIAbS76DLYBB
S55220:DTP0DU7:D/XaAS76DTXaaU9:<LIBBS76DTXaaU9:<LIBBS76DTXaaU9:<L@>DTP05S76DLXaa
U7:<L@02ool00`00ooooo`0:ool01@00oooooh@@Nnl00h@@00]kkh@@Q12447__Q11kkh@@Nnn447__
00F44003Nnn448@@00:44003Nnn4<7_?00:4<006Nnn447__Q124<8@@0g__01Z447__Q31kkh@@Nnn4
47__Q11kkh@@Q32447_?Po1kkg_?Nnn448@`S36447__Nln<LG__0h@@00N4<8aANln<<G_?Q3244002
Nll028@@Nnn447__Q11kkh@@Nnl9Q1002W__Q11kkh@@Nnn447__Q11kch`a18@@00=kkh`aQ1000X@@
00B4<8@@Q11kk`>44003Nnn447__00F44004Nnoooooo0007ool000Ooo`0>003oooooU;:L/iBbW;>D
/YbcU;:L/iBbW;>D/P>Ld`08U=:LdiBbW=>DdYccU=:Ld`:D/P05>PNLdiBbU9:Ld`02U9802ibcQ32<
DHaaU9:<LIBBS76DTXaaU9800Xaa0XaA0X@`00>447_?Jhd00V]=00AcSV</BVTaQP8ii`0H@PPj1d8X
BTUBZU[[JfeBZT8XDZY[CDZ9BRUS;6]=@TQS35:ZBVUS;7>>O0mkkg`?1HaA0Xaa02B<DHaaS56<LHaA
S76<DIBBQ312:8aaU;:<DIBbQ32DTXaaU9:<LIBBS76DTXaaU9:<LIBBS76DTXaaU9:<LIBBS76DTXaa
U982S7401HaAS77ooooo00003?oo00<00?ooool00g__01^447__Q11kkh@@Nnn447__Q11kkh@@Nnn4
47__Q11kkh@@Nnn447__Q11kkh@@Nnn4<7?>Q3000g__00>447__Q1000X@@00Akkh@@Nnn4409kk`09
O0n447__Q11kkh@@O0n4<7`?00:4400>Ljj448@@Nnn447__Q11kcg>^Q32<<H@@NnmcSP=kk`09Q324
47__S76447>^Q32447_?009kk`08Q11kkh@@Nnn447__Q11kk`>44003O0n447__00=kk`06Q11kkh@@
Nnn4<8@@0g__01F447__Q11kkh@@Nnn447__Q11l3h@@O0n447__Q11kkh@@Nnn447__Q1000_oo00<0
0?ooool01Ooo0007ool02P00oooooicCU;:LdiBbW=>D/YcC0iBb1IcC00>DdYcCU=800icC00VDdYbc
U99229CBW=><LIccS7400YBb0XaA00VDLXaaU9:<LIAbS76DTXaaU7800Xaa01V4<8`aQ124<7__Nlm[
KG>>JfeRk488:DDiadY9DZYJbe:ZF/]S37>>HbaJZd88BTUBRP02@PP03F]=@RQJjf</BRUBRW>^Hdb4
<7__Q124<8aa00><D@0ZU7:<LIAbS76DLXaaU7:<LIAbU9:<DD88U7:DTXaaU;:<<HaaU9:<LIBBS76D
TXaaU9:<LIBBS76DTXaaU9:<LIBBS76DTXaaU9:<LIAbS76DLXaA0_oo00<00?ooool02_oo00T00?oo
oon447__Q11kkh@@Nnl00h@@015kkh@@Nnn447__Q11kkh@`Nnn447__Q11kkh@@Nnn447__00:44004
Nnn4<8@@Nnl4Q1000h@`Q1244004Q1001g__Q11kkh@@Nnn447__00:4400<Nlmkkh@@NlnDLX@`Nnmc
cX@@S76<<F]]0X@@00V<DG__Nnmc[X@`Nnn448@`Njl00X@`0W__00V4<7__Nnn447__Q11kkh@@Nnl0
0h@@01]kkh@@Q12447__Q11kch@`Nnn447__Q31kch@`Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl0
1H@@00Mkkh@@Nnn447__Q11kk`02ool00`00ooooo`05ool000Ooo`03003ooooo00RD/P0>U9:D/YBb
W=>DdYcCU;:L/iBbW=>DdYcCU;:L/`:D/P09>NNLdiBbU9:LdhaaU9:D/XaA00:<L@03U9:<LIBB00B<
L@04S56<LH@`Q302Q10017`?Nlmc[W>>0V]]00EJbd8X:FE225:Z009[K@03HbaJjf]=009c[P0AHba2
:36V>LLYID88JhdaQV]=Nlm2B6]=O0mS37__Nlmkk`03S5404h@`S56<DHaaS56<LHaAS76<DHaaS56D
TX@`@PR<DIBBS56D/X@`01F<L@04S56<LHaAS542ool00`00ooooo`0:ool04P00ooooog`?Q11kkh@@
Nnn447__Q11kkh@@Nnn447__Q11kk`>440=kk`0<Q11kkh@@Nnn447__Q11kch`aQ11kkh@@0W__0h@@
00ikkh@@O0n447__Q11l3h@@O0n447__Q11kkh@@0g__00Ukch@`Q324D8@@O0n<DG_?Q1000W__0264
<8@@S56<<HaAQ11kkhaAJfekkg_?S35c[XaANlmkkg`?Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11k
kh@@O0l00W__0X@@01=kkh@@Nnmkkh@@Nnn447__Q11kkh@@O0n447__Q11kkh@@O0n44003Nnl01H@@
O0n447__Q1000_oo00<00?ooool01Ooo0007ool02P00oooooibcU;:L/iBbW;>D/Ybc0YBb00bDTYbc
U=:LdiCBW=>D/YcCU;:LdiCBW=<2U;801iBB@PRD/YbcS76Ldhaa00BDTP03U;:DTYBb00:DTP04S76D
LXaaS742S542Q302Q102Lhh08F]]Lhi[CF</DXY::E[[Lhj448@`Lji[CF]]Nnn448?`HbaJbe:ZBRU:
BF]=@RR448aaHbb449bcJdekkg_?Q124<004S542S7408iAbS76DLXaaU7:<LIAbS76<<D88U7:DTXaA
U9:<<HaaU7:<LIAbS76DLXaaU7:<LIAbS76DLXaaU7:<LIAbS76DLXaaU7800Xaa00><DHaaS5400_oo
00<00?ooool02_oo00<00?ooool00h@@00Ekkh@@Nnn447__00>44003Nnn4<7__00:44003Q32448@@
00:44005Nnn448@@Q11kk`02Q10027__Q32447__Q31kkh?`Nnl5Q1001G__Q11kkh@@Nnl028@@029c
[W__Q11kkh@@Llic[W_?S564<8@@Ljj447>>Njmkkh@@Nnn4<7__Q31c[YbcNnmcSXaaQ11c[X@@Nnn3
l7__Q11kk`>44003Nnn4<8@@00>4400ANnn<<G__Q31kkh@`Nln4<7__Po1kkh@@Nnn447__Q11kk`05
Q1002g__Q11kkh@@Nnn447__Q11kkh@@Nnl00_oo00<00?ooool01Ooo0007ool03000oooooiBBU;:D
TYBbU9:D/YBBU;:DTP:D/P03W;>D/Ybc00>D/P03W;>D/YcC00:D/P:DTP07>NND/YBBS76DdXaAS740
0YBB00>D/YBBU;800YBB0Xaa00B<DHaaQ32<D@:4<0:4409kk`0<Llikcg?>Nlmc[W>>Jdf<DIBBW?>L
dhaa0X@@00>4<8@@S7400Xaa00jDTV^=DZYBZX@@S76Llg__S56Ldg_?Nnmkcg__0X@`02B<DH@`S56<
DHaaS56<LHaAS76<DHaaS56DTX@`@PR<DIBBQ32DTX@@S76<DHaaS56<LHaAS76<DHaaS56<LHaAS76<
DHaaS543S744S5401H@`S57ooooo00003?oo00X00?ooooml3h@@O0n447__Q11l3`9kk`06Q11kkh@@
Nnn447__0h@@00akkh@@O0n447`?Q11kkh@@Nnn447_?Q304Q103Nnl048@@Nnn447__Q11kkh@@Nnn4
47__Q11kkh@@Nnn447__0X@@00b<DG_?Nnn<DIBBQ11kkh@@S35kkh@`Nnl2Q1005jDdLhikkg`?Nln4
47_?Q31kkf^=S56447_?Q31kkg_?Q11l3h@@Nnn447__Q1000g__00>447__Q1000X@@00El3g__Q11k
ch@@009kk`03Q11kkh@@00:4400BNnn447__Nnml3h@@Nnn447__Q11kkh@@O0n447__Q11kkh@@0_oo
00<00?ooool01Ooo0007ool02P00oooooiBbU9:D/YBBU;:DTYBb0iBB0YBb00fLdiBbW;>D/YbcU;:L
diBbW=>DTYBbU9922002U;800haaW=><D@02U9800iBbU9:D/P02U98018aaU7:<DIAb18aA00B4<8@@
Nnn440:4<0=kk`:44003S36DdYcc00:Ll`0CU9:DLXaAS55kkhaaS56DTYccS35Jje:Z_ONDLYBBQ11c
[XaANnl00W_?01:448@`S564<8`aQ32<DHaaU7:<LIAbS76DLXaaU7:<LH`a>NL2S7405haAU9:4<8aa
U7:<LIAbS76DLXaaU7:<LIAbS76DLXaaU7:<LIAbS76DLXaaU78018aA00B4<?ooool000coo`07003o
ooooQ11kkh@@Nnl00h@@00Ekkh@@Q12447__00Z4400@Q32448@@Nnn448@`Nnn4<8@@Nnn447__Q11k
kh@@Nnl3Q1000g__Q11kk`04Q10018?`Nnmkkg__0h@@00=kkh?`Nnl00W_?0X@@0g__012447__Nlmk
cf=<Ljj<LG__Q32<LG>^Q11kkg_?Q11kk`:4<003Nnn447__00V4400:Nnn447__Q31kkh@@Nnn4<7_?
S342Q1001G__Q12448@@Nnl00h@@00=kkh@@Nnl00h@@00Ekkh@@Nnn447__00>44004Nnoooooo0007
ool000Ooo`0<003oooooU9:D/YBBU;:DTYBbU9:D/Xaa0YBB0YBb00>L/iBbU;800iBb00>L/iBbU;80
0YBB00liiiBbU9:<LIBbS56<LIBBS76DTXaaU9:<LHaAQ3000haA00J4<8aAQ324<7`?Q102Nnl027?>
Lhi[CF]]Jhekcg__Q302Q1001G__Q11kcg_?Jhd00W__00M[KF]=Q11ccV<<F/_W?002Q1001g>^F/][
SG_?Jhekcg__00:4<00WS564<8aAQ32<LHaAS76<DHaaS56<LHaAS764447XS56DTX@`U9:448aaS56<
LHaAS76<DHaaS56<LHaAS76<DHaaS56<LHaAS76<DHaa00:<D@04Q32<DH@`S542ool00`00ooooo`0:
ool01@00ooooog__Q1000g__00f447__Nnml3h@@Nnn447__Q11kkh@@Nnn44003Nnl00h@@Nnn44003
Nnl00h@@Nln44003Nnl01h@@Nnmkkg__Q11kkh@@00=kk`03Q11l3h@@00:44003Nnn447__00:44005
Q32448@@Q12<D@03Nnl01X@@Nnn448@`Q11ccP:<D@:44004S75c[W>^Nnl2Q1002iBBQ12447__Q31l
3h@@Nnn447`?Q1000g__00J447__Q11kkh@@Nnl3Q104Nnl2Q10027__Q11kkh@@Nnn447__Q103Nnl0
2h@@Nnn447__Q11kkh@@Nnn447__Q1000W__0_oo00<00?ooool01Ooo0007ool02`00oooooiBBS76D
TXaaU9:<LIBBS7400YBB00ND/YBBU;:DTYbcU;:L/`02U;800iBBU;:DTP02U9801cWWU9:D/XaAW=><
DIAb00:DTP04S76DLXaaU782S7400haAS76<D@03S54018@`S36448@`0W__00Qc[W>>JfecSW>^Nln4
48?`0g_?011kkg>^Lhikkg>>Jfekch@`Po1Jjd88Q124<8@@Nnmc[P9kc`0:Po2448@`Q32<<H@`S564
<8`aQ304S542S74019AbS76<<D880Xaa00b4<9BBS564<8aAQ32<DH@`S564<8aAQ30:S5401XaaS56<
DH@`S364<0;oo`03003ooooo00[oo`03003ooooo00V44003Nnn448@@00>44003Nnn448@@00R44008
Po24<8?`Q32447__Q11kk`>4400?Nnn448@@Q11kkh@@Nnn447__Q11kkh?`Nnn447__00>4<0:44005
Q32448@@Q11kk`02Q1000h`aNnn4<002Q3000g_?Q1244002Q302Nll4Q102Nnl9Q1000g__Q11kk`04
Q1001X@`Q12447__S35ccP:44003Q32448@@00Z44005Nnn4<8@@Q11kk`05Q10018@`ooooo`001ooo
0007ool03P00ooooohaaU9:<LIBBS76DTXaaU9:<LIBBS742U9800iBbU9:D/P02U;803YBBU;:DTYBB
S76DTSW7U;:<LHaAU;:<DHaaU984S746S54018@`S564<8@`0h@@00=kkg?>Lhh00V]]00a[SG>^Llik
kg?>Lji[SG>^Jhe[KF=<Nll2Lhh03G?>Q11[SE::<JIkcg?>Nlmc[W>>Jhekcg__00:440:4<008S564
<8@`Q12<DH@`S564<0B<D@0OS764<488Q32<DH@@U9:4<8aAQ32<DH@`S564<8aAQ32<DH@`S564<8aA
Q32<DH@`S564<8aAQ32<DH@`S5400X@`0_oo00<00?ooool02_oo00L00?oooomkkh@@Nnn44003Nnl0
2H@@Nnmkkg__Q11kkh@@Nnn44003Nnl01H@@Nnn447`?Q1000g__00^4<7_?Q11kkh@@Nnn447`?Q11k
kh@@00=kk`0=Q11kkh@@Nnn447__Q11kkh@@Nnn447`?Q1000W__00Mkcg__Nnn447__Q11kk`02Q302
Nnl00h@@Nnmkc`02Q1000h@`Nln44003Q10047`?Q11kkh@@Nnn447__Q11l3h@@Nnn447__Q11kkh@@
17__0X@@0W__00R447__Nnn447__Q11kkh@@0g__00f447__Q11kkh@@Nnn447__Q11kkh@@Nnn44003
Nnl018@@ooooo`001ooo0007ool02`00oooooiBBS76DTXaaU9:<LIBBS74019BB00VD/YBBU;:DTYBb
U9:D/YBBU;800YBB01:<LCWWU9:DTXaAW=>4<9AbS76DLXaaU7:<LIAbS56<LHaAS742S54018@`S364
<8@`0X@@0W__0W>>00A[KG>>Ljikk`9kc`9c[P9cSP03JfecSW>^009c[P06Nnmc[V</BTTiYg>>0g>^
00mcSW>^Nnn447__Q124<8`aQ32<<H@`S364<8aAQ3000XaA00J<LHaAS76<LH`a@PP2S54038@`U9:<
<H@`S564<8aAQ32<DH@`S564<0V<D@07Q32<DHaAS564<8`aQ1000_oo00<00?ooool02_oo00T00?oo
oon447__Q11kkh@@Nnl00h@@00]kkh@@Nnn447__Q11kkh@`Nnn447__00>4400;Nnn3l7__Po2447__
Q124<7__Q11kk`02Q1001X?`Q12447__Q11kk`>44003Nnn447__00:44006Q32448@@Nnn3l7__0W_?
0W__00>447__Q1000X@@00Ykkh@@Nnn3l7__S55kkhaANnn4<0>44006Q31kkh@@Nnn447__1h@@00mk
kh@@Nnn447__Q11kkh@`Nnn447__Q31kch@@Nnl01h@@00Ekkh@@Nnn447__00>44005Nnn448@@Q11k
k`04Q102ool00`00ooooo`05ool000Ooo`03003ooooo00V<L@03U9:<LIBB00>DTP03U;:DTYBB00:D
TP09S76DTXaaU98iaiBBS76<DIBb00:<D@05U9:<LHaaS56<L@02S5401X@`S564<8aAQ32<D@:4<0:4
4004O0n447_?Ljh3Jdd04V]]Jhe[CF]=Jfe[CF]]JdecSV^=Jfe[SG_?LlicSV<<DXY2209[C@08JfeS
C6]=HdacSW>^Q11l3`:440>4<007Q124<8@`S564<8aAQ3000haA00J4447XQ32<DG`?U98;Q3002haA
Q32<DH@`S564<8aAQ32<DH@`S5400X@`0X@@0_oo00<00?ooool02_oo01H00?oooomkkh@@Nnn447`?
Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kk`>44003Nnn447`?009kk`04Q11kch@`O0l2Nnl02H@@
Nnmkkg`?Q11l3h@@O0n44002Nnl05W`?Q11kkh@@Nln447__Q11l3h@@Nnn447__Q31kkh@@O0n447__
Q11kkh@@0W__00YccX@@Q31c[W__Nlmkkh@@Nnn4409kc`:440Ekk`07Q11kkg__Nnn447__Q10017__
0X@@00ekkh@@Q11kcg__Q11kkh@@Nnn447__Q11kk`03Q10027__Q11l3h@@Nnn447__Q102Nnl017`?
Q11kkh@@0_oo00<00?ooool01Ooo0007ool03`00oooooiAbS76DLXaaU7:<LIAbS76DLXaaU9:<L@02
U9800iBbU9:D/P04U98018aaU9:<LCWW0YBB00>4<9BbQ3000Xaa00>DLXaaS74018aA00J4<8aAQ32<
<H@`S342Q1001W__Q11kkg_?JfeS;09Jj`0AF/]Rk5:ZF^]S36</H`a[;F]=Lhi[KG>>Ljikkg_?LjiS
C002Hb`016/]H`aS35[;0U[[00QS;7__Q12448`aQ32<<H@@0X@`00B<<H@`S364<0B<D@0MQ30iihaA
S56448aaS364<8`aQ32<<H@`S364<8`aQ32<DH@`S564<8aAQ32<DH@`S364<8aAQ32<D@02Q30018@@
ooooo`003?oo00<00?ooool00h@@00=kch@@Nnl00h@@00=kkh@@Nnl018@@00f4<8@@Q12448@`Nnn3
l7__Q32448?`Q123l002Q1001g__Q11kkh@@Nnn447__00>44003Nnn447__00>44003Nnn447_?00N4
4003Q32<<G__00:44003S36448?`00:440=kk`:44009S36448@@Nnn3l7__Q11kkhaA00:44003Nnn4
47__00>44005Nnn448@@Q11kk`03Q1001g__Q11kkh@@Nnn4<7_?00>44003Nnn447__00F4400<Nnn4
47__Q11kkh@@Nnn4<7__Q11kkh?`0X@@00Akkoooool000Ooo`001ooo00X00?oooon<DHaaS56<LHaA
S76<D@B<L@04U9:<LIBBS743U9800haaU9:<L@03S740236VU9:<LHaAU9:4<8aAS744S54018@`S564
<8aA18@`0X@@00Ul3h@@Nnmkcg>>JdeJje:ZDXX00U:Z00US36</Lhi[KF]=HdacSW?>Nll00W>>00Ic
[X@@Q12447_?Ljh2Lhh00f]=JbeS;002Jdd01H@@Nnn448@@Q3000X@@00=l3h@`Q10018@`01:<DH@`
S56443WWQ32<DG__S76448@`Q124<8@@Q32448@`Q109Q30018@@Q324<8aA0X@`0X@@0_oo00<00?oo
ool02_oo01T00?ooooml3h@@O0n447__Q11kkh@@Nnn447__Q11kkh@@O0n447__Q11kkh@@Nnn44002
Nnl2Q1001g__Q11ccX@`Nnn447_?009kk`0>Q11kkh@@O0n447__Q11kkh@@Nnn447__Q11kk`>4400?
Llikkg_?Nnmkcg__Llic[W?>Q11l3g__Llikcg__00:44005Q31kkg__Nnn44004Nnl2Q10048@`Q11k
kh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@0W__00El3h@@Nnn448@`009kk`0IQ11kkh@@O0n447__
Q11kkh@@Nnn447__Q11kkh@@O0n447__Q11kkh@@Nnn447__Q1000_oo00<00?ooool01Ooo0007ool0
3`00oooooiAbS76DLXaaU7:<LIAbS76DLXaaU7:<L@07U98038aaU7:<LIAbS74iahaaU7:4<9BbQ32<
D@:<L@0:S56<LHaAS564<8aAQ32<<H@`S342Q302Q1001W__Q11kkg_?Jfe[;@=S3003JbecSW__009k
k`0;Jfe[CF]]Nlmkkg>>H`a[;G>^S3644002Nnl03H@@Nnmkkg>^Nlmkkh@@Nnn447__Q32448@`00>4
4006S364<8`aQ32<DH@`0XaA00J443WWS364<8@@S742Q3005H`aQ32<<H@`S364<8`aQ32<<H@`S364
<8`aQ32<<H@`S364<8`aQ32<<@02Q10017__ooooo`003?oo00D00?oooon447__00^4400<Nnn447__
Q11kkh@@Nnn4<7__Q11kkh@@0W__00F447_?Q32447__00>44009Nnn447__Q11kkh@@Nnn447__00>4
4005Nnn448@@Q31kc`02Q1004h`aQ32DLX@@S56448`aS56447>^S35c[X@`Q11kch@@Po1kch?`00=k
k`:44003S36448@@00:44005Nnn447__Q11kk`05Q1001G__Q11kkh@@Nnl00h@@00=kkh`aNll01H@@
00=kkh@@Q1000h@@00=kkh@@Q1000h@@00Ekkh@`Q12447__00B440;oo`03003ooooo00Goo`001ooo
00`00?oooon<DHaaS56<LHaAS76<DHaaS544S7401iBBS76DTXaaU9:<LIBB00:<L@07S56<LC6VU9:<
LH@`U9800X@`00N<LHaAS564<8aAQ32<D@04Q3002h@@Q32448@@Nnn447__Q11kkg_?Jhd00W>>01=k
cg__LhiccX@@LhiS35:ZF^]S37__H`aBJTZ9JdeccW_?JfecSP02Ljh2Lhh00g>^Nnn44002Nnl00h@@
O0n44002Q1001G`?Q12448@`Q1000X@`01:<DH@`S55l3cWWQ32<DG__S76448@`Q124<8@@Q32448@`
Q109Q30018@@Q324<8@`0X@@00El3h@@ooooo`0000coo`07003oooooNnn447__Q1000g__00n447__
Q11kkh@@O0n447__Q11kkh@@Nnn447__Q1001G__00>447?>Q1001G__00F447__Q11kkh@@00=kk`05
Q11kkh@@Nnn44003Nnl3Q102Nnl077_?Q11kcg_?Nnn<DG>^Nnn<LH@@Q524<7_?Q31kkh@@O0n4<7`?
Q11l3h@@O0n447?>Q11kkh@@0g__00N447__Q31kkh@@Nnn44005Nnl04h@@Nlmkkh@@Nlmkkh@@Nnn4
47__Q11kkh@@Nnn447__Q11kkh@@00=kk`09Q11kkh@@Nnn447__Q11kkh@@00;oo`03003ooooo00Go
o`001ooo00<00?ooool028aA00JDLXaaU7:<LIBBS743U98048aaU9:DTYBBS76DLXaA@PR4<8aaQ32<
DH@@U7:448aa18aA00B4<8`aQ32<<@:4<008Q124<8@@Q11kkh@@Nnn3l09kk`9kc`0=Ljikcf]]Lhi[
KF]=H`aJje[;H`acSW>^Lhh00W>^00Ikcg>^Nlmc[W_?Ljh2Nll01W__Nlmkkg__Q11kk`B44008Q324
48@`Q124<8@@Q32440:4<00MS35:BG__Q32<DG__S56448@`Q124<8@@Q32448@`Q124<8@@Q32448@`
Q124<8@@S364<8`aQ32<<@02Q10017__ooooo`003?oo00@00?oooon4<0B44003Nnn4<7__00>44006
Nnn448@@Q11kkh@`0X@@00=kkh@`Nnl00X@@00Mkkh@@Q12448@`Q123l002Q1003g__Q11kkh@@Nnn4
47__Q11kkh@@Nnn447__Q11kk`03Q1001G__Q11kkh@@Nnl00X@@0X@`00V<DG__Lhikkh`aLjikcg__
S3400X@@00=kkh@`Nnl00h@@00Mkkh@@Q12447__Q11kk`09Q1000h@`Q1244002Q1001W__Nln<<G__
Po24<0>44003Nnn448@@00B44003Q32448@@00:44003Nnn448@@00>44005Nnn448@@Q11kk`02ool0
0`00ooooo`05ool000Ooo`0:003oooooQ32<DH@`S564<8aAQ302S5402haaS56<LHaaU9:<LIBBS76D
TXaaU9800Xaa0XaA00PiihaAS56<DH@`Q12<LH@@0XaA00>4<8aAQ3000h@`1X@@00=kkh@@Nnl00g__
00=ccW_?Ljh01G>^00=[SF]]Hb`00V]=00AcSV^=LhicSPAc[P0>Nlmc[W_?Llikcg?>NlmccX@@Nnn4
47__Q11l3`b44006BVUccX@`Q31kkh@`4X@@00>4<8@@Q3000X@@00El3h@@ooooo`0000coo`0C003o
ooooNnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q1000g__00>447__Q1000W__00Qkch@@Nnn4
47__Q31kkh@@0g__00>447__Q1000g__00Z447__Nnmkkh@@Nnn447__Q11kc`9kk`06Q11kkg__Nnn4
47_?0X@@00AkkhaAS564<0>44004Nnn447__Q103Nnl03H@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@
00=kk`>44006Nnn447__Q11kkg_?0X@@00Akch@@Nln440=kk`0EQ11kkh@@Nnn447`?Q11kkh@@Nnn4
47__Q11l3h@@Nnn447__Q11kkh@@00;oo`03003ooooo00Goo`001ooo00<00?ooool028aA0Xaa00^D
LXaaU7:<LIBBS76DLXaaU9:<LIBB00:<L@09S55228@`S764<8aAQ12DLX@@00><D@04Q32<DH@`S342
Q3000h@@Q3244003Q10017__Q11kkg__0W_?00=c[W_?Ljh00W>^0g_?0g>>00Akcg>>LjicSP9c[P06
Nlmc[W_?Ljikcg>^0W_?00Qkkg_?Nnmkkh@@Nnn447__18@@02F4<8@@Q32448@`Q124<8@@S35:BG__
Q12<DG__S56448@`Q124<8@@Q32448@`Q124<8@@Q32448@`Q124<8@@Q32448`aQ32<<@02Q10017__
ooooo`003?oo00@00?oooon4<0:44007Nnn447__Q11kkh@@Nnl00h@@00ekkh@@Q12447__Q11kkh@@
Nnn447__Po1kk`04Q1001X?`Q12447__Q11kk`F4400;Nnn447__Q11kkh@@Nnn447__Q11kk`03Q100
0g__Q11kk`02Nnl00h?`Q1244003Nnl018@@Nnn447__0h@@00=kkh@@Q1000h@@00Mkkh@@Nnn447__
Q11kk`03Q1000g__Q1244005Q1005g__Q11kch@`Q123l8@`Q11kkh@@Nnn447__Q11kkh@@Nnn447__
Q11kkh@@Nnl018@@00>3l7__Q1000X@@00Akkoooool000Ooo`001ooo00X00?oooon4<8aAQ32<DH@`
S564<0B<D@B<L@05U9:<DHaaS76DTP02S742S54033WWS56<DHaAQ32448aaQ124<8aAQ32<D@:4<00:
Q124<8@@Q11l3h@@O0n447__Q102Nnl2Nll017?>Nlmc[W>^0W>>00=[SG>>Jhd00V]]00AcSW>^Lhi[
S@9cSPAc[P08Nlmc[W_?Llikcg?>NlmccP9kk`0>Q11kkh@@Nnn447`?Q11l3h@@O0n447`?Q11l3`:4
400HBTUccX@@Q31kkh@`Q11l3h@@O0n447`?Q11l3h@@O0n447`?Q11l3h@@O0n447`?0X@@00F4<8@@
Q11kkh@@00;oo`03003ooooo00[oo`0;003oooooNnn447__Q11kkh@@Nnn44005Nnl05H@@Nnmkkg__
Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q31kkh@@Nnn44002Nnl2Q10037`?Q11kkh@@Nnn447__Q11k
kh@@Nnn440Mkk`04Q11kkh@@Nnl3Q10027__Q11kkh@@Nnn447__Q103Nnl05h@@Nnn447__Q11kkh@@
Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q1000W__0X@@00Qkkh@`Nln447__Q11kkh@@0g__
016447__Q11kkh@@O0n447__Q11kkh@@Nnn447__Q11kkh@@00;oo`03003ooooo00Goo`001ooo00/0
0?oooon<DH@`S564<8aAQ32<DH@`00:<D@0;S76<DIAbS76DLXaaU7:<LIAbS76DLP02S54048@`@PR4
<8aaQ32<DH@@U7:448aAQ32<<H@`S364<8`a18@@00Qkkh@@Nnn447__Po1kcg__0W_?0W>^00=cSW>^
Jfd00g>>00M[KG>>Ljikcg>>LjicSP02Ljh01W_?Ljikcg>^Nlmc[P9kc`0:Nnmkcg__Nnn3l7__Po1k
kh@@Nnl:Q1001h@`BTUkch@@S35kkh`a01>44006Q32448@`Nnn447__0_oo00<00?ooool02_oo00<0
0?ooool018@@00>4<8@@Q1001H@@00>3l7__Q1001X@@00=kkh@@Q1001X@@00>3l8@@Q10018@@00Qk
kh@@Q12447__Q31kkh?`0X@@00Akkh@@Nnn3l0>44003Q31kkh@@00:44004Nnn4<8@@Q102Nnl2Q100
1G__Q11kkh@@Nnl00h@@00=kkh@@Q1000W__00b3l7__Q11kkh@@Nnn447__Q11kkh@@Nnl7Q1001g__
S36448@@Q32448@`00>44003Nnn447__00>4400;Nnn447__Q11kkh@@Nnn447__Q11kk`03Q10017__
ooooo`001ooo0007ool00`00ooooo`09Q3002haAQ32<DHaAS76<DHaaS56<LHaAS7400XaA00>4<8aA
>NL00haA00B4<8@@S76440B4<0B44006O0n447__Q11kkh@@0g__00=kcg?>Nll00W>^0W>>00A[SG>>
Lhic[P9cSP05Jhekcg_?Lhi[S@02Lhh4Ljh02W_?Ljikcg?>NlmccW_?Llikkg_?17__00j447__Q11k
kh@@Nnn447__Q11kkh@@O0m:BG>^0X@@01Ukch@@Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@
Nnn447__Q11l3h@@O0n44002Nnl2ool00`00ooooo`0:ool03@00ooooog__Q11kkh@@Nnn447__Q11k
kh@@00=kk`0CQ11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn4<7__Q1000g__00>447__Q100
0g__03V447__Q11kkh@@Nnn447__Q11kkh@@Nnn447`?Q11kkh@@Nnn447__Q11kkh@@Llj447__Q11k
kh@@Nnn447`?Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q100
0g__00V447__Q11kkh@@Nnn447__Q1000g__00^447__Q11kkh@@Nnn447__Q11l3h@@009kk`04O0n4
47__Nnl2ool00`00ooooo`05ool000Ooo`0;003oooooS364<8`aQ32<<H@`S364<004S542S7401iAb
S76<LHaAU7:<LIAb00:<D@0<Q31228@`S764<8aAQ12DLX@@S364<8`a0X@`00Z448@`Q12447__Q11k
kh@@Nnn3l09kk`9kc`04Ljikcg>^Ljh2Lhh01G>^Nlmkcg_?Lhh00W>^00Akkg>>LjicSP9c[P06Nlmc
[W_?Ljikcg>^0W_?00Akkg_?Nnmkc`Akk`0VQ11kkh@@Nnn447__Q11kkh@@Nnn447__Q11:BG_?Nnn<
<G_?S35kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kk`>44003Nnn3l7__00;oo`03
003ooooo00[oo`03003ooooo00>44007Nnn447__Q11kkh@@Nnl00h@@00Ekkh@@Nnn447__00N44006
Nnn448@@Po2447__0X@@00Ukkh@@Nnn447__Q11kkh@@Nnl01H@@00ikkh@@Q123l8@@Po2448@`Nnn4
47__Q11kkh?`0X@@0W__38@@00=kkh@@Q1001H@@00Ukkh@@Nnn447__Q11kkh@@Nnl01H@@00Ekkh@`
Q12448@`00>4400?Nnn447__Po1kkh?`Nnn447__Q11kkh@@Nnn447__00>44003Nnn448@@00:440;o
o`03003ooooo00Goo`001ooo00<00?ooool02H@`00><DH@`S5400haA00F<LHaAS56<DHaa00:<D@:4
<008>NN<DHaAS564<8@@S76440:4<00:Q124<8@@Q11l3h@@Nnn447__Q104Nnl2Nll01g?>Nlmc[W>^
JhecSV^=00=c[P07JhecSV]]Lhic[W>>Jhd00W>>17>^00akcg>^NlmccW_?Llikcg?>NlmccW__Nll2
Nnl03X@@Nnn447__Q11kkh@@Nnn447__Q11l3dXYLjh2Q1006G_?Q12447__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q11kkh@@Nnn447`?Q11kkh@@009kk`;oo`03003ooooo00[oo`0S003oooooNln447__
Q11kkh@@Nnn447__Q11kkh@@O0n447__Q11kkh@@Nnn447__Q11kkh@@O0n447_?Q11kch@@Llj44003
Nnl01h@@Nnn447__Q11kkh@@009kk`07O0n447__Q11kkh@@Nnl01H@@00El3h@@Nnn447__00>44006
Nnn447__Q11kkh@@0g__00>447__Q1001G__01>447__Nnmkkh@@Nnn447__Q11kkh@@O0n447__Q11k
kh@@O0n44003Nnl01h@`Nnn447__Q11kkh@@00=kk`0AQ11kkg__Nnn447__Q11kkh@@O0n447__Q11l
3h@@Nnn44002ool00`00ooooo`05ool000Ooo`0=003oooooS364<8`aQ32<<H@`S364<8aAQ3000XaA
00B<LHaAU7:<L@R<D@07@RR448`aQ32<DG__S7400X@`00J448@`Q124<8@@Q302Q1002W__Q11kkh@@
Nnn3l7__Po1kcg__0W_?00Ac[W_?Ljikc`=c[P03Nlmc[W_?00Akc`04Ljikcg_?Nnl:Nll3Nnl0:h?`
Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn4448XNlmkkh@`Nln4<7__Q11kkh@@Nnn447__Q11kkh@@
Nnn447__Q11kkh@@Nnn447__Q11kkh@@009kk`04Nloooooo000<ool00`00ooooo`07Q1001G__Q11k
kh@@Nnl00h@@00Akkh`aNnn4<0:44003Nnn447__00>44005Nnn448@`Q11kk`05Q1000g__Q11kk`03
Q1000g__Q11kk`03Q1000g__Po1kk`03Q1002g__Po1kkh@@Nnn447__Po1kkh@@Nnl00X@@00B3l7__
Q11kk`F44005Nnn448@@Q11kk`03Q1001g__Q11kkh@@Nnn447__00>44003Nnn447__00:44005Q324
48?`Q31kk`02Q10047__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@`0X@@00Ekkh@@Q12447__
00;oo`03003ooooo00Goo`001ooo00X00?oooon448@`Q124<8@@Q32440:4<003S564<8aA00><D@0:
S764<8aAQ32<DH@`S564<8aA@PP2Q1001HaAQ31kkhaAQ30028@@00Ikkh@@Nnn447__Q103Nnl01g_?
Llikcg?>Nlmc[W_?00Ec[P05NlmccW_?Llikc`02Ljh03g>>NlmccW_?Ljikcg?>NlmccW_?Llikcg?>
Nnmkc`04Nnl03X@@Nnn447__Q11kkh@@Nnn447__Q11kkdXYLjh2Q1006G_?Q12447__Q11kkh@@Nnn4
47__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@009kc`;oo`03003ooooo00[oo`0?003ooooo
Nnn447__Q11l3h@@Nnn447__Q11kkh@@00Ekk`0>Q11kkh@@O0n447__Q11kkh@@Nnn447__Q31kc`9k
k`0AQ11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn44003Nnl01X@@Nnn447__Q11kk`>440=k
k`0?Q11kkh@@O0n447__Q11kkh@@Nnn447__Q11kkh@@00Ekk`0ZQ11kkh@@Nnn447__Q11l3h@@O0n4
47__Q11kkh@@Nnn447__Q31kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn4
47__0X@@00Akkoooool000Ooo`001ooo00d00?oooon<<H@`S364<8`aQ32<<H@`S364<004S5400haa
S56<D@07S5401d8XQ12<<H@`S55kkhaa00:4<006Q124<8@@Q32448@`0X@@00Qkkh@@Nnn447__Po1k
kh?`0W__17_?00Mc[W_?Ljikcg>^Nlmc[P02Nll2Nnl017_?Lhic[W>^2g_?0g__02^3l7__Q11kkh@@
Nnn447__Q11kkh@@Nnn447__Q112:7_?Nnn4<7_?Q31kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@
Nnn447__Q11kkh@@Nnn44002Nnl017_?ooooo`003?oo00@00?oooon3l0B4400;Nnn448@@Q11kkh@@
Nnn447__Q11kk`05Q1001W__Q11kkh@@Nnn4409kk`07Q11kkg__Q11kkh@@Nnl00h@@00=kkh@@Q100
18@@00B4<7__Q11kk`>44007Nnn448@@Q11kkh@@Nnl00h@@00=kkh@@Nnl00X@@0124<8@@Q11kkh@@
Nnn447__Q11kkh@@Nnn447__Q11kk`>44007Nnn448@@Q11kkh@@Nnl00h@@00Ekkh@@Nnn447__00:4
4003Po1kkh@@00:4400ENnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn4<8@@00;o
o`03003ooooo00Goo`001ooo00X00?oooon448@`Q124<8@@Q32440B4<00>S564<8aAQ32<DH@`S564
<8aAQ32<DH@`S55220:44005S564<7__S564<008Q1001W__Q11kkh@@Nnn440Akk`9kc`04Llikcg?>
Nll3Ljh067_?Ljikcg?>NlmccW__LlicSV^=LjiccW_?Llikcg?>NlmccW_?Llikcg?>Nnmkc`Akk`0>
Q11kkh@@Nnn447__Q11kkh@@Nnn447__BRUc[P:4400INln448@@Nnn447__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q11kkh@@Nnn447__Q1000W_?0_oo00<00?ooool02_oo01d00?oooomkkh@@Nnn447`?
Q11l3h@@O0n447`?Q11l3h@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@009kk`0<Nln4<7_?Q11l3h@@
O0n447__Q11l3g__0X@@019kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q106Nnl01W`?
Q11l3h@@Nnn440Ekk`0PQ11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447`?Q11kkh@@Nnn4
47__Q11kkh@`Nln447__Q11kk`>4400BNnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11l3h@@
0_oo00<00?ooool01Ooo0007ool04@00oooooh`aQ32<<H@`S364<8`aQ32<<H@`S364<8aAQ3002XaA
00M2:8@@S364<8aANnn<L@02Q3001X@@Q32448@`Q124<0:44008Nnn447__Q11kkh?`Nnn3l0Akk`05
Nlmkkg_?Nlmc[P04Nll01G__Nlmkkg__Nll00g>>0W_?00Qkkg_?Nnmkcg__Nlmkkg_?17__02^3l7__
Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q112:7_?Nnn4<7_?Q31kkh@@Nnn447__Q11kkh@@Nnn447__
Q11kkh@@Nnn447__Q11kkh@@Nnn44002Nnl017_?ooooo`003?oo00D00?oooon447__00>44005Nnn4
48@@Q11kk`05Q1001G__Q11kkh@@Nnl00h@@00Akkh@@Nnn4409kk`05Q323l7__Q11kk`06Q1000h@`
Q1244008Q1002G__Q11kkh@@Nnn447__Q11kk`03Q1001G__Po1kkh@@Nnl01H@@00Mkkh@@Q12447__
Q11kk`03Q1003G__Q11kkh@@Nnn447__Q11kkh@@Nnn447__00B44005Po2448@@Q123l004Q1001G__
Q12448@`Nnl00h@@00Ikkh@@Nnn447__Q302Q1001G__Q12448@@Nnl00_oo00<00?ooool01Ooo0007
ool03P00oooooh@@Q32448@`Q124<8@@Q32448@`Q102Q30038aAQ32<DH@`S564<8aAQ32<DH@`S552
20:44005S564<7__S564<008Q1001W__Q11kkh@@Nnn440Ikk`09Nlmkkg?>NlmccW_?Llikcg?>009k
c`08Nnmkch@@LlicSV]]Lhic[P=kk`09Nlmkkg_?Nnmkcg__Nlmkkg_?00Akk`0>Q11kkh@@Nnn447__
Q11kkh@@Nnn447__BRUc[P:4400INln448@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q1000W_?0_oo00<00?ooool02_oo01D00?oooomkkh@@Nnn447__Q11kkh@@Nnn447__
Q11l3h@@Nnn447__Q1000W__0X@@0g__00^447__Q11kkh@`Nln447__Q11l3h@@00Ekk`09Q11kkh@@
Nnn447__Q11kkh@@00Ekk`08Q11kkh@@Nnn447__Q11l3`:4409kk`0aQ11kkh@@Nnn447__Q11kkh@@
Nnn447__Q11kch@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@O0n447__Q11kkh@@Nln447__Q31kkh@@
Nnn447__Q11kkh@@Nnn447`?Q1000g__00F447__Q11kkh@@00=kk`03Q11kkg__00;oo`03003ooooo
00Goo`001ooo00X00?oooon<<H@`S364<8`aQ32<<@>4<006S364<8`aQ32<DH@`28aA00M2:8@@S364
<8aANnn<L@02Q3001X@@Q32448@`Q124<0:4400<Nnn447__Q11kkh?`Nnn3l7__Po1kkh?`0W__00=k
cg__Nll00W_?17__00>3l8@@Nnl00f]]00=kcg__Po002g__02^3l7__Q11kkh@@Nnn447__Q11kkh@@
Nnn447__Q112:7_?Nnn4<7_?Q31kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@
Nnn44002Nnl017_?ooooo`003?oo00L00?oooon447__Q11kk`03Q1000g__Q11kk`03Q1001G__Q124
48@`Nnl00h@@00=kkh@@Nnl00h@@0W__00B4<8?`Nnn4<0:44005Nnn448@@Q11kk`07Q1002G__Q11k
kh@@Nnn447__Q11kk`05Q1002G__Q12448@@Nnn447__Q11kk`09Q1004g__Po1kkh@@Nnn447__Q11k
kh@@Nnn447__Q11kkh@@Nnn447__00F44003Q32447__00F4400CNnn447__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q11kkh@@Nnl00_oo00<00?ooool01Ooo0007ool02`00oooooh@@Q32448@`Q124<8@@
Q3000h@@18@`00Z<DH@`S564<8aAQ32<DH@`S55220:44005S564<7__S564<008Q1001W__Q11kkh@@
Nnn440=kk`03Q11kkg__009kk`9kc`07Llikcg?>NlmccW__Nll00W__00J447?>Lhi[CF]]Ljh3Nnl0
2G_?Nnmkcg__Nlmkkg_?Nnmkc`04Nnl03X@@Nnn447__Q11kkh@@Nnn447__Q11kkdXYLjh2Q1006G_?
Q12447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@009kc`;oo`03003o
oooo00[oo`0I003oooooNnn447__Q11l3h@@Nnn447__Q11kkh@@Nnn447__Q11l3h@@Nnn447__Q100
0g__00N447`?Q11kkh@`Nln44003Nnl00h@@Nnn44003Nnl00h@@Nnn44003Nnl02h@@Nnn447__Q11k
kh@@Nnn447`?Q1000g__00>447__Q1001G__00^447__Q11kkh@@Nnn447__Q11kkh@@00=kk`0IQ11k
kh@@Nnn447`?Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@`Nln447__Q1000W__01Al3h@@Nnn4
47__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@0_oo00<00?ooool01Ooo0007ool01@00oooo
oh@`Q1000X@`00n<<H@`S364<8`aQ32<<H@`S364<8aAQ32<LHaAU7800XaA01:4<8`aQ11228@`S764
<8aAQ12DLX@@Q32448@`Q124<8@@Q306Q1005g__Q11kkh@@Nnn3l7__Po1kkh?`Nnn3l7__Po1kkh?`
Nnn3l7__Po2448?`Nll00W>^00=kcg__Q1002g__00b3l7__Q11kkh@@Nnn447__Q11kkh@@Nnl3Q100
65::Hbb4<7__Q32447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn<<@:44005Nnn447__
Nnmc[P02ool00`00ooooo`0:ool02`00oooooh@@Nnn4<7__Q11kkh@@Nnl018@@00>4<7__Q1000X@@
00=kkh@@Nnl00h@@00=kkh`aNnl00W__0X@@00Mkkh@@Q11kkh@@Nnn4<002Q1000g__Q1244003Q100
0g__Q1244002Q10038?`Nnn447__Q11kkh@@Nnn447__Q11kk`:44003Q32448@@009kk`J44006Nnn4
48@@Po1kkh?`0X@@00Mkkh@@Nnn447__Q11kk`04Q1002H@`Q12447__Q11kkh@`Nln4<002Nnl2Q100
0g__Q1244008Q1002X?`Nnn447__Q11kkh@@Nnn447__0X@@0_oo00<00?ooool01Ooo0007ool00`00
ooooo`03Q104Q3000haAQ124<003Q3000haAQ32<D@04S542Q302Q1000cWWQ324<002Q3002h@@S764
48@@Q32448@`Q124<8@@Q3000X@@01Yl3h@@O0n447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11k
kh@@Nnn447__Q11kkg_?0W>^00=ccX@@O0l02G__02Mkcg__Nnn447__Q11kkh@@Nnn447__Q11kkh@@
Nnn447__DXYS;8@`Nnn4<7`?Q11kkh@@Nnn447__Q11kkh@@O0n447`?Q11l3h@@O0l00h@@00Akkh@@
O0n4409kc`;oo`03003ooooo00[oo`05003oooooNnn44003Nnl04X@@Nnn447__Q11kkh@@Nnn447__
Q11kkh@@Nnn447__Q11kk`:4409kk`05Q11kkh@`Nln44003Nnl00h@@Nnn44007Nnl02H@@Nnn447__
Q11kkh@@Nnn44003Nnl038@@Nnn447__Q11kkh@@Nnn447`?Q11l3`>4400JNln447__Q11kkh@@Nnn4
47__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@O0n4409kk`03Q11kch@@009kk`0FQ11kkh@@
Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl3Q102ool00`00ooooo`05ool000Oo
o`09003oooooS364<8`aQ32<DH@`00:<D@04S364<8aAQ306S5400haaS56<D@02Q3005X@@@NR4<8aA
Q32<DG__U79kkh`aQ32<<H@`S364<8`aQ32<<H@@Q32448@`0X@@015kkh@@Nnn447__Q11kkh@@Nnn4
47__Q11kkh@@Nnn447__00>4409kk`0KNlmkkg__Q11kkh?`Nnn3l7__Po1kkh?`Nnn3l7__Q11kkh@@
Nnn447__Q11kkh@@Nnn447__00>44004DXY[;H@`Po02Q3002G__Q11kkh@@Nnn447__Q11kk`08Q100
28`aQ12448@@Q32448?`Nll2ool00`00ooooo`0:ool00`00ooooo`03Q1001g__Q11kkh@@Nnn447__
00>44003Nnn448@@00F44005Nnn447__Q11kk`04Q1000g__Q1244002Q1002g__Q12448@@Nnn447__
Q11kkh@@Nnl01H@@00mkkh@@Q12447__Q11kkh@@Nnn447__Q11kkh@@Nnl018@@00R4<7__Q11kkh@@
Nnn447__1H@@00=kkh@@Nnl02H@@00]kkh@@Nnn447__S35kkh@@Nnn447__00F4400=Nnn447__Q11k
kh@@Nnn447__Q11kkh@@Nnl00h@@00=kkh@@Q1000_oo00<00?ooool01Ooo0007ool00`00ooooo`03
Q3000haAQ32<D@02S5400h@`S564<004S5400haaQ32<D@02S542Q302Q1000cWWQ324<002Q3000h@@
S564400:Q3000h@@Q3244003Q10057`?Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447`?
Q103Nnl3Q1003G__Q11kkh@@Nnn447__Q11kkh@@Nnn447`?00>4400>O0n447`?Q11l3h@@O0n447`?
DZYS;8@`Nnn4<0:44007O0n447`?Q11l3h@@O0l02H@@00>4<8@@O0l00h@@00Ekkg_?ooooo`0000co
o`09003oooooNnn447__Q11l3h@@00=kk`06Q11kkh@@Nnn447__0h@@01Akkh@@Nnn447__Q11kkh@@
Nnn447__Q31kkh@@Nnn447__Q11kkh@@1G__00J447__Q11kkh@@Nnl3Q1003G__Q11kkh@@Nnn447__
Q11kkh@@Nnn447__00F4400MNnn447__Q11kkh@@Nnn447`?Q11kkh@@O0n447__Q11kkh@@Nnn447__
Q11kkh@@O0n447__Q11kk`02Q104Nnl05X@@Nnn447__Q11kkh@@Nnn447`?Q11kkh@@Nnn447__Q11k
kh@@Nnn447__0h@@0_oo00<00?ooool01Ooo0007ool01@00ooooohaAQ3000XaA00B<LHaAU7:<L@:<
D@09S76<DIAbS76DLXaaU7:<LIAb00:<L@0;Q32<<H@@@PR4<8aAQ32<DG__U79kk`09S5406X@`S364
<8`aQ32<<H@@Q32448@`Q124<8@@Q32448@`Q124<8@@Q32448@`Q124<8@@Q303Q1000h@`Q124<008
Q1000g__Q1244002Q102Q30098`aQ32<<H@`S364<8`aQ32<<H@`Q11BZV]=Q32448@`S364<8`aQ32<
<H@`S364<8`aQ32<<H@`S364<8`aQ32<<H@`S364<0:44004S36448@@Nll2ool00`00ooooo`0:ool0
0`00ooooo`03Q1001G__Q12448@@Nnl01H@@00Ekkh@@Q12447__00>44003Nnn447__00>44004Nnn4
48@`Nnl2Q1002G__Q12448?`Nnn447__Q11kk`03Q1001g__Q12448@@Nnn447__00:4400<Po1kkh@@
Q123l8@@Po1kkh@@Nnn447__0h@@00Mkkh@@Nnn447__Q11kk`03Q1000g__Q11kk`02Q1000h@`Nnn4
4002Q1000g__Po1kk`05Q1001W__Q31kkh@`Nnn4<0=kk`06Q11kkh@@Nnn447__0X@@00Qkkh@@Q11k
kh@@Nnn447__0h@@00=kkh@@Nnl00X@@0_oo00<00?ooool01Ooo0007ool01000oooooh@`18aA0haa
00><DHaaS54018aa00NDTXaaU9:<LIBBS76<D@02Q30023WWS56<DHaAQ32448aaQ108S54018@`S564
<8aA18@`01>448@`Q124<8@@Q32448@`Q124<8@@Q32448@`Q124<8@@Q3244005Q30=Q1000h@`Q124
<00:Q3001h@@DZYS;8aANnn<DH@@00Z4<007S564<8aAQ32<DH@`S5400X@`0X@@0X@`00Ekkg_?oooo
o`0000coo`09003oooooNnn447__Q11kch@@00=kk`05Q11kkh@@Nnn44003Nnl028@@Nnn447__Q11k
kh@@O0l2Nnl02h@@Nnn4<7__Q11kkh@@Nnn447__Q1000W__00Mkch@@Nnn447`?Q11kk`03Q1001W__
Q11kkh@@Nnn440=kk`03Q11kch@@00=kk`03Q11kkh@@00=kk`05Q11kkg__Nnn44003Nnl00h@@Nnn4
4003Nnl01h@@Nnmkkg__Q11kkh@@00Ekk`06Q11kkg__Nnn447`?1W__00>447__Q1000g__00>447__
Nnl00g__00V447__Q11kkh@@Nnn447__Q1000_oo00<00?ooool01Ooo0007ool04@00ooooohaaS56D
LXaaU7:<LIBBS76DLXaaU7:<LIBBS7400YBB00>D/YBBU;800YBB0Xaa01:<DD8XS56DLXaAU7:4<9BB
Q32<LHaAS76<DHaaS56<LHaAS744S5405h@`S564<8`aQ32<<H@`S364<8`aQ32<<H@`S364<8`aQ32<
<H@`S364<8`aQ3000haA00^4<8`aQ124<8@@Q32448@`Q124<8@@00:4<00=S364<8`aQ32<DH@`S364
<8`aQ32<<H@`S3400X@`01QBZV]=S56448aAS364<8`aQ32<<H@`S364<8`aQ32<DH@`S564<8aAQ32<
DH@`S543Q30018`aQ32447__0_oo00<00?ooool02_oo00L00?oooon447__Q11kk`02Q1000h?`Nnn4
4006Q1001G__Q11kkh@@Nnl00h@@00Ekkh@@Nnn447__00:44003Po2448@@00:44009Nnn447__Q11k
kh@@Nnn447__00N4400;Nnn447__Q11kkh@@Nnn447__Q11kk`05Q1000g__Q11kk`03Q1001g__Q124
48@@Nnn447__00F44005Nnn447__Q11kk`05Q1002G__Q11kkh@@Nnmkcg__Q31kk`03Q1003g__Q124
48@@Nnn447__Q11kkh@@Nnn447__Q11kk`03Q1001G__Q11kkh@@Nnl00_oo00<00?ooool01Ooo0007
ool01P00ooooohaAS76<D@:<L@03U9:<LIBB00><L@04U9:<LIBBS742U983U;82U982S7400d88S76<
L@02S7402h@`U9:<DHaAS76<DHaaS56<LHaAS74018aA00B4<8aAQ32<DA>4<0><D@0=Q32<DH@@Q324
48@`Q124<8@@Q32448@`Q10018@`00V<DH@`S564<8aAQ32<DH@`S5400X@`01R445[;Hbb<DG__S564
<8aAQ32<DH@`S564<8aAQ32<DH@`S564<8aAQ32<DH@`S542Q30018@@Q324<8@`0W__0_oo00<00?oo
ool02_oo01D00?oooomkkh@@Nnn447__Q11kkh@@Nnn447__Q11l3h@@Nnn447__Q1000g__00B447__
Q124409kk`0;Q11kkh@`Nnn447__Q11kkh@@Nnn44002Nnl2Q1009W`?Q11kkh@@O0n447__Q11kkh@@
Nnn447__Q11l3h@@Nnn447__Q11kkh@@O0n4<7__Q11kkh@@Nnn447__Q11l3h@@Nnn447__Q103Nnl0
3X@@Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnl2Q1000h@`Ljj44002Q1004g__Q11kkh@@Nnn447__
Q11kkh@@Nnn447__Q11kkh@@Nnn447__00>44004Nnn447__Nnl2ool00`00ooooo`05ool000Ooo`03
003ooooo00:4<00:U7:<LIAbS56DLYBBU7:<LIAbS745U980;haaU9:<LIAbS76DLXaaDVYkkiBbS56D
LXaaU7:DdYAbS76DLXaaU7:<LIAbS76DLXaaU7:<LIAbS76DLXaaU7:<DHaaS56<LHaAS76<DHaaS56<
LHaAS76<DHaaS5400Xaa00FDLXaaU7:<DHaa00><D@0WS76<DHaaS56<LHaAS76<DHaaS56DLXaaU7:<
LIBBS76DLXaaU7:<LIAbS76DLXaAQ11S36/]S56Ldh@`S36<DHaaS56<LHaAS76<DHaa00V<D@05U7:<
LHaaS56<<@02Q10017__ooooo`003?oo00@00?oooon440:4<005Q124<8@@Q11kk`04Q1000h`aNnn4
4004Q10017__Q12448@`18@@00f4<8@@Q12447_?Q11kkh@@Nnn447__Q11kk`03Q10037__Q12448@@
Nnn447__Q11kkh?`Nnn4409kk`05Q11kkg__Q11kk`03Q1002W__Q11kkh@@Nnn447__Q11kkh?`0W__
0X@@00Qkkh?`Nnn447__Q11kkh@@0W__18@@00=kkh@@Nnl00X@@00F<DH@@Nln447_?00:44009Nnn4
47__Q11kkh@@Nnn447__00F44005Nnn447__Q11kk`05Q10017__ooooo`001ooo0007ool01`00oooo
oh@`S76DTYBb00>DTP04U;:DTYBbU984U;801IbcU;:D/YBBU;8019BB00QBRX@`W=>DTYBbW;>DTYcc
19BB00><LIBBS7402YBB28@`00f<DH@`S564<8aAQ32<DH@`U9:<LIBBS76DTP03S7401h@`Q124<8@@
Q32448@`00:44005O0n448@@Q3244002Q3003XaAQ32<DH@`S564<8aAQ32Ldh@`JbeS38@@S742Q300
48aaS56<LHaAS76<DHaaS56<LHaAS76<DHaaS56<LHaA18aa00F<DH@`Q31kkh@@00;oo`03003ooooo
00[oo`05003oooooNnn44003Nnl00h@@Nnmkk`03Nnl03H@@Nnmkkg__Q11kkh@@Nnn447__Q11l3h@@
009kk`03Llj447_?009kk`03Nlmkkg__00=kk`03Q11kkh@@00=kk`03Q11kkg__009kk`03Nln448@@
00N44007Nnn447__Q31l3h@@O0l01W__00>447_?Q3000X@@00Ekkh@@Q12447__00J44004Q32448@@
Nnl2Q1006h@`O0n448@@Nlml3h@`Ljj<DG_?Q11kkh@@Nnn447__Q11kkh@@O0n447`?Q11kkh@@Nnn4
4003Nnl01h@@Nnn447__Q11l3h@@00;oo`03003ooooo00Goo`001ooo00<00?ooool00Xaa0iBb00VD
TYbcU=:L/iBbW=>D/YcCU=800icC00BDdYcCU;:L/`:D/P0:U99::G_?U7:4<9AbS76<<HaAW;<2U;82
U9802haaU7:<LIBBS76DTXaaU9:<LIBBS7400YBB01FD/YBBU;:DTYBbU9:D/YBBU;:DTYBbU9:D/YBB
U;:<LIAbS76DLXaAS7400XaA2iBB00bD/YBBU;:D/YbcU9:D/YBBU;:DTYBbU982U;8068aAHbaS;8@@
U;:<LIcCS76DTXaaU9:<LIBBS76DTXaaU9:<LIBBS76DTXaaU9:<L@>DTP:<L@:4<004Nnoooooo000<
ool00`00ooooo`03Q1003g__Q11kkh@@Nnn447__Q11kkh@@Nnn447__Q11kk`02Q10018?`Nnn447__
0XaA00Z448@`S36448aAQ32447__Q11kk`:44004Q32448@@Nnl5Q1000g__Q11kk`03Nnl00g_?Nnmk
k`02Nnl01h?`Nnn447__Q11kkh?`00N44003Q31kkh?`00=kk`03Po1kkg__009kk`03Nln447__00=k
k`09Nln447__Po1kkh@@Nnn3l7_?00:4<005Ljj<DG__Nnmkc`02Q1001g__Q11kkh@@Nnn447__00>4
4007Nnn447__Q11kkh@@Nnl01H@@00Akkoooool000Ooo`001ooo00L00?oooon4<8aaU9:D/P03U984
U;801ibcU;:LdiBbW=>D/Ybc00BD/P0<U9:D/U[;S56LlicCWA>U59BbW;>DdYcC0YBb0YBB00><LIBB
U;8029Bb00R<LHaAS76<DHaaS56<LHaA28aa00FLdiBbW=>D/Ybc00>D/PV<D@03Q32<DH@`00:<D@03
S76<DHaA00N<D@0@Nlm[SE[[F^^4<9BbU9:DdYBBS76DTXaaU9:<LIBBS74=U982S542Q102ool00`00
ooooo`0:ool02@00ooooog__Q11kkh@@Nnn44006Nnl037`?Q11kkh@@O0n447__Q11kkh@@Nnn4409k
k`07Llikkg>^Nlmkkh@@Nll017__0h@@00=l3g__Nnl017__00B447__Q31l3`:44003Q31kkh@@00:4
4005Nnn447__Q11l3`02Q102Nll02G__Nlmkkg_?Nnmkch@@Nnn44003Nnl018@@Nnn447`?0h@@00]k
kh@@Nnn447`?Q31kkh@@Nnn447__00:<D@06Q11c[XaANln447>^0W__00>447__Q1001G__00f447__
Q11kkh@@Nnn447__Q11kkh@@Nnn44002Nnl2ool00`00ooooo`05ool000Ooo`09003oooooS56<LIBb
U9:D/YBB00:D/P06W;>D/YcCU;:LdiCB0icC012DdYcCU;:L/iBbW;>DTUZ[Q12DTXaaW;>D/XaaS56L
/`:D/P:DTP0<S76DLXaaW;>D/YbcU;:L/iBbW;>D/Ybc29BB27__011Jbe[[F/]Jbe:ZF/]BZUZ[BTU:
JDY9BVU:BDYYBTU:J@=22092:00/BRU2:4Y9BVUBRTYYDXY:JE::BVUBRV</JfeS36]=S56DTX@`S56D
TYBbU9:D/YBBU;:DTYBbU9:D/YBBU;:DTYBbU9:D/YBBU;:DTYBbU9:DLXaAS36440;oo`03003ooooo
00[oo`03003ooooo00N4400?Nnn447__Q11kkh@@Nnn447__Q11kkh@@Nnn447__00J44006Po1kkhaA
Q32447__0X@@0X@`00J<<H@`Q11kkh@@Nnl5Q10017__Q11kkh@@17__00J<DH`aQ12447__Q102Nll0
0haAQ324<003Q102Nnl018@`Q11kkh@@0g__00>3l8@@Q1000X@@00Ikkh@@Nnn447__Q103Nnl00h@@
Nnn44002Ljh017>>U9:<DH@@0X@`00Akkh@@Nnn440=kk`04Q11kkh@@Nnl6Q1001H@`Nnn447__Q300
0X@@00Akkoooool000Ooo`001ooo00P00?oooon4<8aaU9:D/Xaa0YBB0YBb00^L/iBbW;>D/YcCU=:L
diBbW=>D/Ybc00BD/P06F^^<DHaaS56D/YcC0Xaa029kcg__Nlmkkg_?Nnmkcg__BVUBRTYYDXY:JE::
BVUBRTYYH`aJjf<<F^]S35[[H`aJjg__Nlmkkg_?Nnmkcg__Nln4<0B4400=O0n447__S564<8aAQ32<
DH@`S564<8aAQ3000XaA00B<LHaAS76<L@RDTP08Q124<8@@Q32LliBbQ32440ZDTP09U;:DTYBbU9:D
/YBBU;:DTYBb00:DTP04S76<DH@@Q102ool00`00ooooo`0:ool01@00ooooog__Q1000g__00>447__
Q1001G__00V447__Q11kkh@@Nnn447__Q1000W__00Akcg__O0n4<09kc`9kk`0AQ32447__Q11kkg_?
LjicSXaAQ32448@`Nnn447`?Q11kk`02Nll2Nnl018@@Q32<DHaA0W_?17__00Z4<8@@Q11kkh@@Nnn4
47__Q11l3`Qkk`05Q11kch@@Nnn4400;Nnl018aAQ12<DH@@0W_?00Z<DH@`Nnmkkh@@Nnn447__Q11k
k`>4400>O0n447__Q11kkh@@Nnn447__Q11kkh@@O0mkk`;oo`03003ooooo00Goo`001ooo00<00?oo
ool00X@@0haA00V4<8aAS56DLXaaU7:<LIBBS7400iBB00B<LIAbS76DLP:<L@0;S54YADY9DVY225::
DZYBRTYYLhi[K@02Lhh2Ljh2Nll06IBbU9:D/YBBU;:DTYBbU9:D/XaaU7:<LIAbS76DLXaaU7:4<8aA
Q32<DH@`S564<8aA00BDTP0?S76DLXaaU7:4<8`aQ32<<H@`S364<8`aS76DTXaa00:DTP0=U;:DTYBb
S76DTXaaU9:<LIBBS76DTYBbYA@00YBB00BU59ccS56<L@VDTP09U;:DTYBbU9:D/YBBU;:DTYBb00:D
TP05S76DLX@`S3644002ool00`00ooooo`0:ool00`00ooooo`03Q1002G__Q32448@@Nnn447__Q11k
k`03Q1000g__Q11kk`05Q1002G__U79ccX?`Q32447__Q32<D@02Nll017__Q12<DH@@0XaA00=kkg_?
Nnl01g__00J447__Q11kkh?`Nnl2Q1000h`aQ124<004Q3000g__Q11kk`03Q10017__Q12448`a0h@`
00j<<H@@Q31kkh@@Nnn447__Po1kkh@@Nnn447__1H@@00Qkkg_?Nnmkkg>>Nln448@`2X@@00Ukkh@@
Nnn447__Q11kkh@@Nnl01H@@00Akkoooool000Ooo`001ooo00P00?oooom[SG>^Nlmkkg?>0W_?00J4
47__Q11kkh@@O0l2Q1004X@`Q12447`?Q11kkh@@Nnn445[[Nnmkcf]]Nnn<DG`?Q11kc`9kk`05Q124
<8aAS56<L@09Q1004h@`Q124<8@@Q32448@`Q12<DH@`S564<8aAQ32<DH@`S76<DHaa00:<D@0=Q32<
DH@`S564<8aAQ32<DH@`S564<8aAQ30018aA00V<LHaAS76<DHaaS56<LHaAS7400XaA00n<LH@@NnnD
TXaaQ12<DIBBS76DTXaaU9:<LIBBS7402IBB00J<LIBBS76<LHaAQ302Q102ool00`00ooooo`0:ool0
2000ooooog__Q31kkh@@O0l3Q1001g__Q11kkh@@O0n447`?009kk`0AQ11kkh@@Nnn447`?Q11kkg_?
O0n<DG__Nlmkkh@@O0n4<002Q104Nnl2Q10017`?Q11kkh@`0X@@00Yl3h@@Nnn447`?Q11kkh@@Nnn4
40=kk`05Q11kkh@@Nnn44003Nnl01h@@Nnn447__Q11kkh@@00Ekk`05Q11kkg__Nnn44003Nnl02X@@
Nnn447__Q11kkh@@Nnn447__0X@`0W__00>4<7__Nnl01G__00R447__Q11kkh@@Nnn447_?17__00F4
47__Nnmkkh@@009kk`;oo`03003ooooo00Goo`001ooo00<00?ooool0Q?oo00<00?ooool02_oo00<0
0?ooool0Q?oo00<00?ooool01Ooo0007ool00`00ooooo`24ool00`00ooooo`0:ool00`00ooooo`24
ool00`00ooooo`05ool000Ooo`03003ooooo08Coo`03003ooooo00[oo`03003ooooo08Coo`03003o
oooo00Goo`001oooR0003?ooR0001ooo003oool[ool00?ooob_oo`00oooo:ooo0000\
\>"],
  ImageRangeCache->{{{0, 297.75}, {141.25, 0}} -> {-0.0539813, -0.0238096, 
  0.00707965, 0.00707965}, {{7.625, 142.125}, {137.875, 
  3.3125}} -> {-10.2455, -6.06223, 0.991593, 0.991593}, {{155.562, 290.125}, {
  137.875, 3.3125}} -> {-156.867, -6.02963, 0.991131, 0.991131}}]
}, Open  ]],

Cell["\<\
The error signal's dynamic range, its normalized total power (in dB) and the \
SNR (in dB) are:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({SignalRange[A - B], \ SignalPower[\(1\/128\^2\) \((A - B)\)], \ 
      10\ Log[10, \ 
            SignalPower[A, \ Decibel -> False]\/SignalPower[A - B, \ 
                Decibel -> False]] // N}\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \({{\(-24\), 39}, \(-51.0332421522832468`\), 30.6521470116944438`}\)], 
  "Output",
  CellLabel->"Out[29]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["APPENDIX", "Section"],

Cell["Function Category", "Subsection"],

Cell[BoxData[
    \(Category[0]\  := \ 0; \nCategory[x_] := Floor[Log[2, \ Abs[x]]] + 1; 
    \)], "Input"],

Cell["Function ZigZagOrder", "Subsection"],

Cell["\<\
Here is the ZigZagOrder function with all necessary utility functions.\
\>", "Text"],

Cell[BoxData[
    \(\(ZigZagOrder[x_?MatrixQ] := \ 
      With[{zz = zigzag[Length[x]/2]}, \n
        Join[FixedPoint[dropzero, \ Extract[x, \ zz]], \ {"\<EOB\>"}]\t]; 
    \)\)], "Input"],

Cell[BoxData[
    \(oddrow[x_, \ L_] := 
      Join[\({1, 0} + #\ &\)\ /@\ Take[x, \ \(L + 1\)\/2], \n\t\t
        \({0, 1} + #\ &\)\ /@\ Take[x, \(-\(\(L + 1\)\/2\)\)]]; \n\n
    dropzero[x_] := If[Last[x]\  == \ 0, \ Drop[x, \ \(-1\)], \ x]; \n\n
    zigzag[K_] := 
      Module[{a, b, c, d, e}, \n\t\t
        a = Table[
            \(Join[Thread[{2\ #1 - Range[#1], 
                      2\ #1 - Reverse[Range[#1, \ 2\ #1 - 1]]}], \n\t
                  Rest[Thread[{Reverse[Range[#1]], Range[#1, \ 2\ #1 - 1]}]]]&
                \)[i], {i, K}]; \n\t\tb = \(oddrow[#, \ Length[#]]&\)\ /@\ a; 
        \n\t\tc = Flatten[Thread[{a, b}], 1]; \n\t\t
        d = Flatten[
            \({#[\([1]\)], \ Reverse[#[\([2]\)]]}&\)\ /@\ Partition[c, 2], 
            1]; \n\t\t
        e = \(\(2\ K + 1 - #\ &\)\ /@\ Reverse[#]\ &\)\ /@\ 
            Reverse[Drop[d, \(-1\)]]; \n\t\tFlatten[Join[d, e], 1]]; \)], 
  "Input"]
}, Closed]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
PrintingStyleEnvironment->"Printout",
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{706, 564},
WindowMargins->{{Automatic, 221}, {Automatic, 24}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 56, 0, 111, "Title"],
Cell[1768, 51, 143, 5, 72, "Address"],
Cell[1914, 58, 72, 0, 24, "Caption"],
Cell[1989, 60, 76, 2, 31, "Input"],
Cell[2068, 64, 93, 2, 31, "Input"],
Cell[2164, 68, 133, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[2322, 75, 31, 0, 56, "Section"],
Cell[2356, 77, 1419, 22, 248, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3812, 104, 32, 0, 56, "Section"],
Cell[3847, 106, 860, 18, 95, "Text"],
Cell[4710, 126, 870, 13, 129, "Text"],
Cell[5583, 141, 69, 0, 24, "Caption"],
Cell[5655, 143, 162, 4, 31, "Input"],
Cell[5820, 149, 957, 14, 129, "Text"],
Cell[6780, 165, 179, 3, 24, "Caption"],
Cell[6962, 170, 131, 3, 31, "Input"],
Cell[7096, 175, 119, 3, 24, "Caption"],

Cell[CellGroupData[{
Cell[7240, 182, 253, 5, 71, "Input"],
Cell[7496, 189, 45287, 769, 120, 6406, 285, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[52798, 961, 109, 3, 24, "Caption"],

Cell[CellGroupData[{
Cell[52932, 968, 169, 4, 31, "Input"],
Cell[53104, 974, 9620, 241, 137, "Output"]
}, Open  ]],
Cell[62739, 1218, 1002, 21, 112, "Text"],
Cell[63744, 1241, 109, 3, 24, "Caption"],

Cell[CellGroupData[{
Cell[63878, 1248, 233, 5, 71, "Input"],
Cell[64114, 1255, 581, 13, 137, "Output"]
}, Open  ]],
Cell[64710, 1271, 173, 5, 24, "Caption"],

Cell[CellGroupData[{
Cell[64908, 1280, 105, 2, 31, "Input"],
Cell[65016, 1284, 2724, 67, 137, "Output"]
}, Open  ]],
Cell[67755, 1354, 560, 12, 78, "Text"],
Cell[68318, 1368, 452, 12, 56, "Text"],
Cell[68773, 1382, 519, 14, 61, "Text"],

Cell[CellGroupData[{
Cell[69317, 1400, 196, 4, 61, "Input"],
Cell[69516, 1406, 79, 2, 30, "Output"]
}, Open  ]],
Cell[69610, 1411, 47, 0, 24, "Caption"],

Cell[CellGroupData[{
Cell[69682, 1415, 74, 2, 31, "Input"],
Cell[69759, 1419, 79, 2, 30, "Output"]
}, Open  ]],
Cell[69853, 1424, 166, 3, 44, "Text"],

Cell[CellGroupData[{
Cell[70044, 1431, 160, 3, 51, "Input"],
Cell[70207, 1436, 2152, 53, 137, "Output"]
}, Open  ]],
Cell[72374, 1492, 69, 0, 24, "Caption"],

Cell[CellGroupData[{
Cell[72468, 1496, 87, 2, 31, "Input"],
Cell[72558, 1500, 61, 2, 30, "Output"]
}, Open  ]],
Cell[72634, 1505, 117, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[72776, 1512, 196, 4, 61, "Input"],
Cell[72975, 1518, 79, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73091, 1525, 74, 2, 31, "Input"],
Cell[73168, 1529, 79, 2, 30, "Output"]
}, Open  ]],
Cell[73262, 1534, 63, 0, 27, "Text"],
Cell[73328, 1536, 1545, 29, 236, "Text"],

Cell[CellGroupData[{
Cell[74898, 1569, 79, 1, 31, "Input"],
Cell[74980, 1572, 208, 3, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[75237, 1581, 31, 0, 56, "Section"],
Cell[75271, 1583, 534, 8, 78, "Text"],
Cell[75808, 1593, 114, 2, 24, "Caption"],

Cell[CellGroupData[{
Cell[75947, 1599, 63, 1, 31, "Input"],
Cell[76013, 1602, 83, 1, 30, "Output"]
}, Open  ]],
Cell[76111, 1606, 468, 7, 78, "Text"],
Cell[76582, 1615, 92, 2, 24, "Caption"],

Cell[CellGroupData[{
Cell[76699, 1621, 215, 3, 51, "Input"],
Cell[76917, 1626, 39749, 2252, 186, 31800, 2149, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[116681, 3881, 1676, 36, 284, "Text"],
Cell[118360, 3919, 175, 6, 32, "Text"],
Cell[118538, 3927, 466, 15, 44, "Text"],
Cell[119007, 3944, 178, 6, 31, "Text"],
Cell[119188, 3952, 227, 7, 31, "Text"],
Cell[119418, 3961, 60, 0, 27, "Text"],
Cell[119481, 3963, 267, 9, 54, "Text"],
Cell[119751, 3974, 165, 3, 44, "Text"],
Cell[119919, 3979, 119, 4, 35, "Text"],
Cell[120041, 3985, 871, 18, 95, "Text"],
Cell[120915, 4005, 526, 9, 171, "Input"],
Cell[121444, 4016, 110, 2, 24, "Caption"],

Cell[CellGroupData[{
Cell[121579, 4022, 71, 1, 31, "Input"],
Cell[121653, 4025, 564, 12, 137, "Output"]
}, Open  ]],
Cell[122232, 4040, 553, 14, 65, "Text"],

Cell[CellGroupData[{
Cell[122810, 4058, 82, 1, 31, "Input"],
Cell[122895, 4061, 127, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[123071, 4069, 33, 0, 56, "Section"],
Cell[123107, 4071, 1184, 23, 146, "Text"],
Cell[124294, 4096, 47, 0, 43, "Subsection"],
Cell[124344, 4098, 365, 6, 61, "Text"],
Cell[124712, 4106, 91, 2, 24, "Caption"],
Cell[124806, 4110, 160, 4, 31, "Input"],
Cell[124969, 4116, 92, 2, 24, "Caption"],
Cell[125064, 4120, 242, 5, 91, "Input"],

Cell[CellGroupData[{
Cell[125331, 4129, 175, 4, 51, "Input"],
Cell[125509, 4135, 28527, 1156, 93, 16486, 1003, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[154051, 5294, 116, 3, 24, "Caption"],

Cell[CellGroupData[{
Cell[154192, 5301, 179, 3, 51, "Input"],
Cell[154374, 5306, 18353, 484, 186, 4335, 306, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[172742, 5793, 375, 10, 44, "Text"],
Cell[173120, 5805, 1054, 23, 242, "NumberedTable"],
Cell[174177, 5830, 457, 9, 61, "Text"],
Cell[174637, 5841, 453, 14, 242, "NumberedTable"],
Cell[175093, 5857, 192, 5, 25, "Caption"],

Cell[CellGroupData[{
Cell[175310, 5866, 52, 1, 31, "Input"],
Cell[175365, 5869, 872, 11, 163, "Output"]
}, Open  ]],
Cell[176252, 5883, 254, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[176531, 5892, 54, 1, 31, "Input"],
Cell[176588, 5895, 49, 1, 30, "Output"]
}, Open  ]],
Cell[176652, 5899, 966, 20, 95, "Text"],
Cell[177621, 5921, 47, 0, 43, "Subsection"],
Cell[177671, 5923, 1404, 28, 146, "Text"],
Cell[179078, 5953, 521, 15, 258, "NumberedTable"],
Cell[179602, 5970, 279, 7, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179918, 5982, 39, 0, 56, "Section"],
Cell[179960, 5984, 581, 9, 95, "Text"],

Cell[CellGroupData[{
Cell[180566, 5997, 153, 4, 31, "Input"],
Cell[180722, 6003, 63, 2, 30, "Output"]
}, Open  ]],
Cell[180800, 6008, 56, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[180881, 6012, 82, 1, 77, "Input"],
Cell[180966, 6015, 70, 1, 30, "Output"]
}, Open  ]],
Cell[181051, 6019, 152, 3, 27, "Text"],
Cell[181206, 6024, 170, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[181401, 6032, 278, 6, 71, "Input"],
Cell[181682, 6040, 163602, 2860, 152, 69198, 1690, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[345299, 8903, 119, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[345443, 8910, 255, 5, 79, "Input"],
Cell[345701, 8917, 126, 3, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[345876, 8926, 27, 0, 56, "Section"],
Cell[345906, 8928, 39, 0, 44, "Subsection"],
Cell[345948, 8930, 107, 2, 63, "Input"],
Cell[346058, 8934, 42, 0, 44, "Subsection"],
Cell[346103, 8936, 94, 2, 28, "Text"],
Cell[346200, 8940, 188, 4, 63, "Input"],
Cell[346391, 8946, 918, 18, 280, "Input"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

