(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    726364,      16692]*)
(*NotebookOutlinePosition[    727106,      16718]*)
(*  CellTagsIndexPosition[    727062,      16714]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
2D FILTER DESIGN -
WINDOW METHOD\
\>", "Title"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input"],

Cell[BoxData[
    \(<< SignalPlot`\)], "Input",
  CellLabel->"In[41]:="],

Cell[CellGroupData[{

Cell["6.1 INTRODUCTION", "Section"],

Cell["\<\
Design of 2D FIR using the window method is similar to its 1D counterpart. \
The infinite impulse response sequence is obtained from the ideal, desired \
frequency response by means of the inverse Discrete-Time Fourier Transform \
and  is subsequently truncated and smoothed using a selected finite-duration \
window sequence. However, an additional filter characteristic that has no \
counterpart in 1D FIR filters needs to be considered. A 2D FIR filter may \
have a rectangular or circular region of support. This leads to two different \
design methods:
- computation of the ideal 2D circularly supported IIR, followed by trunction \
with a circularly supported 2D window sequence,
- computation of two ideal 1D IIR sequences, truncation with selected 1D \
window sequence and formation of a 2D rectangularly supported FIR sequence \
from an outer product of the 1D sequences.
In the next two sections we explore both design methods.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 2D WINDOW METHOD WITH RECTANGULAR SUPPORT", "Section"],

Cell["Step 1: Evaluation of the desired impulse response", "Subsection"],

Cell["\<\
A 2D ideal lowpass filter with rectangular support is a separable function of \
frequency. Therefore its impulse response may be written as a product of two \
1D impulse responses:\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`h\_I[n\_1, n\_2]\  = \ f[n\_1]\ \ g[n\_2]\)]],
  ", \t",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < \ n\_1, \ 
      n\_2\  < \ \(+\[Infinity]\)\)]],
  "\t"
}], "NumberedEquation"],

Cell[TextData[{
  "Typically  ",
  Cell[BoxData[
      \(TraditionalForm\`f\  = \ g\)]],
  StyleBox[", ",
    FontSlant->"Italic"],
  "as when the same filter is used in both spatial directions. The 2D impulse \
response is therefore easily obtained from the 1D ideal filter. An ideal, \
zero-phase 1D lowpass filter is defined as "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(F(\[Omega])\), " ", "=", " ", 
          RowBox[{"{", GridBox[{
                {\(1, \ \ 
                  \(-\[Omega]\_C\)\  \[LessEqual] \ \[Omega] \[LessEqual] 
                    \[Omega]\_C\)},
                {\(0, \ \ \ \ \ \ otherwise\)}
                },
              ColumnAlignments->{Left}]}]}], TraditionalForm]]]
}], "NumberedEquation",
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_C\)]],
  " is the so-called cutoff frequency. The impulse response sequence is given \
by the inverse DTFT. Here is an example of an ideal lowpass filter with \
cutt-off frequency at 0.4\[Pi]:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Omega]\_C = \ 0.4  \[Pi]; \n
    f = \(1\/\(2  \[Pi]\)\) 
          \(\[Integral]\_\(-\[Omega]\_C\)\%\[Omega]\_C Exp[I\ w\ n] 
              \[DifferentialD]w\)\  // ExpToTrig\)], "Input"],

Cell[BoxData[
    \(Sin[1.25663706143591724`\ n]\/\(n\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox[
  "The 2D, finite-duration impulse response can now be easily computed by \
evaluating "],
  StyleBox["f ",
    FontSlant->"Italic"],
  StyleBox["at a finite number of integer points "],
  StyleBox["L",
    FontSlant->"Italic"],
  StyleBox[" and forming "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h\_R[n\_1, n\_2]\)]]],
  StyleBox[" according to (1), with "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f\  = \ \(g\  = \ h\)\)]]],
  StyleBox[" and rectangular region of support "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(R : \ \(-\(\(L - 1\)\/2\)\) \[LessEqual] n\_1, \ 
      n\_2\  \[LessEqual] \(L - 1\)\/2\ \)\)]]],
  StyleBox["."]
}], "Text"],

Cell[BoxData[
    \(L = 15; \nz = Limit[f, n -> 0]; \n
    h = Table[If[n == 0, z, N[f]], {n, \(-\(\(L - 1\)\/2\)\), \(L - 1\)\/2}]; 
    \nhR = Outer[Times, h, h]; \)], "Input",
  CellLabel->"In[44]:="],

Cell[TextData[StyleBox[
"Here is a plot of the truncated impulse response."]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot3D[hR, PlotRange -> All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.19846 .17893 -5.85476 -9 ]
[.19846 .17893 .14524 0 ]
[.42923 .08816 -10.816 -9 ]
[.42923 .08816 1.18401 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.79412 .13786 0 -6.12234 ]
[.79412 .13786 6 2.87766 ]
[.89499 .29234 0 -5.97603 ]
[.89499 .29234 12 3.02397 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[.01878 .29853 -6 -2.77056 ]
[.01878 .29853 0 6.22944 ]
[.00972 .35535 -24 -2.8187 ]
[.00972 .35535 0 6.1813 ]
[.00031 .41428 -18 -2.86883 ]
[.00031 .41428 0 6.13117 ]
[-0.00944 .47544 -24 -2.92105 ]
[-0.00944 .47544 0 6.07895 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.20751 .18843 m
.21203 .19319 L
s
[(5)] .19846 .17893 .95159 1 Mshowa
.43745 .0984 m
.44155 .10351 L
s
[(10)] .42923 .08816 .80266 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(15)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.25192 .17104 m
.25459 .17394 L
s
.2971 .15335 m
.29972 .15629 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.4859 .07942 m
.48831 .08254 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.16384 .20553 m
.1666 .20834 L
s
.12091 .22234 m
.12371 .22511 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78177 .14231 m
.7756 .14454 L
s
[(5)] .79412 .13786 -1 .36052 Mshowa
.88252 .29643 m
.87629 .29847 L
s
[(10)] .89499 .29234 -1 .32801 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(15)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.8032 .17508 m
.79948 .1764 L
s
.82395 .20683 m
.82023 .20812 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.90091 .32455 m
.89716 .32575 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.75965 .10848 m
.75596 .10983 L
s
.7368 .07352 m
.73311 .0749 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03103 .29382 m
.03715 .29147 L
s
[(0)] .01878 .29853 1 -0.38432 Mshowa
.02201 .35075 m
.02815 .34846 L
s
[(0.05)] .00972 .35535 1 -0.37362 Mshowa
.01265 .4098 m
.01882 .40757 L
s
[(0.1)] .00031 .41428 1 -0.36248 Mshowa
.00294 .47109 m
.00913 .46892 L
s
[(0.15)] -0.00944 .47544 1 -0.35088 Mshowa
.125 Mabswid
.02925 .30504 m
.03293 .30364 L
s
.02746 .31635 m
.03114 .31495 L
s
.02566 .32773 m
.02934 .32634 L
s
.02384 .3392 m
.02752 .33782 L
s
.02016 .36239 m
.02385 .36102 L
s
.01831 .37411 m
.022 .37275 L
s
.01643 .38592 m
.02013 .38457 L
s
.01455 .39782 m
.01825 .39647 L
s
.01074 .42188 m
.01444 .42054 L
s
.00881 .43404 m
.01252 .43272 L
s
.00687 .4463 m
.01058 .44498 L
s
.00491 .45865 m
.00862 .45734 L
s
.0328 .28268 m
.03647 .28126 L
s
.03455 .27162 m
.03822 .27019 L
s
.03629 .26063 m
.03996 .2592 L
s
.00095 .48363 m
.00467 .48234 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.648 .747 .922 r
.38178 .61546 .40403 .63507 .44111 .62481 .41917 .6055 Metetra
.686 .762 .909 r
.41917 .6055 .44111 .62481 .47875 .61236 .45719 .59151 Metetra
.697 .753 .895 r
.45719 .59151 .47875 .61236 .51688 .59904 .4957 .57603 Metetra
.655 .725 .901 r
.4957 .57603 .51688 .59904 .55553 .58802 .53469 .56503 Metetra
.572 .699 .928 r
.53469 .56503 .55553 .58802 .59481 .58081 .57435 .56141 Metetra
.508 .712 .963 r
.57435 .56141 .59481 .58081 .63481 .57496 .61487 .56056 Metetra
.566 .796 .986 r
.61487 .56056 .63481 .57496 .67538 .56586 .65602 .55366 Metetra
.699 .864 .96 r
.65602 .55366 .67538 .56586 .7163 .5511 .69736 .53611 Metetra
.759 .847 .918 r
.69736 .53611 .7163 .5511 .75753 .53299 .7388 .51232 Metetra
.731 .788 .898 r
.7388 .51232 .75753 .53299 .79934 .51618 .7808 .4912 Metetra
.668 .733 .898 r
.7808 .4912 .79934 .51618 .84205 .5032 .82391 .47754 Metetra
.626 .712 .909 r
.82391 .47754 .84205 .5032 .88565 .49258 .86816 .46848 Metetra
.636 .734 .919 r
.86816 .46848 .88565 .49258 .92989 .48105 .91302 .45789 Metetra
.672 .761 .917 r
.91302 .45789 .92989 .48105 .97454 .46721 .95812 .44307 Metetra
.662 .732 .902 r
.35906 .59327 .38178 .61546 .41917 .6055 .3968 .58177 Metetra
.661 .721 .893 r
.3968 .58177 .41917 .6055 .45719 .59151 .43507 .57012 Metetra
.661 .744 .912 r
.43507 .57012 .45719 .59151 .4957 .57603 .4739 .55829 Metetra
.658 .782 .94 r
.4739 .55829 .4957 .57603 .53469 .56503 .51329 .5463 Metetra
.659 .775 .935 r
.51329 .5463 .53469 .56503 .57435 .56141 .55325 .53413 Metetra
.661 .703 .878 r
.55325 .53413 .57435 .56141 .61487 .56056 .5938 .52178 Metetra
.652 .633 .818 r
.5938 .52178 .61487 .56056 .65602 .55366 .63495 .50925 Metetra
.648 .608 .796 r
.63495 .50925 .65602 .55366 .69736 .53611 .67671 .49653 Metetra
.652 .633 .818 r
.67671 .49653 .69736 .53611 .7388 .51232 .7191 .48362 Metetra
.661 .703 .878 r
.7191 .48362 .7388 .51232 .7808 .4912 .76212 .47052 Metetra
.659 .775 .935 r
.76212 .47052 .7808 .4912 .82391 .47754 .80581 .45721 Metetra
.658 .782 .94 r
.80581 .45721 .82391 .47754 .86816 .46848 .85016 .4437 Metetra
.661 .744 .912 r
.85016 .4437 .86816 .46848 .91302 .45789 .8952 .42999 Metetra
.661 .721 .893 r
.8952 .42999 .91302 .45789 .95812 .44307 .94094 .41606 Metetra
.678 .73 .889 r
.33579 .56982 .35906 .59327 .3968 .58177 .37392 .55613 Metetra
.623 .699 .899 r
.37392 .55613 .3968 .58177 .43507 .57012 .41237 .54815 Metetra
.593 .724 .935 r
.41237 .54815 .43507 .57012 .4739 .55829 .45142 .54206 Metetra
.666 .805 .95 r
.45142 .54206 .4739 .55829 .51329 .5463 .49126 .52869 Metetra
.764 .811 .89 r
.49126 .52869 .51329 .5463 .55325 .53413 .53164 .50369 Metetra
.756 .716 .815 r
.53164 .50369 .55325 .53413 .5938 .52178 .57225 .47428 Metetra
.682 .614 .773 r
.57225 .47428 .5938 .52178 .63495 .50925 .61329 .45358 Metetra
.6 .547 .767 r
.61329 .45358 .63495 .50925 .67671 .49653 .65537 .44815 Metetra
.541 .541 .804 r
.65537 .44815 .67671 .49653 .7191 .48362 .69876 .45167 Metetra
.549 .635 .889 r
.69876 .45167 .7191 .48362 .76212 .47052 .74299 .4509 Metetra
.644 .788 .951 r
.74299 .4509 .76212 .47052 .80581 .45721 .78731 .43833 Metetra
.715 .822 .932 r
.78731 .43833 .80581 .45721 .85016 .4437 .83165 .41821 Metetra
.695 .757 .9 r
.83165 .41821 .85016 .4437 .8952 .42999 .87674 .39994 Metetra
.646 .704 .889 r
.87674 .39994 .8952 .42999 .94094 .41606 .92319 .38755 Metetra
.676 .751 .907 r
.31178 .54826 .33579 .56982 .37392 .55613 .35025 .53458 Metetra
.625 .741 .93 r
.35025 .53458 .37392 .55613 .41237 .54815 .38904 .5256 Metetra
.607 .728 .931 r
.38904 .5256 .41237 .54815 .45142 .54206 .42844 .51813 Metetra
.669 .738 .902 r
.42844 .51813 .45142 .54206 .49126 .52869 .46865 .50461 Metetra
.739 .757 .867 r
.46865 .50461 .49126 .52869 .53164 .50369 .50948 .48139 Metetra
.764 .778 .865 r
.50948 .48139 .53164 .50369 .57225 .47428 .55064 .45445 Metetra
.72 .796 .911 r
.55064 .45445 .57225 .47428 .61329 .45358 .59223 .43471 Metetra
.577 .766 .968 r
.59223 .43471 .61329 .45358 .65537 .44815 .63471 .42763 Metetra
.469 .704 .971 r
.63471 .42763 .65537 .44815 .69876 .45167 .67837 .42792 Metetra
.543 .708 .947 r
.67837 .42792 .69876 .45167 .74299 .4509 .72288 .4246 Metetra
.653 .734 .909 r
.72288 .4246 .74299 .4509 .78731 .43833 .76764 .41144 Metetra
.702 .751 .89 r
.76764 .41144 .78731 .43833 .83165 .41821 .8126 .39198 Metetra
.69 .755 .902 r
.8126 .39198 .83165 .41821 .87674 .39994 .8583 .374 Metetra
.647 .744 .92 r
.8583 .374 .87674 .39994 .92319 .38755 .90524 .36085 Metetra
.629 .778 .953 r
.28682 .53014 .31178 .54826 .35025 .53458 .32546 .52006 Metetra
.708 .832 .941 r
.32546 .52006 .35025 .53458 .38904 .5256 .36508 .50242 Metetra
.723 .758 .881 r
.36508 .50242 .38904 .5256 .42844 .51813 .40527 .48206 Metetra
.645 .65 .841 r
.40527 .48206 .42844 .51813 .46865 .50461 .44566 .47035 Metetra
.509 .603 .883 r
.44566 .47035 .46865 .50461 .50948 .48139 .48652 .47281 Metetra
0 .543 .829 r
.48652 .47281 .50948 .48139 .55064 .45445 .52842 .48081 Metetra
.379 0 .023 r
.52842 .48081 .55064 .45445 .59223 .43471 .57137 .47737 Metetra
.25 0 .103 r
.57137 .47737 .59223 .43471 .63471 .42763 .6147 .45358 Metetra
.6147 .45358 .63471 .42763 .67837 .42792 .65797 .41804 Metetra
.792 .925 .924 r
.65797 .41804 .67837 .42792 .72288 .4246 .70165 .38783 Metetra
.665 .671 .846 r
.70165 .38783 .72288 .4246 .76764 .41144 .74659 .37195 Metetra
.6 .628 .851 r
.74659 .37195 .76764 .41144 .8126 .39198 .79298 .36497 Metetra
.613 .724 .925 r
.79298 .36497 .8126 .39198 .8583 .374 .84009 .35523 Metetra
.676 .833 .959 r
.84009 .35523 .8583 .374 .90524 .36085 .88724 .33757 Metetra
.537 .766 .982 r
.261 .513 .28682 .53014 .32546 .52006 .29967 .50796 Metetra
.798 .86 .896 r
.29967 .50796 .32546 .52006 .36508 .50242 .34046 .4786 Metetra
.805 .766 .818 r
.34046 .4786 .36508 .50242 .40527 .48206 .38181 .44099 Metetra
.621 .618 .826 r
.38181 .44099 .40527 .48206 .44566 .47035 .42228 .43181 Metetra
0 .21 .736 r
.42228 .43181 .44566 .47035 .48652 .47281 .46258 .46939 Metetra
.805 .325 .065 r
.46258 .46939 .48652 .47281 .52842 .48081 .50472 .52732 Metetra
.599 .211 .279 r
.50472 .52732 .52842 .48081 .57137 .47737 .54916 .54821 Metetra
.183 0 .193 r
.54916 .54821 .57137 .47737 .6147 .45358 .59382 .49984 Metetra
.59382 .49984 .6147 .45358 .65797 .41804 .63696 .41332 Metetra
.942 .92 .761 r
.63696 .41332 .65797 .41804 .70165 .38783 .67977 .3466 Metetra
.679 .658 .823 r
.67977 .3466 .70165 .38783 .74659 .37195 .72481 .32722 Metetra
.46 .53 .842 r
.72481 .32722 .74659 .37195 .79298 .36497 .77278 .33715 Metetra
.478 .659 .94 r
.77278 .33715 .79298 .36497 .84009 .35523 .82151 .33881 Metetra
.725 .879 .953 r
.82151 .33881 .84009 .35523 .88724 .33757 .86881 .31511 Metetra
.512 .725 .969 r
.23464 .49209 .261 .513 .29967 .50796 .27344 .48928 Metetra
.809 .804 .847 r
.27344 .48928 .29967 .50796 .34046 .4786 .31514 .45411 Metetra
.828 .765 .793 r
.31514 .45411 .34046 .4786 .38181 .44099 .35748 .40814 Metetra
.611 .665 .878 r
.35748 .40814 .38181 .44099 .42228 .43181 .39814 .39994 Metetra
.587 .133 0 r
.39814 .39994 .42228 .43181 .46258 .46939 .43793 .45409 Metetra
.864 .415 .076 r
.43793 .45409 .46258 .46939 .50472 .52732 .47976 .53662 Metetra
.667 .155 .014 r
.47976 .53662 .50472 .52732 .54916 .54821 .52489 .5698 Metetra
.768 .948 .617 r
.52489 .5698 .54916 .54821 .59382 .49984 .57076 .50857 Metetra
.986 .894 .633 r
.57076 .50857 .59382 .49984 .63696 .41332 .61469 .39649 Metetra
.937 .832 .715 r
.61469 .39649 .63696 .41332 .67977 .3466 .65775 .31211 Metetra
.699 .709 .855 r
.65775 .31211 .67977 .3466 .72481 .32722 .70315 .29084 Metetra
.312 .499 .881 r
.70315 .29084 .72481 .32722 .77278 .33715 .75196 .30849 Metetra
.402 .617 .938 r
.75196 .30849 .77278 .33715 .82151 .33881 .80165 .31533 Metetra
.747 .824 .911 r
.80165 .31533 .82151 .33881 .86881 .31511 .84938 .28847 Metetra
.575 .696 .924 r
.20804 .46492 .23464 .49209 .27344 .48928 .24728 .45925 Metetra
.759 .729 .825 r
.24728 .45925 .27344 .48928 .31514 .45411 .28909 .42892 Metetra
.805 .766 .818 r
.28909 .42892 .31514 .45411 .35748 .40814 .33162 .39023 Metetra
.6 .795 .974 r
.33162 .39023 .35748 .40814 .39814 .39994 .3728 .38032 Metetra
.552 .016 0 r
.3728 .38032 .39814 .39994 .43793 .45409 .41309 .41776 Metetra
0 0 .441 r
.41309 .41776 .43793 .45409 .47976 .53662 .45499 .47587 Metetra
.379 .426 .784 r
.45499 .47587 .47976 .53662 .52489 .5698 .49986 .49642 Metetra
.733 .599 .708 r
.49986 .49642 .52489 .5698 .57076 .50857 .54602 .44667 Metetra
.828 .665 .68 r
.54602 .44667 .57076 .50857 .61469 .39649 .59115 .35828 Metetra
.855 .738 .734 r
.59115 .35828 .61469 .39649 .65775 .31211 .63564 .29001 Metetra
.702 .812 .933 r
.63564 .29001 .65775 .31211 .70315 .29084 .68176 .26965 Metetra
.258 .61 .955 r
.68176 .26965 .70315 .29084 .75196 .30849 .73049 .27893 Metetra
.478 .659 .94 r
.73049 .27893 .75196 .30849 .80165 .31533 .78016 .27982 Metetra
.713 .728 .862 r
.78016 .27982 .80165 .31533 .84938 .28847 .82871 .25502 Metetra
.637 .693 .885 r
.18107 .43376 .20804 .46492 .24728 .45925 .22103 .42228 Metetra
.687 .677 .834 r
.22103 .42228 .24728 .45925 .28909 .42892 .2623 .403 Metetra
.723 .758 .881 r
.2623 .403 .28909 .42892 .33162 .39023 .30426 .38091 Metetra
.59 .879 .993 r
.30426 .38091 .33162 .39023 .3728 .38032 .34617 .36766 Metetra
.273 .707 .965 r
.34617 .36766 .3728 .38032 .41309 .41776 .38817 .36893 Metetra
.467 .523 .832 r
.38817 .36893 .41309 .41776 .45499 .47587 .43112 .37584 Metetra
.565 .457 .69 r
.43112 .37584 .45499 .47587 .49986 .49642 .47556 .37098 Metetra
.62 .47 .657 r
.47556 .37098 .49986 .49642 .54602 .44667 .52107 .34519 Metetra
.668 .522 .677 r
.52107 .34519 .54602 .44667 .59115 .35828 .56689 .30732 Metetra
.721 .65 .778 r
.56689 .30732 .59115 .35828 .63564 .29001 .61298 .2749 Metetra
.653 .871 .981 r
.61298 .2749 .63564 .29001 .68176 .26965 .66001 .25714 Metetra
.479 .829 .997 r
.66001 .25714 .68176 .26965 .73049 .27893 .70835 .24845 Metetra
.613 .724 .925 r
.70835 .24845 .73049 .27893 .78016 .27982 .75758 .23688 Metetra
.669 .672 .844 r
.75758 .23688 .78016 .27982 .82871 .25502 .8071 .21716 Metetra
.672 .714 .88 r
.15324 .40338 .18107 .43376 .22103 .42228 .1939 .38743 Metetra
.627 .673 .874 r
.1939 .38743 .22103 .42228 .2623 .403 .23471 .37632 Metetra
.607 .728 .931 r
.23471 .37632 .2623 .403 .30426 .38091 .27613 .36675 Metetra
.655 .857 .977 r
.27613 .36675 .30426 .38091 .34617 .36766 .31875 .35083 Metetra
.757 .851 .921 r
.31875 .35083 .34617 .36766 .38817 .36893 .36256 .32479 Metetra
.725 .671 .797 r
.36256 .32479 .38817 .36893 .43112 .37584 .40692 .29486 Metetra
.64 .53 .714 r
.40692 .29486 .43112 .37584 .47556 .37098 .45142 .27234 Metetra
.579 .467 .691 r
.45142 .27234 .47556 .37098 .52107 .34519 .49633 .26291 Metetra
.549 .475 .725 r
.49633 .26291 .52107 .34519 .56689 .30732 .54224 .26107 Metetra
.57 .602 .846 r
.54224 .26107 .56689 .30732 .61298 .2749 .5893 .25541 Metetra
.639 .831 .974 r
.5893 .25541 .61298 .2749 .66001 .25714 .63714 .2395 Metetra
.702 .872 .962 r
.63714 .2395 .66001 .25714 .70835 .24845 .6855 .21699 Metetra
.69 .755 .902 r
.6855 .21699 .70835 .24845 .75758 .23688 .73466 .19595 Metetra
.644 .677 .867 r
.73466 .19595 .75758 .23688 .8071 .21716 .78503 .17985 Metetra
.679 .745 .901 r
.12415 .37636 .15324 .40338 .1939 .38743 .16523 .35963 Metetra
.619 .726 .923 r
.16523 .35963 .1939 .38743 .23471 .37632 .2063 .34885 Metetra
.593 .724 .935 r
.2063 .34885 .23471 .37632 .27613 .36675 .24796 .33998 Metetra
.671 .756 .914 r
.24796 .33998 .27613 .36675 .31875 .35083 .29104 .3234 Metetra
.756 .773 .867 r
.29104 .3234 .31875 .35083 .36256 .32479 .33554 .29452 Metetra
.773 .76 .842 r
.33554 .29452 .36256 .32479 .40692 .29486 .3806 .26096 Metetra
.717 .728 .859 r
.3806 .26096 .40692 .29486 .45142 .27234 .42561 .2365 Metetra
.588 .671 .897 r
.42561 .2365 .45142 .27234 .49633 .26291 .47083 .22799 Metetra
.478 .629 .919 r
.47083 .22799 .49633 .26291 .54224 .26107 .51705 .22878 Metetra
.525 .676 .933 r
.51705 .22878 .54224 .26107 .5893 .25541 .56456 .22501 Metetra
.651 .748 .921 r
.56456 .22501 .5893 .25541 .63714 .2395 .61297 .20876 Metetra
.712 .772 .899 r
.61297 .20876 .63714 .2395 .6855 .21699 .66192 .18451 Metetra
.695 .757 .9 r
.66192 .18451 .6855 .21699 .73466 .19595 .71165 .16211 Metetra
.644 .731 .912 r
.71165 .16211 .73466 .19595 .78503 .17985 .76264 .14579 Metetra
.662 .762 .924 r
.09385 .35117 .12415 .37636 .16523 .35963 .1351 .33598 Metetra
.662 .778 .935 r
.1351 .33598 .16523 .35963 .2063 .34885 .17703 .32054 Metetra
.661 .744 .912 r
.17703 .32054 .2063 .34885 .24796 .33998 .21965 .30484 Metetra
.657 .699 .878 r
.21965 .30484 .24796 .33998 .29104 .3234 .26299 .28888 Metetra
.658 .707 .883 r
.26299 .28888 .29104 .3234 .33554 .29452 .30705 .27266 Metetra
.659 .807 .954 r
.30705 .27266 .33554 .29452 .3806 .26096 .35186 .25616 Metetra
.553 .91 .964 r
.35186 .25616 .3806 .26096 .42561 .2365 .39744 .23937 Metetra
.413 .863 .849 r
.39744 .23937 .42561 .2365 .47083 .22799 .4438 .2223 Metetra
.553 .91 .964 r
.4438 .2223 .47083 .22799 .51705 .22878 .49097 .20493 Metetra
.659 .807 .954 r
.49097 .20493 .51705 .22878 .56456 .22501 .53897 .18725 Metetra
.658 .707 .883 r
.53897 .18725 .56456 .22501 .61297 .20876 .58782 .16926 Metetra
.657 .699 .878 r
.58782 .16926 .61297 .20876 .66192 .18451 .63755 .15095 Metetra
.661 .744 .912 r
.63755 .15095 .66192 .18451 .71165 .16211 .68817 .13231 Metetra
.662 .778 .935 r
.68817 .13231 .71165 .16211 .76264 .14579 .73971 .11333 Metetra
.648 .753 .926 r
.06269 .32443 .09385 .35117 .1351 .33598 .10416 .31011 Metetra
.688 .772 .915 r
.10416 .31011 .1351 .33598 .17703 .32054 .14686 .29136 Metetra
.697 .753 .895 r
.14686 .29136 .17703 .32054 .21965 .30484 .19035 .27089 Metetra
.652 .712 .891 r
.19035 .27089 .21965 .30484 .26299 .28888 .23398 .25517 Metetra
.571 .687 .919 r
.23398 .25517 .26299 .28888 .30705 .27266 .27773 .24731 Metetra
.504 .73 .975 r
.27773 .24731 .30705 .27266 .35186 .25616 .32228 .24234 Metetra
.538 .847 .998 r
.32228 .24234 .35186 .25616 .39744 .23937 .36831 .23072 Metetra
.676 .931 .97 r
.36831 .23072 .39744 .23937 .4438 .2223 .41573 .2075 Metetra
.763 .905 .939 r
.41573 .2075 .4438 .2223 .49097 .20493 .46395 .17745 Metetra
.735 .806 .908 r
.46395 .17745 .49097 .20493 .53897 .18725 .51263 .15019 Metetra
.665 .721 .891 r
.51263 .15019 .53897 .18725 .58782 .16926 .56198 .13082 Metetra
.623 .699 .899 r
.56198 .13082 .58782 .16926 .63755 .15095 .61236 .11627 Metetra
.636 .734 .919 r
.61236 .11627 .63755 .15095 .68817 .13231 .66375 .09994 Metetra
.674 .771 .924 r
.66375 .09994 .68817 .13231 .73971 .11333 .71591 .07893 Metetra
.654 .738 .911 r
.0309 .29462 .06269 .32443 .10416 .31011 .07281 .27919 Metetra
.674 .738 .899 r
.07281 .27919 .10416 .31011 .14686 .29136 .11575 .26126 Metetra
.681 .749 .903 r
.11575 .26126 .14686 .29136 .19035 .27089 .15946 .24229 Metetra
.658 .758 .924 r
.15946 .24229 .19035 .27089 .23398 .25517 .20358 .2257 Metetra
.614 .742 .937 r
.20358 .2257 .23398 .25517 .27773 .24731 .24808 .21315 Metetra
.599 .706 .918 r
.24808 .21315 .27773 .24731 .32228 .24234 .29338 .20197 Metetra
.631 .681 .879 r
.29338 .20197 .32228 .24234 .36831 .23072 .33988 .18709 Metetra
.672 .683 .852 r
.33988 .18709 .36831 .23072 .41573 .2075 .38759 .16592 Metetra
.697 .707 .855 r
.38759 .16592 .41573 .2075 .46395 .17745 .43617 .14096 Metetra
.696 .74 .885 r
.43617 .14096 .46395 .17745 .51263 .15019 .4854 .11729 Metetra
.666 .758 .919 r
.4854 .11729 .51263 .15019 .56198 .13082 .53537 .09766 Metetra
.641 .751 .928 r
.53537 .09766 .56198 .13082 .61236 .11627 .58632 .08041 Metetra
.648 .739 .916 r
.58632 .08041 .61236 .11627 .66375 .09994 .63827 .06204 Metetra
.666 .737 .903 r
.63827 .06204 .66375 .09994 .71591 .07893 .69112 .04099 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.20751 .18843 m
.21203 .19319 L
s
[(5)] .19846 .17893 .95159 1 Mshowa
.43745 .0984 m
.44155 .10351 L
s
[(10)] .42923 .08816 .80266 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(15)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.25192 .17104 m
.25459 .17394 L
s
.2971 .15335 m
.29972 .15629 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.4859 .07942 m
.48831 .08254 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.16384 .20553 m
.1666 .20834 L
s
.12091 .22234 m
.12371 .22511 L
s
.07869 .23888 m
.08153 .2416 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
_Woo1@000Woo00<007ooOol0F7oo0030Ool01`00Oomoogoo001oo`0005Uoo`00`7oo00<007ooOol0
0goo00<007ooOol0Egoo0030Ool01000Oomoogoo0P00FWoo0030Ool01@00Oomoogoo0000Fgoo002o
Ool20003Ool3001IOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00agoo0P00Egoo0035
Ool200000goo0000001FOol00<9oo`<000=oo`8005Ioo`00`7oo0P001Woo00<007oo0000EGoo002m
Ool30008Ool01000Oomoo`00E7oo002kOol2000;Ool01000Oomoo`00E7oo002hOol5000;Ool01@00
Oomoogoo0000Dgoo002eOol3000@Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool00;=oo`8001Aoo`05
001oogooOol0001BOol00;1oo`<001Ioo`03001oogoo009oo`03001oogoo04moo`00[Woo0P006Goo
00<007ooOol00Woo0P00D7oo002[Ool5000HOol20005Ool00`00Oomoo`1>Ool00:Uoo`8001Yoo`<0
0003E_`0000000Eoo`03001oogoo04eoo`00YWoo0`006Woo0P0015Kl0P001Goo00<007ooOol0CGoo
002TOol2000JOol30006E_`00`00E_`00005Ool00`00Oomoo`1<Ool007ioo`D0009oo`03001oogoo
01Uoo`<001Uoo`<000UFo004001Fo5Kl0005Ool00`00Oomoo`1;Ool0081oo`07001oogooOol007oo
000067oo10005goo0`0035Kl00@005KlE_`000Eoo`03001oogoo04]oo`00P7oo00L007ooOomoo`00
Ool0000EOol3000IOol20002D_d00`00E_aFo00:E_`01@00E_aFo5Kl00001Goo00<007ooOol0BWoo
0020Ool01`00Oomoogoo001oo`0001=oo`8001Uoo`<000ABo@03001Fo5Kl00YFo003001Fo5Kl009F
o003001oogoo00=oo`03001oogoo04Uoo`00P7oo00L007ooOomoo`00Ool0000@Ool3000HOol30008
D_d00`00E_aFo009E_`00`00E_aFo002E_`00`00Oomoo`03Ool00`00Oomoo`19Ool007moo`8000Ao
o`03001oogoo00aoo`<001Uoo`8000aBo@03001Fo5Kl00QFo003001Fo5Kl009Fo08000Eoo`03001o
ogoo04Qoo`00TWoo0P0000=oo`0000005Woo0`003U;m00<005KlE_`025Kl00<005KlE_`00P000ULM
00<007ooOol00goo00<007ooOol0Agoo002?Ool3000HOol30002Dad00`00D_eBo@0=D_d00`00E_aF
o007E_`30004Ead00`00Oomoo`03Ool00`00Oomoo`17Ool008eoo`8001Moo`@000IC7@03001BoE;m
00eBo@03001Fo5Kl00EFo08000MG7@03001oogoo00=oo`03001oogoo04Ioo`00RWoo0`005Woo0`00
2U<M00<005;mD_d03U;m00<005KlE_`00UKl0P000ULM00<005LMEad01ELM00<007ooOol00goo00<0
07ooOol0AGoo0028Ool2000FOol3000>Dad00`00D_eBo@0=D_d00`00E_aFo0020004Ead00`00EaeG
7@05Ead00`00Oomoo`03Ool00`00Oomoo`15Ool008Eoo`<00003Ool007oo01=oo`80009G7@03001C
7E<M00eC7@03001BoE;m00aBo@<000IG7@03001G7ELM00IG7@03001oogoo00=oo`03001oogoo04Ao
o`00Pgoo0P001Goo00<007ooOol03goo0P001ELM00<005<MDad03E<M00<005;mD_d025;m0`000U;m
00<005LMEad015LM00<005LMEad01eLM00<007ooOol00goo00<007ooOol0@goo0020Ool3000FOol3
0007Ead00`00DaeC7@0=Dad00`00D_eBo@04D_d40005D_d00`00EaeG7@04Ead00`00EaeG7@07Ead0
0`00Oomoo`02Ool20015Ool007ioo`8001Moo`8000]G7@03001C7E<M00eC7@03001BoE;m00<000YB
o@03001G7ELM00=G7@03001G7ELM00MG7@8000Eoo`03001oogoo049oo`00Ngoo0`005Woo0`003ULM
00<005<MDad035<M0`003U;m00<005LMEad00ULM00<005LMEad01ELM0P000ULM00<007ooOol00goo
00<007ooOol0@Goo001iOol20002Ool00`00Oomoo`0BOol20002F_`00`00EaeG7@0=Ead00`00DaeC
7@08Dad30002C]`00`00D_eBo@0=D_d01@00EaeG7ELM000015LM0`0015LM00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol0>7oo001fOol3000GOol20005F_`00`00EaeG7@0<Ead00`00DaeC7@04
Dad40005C]`00`00D_eBo@0=D_d01P00EaeG7ELM001G7@<000QG7@03001oogoo00=oo`03001oogoo
00Aoo`03001oo`0003Uoo`00Lgoo0`0067oo0P0025[l00<005LMEad035LM00<005<MDad00`002TkL
00<005;mD_d03E;m00<005LMEad00P0035LM00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
=goo001aOol2000IOol2000:F_`00`00EaeG7@0<Ead3000>C]`00`00D_eBo@0<D_d4000>Ead00`00
Oomoo`02Ool00`00Oomoo`03Ool2000jOol006ioo`@001Qoo`8000eJo003001G7ELM00QG7@<0009F
o003001>g4kL00a>g003001BoE;m00YBo@80009Fo@8000iG7@03001oogoo00=oo`03001oogoo009o
o`03001oogoo03Uoo`00K7oo0P006Woo0P0045[l00<005LMEad015LM0`001UKl00<004kLC]`034kL
00<005;mD_d01U;m0`001EKm00<005LMEad03ELM00<007ooOol00Woo0P000goo0`00>Goo001YOol3
000JOol200000e[K001Jo00@F_`00`00EaeG7@030009E_`00`00C]a>g00=C]`00`00D_eBo@02D_d3
0008E_d2000>Ead20002Ool3000oOol004Uoo`03001oogoo01]oo`8001]oo`8000AJf`03001Jo5[l
00mJo08000eFo003001>g4kL00a>g003001BoE;m008000]Fo@8000]G7@<0009Bo@03001oogoo009o
o`03001oogoo03aoo`00B7oo00<007oo00006Goo0`006goo0P001U[K00<005[lF_`03E[l0P0000=O
?@00E_`03EKl00<004kLC]`02dkL0`003EKm00<005Km00001ULM10001E;m00<007ooOol00Woo00<0
07ooOol0?7oo001:Ool00`00Oomoo`0EOol20002Ool00`00Oomoo`0GOol20009F]/00`00F_aJo00:
F_`20003Gcd00`00E_aFo00=E_`00`00C]a>g007C]`30002E]`00`00E_eFo@0<E_d00`00E_d00002
Ead3000:D_d00`00Oomoo`02Ool00`00Oomoo`0kOol004Qoo`8001Eoo`<001aoo`8000aJf`03001J
o5[l00MJo08000IO?@03001Fo5Kl00aFo003001>g4kL00A>g0<000EFg003001FoEKm00aFo@03001F
o@00008000iBo@03001oogoo009oo`03001oogoo03Yoo`00B7oo00<007ooOol04Woo0P007Goo0P00
3e[K00<005[lF_`015[l0P0025lm00<005KlE_`03EKl00<004kLC]`00`002EKL00<005KmE_d02eKm
0P000U/L00<005;mD_d035;m00<007ooOol00Woo00<007ooOol0>Woo0018Ool3000?Ool3000MOol2
00000eJk001Jf`0>F]/00`00F_aJo002F_`2000;Gcd00`00E_aFo00<E_`3000=E]`00`00E_eFo@08
E_d30003Fa`00`00D_eBo@0=D_d00`00Oomoo`02Ool00`00Oomoo`0iOol005Qoo`<001eoo`8000=F
^`03001Jfe[K00iJf`04001Jo000000>Gcd00`00E_aFo009E_`20002E]`00`00E]aFg00<E]`00`00
E_eFo@05E_d20002Fa`00`00FaaK7002Fa`00`00D_eBo@0=D_d00`00Oomoo`02Ool00`00Oomoo`0h
Ool005Eoo`<001ioo`8000IF^`03001Jfe[K00iJf`03001O?Elm00iO?@03001Fo5Kl00IFo0<000AF
g003001Fg5KL00aFg003001FoEKm00=Fo@8000AK7003001K75/L00=K7003001BoE;m00aBo@04001o
ogooOol2000jOol0059oo`<001moo`8000UF^`03001Jfe[K00]Jf`800003Hih005lm00mO?@03001F
o5Kl009Fo0<000QFg003001Fg5KL00aFg003001FoEKm008000IK7003001K75/L00=K7003001BoE;m
00aBo@8000Aoo`03001oogoo03Moo`00D7oo0P0087oo0P002eJk00<005[KF]/02U[K00<006>NHih0
0V>N00<005lmGcd03Elm00<005KlE_`00P002eKL00<005KLE]`03EKL0P0025/L00<005/LFa`015/L
00<005;mD_d025;m0`000U:k00<007ooOol00Woo00<007ooOol0=Woo001=Ool3000OOol3000>E[/0
0`00F]]Jf`07F]/20006Hih00`00GceO?@0<Gcd3000>E]`00`00E]aFg00:E]`200000e/L001K7007
Fa`00`00FaaK7005Fa`00`00D_eBo@03D_d40005D[/00`00Oomoo`02Ool00`00Oomoo`0fOol004]o
o`80009oo`8001]oo`<0009B_003001F^eJk00aF^`03001Jfe[K00IJf`03001SWV>N00MSWP03001O
?Elm00QO?@<0009G?P03001Fg5KL00eFg003001Fg5KL00MFg08000=K7003001K75/L00IK7003001K
75/L00EK7003001BoE;m00<000YB^`03001oogoo009oo`03001oogoo03Eoo`00B7oo0`007Woo0`00
1E:l00<005JkE[/03EJk00<005[KF]/00e[K0P002f>N00<005lmGcd015lm0`001ULn00<005KLE]`0
35KL00<005KLE]`01EKL0P001U/L00<005/LFa`01E/L00<005/LFa`01E/L0`003E:k00<007ooOol0
0goo00<007ooOol0=7oo0016Ool2000NOol30009D[`00`00E[]F^`0=E[/01@00F]]Jfe[K00003V>N
00<005lmGcd00`002ELn00<005KLE]`03EKL00<005KLE]`00UKL0P002E/L00<005/LFa`015/L00<0
05/LFa`00e/L0P000U/L00<005:kD[/035:k00<007ooOol00Woo00<007ooOol0=7oo0013Ool3000L
Ool4000=D[`00`00E[]F^`0<E[/01000F]/000003f>N0`003ELn00<005KLE]`035KL00<005KLE]`0
0P0035/L00<005/LFa`00e/L00<005/LFa`00`0015/L00<005:kD[/035:k00<007ooOol00goo00<0
07ooOol0<goo0011Ool200000goo001oo`0FOol60003C]d00`00D[aB_00;D[`00`00E[]F^`0=E[/0
0`00HiiSWP0=Hih20002Akh00`00EciG?P0<Ech00`00E]aFg00;E]`3000>Fa`00`00FaaK7003Fa`3
0008Fa`00`00D[]B^`0<D[/00`00Oomoo`02Ool2000dOol003ioo`<001Moo`@000U>g@03001B_5:l
00aB_003001F^eJk00YF^`800003Ekl0000000]SWP8000E7_P03001G?ULn00aG?P03001Fg5KL00MF
g0<0009Bo@03001K75/L00eK7003001K75/L00<000YK7003001B^e:k00aB^`03001oogoo00=oo`03
001oogoo039oo`00?7oo0P005goo0`000Tkm00<004kMC]d02DkM00<005:lD[`02e:l00<005JkE[/0
25Jk0P001ENo0P001V>N0`0024Nn0P0035Ln00<005KLE]`015KL0`001E;m00<005/LFa`03U/L0P00
0U/L00<005/LFa`02E/L00<005:kD[/02e:k0P001Goo00<007ooOol0<Goo000iOol3000FOol30006
C_d00`00C]e>g@09C]d00`00D[aB_00;D[`00`00E[]F^`05E[/20009Ekl20002Hih2000=Akh00`00
EciG?P0:Ech00`00E]aFg0030009D_d00`00FaaK700;Fa`200000e]n001K7002Fa`00`00FaaK7009
Fa`00`00D[]B^`08D[/20002E[/00`00Oomoo`02Ool00`00Oomoo`0aOol003Moo`<001Eoo`<000U>
o@03001>gDkM00U>g@03001B_5:l00aB_003001F^eJk009F^`8000aG_`D000i7_P03001G?ULn00EG
?PL000eBo@03001K75/L00QK708000=KOP05001K75/LFa`0000;Fa`00`00D[]B^`06D[/20004E[/0
0`00Oomoo`03Ool00`00Oomoo`0`Ool003Aoo`<001Eoo`<000e>o@03001>gDkM00U>g@03001B_5:l
00]B_003001F^eJk008000]G_`<000DgNaH000I2_@03001BoE;m00aBo@03001K75/L00EK708000IK
OP04001K75/L000<Fa`00`00D[]B^`02D[/30007E[/00`00Oomoo`03Ool00`00Oomoo`0_Ool0035o
o`<001Eoo`<0009G7@03001>oDkm00a>o@03001>gDkM00U>g@03001B_5:l00YB_0<000]G_`8000<g
N`H000=:_003000nWCjM00TnW@030012_D:m00U2_@03001BoE;m00aBo@03001K75/L00=K708000UK
OP03001K700000aK7003001B^e:k008000YF^`03001oogoo00=oo`03001oogoo02moo`00;goo0P00
5Woo0P001ULM00<004kmC_d034km00<004kMC]d02DkM00<005:lD[`01E:l10000dMo100015No2000
2TZl00<003jM?Yd023jM00<004:m@[d02T:m00<005;mD_d035;m00<005/LFa`00P0035]n0P002e/L
10003EJk00<007ooOol00goo00<007ooOol0;Woo000/Ool3000EOol30009Ead00`00C_e>o@0;C_d0
0`00C]e>g@09C]d01000D[aB_5:l10002dMo1P0000E7_P00001Jn`0000]:_003000nWCjM00TnW@03
0012_D:m00Y2_@03001BoE;m00]Bo@<000iKOP8000MK70@0009>o@03001F^eJk00eF^`03001oogoo
009oo`8002moo`00:Woo0P000goo00<007ooOol03goo0`003ELM0P0034km00<004kMC]d014kM2000
3DMo0`0014Nn0P000e[k00<004ZlB[`02TZl00<003jM?Yd02CjM00<004:m@[d02T:m00<005;mD_d0
1e;m0`000U=O00<005]nFgh03E]n00@005/LFaaK70@000M>o@03001F^eJk00aF^`03001oogoo00=o
o`03001oogoo02eoo`009goo0`005Goo0P000UKl00<005LMEad03ELM00<004kmC_d024km20001d;o
0P002DMo0`001DNn0P001U[k00<004ZlB[`02TZl00<003jM?Yd023jM00<004:m@[d02T:m00<005;m
D_d015;m0`001U=O00<005]nFgh02e]n1@002dkm00<005JkE[/03EJk00<007ooOol00goo00<007oo
Ool0;7oo000UOol2000FOol20005E_`00`00EaeG7@0=Ead01000C_e>oDkm1P000dZm00<004;o@_l0
2d;o0`000dMo0`001TNn0P002E[k00<004ZlB[`02TZl00<003jM?Yd023jM00<004:m@[d02T:m00<0
05;mD_d00`002U=O0P0025]n100000<oG`0000003Dkm00<005JkE[/035Jk00<007ooOol017oo00<0
07ooOol0:goo000SOol2000FOol20008E_`00`00EaeG7@0<Ead4000:B[d2000>@_l50005Akh2000;
F_/00`00B[a:_00:B[`00`00?YdnW@09?Yd00`00@[e2_@08@[d4000?Del01000FgiKOU]n10001CmO
0P003Dkm00<005JkE[/035Jk0P001Goo00<007ooOol0:goo000SOol2000DOol2000;E_`20009Ead3
0002D]`00`00B[e:_@0;B[d00`00@_m2o`08@_l30005Ech5000>F_/00`00B[a:_00:B[`00`00?Ydn
W@08?Yd00`00@[e2_@02@[d60003BW/00`00DemCG`0=Del50009?el2000=C_d00`00E[]F^`09E[/2
0002F_/00`00Oomoo`03Ool00`00Oomoo`0ZOol002=oo`03001oo`00011oo`<000mFo003001G7ELM
00AG7@8000IBg003001:_DZm00]:_@030012od;o00E2o`8000YG?P03001S6P0000mJn`03001:_4Zl
00Q:_14000Y:N`03001CGe=O00UCG`L000/oG`8000a>o@03001F^eJk00MF^`8000AJn`03001oogoo
00Aoo`03001oogoo02Uoo`008goo00@007ooOol000aoo`<0009Fo003001Fo5Kl00iFo003001G7ELM
00<000QBg003001:_DZm00a:_@800092o`<000YG?P8000=S6P03001Jne[k00aJn`03001:_4Zl009:
_0H00099eP030015mdGg00U5m`03001:NdYk00]:N`8000ICG`D000ECO`8000XoG`8000a>o@03001F
^eJk00AF^`8000MJn`03001oogoo00=oo`8002Yoo`008Woo0`000Woo00<007ooOol01goo0P001UKl
00<005KlE_`03EKl0`0035;L00<004ZmB[d034Zm0`0035Ln00<006<JHaX00f<J00<005[kF_/03E[k
10002DWF00<004GgAOL024Gg00<004YkBW/03DYk00<005=ODel01@002U=o10001SmO0P0034km00<0
05JkE[/00UJk0P002E[k00<007ooOol017oo00<007ooOol0:7oo000ROol00`00Oomoo`03Ool00`00
Oomoo`03Ool30009E_`00`00E_aFo00:E_`20002Fa`00`00D]aBg00;D]`00`00B[e:_@09B[d20002
E]`00`00EciG?P09Ech00`00HaYS6P05HaX00`00F_]Jn`0:F_/3000<BMH00`00AOM5m`09AOL00`00
BW]:N`0=BW/5000:Dgl20002Fcd00`008Wh0000500000cmO0000000<C_d01000E[/0000035[k00<0
07ooOol017oo00<007ooOol09goo000ROol00`00Oomoo`04Ool5000=E_`20008E_`20005Fa`00`00
D]aBg00;D]`00`00B[e:_@06B[d20005E]`00`00EciG?P07Ech00`00HaYS6P07HaX00`00F_]Jn`07
F_/20002DQH00`00BMI9eP0:BMH00`00AOM5m`09AOL00`00BW]:N`0;BW/5000:Dgl20005Fcd00`00
8WhROP048WhA000?F_/00`00Oomoo`03Ool00`00Oomoo`03Ool50002Ool00`00Oomoo`0JOol0029o
o`8000Eoo`80009Bo@03001Fo5Kl00eFo003001Fo5Kl00=Fo08000QK7003001Bg5;L00YBg003001:
_DZm00=:_@<000QFg08000IG?P03001S6V<J00US6P03001Jne[k00AJn`8000EB5P030019eTWF00U9
eP030015mdGg00Y5m`03001:NdYk00Q:N`<000ANV003001COe=o00ACO`<000QK?@03000ROR9n00HR
OP8000/n_P03001Jne[k00eJn`03001oogoo00Aoo`03001oogoo00Aoo`07001oogooOol007oo0000
6goo000ROol01000Oomoogoo0`001E;m00<005KlE_`03EKl00<005KlE_`00P002e/L00<005;LD]`0
2U;L00<004ZmB[d00P003EKL00@005LnEciG?P8000aS6P03001Jne[k009Jn`8000MB5P030019eTWF
00Y9eP030015mdGg00U5m`03001:NdYk00E:N`@000MNV080009CO`8000aK?@03000ROR9n00DROP80
00/n_P03001Jne[k00iJn`03001oogoo00Aoo`03001oogoo00=oo`07001oogooOol007oo00006goo
000ROol40009D_d00`00E_aFo00<E_`3000=Fa`00`00D]aBg00:D]`3000@E]`00`00Ech0000?HaX0
1000F_/000002E8F00<004WFBMH02TWF00<004GgAOL02TGg00@004YkBW]:N`<00003BW/005jH00YN
V08000iK?@<000HROP8000/n_P03001Jne[k00]Jn`800003Ged007oo00Aoo`03001oogoo00=oo`07
001oogooOol007oo00006goo000QOol3000<D_d00`00E_aFo009E_`20002Fad00`00FaaK700<Fa`0
0`00D]aBg007D]`20002E]`00`00E]aFg00?E]`00`00HaYS6P0?HaX00`00DQIB5P09DQH00`00BMI9
eP0:BMH00`00AOM5m`0:AOL40002BW/2000;GYP00`00K_L0000<Fcd20002F]/300058Wh00`00?[hn
_P0:?[h00`00F_]Jn`08F_/20003Ged00`00Oomoo`04Ool00`00Oomoo`02Ool01`00Oomoogoo001o
o`0001]oo`0077oo00<007ooOol00Woo00<007oo00003E;m00<005KlE_`01UKl0P001E/M00<005/L
Fa`035/L00<005;LD]`00e;L0`001EKL00<005KLE]`035KL0P0000=S6`00HaX03F<J0`00358F00<0
04WFBMH02TWF00<004GgAOL01dGg10000dYk00<005jHGYP02ejH00@006kgK_L000UK?@8000AJf`03
000Uo2Gl008000<ROP8000/n_P03001Jne[k00MJn`03001OGEmM00AOG@03001oogoo009oo`03001o
o`00009oo`8000Aoo`03001oogoo01Yoo`006goo00<007oo00000goo0P0000=oo`00D_d035;m00<0
05KlE_`00eKl0P0025/M00<005/LFa`035/L00<005;LD]`00P002EKL00<005KLE]`02UKL00<006<K
Ha/00V<K00<006<JHaX02V<J00D005jiG[UN^@0000]B5P030019eTWF00Y9eP030015mdGg00A5m`<0
00=5m`04001:N`00000=GYP00`00K_M^m`02K_L00`00FceK?@03Fcd30007F]/010009O`Uo2Gl0`00
00<ROP0000002cjn00<005[kF_/015[k0P0025mM00<007ooOol00goo00<007ooOol08goo000KOol0
0`00Ool00003Ool01@00Oomoogoo00003E;m00<005KlE_`00P002e/M00<005/LFa`02e/L0`0035KL
00<005KLE]`01eKL0P001V<K00<006<JHaX026<J00<005jiG[T00Uji00<0058FDQH02E8F00<004WF
BMH02TWF00@004GgAOM5m`<000M5m`03001NV5jH00aNV003001^mfkg00A^m`03001K?E/m008000YJ
f`03000Uo2Gl00@Uo0<000`n_P04001Jne[kF_/2000;Ged00`00Oomoo`03Ool00`00Oomoo`0ROol0
01]oo`03001oo`0000=oo`03001oogoo009oo`03001BoE;m00YBo@<000iK7@03001K75/L00MK70<0
009Fo@03001Fg5KL00]Fg003001Fg5KL00AFg08000QS6`03001S6V<J00IS6P8000EN^@03001B5U8F
00UB5P030019eTWF00Y9eP@000U5m`03001F5@0000eNV003001^mfkg00E^m`8000eJf`03000Uo2Gl
00DUo0P000Dn_P04001Jn`00000=Ged00`00Oomoo`03Ool00`00Oomoo`0ROol001]oo`03001oo`00
00=oo`8000Aoo`03001BoE;m00MBo@80009C7@03001K7E/M00eK7@03001K75/L00AK708000IFo@03
001Fg5KL00]Fg003001Fg5KL009Fg003001S6f<K00US6`03001S6V<J00AS6P03001N^Eji00EN^@03
001B5U8F00YB5P030019eTWF00M9eP@000Y5m`04001F5EHE000<GYP00`00K_M^m`06K_L2000=F]/0
0`009O`Uo0069O`20005<Wh7000@Ged00`00Oomoo`03Ool00`00Oomoo`0QOol001aoo`03001oogoo
009oo`03001oogoo00Aoo`03001BoE;m00=Bo@<000EC7@8000iK7@03001K75/L00<000QFo@03001F
g5KL00aFg004001Fg000000=Ha/00`00HaYS6P02HaX00`00G[UN^@07G[T00`00DQIB5P09DQH00`00
BMI9eP05BMH20003BMH00`00AOM5m`07AOL00`00EQEF5@02EQD00`00GYQNV008GYP00`00K_M^m`06
K_L00`00MeH0000>F]/00`009O`Uo0069O`2000;<Wh00`00GeeOG@0;Ged200000enN001oo`04Ool0
0`00Oomoo`0POol0021oo`03001oogoo00Ioo`03001BoE;m008000YC7@03001K7E/M00]K7@<000aF
o@03001Fg5KL00]Fg080011S6`04001S6P00000:G[T00`00DQIB5P09DQH00`00BMI9eP02BMH30005
BMH00`00AOM5m`06AOL00`00EQEF5@03EQD00`00GYQNV008GYP00`00K_M^m`06K_L01000MeIgEP00
3E[K00<002Gl9O`01bGl0P002c9n00<005mMGed025mM0P0015nN00<007ooOol00Woo00<007ooOol0
87oo000POol20008Ool2000=Dad00`00FaeK7@06Fad40002Ead00`00E_eFo@0;E_d00`00E]aFg008
E]`20002Ead00`00Ha]S6`0>Ha/00`00G[UN^@0:G[T00`00DQIB5P09DQH00`00BMH000020009BMH0
0`00AOM5m`03AOL20007EQD00`00GYQNV006GYP00`00K_M^m`06K_L00`00MeIgEP02MeH00`00F]]J
f`0:F]/400079O`00`00<WhbOP09<Wh00`00GeeOG@06Ged20006Gih00`00Oomoo`02Ool2000QOol0
021oo`03001oogoo00Qoo`03001C7E<M00aC7@80009K7@@000MG7@03001FoEKm00]Fo@03001Fg5KL
00EFg08000EG7@03001S6f<K00]S6`800003Hgd005ji00]N^@03001B5U8F00MB5P<000a9eP030015
mdGg0095m`03001F5EHE00MF5@03001NV5jH00INV003001^mfkg00I^m`03001gEWMF009gEP03001J
fe[K00QJf`800004E[X003XJ>QX400039O`2000;<Wh00`00GeeOG@03Ged20009Gih00`00Oomoo`03
Ool00`00Oomoo`0NOol0021oo`03001oogoo00Uoo`8000eC7@<000aG7@03001FoEKm00YFo@03001F
g5KL00=Fg08000QG7@03001S6f<K00QS6`8000=SO@03001N^Eji00YN^@03001B5U8F00AB5P<0009B
5P030019eTWF00Y9eP050015mdGgAOL0000;EQD00`00GYQNV004GYP00`00K_M^m`06K_L00`00MeIg
EP04MeH00`00F]]Jf`05F]/20004E[X00`00>QXj6P03>QX6000;<Wh00`00GeeOG@02000<Gih00`00
Oomoo`02Ool00`00Oomoo`0NOol0021oo`8000aoo`03001C7E<M00QC7@80009G7@03001G7ELM00]G
7@03001FoEKm00YFo@03001Fg5KL008000]G7@03001S6f<K00ES6`8000ISO@03001N^Eji00UN^@04
001B5U8FDQH30005DQH00`00BMI9eP0:BMH01000AOM5m`0035HE00<005jHGYP00ejH00<006kgK_L0
1fkg00<007MFMeH01GMF00<005[KF]/00U[K0P001UJj00<003XJ>QX01cXJ40003UnN0P0017oo00<0
07ooOol07Goo000POol00`00Oomoo`0<Ool00`00DaeC7@04Dad30005Ead2000<Ead00`00E_eFo@08
E_d4000>Ead00`00Ha]S6`02Ha/20008Hgd00`00G[UN^@09G[T40008DQH00`00BMI9eP0;BMH2000>
EQD00`00GYQNV002GYP00`00K_M^m`06K_L00`00MeIgEP06MeH00`00F]]Jf`020009E[X00`00>QXj
6P07>QX00`00>QX0000;?[h00`00GiiOWP09Gih30002Eeh00`00Oomoo`02Ool00`00Oomoo`0LOol0
01moo`03001oogoo00ioo`80009C7@8000YG7@03001G7ELM00YG7@04001FoEKmE_d60003B_d00`00
EaeG7@0=Ead01000Ha/000002f=m00<005jiG[T01Uji10002e8F00<004WFBMH02TWF00<005HEEQD0
3EHE00D005jHGYQNV00000U^m`03001gEWMF00MgEP8000]F^P03000j6SXJ00Pj6P8000`n_P8000IO
WP<000EGGP03001oogoo009oo`03001oogoo01aoo`007goo0`0047oo0P003ELM00<005LMEad025LM
1@002T[m00<005LMEad035LM0P003F=m00<005jiG[T00eji0`000eji00<0058FDQH02E8F00<004WF
BMH024WF0`0045HE00<005jH00002Fkg00<007MFMeH01gMF00<007^h000035Jj00<003XJ>QX023XJ
0P003Cjn00<005nNGih00`002EMN00<007ooOol00Woo00<007ooOol06goo000OOol00`00Oomoo`0A
Ool00`00EaeG7@0<Ead20003Ead50003C_d00`00B_e:o@0:B_d20009Ead30002Dgl2000<Hgd00`00
G[T000020006G[T00`00DQIB5P09DQH00`00BMI9eP06BMH20002COD00`00EQEF5@0>EQD00`00GYP0
0009K_L00`00MeIgEP07MeH00`00NkP0000<E[X00`00>QXj6P09>QX2000<?[h3000=Eeh01000Oomo
ogoo0P0077oo000:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`0BOol00`00EaeG7@0<Ead40009C_d00`00B_e:o@0;B_d00`00EaeG7@04Ead20007
Dgl00`00HgeSO@08Hgd3000:G[T00`00DQIB5P08DQH00`00BMI9eP04BMH20005COD00`00EQEF5@0>
EQD00`00K_M^m`08K_L00`00MeIgEP06MeH01@00NkQk^7^h000035Jj00<003XJ>QX023XJ00<003XJ
00001cjn10000Tkm00<005MNEeh02eMN00<007ooOol00Woo00<007ooOol06Woo0009Ool00`00Ool0
0007Ool00`00Ool00002Ool00`00Ool00004Ool2000DOol00`00EaeG7@09Ead20002E_`00`00C_e>
o@09C_d00`00B_e:o@0;B_d00`00EaeG7@03000:Dgl00`00HgeSO@04Hgd30002Hgd00`00G[UN^@08
G[T00`00DQIB5P09DQH01000BMI9eTWF0P001dge00<005HEEQD03EHE00<006Ze000026kg00<007MF
MeH01WMF00<007^hNkP00W^h00<005JjE[X02UJj00<003XJ>QX02CXJ0P000cjn10001dkm00<005MN
Eeh02UMN0P0017oo00<007ooOol06Goo0009Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomo
o`02Ool00`00Oomoo`0DOol00`00EaeG7@06Ead20005E_`00`00C_e>o@09C_d00`00B_e:o@0:B_d3
000>Dgl20002Hgd20005Hgd00`00G[UN^@08G[T00`00DQIB5P09DQH01000BMH000002Dge00<005HE
EQD03EHE00<006Ze000026kg00<007MFMeH01WMF00<007^hNkP00g^h00<005JjE[X02UJj00<003XJ
>QX023XJ1@002dkm00<005MNEeh01UMN10000U;m00<007ooOol00Woo00<007ooOol067oo0009Ool0
0`00Ool00007Ool00`00Ool00002Ool20005Ool00`00Oomoo`0EOol00`00EaeG7@03Ead20008E_`0
0`00C_e>o@09C_d00`00B_e:o@05B_d40002C_d2000>Dgl>0007G[T00`00DQIB5P07DQH4000;COD0
0`00EQEF5@0<EQD01@00J[EZ]FZe00001Vkg00<007MFMeH01WMF00<007^hNkP017^h00<005JjE[X0
2UJj00<003XJ>QX00SXJ1P000TjK0P003Dkm00@005MNEeiGGP@000IBo@03001oogoo009oo`03001o
ogoo01Qoo`002Goo00<007oo00001goo00<007oo00000Woo00<007ooOol00goo0P0067oo00<005LM
Ead00P002UKl00<004kmC_d02Tkm00<004[mB_d0100024km0P0025=o10000T^O0P001b;N00<003XJ
>QX01P000Uji00<0058FDQH01P000TWF00<004geCOD02dge00<005HEEQD02eHE00D006ZeJ[EZ]@00
00I^m`03001gEWMF00EgEP03001k^7^h00Ik^003001F^UJj00UF^PD000Q>V`8000e>o@@000]Bo@03
001oogoo009oo`03001oogoo01Moo`002Woo00<007ooOol01goo00@007ooOomoo`<000=oo`03001o
ogoo01Qoo`8000eFo003001>oDkm00U>o@<000i>o@80009CO`D000M;W`8000HRgP03000j6SXJ00Dj
6PD000Q9eP03001=mDge00]=m@03001F5EHE00YF5@03001Z]FZe00=Z]@03001^mfkg009^m`03001g
EWMF00IgEP03001k^7^h00Ik^003001F^UJj00IF^P<00003E[/004jK00]>V`8000Y>o@80009K7003
001BoE;m00]Bo@03001oogoo009oo`03001oogoo01Ioo`007Woo00<007ooOol06Goo00<005KlE_`0
35Kl00<004kmC_d01Dkm0`000U:k00<004kmC_d03Dkm1@002d^O0`0012;N00<003XJ>QX01cXJ00<0
04WFBMH02DWF00<004geCOD02Tge00<005HEEQD02UHE00<006ZeJ[D016Ze00D006kgK_M^m`0000Mg
EP03001k^7^h00Qk^003001F^UJj00=F^P8000EF^`03001>VdjK00Y>V`8000M>o@8000AK7003001B
oE;m00aBo@03001oogoo008001Qoo`007Woo0P006goo00<005KlE_`035Kl00<004kmC_d010001U:k
00<004kmC_d02Tkm100000=O700000000P0014^O1@000dlo00<002;N8]h00R;N00<003XJ>QX01SXJ
00<004WFBMH02DWF00<004geCOD02Tge00<005HEEQD02EHE00<006ZeJ[D01FZe00@006kgK_L000Qg
EP03001k^7^h00Qk^003001F^UJj00<000MF^`03001>VdjK00Y>V`03001>V`0000A>o@8000MK7003
001BoE;m00]Bo@03001oogoo009oo`03001oogoo01Eoo`007Woo00<007ooOol06goo00<005KlE_`0
2eKl0`002e:k0P0024km0`0025lL10002Dlo00D002;N8]hRgP0000Tj6P030019eTWF00Q9eP03001=
mDge00]=m@03001F5EHE00QF5@03001Z]FZe00IZ]@03001^m`0000MgEP03001k^7^h00Yk^08000]F
^`03001>VdjK00Y>V`80009>o@8000YK7003001BoE;m00YBo@8000=oo`03001oogoo01Eoo`007Woo
00<007ooOol077oo0P002EKl0P000UKL00<005:kD[/02e:k00<004kmC_d00Tkm0`002elL00<006LJ
00002dlo00D002;N8]hRgP0000Pj6P030019eTWF00Q9eP03001=mDge00]=m@03001F5EHE00MF5@03
001Z]FZe00MZ]@8000MgEP03001k^7^h00Uk^0800003Ikd005Jk00YF^`03001>VdjK00]>V`<000eK
7003001BoE;m00EBo@@0009Bg005001oogooOol0000FOol001ioo`8001moo`03001Fo5Kl00=Fo0<0
00EFg003001B^e:k00]B^`D000aO7005001W6VLJIaX0000;Ccl010008]hRgP0023XJ00<004WFBMH0
24WF00<004geCOD02dge00<005HEEQD01eHE00<006ZeJ[D026Ze00<007MFMeH01GMF00<007^hNkP0
1g^h0P000fNm00<005JkE[/02UJk00<004jKCY/024jK0P0000=K700000003E/L00@005;mD_eBo@@0
00IBg003001oogoo009oo`03001oogoo01=oo`007Goo00<007ooOol087oo00<005KlE_`00P002EKL
00<005:kD[/025:k1@003ElL00<006LJIaX00fLJ0P002Tlo0P0000<RgP00>QX01SXJ00<004WFBMH0
24WF00<004geCOD02dge00<005HEEQD01UHE00<006ZeJ[D02FZe0P001GMF00<007^hNkP01g^h00<0
06NmIkd016Nm00<005JkE[/02EJk00<004jKCY/01TjK0P000e/L0P003E/L10002e;L00D007ooOomo
o`0001Eoo`007Goo00<007ooOol08Goo0P002eKL00<005:kD[/01E:k0`0000EB^`00001F^P0000aO
7003001W6VLJ00IW6P04001??dloCcl60002C[`20008>QX00`00BMI9eP08BMH00`00COE=m@0:COD0
0`00EQEF5@06EQD00`00J[EZ]@08J[D00`00OiAoU0020002MeH00`00NkQk^006NkP20007Ikd00`00
E[]F^`0:E[/00`00CY]>V`02CY/30006Fa`20009Fa`30002Fa`00`00D]aBg00:D]`01000Oomoogoo
0P0057oo000MOol3000ROol00`00E]aFg00:E]`01000D[]B^e:k0`000U:k0P0015Jj00<005lLGa`0
1elL0P002VLJ0`002Djl0P001cXJ00<004WFBMH024WF00<004geCOD02dge00<005HEEQD015HE00<0
06ZeJ[D02FZe00<007nDOi@00WnD00<007MF00001W^h0P002VNm00<005JkE[/02EJk00<004jKCY/0
0P002U/L0P001E/L0`001E/L00<005;LD]`02e;L00<007ooOol00Woo00<007ooOol017oo1@000Woo
00<007ooOol00goo000=Ool00`00Oomoo`02Ool00`00Oomoo`050003Ool00`00Oomoo`0SOol00`00
E]aFg00:E]`30003D[/20007E[X00`00GaaO7005Ga`00`00IaYW6P09IaX00`00JaT0000;C[`00`00
>QXj6P05>QX00`00BMI9eP08BMH00`00COE=m@0;COD00`00EQEF5@04EQD00`00J[EZ]@08J[D00`00
OiAoU004Oi@30003NkP2000<Ikd00`00E[]F^`09E[/3000=Fa`00`00FaaK70030009Fa`00`00D]aB
g00:D]`00`00Oomoo`02Ool00`00Oomoo`06Ool01`00Oomoogoo001oo`0000Aoo`0037oo00<007oo
000027oo00<007ooOol00goo00<007ooOol097oo00<005KLE]`01eKL0P0000AFg000D[]B^`8000YF
^P03001O75lL00=O7003001W6VLJ00UW6P05001[6F/IJaT0000;C[`00`00>QXj6P04>QX00`00BMI9
eP08BMH00`00COE=m@0;COD00`00EQEF5@03EQD00`00J[EZ]@09J[D00`00OiAoU003Oi@7000?Ikd0
0`00E[]F^`04E[/40002D_d00`00FaaK700;Fa`3000=Fa`00`00D]aBg009D]`20004Ool00`00Oomo
o`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool000aoo`03001oo`0000Qoo`03001oogoo00=oo`80
02Ioo`03001Fg5KL00=Fg0<000=Fg0<000eF^P05001O75lLGa`0000;IaX00`00JaU[6@03JaT00`00
C[a>_009C[`00`00>QXj6P04>QX00`00BMI9eP07BMH00`00COE=m@0;COD00`00EQEF5@03EQD00`00
J[EZ]@08J[D00`00OiAoU004Oi@9000=Ikd00`00E[]F^`040007D_d00`00FaaK7008Fa`200000e]M
0000000>Fa`00`00D]aBg004D]`40002E_`00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoogoo
0P001Goo000<Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00E]`000020003
E]`30002D]`00`00E[YF^P0<E[X00`00Ga`0000;IaX00`00JaU[6@04JaT00`00C[a>_009C[`00`00
>QXj6P04>QX00`00BMI9eP08BMH00`00COE=m@0;COD01@00EQEF5EHE00002fZe00<007nDOi@00gnD
30001fNm1`002e;m00<005/LFa`01U/L0P0015]M00<005/LFa`035/L00<005;LD]`010001UKl00<0
07ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Ioo`0037oo00<007oo000027oo00<007oo
Ool00Woo00<007ooOol09Woo0`000UKL10001E;L00<005JjE[X03EJj00<006LJIaX02FLJ00<006/I
JaT01V/I00<004jlC[`02Djl00<003XJ>QX00cXJ00<004WFBMH024WF00<004geCOD02dge00D005HE
EQEF5@0000]Z]@03001oU7nD00=oU1<000I6gP03001BoE;m00YBo@03001K75/L00=K708000IKG@80
00eK70<000]Fo004001oogooOol20004Ool20003Ool30004Ool000eoo`03001oogoo00Ioo`8000Ao
o`8002Aoo`<000=oo`8000YBg003001F^UJj00]F^P03001RnP0000YW6P03001[6F/I00M[6@03001>
_4jl00M>_0<000@j6P030019eTWF00Q9eP03001=mDge00]=m@04001F5EHE000;J[D00`00OiAoU003
Oi@5000:?]l00`00A]i6gP08A]h00`00D_eBo@0;D_d00`00FaaK70020009Fed20009Fa`30002E_d0
0`00E_aFo009E_`6000@Ool001aoo`03001oogoo021oo`<000Moo`03001Bg5;L00UBg003001F^UJj
00QF^P8000=RnP03001W6VLJ00IW6P03001[6F/I00U[6@04001>_4jlC[`50003CWX00`00>QXj6P02
>QX00`00BMI9eP07BMH00`00COE=m@0;COD01000EQEF5@002fZe00<007nDOi@00gnD100000=;7P00
?]l02CkO00<004KNA]h024KN00<005;mD_d02U;m0`0035]M0P001E/L0`001EKm00<005KlE_`02UKl
00D007ooOomoo`00011oo`0077oo00<007ooOol07Goo0`002goo00<005;LD]`025;L00<005JjE[X0
1eJj00<006;jH_X016;j0P001FLJ00<006/IJaT02f/I0`0024ij00<003XJ>QX00SXJ00<004WFBMH0
1dWF00<004geCOD034ge0P002fZe00<007nDOi@00gnD0`0014/N00<003kO?]l01ckO00<004KNA]h0
2DKN00<005;mD_d01U;m0`000U<n00<005]MFed02e]M00<005/LFa`00`002EKm00<005KlE_`02EKl
00D007ooOomoo`00011oo`0077oo0P006goo0`003goo00<005;LD]`025;L00<005JjE[X01EJj00<0
06;jH_X01f;j00D006LJIaYW6P0000e[6@03001W6P0000Y>NP05000j6SXJ>QX0000:BMH00`00COE=
m@0;COD2000;J[D00`00OiAoU003Oi@20006Bah00`00?]lng`07?]l00`00A]i6gP09A]h00`00D_eB
o@03D_d20006Dch00`00FeeKG@0:Fed3000<E_d00`00E_aFo009E_`20003Ool00`00Oomoo`0=Ool0
01aoo`03001oogoo01Moo`<0019oo`03001Bg5;L00UBg003001F^UJj00=F^P03001RnV;j00URnP03
001W6P0000e[6@04001W6VLJ000:CWX20002>QX00`00BMI9eP08BMH00`00COE=m@0;COD00`00J[EZ
]@09J[D00`00OiAoU003Oi@20003Bah;0004?]l00`00A]i6gP08A]h00`00D_eBo@030009Dch00`00
FeeKG@05Fed400000eLn0000000=E_d00`00E_aFo004E_`40002Ead01000Oomoo`003goo000KOol0
0`00Oomoo`0EOol3000FOol00`00D]aBg009D]`00`00E[YF^P02000=H_X00`00JaU[6@0;JaT00`00
IaYW6P02IaX00`00CWY>NP08CWX20002>QX00`00BMI9eP07BMH00`00COE=m@0:COD2000;J[D00`00
OiAoU003Oi@50005CSP00`00ASU6>@03ASTB000=Dch00`00FeeKG@040006Ech2000<E_d00`00E_aF
o0040007Ead00`00Ool0000?Ool001]oo`8001=oo`<001Yoo`03001Bg5;L00QBg003001F^P0000iR
nP03001W>`0000][6@03001W6VLJ00=W6P03001>NTij00U>NP04000j6SXJ0009BMH00`00COE=m@09
COD01000GWINMP002VZe00<007nDOi@00WnD00<004hhCSP02Dhh00<004HiAST024Hi00<004JLAY`0
24JL00<005<nDch02e<n0`002eLn00<005KmE_d02UKm0`002eLM00<007oo00003goo000KOol00`00
Oomoo`0?Ool3000NOol00`00D]aBg004D]`5000=H_X20003Ic/00`00JaU[6@06JaT20007IaX00`00
CWY>NP08CWX200000cXJ0019eP08BMH00`00COE=m@08COD01@00GWINMUif00002FZe00<007nDOi@0
0gnD0P002Thh00<004HiAST024Hi00<004JLAY`02DJL00<005<nDch01e<n0`000ULM00<005LnEch0
2ELn0P001eKm10000U;m00<005LMEad02ULM0P003goo000KOol00`00Oomoo`0=Ool2000ROol60005
B]d00`00H_YRnP09H_X00`00Ic]W>`04Ic/00`00JaU[6@04JaT00`00IaYW6P08IaX00`00CWY>NP08
CWX30009BMH00`00COE=m@07COD00`00GWINMP03GWH00`00J[EZ]@06J[D00`00OiAoU002Oi@00`00
EWP0000;CSP00`00ASU6>@08AST00`00AYa6W009AY`00`00DciC?P04Dch20006Ead00`00EciG?P09
Ech20002E_d40006D_d00`00EaeG7@0;Ead00`00Oomoo`0=Ool001]oo`8000]oo`<002Eoo`03001:
gD[M00Q:g@03001RnV;j00MRnP03001W>fLk00EW>`03001[6F/I00=[6@03001W6VLJ00UW6P03001>
NTij00Q>NP@000U9eP03001=mDge00E=m@03001NMUif00ANMP03001Z]FZe00EZ]@03001oU7nD00=o
U004001FN5Ih000:CSP00`00ASU6>@08AST00`00AYa6W00:AY`00`00DciC?P030008Ead00`00EciG
?P09Ech4000;D_d00`00EaeG7@0:Ead2000>Ool001]oo`03001oogoo00Moo`<002Uoo`03001:gD[M
00Q:g@03001RnV;j00ERnP03001W>fLk00MW>`05001[6F/IJaT0000=IaX00`00CWY>NP06CWX50009
BMH00`00COE=m@04COD00`00GWINMP05GWH00`00J[EZ]@05J[D00`00OiAoU002Oi@01@00EWQFN5Ih
00002Thh00<004HiAST02DHi00<004JLAY`02DJL0`0035LM00<005LnEch00ULn1P000U;M0P0035;m
00<005LMEad01ELM100000=oo`00Ool03Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`050002Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool3000]Ool00`00B]e:g@07B]d00`00H_YRnP04H_X00`00Ic]W
>`09Ic/00`00JaT0000>IaX01000CWY>NTij1@000e:J0`0024WF00<004geCOD00dge00<005ifGWH0
1eif00<006ZeJ[D00fZe00<007nDOi@00gnD00<005IhEWP00UIh00<004hhCSP024hh00<004HiAST0
2DHi00<004JLAY`014JL10000UKL00<005LMEad02ULM1@0025;M0P0035;m00@005LMEaeG7@@000Eo
o`03001oogoo00aoo`001Goo00<007oo000027oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`02
Ool3000`Ool00`00B]e:g@08B]d01000H_YRnV;j0P003FLk00<006LJIaX03VLJ0`0025:J0P0000<a
^@0000001TWF00<004geCOD00Tge00<005ifGWH025if00<006ZeJ[D00fZe00<007nDOi@00WnD00<0
05IhEWP00eIh00<004hhCSP024hh00<004HiAST02DHi00<004JLAY`010001eKL00<005LMEad01eLM
0P000UKl00<005;MD]d02E;M0P002e;m10002Goo00<007ooOol037oo0005Ool00`00Ool00008Ool0
0`00Oomoo`03Ool01000Oomoogoo1@00=7oo00<004[MB]d024[M00<006;j00003FLk0P0000=WO000
IaX036LJ0`002e:J0P000S6i0P0014WF00D004geCOE=m@0000aNMP03001Z]FZe009Z]@03001oU7nD
009oU003001FN5Ih00=FN003001>>4hh00U>>0030016>DHi00Q6>@<000aFg003001G7ELM00=G7@<0
00AFo003001BgE;M00YBg@8000IBo@@000eoo`03001oogoo00aoo`001Goo00<007oo000027oo00@0
07ooOomoo`8000Aoo`8003Qoo`03001:gD[M00A:g@D000eW>`03001WO6Ml009WO003001W6VLJ00QW
6P8000=O7003001BVU:J00QBVP8000@a^@8000=9eP03001=m@0000eNMP05001Z]FZeJ[D00004Oi@0
0`00EWQFN005EWP00`00CSQ>>008CSP00`00ASU6>@04AST40002DYX00`00E]aFg00;E]`00`00EaeG
7@020008E_`00`00D]eBg@09D]d20002D_d4000AOol00`00Oomoo`0<Ool000Eoo`03001oo`0000Qo
o`05001oogooOol00006Ool00`00Oomoo`0gOol60005@_l2000:Ic/00`00IgaWO004Ig`00`00IaYW
6P05IaX20005Ga`00`00DYYBVP09DYX20005<KT200000dWF0000000>GWH01@00J[EZ]FZe000017nD
00<005IhEWP01EIh00<004hhCSP02Dhh00<004Hi00000`001U:J00<005KLE]`02eKL0`002eKl00<0
05;MD]d02E;M0`005Goo00<007ooOol037oo0006Ool00`00Oomoo`06Ool20003Ool30005Ool2000h
Ool2000:@_l00`00Ic]W>`05Ic/20008Ig`00`00IaYW6P02IaX20008Ga`00`00DYYBVP08DYX20007
<KT2000@GWH00`00J[D00004Oi@00`00EWQFN007EWP00`00CSQ>>007CSP3000;DYX00`00E]aFg008
E]`20002Gc`00`00E_aFo00:E_`00`00D]eBg@04D]d400000goo001oo`0EOol00`00Oomoo`0<Ool0
01ioo`03001oogoo03Moo`030012od;o00Q2o`03001W>fLk00=W>`03001WO6Ml00UWO004001W6P00
000:Ga`00`00DYYBVP09DYX00`00<KTa^@06<KT00`00GWINMP0>GWH00`00J[D00003Oi@20009EWP0
0`00CSQ>>004CSP300000e9i001BVP0<DYX00`00E]aFg005E]`20004Gc`00`00E_aFo00:E_`00`00
D]eBg@040006Ool00`00Oomoo`0DOol00`00Oomoo`0;Ool001moo`03001oogoo03Moo`030012od;o
00Q2o`800003Ic/0000000aWO08000eO7003001BVU:J00QBVP8000Pa^@03001NMUif00iNMP03001o
U00000<000]FN003001>>00000<000EBN@03001BVU:J00]BVP03001Fg5KL009Fg08000MO?003001F
o5Kl00UFo0<000Yoo`03001oogoo01Aoo`03001oogoo00]oo`0087oo00<007ooOol0=goo0P001T;o
1@0036Ml0P000U]N00<005lLGa`02UlL00<005:JDYX01U:J1000236i00<005ifGWH03Uif0P000V?C
00<005IhEWP02EIh0`002E9i00<005:JDYX02e:J00<005KLE]`00P002Ull00<005KlE_`015Kl1000
3Woo00<007ooOol04goo00<007ooOol02goo000QOol2000iOol60005Aal20007Ig`30005Feh00`00
GaaO700:Ga`00`00DYYBVP03DYX20003E_`20007<KT00`00GWINMP0=GWH01`00Hm=Sdf?C001RfP00
00MFN0<00003DYX0059i00YBN@03001BVU:J00]BVP8000aO?003001Fo5Kl00@001=oo`03001oogoo
019oo`03001oogoo00]oo`008goo00<007ooOol0=goo0P002TLO0P000fMl0P002E]N0P002UlL00<0
05:JDYX00`001UKl00<0036i<KT01S6i00<005ifGWH035if00@006?CHm<0009RfP03001FN5Ih00=F
N08000EBVP03001BNE9i00QBN@03001BVU:J00UBVP800003Hgd005ll00]O?0<001Qoo`03001oogoo
015oo`03001oogoo00]oo`0097oo00<007ooOol0>7oo00<004LOAal02DLO0`003E]N00<005lLGa`0
15lL1P002EKl00<0036i<KT01S6i00<005ifGWH02eif00@006?CHm<000ARfP03001FN000008000MB
VP03001BNE9i00UBN@03001BVU:J00IBVP8000ASO@03001O?5ll00MO?08001]oo`03001oogoo015o
o`03001oogoo00]oo`009Goo00<007ooOol0>7oo00<004LOAal01DLO0`000U<N0P0035]N1`001Dkm
00<005KlE_`025Kl00<0036i<KT01S6i00<005ifGWH02Eif00@006?CHm<000ARfP<000]BVP03001B
NE9i00QBN@03001BVU:J00ABVP8000MSO@03001O?5ll00=O?0<001ioo`03001oogoo011oo`03001o
ogoo00]oo`009Woo00<007ooOol0>7oo0P000TLO0`001e<N0P001e]N0`000Tkm00<004kmC_d024km
00<005KlE_`01eKl00<0036i<KT01S6i00<005ifGWH02Eif00D006?CHm<006;J00<0009Fg003001B
VU:J00UBVP03001BNE9i00UBN@04001BVU:JDYX2000:Hgd00`00GcaO?002000ROol00`00Oomoo`0@
Ool00`00Oomoo`0:Ool002Moo`8003Yoo`8000aC7P80009KGP<000I>o@03001>oDkm00Q>o@03001F
o5Kl00MFo003000a^C6i00Da^@03001NMUif00QNMP03001Sdf?C00<000EFg003001BVU:J00UBVP03
001BNE9i00UBN@04001BVP00000<Hgd3000TOol00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Uoo`03
001oogoo03Qoo`8000aC7P<000Y>o@03001>oDkm00Q>o@03001Fo5Kl00=Fo0@000Pa^@03001NMUif
00INMP04001Sdf?C0009E]`00`00DYYBVP09DYX00`00DWUBN@09DWT00`00HgeSO@0:Hgd2000XOol0
0`00Oomoo`0?Ool00`00Oomoo`0:Ool002Yoo`03001oogoo03Uoo`03001C7U<N00IC7P<0009G7@03
001>oDkm00U>o@03001>oDkm00Q>o@03001Fo5Kl008000AG?P03000a^C6i00Da^@03001NMUif00EN
MP04001Sdf?C000;E]`00`00DYYBVP08DYX00`00DWUBN@07DWT200000e]n001SO@08Hgd2000[Ool0
0`00Oomoo`0>Ool00`00Oomoo`0:Ool002]oo`03001oogoo03Uoo`80009C7P@000IG7@03001>oDkm
00U>o@03001>oDkm00A>o@H000MG?P8000Da^@03001NMUif00ENMP04001Sd`00000;E]`00`00DYYB
VP09DYX00`00DWUBN@04DWT20004Fgh20005Hgd2000^Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool0
02aoo`8003]oo`8000]G7@8000Q>o@P000E:o@8000QG?P03000a^C6i00<a^@03001NMUif00=NMP03
001Sd`00009G7@03001Fg5KL00UFg003001BVU:J00QBVP03001BNE9i009BN@8000QKOP03001SOF=m
0080031oo`03001oogoo00eoo`03001oogoo00Yoo`00;Woo00<007ooOol0>Goo00<005LMEad02eLM
00@004kmC_e>o@@000=>g003001:oD[m00U:o@03001G?ULn00IG?P03000a^C6i008a^@03001NMUif
009NMP03001Sd`0000AG7@03001Fg5KL00UFg003001BVU:J00QBVP04001BN@00000:Fgh3000cOol0
0`00Oomoo`0<Ool00`00Oomoo`0:Ool002moo`03001oogoo03Uoo`03001G7ELM00YG7@@000Q>g003
001:oD[m00U:o@80009G?P@00003Ech0000000<a^@04001NMUifGWH20006Ead00`00E]aFg008E]`0
0`00DYYBVP04DYX6000:Fgh2000gOol00`00Oomoo`0;Ool00`00Oomoo`0:Ool0031oo`03001oogoo
03Uoo`03001G7ELM00MG7@80009Fo003001>g4kL00Q>g003001:oD[m00U:o@<000MG?P04000a^C6i
0002GWH20007Ead00`00E]aFg004E]`;0005Bcl20006Fgh3000jOol00`00Oomoo`0;Ool00`00Oomo
o`09Ool0035oo`8003Yoo`03001G7ELM00=G7@<000AFo003001>g4kL00U>g003001:oD[m00E:o@<0
009Fo@03001G?ULn00IG?P04000a^@00GWHA0006@]h00`00Bcm;?`09Bcl20002Fgh2000mOol00`00
Oomoo`0;Ool00`00Oomoo`09Ool003=oo`03001oogoo03Qoo`03001G7ELM008000QFo003001>g4kL
00U>g003001:oD[m00@000IFo@8000MG?P@00003D_`004[M00Q:g@030012gT;N00U2gP8000U;?`@0
041oo`03001oogoo00Yoo`03001oogoo00Uoo`00=7oo00<007ooOol0>7oo0P002eKl00<004kLC]`0
24kL0`0035Km00<005LnEch010000U;l00D005;lD_aBo00000U:g@8000]2gP04001;?d/oBcl50015
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool003Eoo`03001oogoo03Qoo`03001Fo5Kl00YFo003001>
g4kL00A>g0<0009Fo003001FoEKm00YFo@<000]Bo003001:gD[M00Q:g@030012gT;N00A2gPP004Yo
o`03001oogoo00Uoo`03001oogoo00Uoo`00=Woo00<007ooOol0>7oo00<005KlE_`02EKl00<004kL
C]`010001UKl00<005KmE_d01eKm0P000U/L00<005;lD_`02U;l00<004[MB]d01T[M2000Dgoo00<0
07ooOol027oo00<007ooOol02Goo000gOol2000iOol00`00E_aFo008E_`3000;E_`20005E_d20005
Fa`00`00D_aBo00:D_`01000B]e:gD[M1000G7oo00<007ooOol01goo00<007ooOol02Goo000iOol0
0`00Oomoo`0gOol00`00E_aFo004E_`30002E_`00`00E_aFo00;E_`00`00E_eFo@020008Fa`00`00
D_aBo009D_`4001QOol00`00Oomoo`07Ool00`00Oomoo`08Ool003Yoo`03001oogoo03Moo`03001F
o5Kl00<000IFo003001Fo5Kl00YFo0<000]K7003001Bo5;l00EBo0<006Eoo`03001oogoo00Moo`03
001oogoo00Qoo`00>goo00<007ooOol0=goo0P002UKl00<005KlE_`01eKl0P000ULM00<005/LFa`0
2U/L00<005;lD_`01000JGoo00<007ooOol01Woo00<007ooOol027oo000lOol2000hOol00`00E_aF
o009E_`00`00E_aFo003E_`30005Ead00`00FaaK7009Fa`3001^Ool00`00Oomoo`05Ool00`00Oomo
o`08Ool003ioo`03001oogoo03Ioo`03001Fo5Kl00UFo003001Fo5Kl008000UG7@03001K75/L00EK
70<0079oo`03001oogoo00Aoo`03001oogoo00Qoo`00?goo00<007ooOol0=Woo0P0025Kl100035LM
00<005/LFa`01000MGoo00<007ooOol017oo00<007ooOol027oo0010Ool00`00Oomoo`0gOol01000
E_aFo5Kl10000e;m00<005LMEad02ULM0`00NWoo00<007ooOol00goo00<007ooOol027oo0011Ool2
000hOol30008D_d00`00EaeG7@07Ead2001nOol00`00Oomoo`03Ool00`00Oomoo`07Ool004=oo`03
001oogoo03Ioo`03001BoE;m00QBo@8000EG7@80081oo`03001oogoo00=oo`03001oogoo00Moo`00
A7oo00<007ooOol0=Woo00<005;mD_d02E;m00<005LMEad00P00Pgoo00<007ooOol00Woo00<007oo
Ool01goo0015Ool00`00Oomoo`0fOol00`00D_eBo@07D_d40026Ool01@00Oomoogoo00002Goo0016
Ool00`00Oomoo`0fOol01000D_eBoE;m1@00Rgoo00@007ooOol000Uoo`00Agoo0P00=goo0`00T7oo
00@007ooOol000Uoo`00BGoo00<007ooOol0=Goo00<007ooOol0T7oo00<007oo00002Goo001:Ool0
0`00Oomoo`0dOol00`00Oomoo`2AOol00`00Ool00008Ool004]oo`03001oogoo03=oo`03001oogoo
099oo`8000Qoo`00C7oo0P00<goo00<007ooOol0TWoo0P0027oo001>Ool00`00Oomoo`0_Ool00`00
Oomoo`2COol20008Ool004moo`03001oogoo02ioo`03001oogoo08moo`@000Yoo`00D7oo00<007oo
Ool0;Goo00<007ooOol0Rgoo10003Woo001AOol2000]Ool00`00Oomoo`27Ool4000BOol005=oo`03
001oogoo02Yoo`03001oogoo08=oo`@001Ioo`00E7oo00<007ooOol0:Goo00<007ooOol0P7oo0`00
6Woo001EOol00`00Oomoo`0XOol00`00Oomoo`1lOol4000MOol005Ioo`03001oogoo02Moo`03001o
ogoo07Qoo`@0025oo`00Egoo0P009goo00<007ooOol0M7oo10009Goo001IOol00`00Oomoo`0TOol0
0`00Oomoo`1`Ool4000YOol005Yoo`03001oogoo02=oo`03001oogoo06eoo`<002eoo`00Fgoo00<0
07ooOol08Woo00<007ooOol0JGoo1000<7oo001LOol2000ROol00`00Oomoo`1UOol4000dOol005io
o`03001oogoo01moo`03001oogoo065oo`@003Qoo`00Ggoo00<007ooOol07Woo00<007ooOol0GGoo
1000?7oo001POol00`00Oomoo`0MOol00`00Oomoo`1JOol30010Ool0065oo`8001eoo`03001oogoo
05Ioo`@004=oo`00Hgoo00<007ooOol06Woo00<007ooOol0DWoo1000Agoo001TOol00`00Oomoo`0I
Ool00`00Oomoo`1>Ool4001;Ool006Eoo`03001oogoo01Qoo`03001oogoo04Yoo`@004moo`00IWoo
00<007ooOol05goo00<007ooOol0Agoo0`00Dgoo001WOol2000GOol00`00Oomoo`13Ool4001FOol0
06Uoo`03001oogoo01Aoo`03001oogoo03moo`@005Yoo`00JWoo00<007ooOol04goo00<007ooOol0
>goo1000GWoo001[Ool00`00Oomoo`0BOol00`00Oomoo`0gOol4001ROol006aoo`80019oo`03001o
ogoo03Aoo`<006Ioo`00KWoo00<007ooOol03goo00<007ooOol0<7oo1000JGoo001_Ool00`00Oomo
o`0=Ool00`00Oomoo`0]Ool4001]Ool0071oo`03001oogoo00aoo`03001oogoo02Uoo`@0075oo`00
LGoo0P0037oo00<007ooOol09Goo1000MGoo001cOol00`00Oomoo`09Ool00`00Oomoo`0ROol3001i
Ool007Aoo`03001oogoo00Qoo`03001oogoo01ioo`@007aoo`00MGoo00<007ooOol01goo00<007oo
Ool06Woo1000P7oo001fOol00`00Oomoo`06Ool00`00Oomoo`0FOol40024Ool007Moo`8000Ioo`03
001oogoo019oo`@008Qoo`00NGoo00<007ooOol00goo00<007ooOol03goo0`00S7oo001jOol00`00
Oomoo`02Ool00`00Oomoo`0;Ool4002?Ool007]oo`05001oogooOol00009Ool4002COol007aoo`80
0003Ool007oo00Aoo`@009Moo`00OWoo0P0000=oo`0000000P00Vgoo001oOol2002OOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0992945, -0.00857701, 
  0.00376239, 0.00376239}}]
}, Open  ]],

Cell[TextData[{
  StyleBox[
  "The stopband attenuation of the filter shown above is very poor. To \
demonstrate this we compute the magnitude response of "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h\)]]],
  StyleBox["."]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListMagnitudePlot[h]; \)\)], "Input",
  CellLabel->"In[45]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.90476 0.596932 0.0067794 [
[.21429 .58443 -9 -9 ]
[.21429 .58443 9 0 ]
[.40476 .58443 -9 -9 ]
[.40476 .58443 9 0 ]
[.59524 .58443 -9 -9 ]
[.59524 .58443 9 0 ]
[.78571 .58443 -9 -9 ]
[.78571 .58443 9 0 ]
[.97619 .58443 -9 -9 ]
[.97619 .58443 9 0 ]
[.01131 .05458 -18 -4.5 ]
[.01131 .05458 0 4.5 ]
[.01131 .19017 -18 -4.5 ]
[.01131 .19017 0 4.5 ]
[.01131 .32576 -18 -4.5 ]
[.01131 .32576 0 4.5 ]
[.01131 .46134 -18 -4.5 ]
[.01131 .46134 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .59693 m
.21429 .60318 L
s
[(0.1)] .21429 .58443 0 1 Mshowa
.40476 .59693 m
.40476 .60318 L
s
[(0.2)] .40476 .58443 0 1 Mshowa
.59524 .59693 m
.59524 .60318 L
s
[(0.3)] .59524 .58443 0 1 Mshowa
.78571 .59693 m
.78571 .60318 L
s
[(0.4)] .78571 .58443 0 1 Mshowa
.97619 .59693 m
.97619 .60318 L
s
[(0.5)] .97619 .58443 0 1 Mshowa
.125 Mabswid
.0619 .59693 m
.0619 .60068 L
s
.1 .59693 m
.1 .60068 L
s
.1381 .59693 m
.1381 .60068 L
s
.17619 .59693 m
.17619 .60068 L
s
.25238 .59693 m
.25238 .60068 L
s
.29048 .59693 m
.29048 .60068 L
s
.32857 .59693 m
.32857 .60068 L
s
.36667 .59693 m
.36667 .60068 L
s
.44286 .59693 m
.44286 .60068 L
s
.48095 .59693 m
.48095 .60068 L
s
.51905 .59693 m
.51905 .60068 L
s
.55714 .59693 m
.55714 .60068 L
s
.63333 .59693 m
.63333 .60068 L
s
.67143 .59693 m
.67143 .60068 L
s
.70952 .59693 m
.70952 .60068 L
s
.74762 .59693 m
.74762 .60068 L
s
.82381 .59693 m
.82381 .60068 L
s
.8619 .59693 m
.8619 .60068 L
s
.9 .59693 m
.9 .60068 L
s
.9381 .59693 m
.9381 .60068 L
s
.25 Mabswid
0 .59693 m
1 .59693 L
s
.02381 .05458 m
.03006 .05458 L
s
[(-80)] .01131 .05458 1 0 Mshowa
.02381 .19017 m
.03006 .19017 L
s
[(-60)] .01131 .19017 1 0 Mshowa
.02381 .32576 m
.03006 .32576 L
s
[(-40)] .01131 .32576 1 0 Mshowa
.02381 .46134 m
.03006 .46134 L
s
[(-20)] .01131 .46134 1 0 Mshowa
.125 Mabswid
.02381 .08848 m
.02756 .08848 L
s
.02381 .12237 m
.02756 .12237 L
s
.02381 .15627 m
.02756 .15627 L
s
.02381 .22407 m
.02756 .22407 L
s
.02381 .25796 m
.02756 .25796 L
s
.02381 .29186 m
.02756 .29186 L
s
.02381 .35965 m
.02756 .35965 L
s
.02381 .39355 m
.02756 .39355 L
s
.02381 .42745 m
.02756 .42745 L
s
.02381 .49524 m
.02756 .49524 L
s
.02381 .52914 m
.02756 .52914 L
s
.02381 .56304 m
.02756 .56304 L
s
.02381 .02068 m
.02756 .02068 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60096 m
.02499 .60096 L
.02605 .60096 L
.02729 .60095 L
.02846 .60094 L
.03053 .60091 L
.03279 .60086 L
.03527 .6008 L
.0379 .60072 L
.04262 .60054 L
.05205 .60002 L
.06244 .59925 L
.08274 .59729 L
.10458 .59494 L
.11537 .59389 L
.12562 .59306 L
.13007 .59277 L
.13482 .59252 L
.13755 .5924 L
.14003 .59231 L
.14253 .59223 L
.14366 .59221 L
.14487 .59218 L
.14606 .59216 L
.14719 .59215 L
.14783 .59214 L
.14853 .59214 L
.14974 .59213 L
.15104 .59213 L
.15169 .59213 L
.15242 .59213 L
.15369 .59214 L
.15489 .59216 L
.15602 .59217 L
.15721 .59219 L
.15933 .59224 L
.16161 .59231 L
.16411 .59241 L
.16933 .59267 L
.1749 .59304 L
.18493 .59392 L
.20628 .59646 L
.22643 .59919 L
.24475 .60141 L
.24977 .60191 L
.25516 .60237 L
.25982 .60271 L
.2649 .603 L
.26766 .60312 L
.27023 .60321 L
Mistroke
.27268 .60327 L
.27404 .60329 L
.27528 .60331 L
.27651 .60332 L
.27763 .60332 L
.27887 .60332 L
.28017 .60331 L
.28131 .60329 L
.28237 .60328 L
.28353 .60325 L
.28477 .60322 L
.28749 .60312 L
.29043 .60297 L
.29579 .60261 L
.301 .60212 L
.30582 .60154 L
.31547 .6 L
.32452 .59806 L
.33445 .59535 L
.34514 .5917 L
.36521 .58254 L
.38633 .56913 L
.40611 .55212 L
.42449 .53113 L
.43504 .5159 L
.44499 .49849 L
.45392 .47917 L
.45891 .4661 L
.46359 .45173 L
.46855 .43303 L
.47308 .41086 L
.47566 .39443 L
.4781 .37427 L
.47945 .36004 L
.48069 .34341 L
.48205 .31825 L
.48274 .30029 L
.4835 .27146 L
.48413 .22862 L
.48483 .11782 L
.48555 .2456 L
.48622 .28055 L
.48743 .3146 L
.48872 .33665 L
.48945 .34596 L
.49024 .35446 L
.49167 .36695 L
.49436 .38404 L
.49693 .39587 L
.49966 .40543 L
Mistroke
.50456 .41777 L
.50708 .42249 L
.50948 .4262 L
.51398 .43158 L
.51649 .43384 L
.51882 .43555 L
.52138 .43702 L
.5228 .43767 L
.52411 .43818 L
.52524 .43855 L
.52648 .43888 L
.52773 .43914 L
.52905 .43933 L
.53021 .43943 L
.53146 .43948 L
.53264 .43947 L
.53371 .4394 L
.53482 .43929 L
.53585 .43914 L
.53698 .43892 L
.53818 .43864 L
.54019 .43805 L
.54241 .43721 L
.54733 .4347 L
.55251 .43108 L
.56177 .42195 L
.56694 .41519 L
.57174 .40762 L
.57697 .39765 L
.58263 .38419 L
.58812 .36733 L
.59052 .35816 L
.59317 .34626 L
.5955 .33355 L
.598 .31628 L
.59938 .30425 L
.60064 .29077 L
.6019 .27344 L
.60311 .25071 L
.60428 .21511 L
.60534 .13557 L
.60657 .18336 L
.60773 .2333 L
.6088 .25806 L
.60978 .27397 L
.61086 .28737 L
.612 .29863 L
.6144 .31647 L
.61663 .32879 L
.61908 .33937 L
Mistroke
.6217 .34842 L
.62701 .362 L
.63191 .37085 L
.63729 .37781 L
.64 .38048 L
.643 .38289 L
.64556 .38454 L
.648 .3858 L
.64935 .38637 L
.65082 .3869 L
.65217 .38729 L
.65339 .38759 L
.65465 .38783 L
.65584 .38799 L
.65709 .3881 L
.65779 .38814 L
.65844 .38815 L
.65953 .38814 L
.66072 .38808 L
.66197 .38795 L
.66313 .38779 L
.66439 .38755 L
.66573 .38723 L
.66813 .3865 L
.67072 .38548 L
.67358 .38407 L
.67868 .3808 L
.68348 .37682 L
.6924 .36676 L
.69742 .35933 L
.70203 .3511 L
.70713 .33999 L
.71195 .32687 L
.71461 .31811 L
.7175 .3069 L
.7199 .29572 L
.72255 .28053 L
.72504 .26178 L
.72623 .25027 L
.72737 .23692 L
.72866 .21716 L
.72983 .1909 L
.7311 .13738 L
.73182 .03354 L
.73248 .10636 L
.73368 .1767 L
.73481 .20605 L
.73582 .22359 L
.73692 .23785 L
.73811 .25009 L
Mistroke
.73938 .26054 L
.74164 .27517 L
.74402 .28692 L
.74618 .29552 L
.75104 .31008 L
.75555 .31975 L
.75981 .32663 L
.76477 .3326 L
.76936 .33659 L
.77175 .33819 L
.77439 .33961 L
.77715 .34074 L
.7784 .34114 L
.77974 .34149 L
.78102 .34176 L
.78218 .34195 L
.78334 .34208 L
.78444 .34216 L
.78573 .34219 L
.78691 .34216 L
.78821 .34207 L
.78887 .342 L
.78959 .34191 L
.79094 .34168 L
.79217 .34142 L
.79494 .34064 L
.79751 .33967 L
.79995 .33854 L
.80455 .33585 L
.80881 .33268 L
.81345 .32846 L
.81846 .32295 L
.82807 .30913 L
.8371 .29104 L
.84232 .27727 L
.84783 .25861 L
.85254 .23711 L
.8552 .22093 L
.85769 .20118 L
.85896 .18815 L
.8603 .17064 L
.86145 .15051 L
.86272 .1164 L
.86343 .08309 L
.86408 .01472 L
.86483 .03851 L
.86554 .09391 L
.86681 .13646 L
.86752 .15123 L
.86819 .1621 L
Mistroke
.86948 .17855 L
.87071 .19039 L
.87299 .207 L
.87545 .22006 L
.87811 .23077 L
.88281 .24439 L
.88518 .24952 L
.88779 .25419 L
.89239 .26052 L
.89669 .2647 L
.89929 .26658 L
.90169 .26795 L
.90434 .26909 L
.90567 .26952 L
.90714 .26991 L
.90842 .27016 L
.9096 .27034 L
.91089 .27046 L
.91154 .2705 L
.91225 .27052 L
.91345 .27051 L
.91473 .27045 L
.91594 .27033 L
.91704 .27019 L
.91943 .26973 L
.92163 .26917 L
.92659 .26741 L
.93097 .26538 L
.9356 .26284 L
.95387 .25112 L
.95913 .24807 L
.96413 .24569 L
.9663 .24487 L
.96861 .24415 L
.96994 .24381 L
.97115 .24357 L
.97236 .24337 L
.9735 .24323 L
.97479 .24313 L
.97552 .2431 L
.97619 .2431 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0
ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0
ggoo00<007ooOol09Woo000EOol2003POol00`00Oomoo`0VOol001Eoo`03001oogoo0=moo`03001o
ogoo02Ioo`005Goo00<007ooOol0ggoo00<007ooOol09Woo000EOol00`00Oomoo`3OOol00`00Oomo
o`0VOol001Eoo`03001oogoo0;aoo`03001oogoo021oo`03001oogoo02Ioo`005Goo00<007ooOol0
_7oo00<007ooOol087oo00<007ooOol09Woo000EOol00`00Oomoo`2lOol00`00Oomoo`0POol00`00
Oomoo`0VOol000Yoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0;aoo`03001oogoo021o
o`03001oogoo02Ioo`002Goo00<007oo00000Woo00<007oo000017oo00<007ooOol0_7oo00<007oo
Ool087oo00<007ooOol09Woo0004Ool30002Ool00`00Ool00002Ool00`00Ool00004Ool3002lOol0
0`00Oomoo`0POol00`00Oomoo`0VOol000Yoo`07001oogooOol007oo000017oo00<007ooOol0_7oo
00<007ooOol087oo00<007ooOol09Woo0009Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomo
o`2lOol00`00Oomoo`0POol00`00Oomoo`0VOol000Yoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo0;aoo`03001oogoo021oo`03001oogoo02Ioo`005Goo00<007ooOol0_7oo00<007ooOol0
87oo0P009goo000EOol00`00Oomoo`2lOol00`00Oomoo`0POol2000WOol001Eoo`03001oogoo0;ao
o`03001oogoo021oo`8002Moo`005Goo00<007ooOol0_7oo00<007ooOol087oo0P009goo000EOol0
0`00Oomoo`2lOol00`00Oomoo`0POol2000WOol001Eoo`03001oogoo0;]oo`80029oo`8002Moo`00
5Goo0P00_7oo0P008Woo0P009goo000EOol00`00Oomoo`2kOol2000ROol2000WOol001Eoo`03001o
ogoo0;]oo`80029oo`8002Moo`005Goo00<007ooOol0^goo0P008Woo0P009goo000EOol00`00Oomo
o`2kOol2000ROol2000WOol001Eoo`03001oogoo0;]oo`80029oo`8002Moo`005Goo00<007ooOol0
^goo0P008Woo0P009goo000EOol00`00Oomoo`2kOol2000ROol2000WOol001Eoo`03001oogoo07Uo
o`03001oogoo03moo`80029oo`8002Moo`005Goo0P00NWoo00<007ooOol0?goo0P008Woo0P009goo
000EOol00`00Oomoo`1iOol00`00Oomoo`0oOol2000ROol2000WOol001Eoo`03001oogoo07Uoo`03
001oogoo03moo`80029oo`8002Moo`005Goo00<007ooOol0NGoo00<007ooOol07Woo00<007ooOol0
7Woo0P008Woo0P009goo000EOol00`00Oomoo`1iOol00`00Oomoo`0NOol00`00Oomoo`0NOol2000R
Ool2000WOol001Eoo`03001oogoo07Uoo`03001oogoo01ioo`03001oogoo01ioo`80029oo`8002Mo
o`005Goo00<007ooOol0NGoo00<007ooOol07Woo00<007ooOol07Woo0P008Woo0P009goo000EOol0
0`00Oomoo`1iOol00`00Oomoo`0NOol00`00Oomoo`0NOol2000ROol2000WOol001Eoo`03001oogoo
07Uoo`03001oogoo01ioo`03001oogoo01ioo`80029oo`8002Moo`005Goo0P00NWoo00<007ooOol0
7Woo00<007ooOol07Woo0P008Woo0P009goo000EOol00`00Oomoo`1iOol00`00Oomoo`0NOol00`00
Oomoo`0NOol2000QOol00`00Ool0000WOol001Eoo`03001oogoo07Uoo`03001oogoo01ioo`03001o
ogoo01ioo`80025oo`03001oo`0002Moo`005Goo00<007ooOol0NGoo00<007ooOol07Woo00<007oo
Ool07Woo0P008Goo00<007oo00009goo000EOol00`00Oomoo`1iOol00`00Oomoo`0NOol00`00Oomo
o`0NOol2000QOol01000Oomoo`009Woo000EOol00`00Oomoo`1iOol00`00Oomoo`0MOol2000POol2
000QOol01000Oomoo`009Woo000EOol00`00Oomoo`1iOol00`00Oomoo`0MOol2000POol2000QOol0
1000Oomoo`009Woo0009Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`1iOol00`00Oomoo`0MOol2
000POol2000QOol01000Oomoo`009Woo0009Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomo
o`1iOol00`00Oomoo`0MOol2000POol2000QOol01000Oomoo`009Woo0004Ool30002Ool00`00Ool0
0002Ool00`00Ool00004Ool3001iOol00`00Oomoo`0MOol2000POol2000QOol01000Oomoo`009Woo
0009Ool20003Ool00`00Ool00004Ool00`00Oomoo`1iOol00`00Oomoo`0MOol2000POol2000QOol0
1000Oomoo`009Woo0009Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`1iOol00`00Oomo
o`0MOol2000POol2000QOol01000Oomoo`009Woo000:Ool20003Ool00`00Oomoo`03Ool00`00Oomo
o`1iOol00`00Oomoo`0MOol2000POol2000QOol01@00Oomoogoo00009Goo000EOol00`00Oomoo`1i
Ool00`00Oomoo`0MOol2000POol2000QOol01@00Oomoogoo00009Goo000EOol00`00Oomoo`1iOol0
0`00Oomoo`0MOol2000POol2000QOol01@00Oomoogoo00009Goo000EOol00`00Oomoo`1iOol00`00
Oomoo`0MOol2000POol2000POol00`00Oomoo`02Ool00`00Oomoo`0SOol001Eoo`03001oogoo07Uo
o`03001oogoo01eoo`80021oo`03001oo`0001moo`03001oogoo009oo`03001oogoo02=oo`005Goo
00<007ooOol0NGoo00<007ooOol07Goo0P0087oo00<007oo00007goo00<007ooOol00Woo00<007oo
Ool08goo000EOol2001jOol00`00Oomoo`0MOol2000POol00`00Ool0000OOol00`00Oomoo`02Ool0
0`00Oomoo`0SOol001Eoo`03001oogoo07Uoo`03001oogoo01eoo`8001moo`04001oogoo000OOol0
0`00Oomoo`03Ool00`00Oomoo`0ROol001Eoo`03001oogoo07Uoo`03001oogoo01eoo`8001moo`04
001oogoo000NOol00`00Oomoo`04Ool00`00Oomoo`0ROol001Eoo`03001oogoo07Uoo`03001oogoo
01eoo`8001moo`04001oogoo000NOol00`00Oomoo`04Ool00`00Oomoo`0ROol001Eoo`03001oogoo
07Uoo`03001oogoo01eoo`8001moo`04001oogoo000NOol00`00Oomoo`04Ool00`00Oomoo`0ROol0
01Eoo`03001oogoo07Uoo`03001oogoo01eoo`8001moo`04001oogoo000NOol00`00Oomoo`05Ool0
0`00Oomoo`0EOol30009Ool001Eoo`03001oogoo07Uoo`03001oogoo01eoo`8001moo`04001oogoo
000NOol00`00Oomoo`05Ool00`00Oomoo`0COol2000<Ool001Eoo`03001oogoo07Uoo`03001oogoo
01eoo`03001oo`0001ioo`04001oogoo000MOol00`00Oomoo`07Ool00`00Oomoo`0?Ool3000>Ool0
01Eoo`03001oogoo07Uoo`03001oogoo01eoo`03001oo`0001ioo`04001oogoo000MOol00`00Oomo
o`08Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool001Eoo`8007Yoo`03001oogoo01eoo`03001oo`00
01ioo`05001oogooOol0000LOol00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool001Eo
o`03001oogoo07Uoo`03001oogoo01eoo`03001oo`0001ioo`05001oogooOol0000LOol00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol001Eoo`03001oogoo07Uoo`03001oogoo01eoo`03
001oo`0001ioo`05001oogooOol0000KOol00`00Oomoo`0;Ool00`00Oomoo`06Ool3000DOol001Eo
o`03001oogoo07Uoo`03001oogoo01eoo`03001oo`0001ioo`05001oogooOol0000KOol00`00Oomo
o`0<Ool30002Ool3000GOol001Eoo`03001oogoo07Uoo`03001oogoo01eoo`03001oo`0001eoo`03
001oogoo009oo`03001oogoo01Qoo`03001oogoo00moo`@001Uoo`005Goo00<007ooOol0NGoo00<0
07ooOol07Goo00<007oo00007Goo00<007ooOol00Woo00<007ooOol067oo00<007ooOol0;7oo000E
Ool00`00Oomoo`1iOol00`00Oomoo`0MOol00`00Ool0000MOol00`00Oomoo`02Ool00`00Oomoo`0H
Ool00`00Oomoo`0/Ool001Eoo`03001oogoo07Uoo`03001oogoo01aoo`04001oogoo000MOol00`00
Oomoo`03Ool00`00Oomoo`0FOol00`00Oomoo`0]Ool001Eoo`03001oogoo07Uoo`03001oogoo01ao
o`04001oogoo000LOol00`00Oomoo`04Ool00`00Oomoo`0FOol00`00Oomoo`0]Ool001Eoo`8007Yo
o`03001oogoo01aoo`04001oogoo000LOol00`00Oomoo`04Ool00`00Oomoo`0FOol00`00Oomoo`0]
Ool001Eoo`03001oogoo07Uoo`03001oogoo01aoo`04001oogoo000LOol00`00Oomoo`05Ool00`00
Oomoo`0EOol00`00Oomoo`0]Ool001Eoo`03001oogoo07Uoo`03001oogoo01aoo`04001oogoo000L
Ool00`00Oomoo`05Ool00`00Oomoo`0DOol00`00Oomoo`0^Ool001Eoo`03001oogoo07Uoo`8001eo
o`04001oogoo000LOol00`00Oomoo`05Ool00`00Oomoo`0DOol00`00Oomoo`0^Ool001Eoo`03001o
ogoo07Uoo`8001eoo`04001oogoo000LOol00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0_
Ool001Eoo`03001oogoo07Uoo`8001eoo`05001oogooOol0000KOol00`00Oomoo`06Ool00`00Oomo
o`0BOol00`00Oomoo`0_Ool001Eoo`03001oogoo07Qoo`03001oo`0001eoo`05001oogooOol0000J
Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0`Ool001Eoo`03001oogoo07Qoo`03001o
o`0001eoo`05001oogooOol0000JOol00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0aOol0
00Yoo`<0009oo`03001oogoo00=oo`03001oogoo07Qoo`03001oo`0001eoo`05001oogooOol0000J
Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0aOol000]oo`06001oogoo001oo`0017oo
00<007ooOol0N7oo00<007oo00007Goo00<007ooOol00Woo00<007ooOol05Woo00<007ooOol02Goo
00<007ooOol03Woo00<007ooOol0<Woo0004Ool30002Ool4000017oo001oo`0017oo0`00N7oo00<0
07oo000077oo00<007ooOol00goo00<007ooOol05Woo00<007ooOol02Woo00<007ooOol037oo00<0
07ooOol0<goo0009Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`1hOol00`00Ool0000L
Ool00`00Oomoo`03Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool2000:Ool2000fOol000Yoo`80009o
o`03001oo`0000Aoo`03001oogoo07Qoo`03001oo`0001aoo`03001oogoo00=oo`03001oogoo01Eo
o`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo03Ioo`002goo00D007ooOomoo`0000Eoo`03
001oogoo07Qoo`03001oo`0001aoo`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo00ioo`80
00Eoo`8003Uoo`005Goo00<007ooOol0N7oo00<007oo00006goo00<007ooOol017oo00<007ooOol0
5Goo00<007ooOol047oo1P00>Woo000EOol00`00Oomoo`1hOol00`00Ool0000KOol00`00Oomoo`05
Ool00`00Oomoo`0COol00`00Oomoo`1AOol001Eoo`03001oogoo07Qoo`03001oo`0001]oo`03001o
ogoo00Eoo`03001oogoo01=oo`03001oogoo055oo`005Goo00<007ooOol0N7oo00@007ooOol001Yo
o`03001oogoo00Eoo`03001oogoo019oo`03001oogoo059oo`005Goo00<007ooOol0N7oo00@007oo
Ool001Yoo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo059oo`005Goo0P00NGoo00@007oo
Ool001Yoo`03001oogoo00Ioo`03001oogoo011oo`03001oogoo05=oo`005Goo00<007ooOol0N7oo
00@007ooOol001Uoo`03001oogoo00Qoo`03001oogoo00ioo`03001oogoo05Aoo`005Goo00<007oo
Ool0Mgoo00D007ooOomoo`0001Uoo`03001oogoo00Qoo`03001oogoo00ioo`03001oogoo05Aoo`00
5Goo00<007ooOol0Mgoo00D007ooOomoo`0001Qoo`03001oogoo00Yoo`03001oogoo00aoo`03001o
ogoo05Eoo`005Goo00<007ooOol0Mgoo00D007ooOomoo`0001Qoo`03001oogoo00Yoo`03001oogoo
00]oo`03001oogoo05Ioo`005Goo00<007ooOol0Mgoo00<007ooOol00Woo00<007ooOol057oo00<0
07ooOol037oo0P002Goo0P00FGoo000EOol00`00Oomoo`1gOol00`00Oomoo`02Ool00`00Oomoo`0D
Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`1IOol001Eoo`03001oogoo07Moo`03001o
ogoo009oo`03001oogoo01Aoo`03001oogoo00moo`L005aoo`005Goo00<007ooOol0Mgoo00<007oo
Ool00Woo00<007ooOol04goo00<007ooOol0Lgoo000EOol2001hOol00`00Oomoo`02Ool00`00Oomo
o`0COol00`00Oomoo`1cOol001Eoo`03001oogoo07Moo`03001oogoo009oo`03001oogoo01=oo`03
001oogoo07=oo`005Goo00<007ooOol0MWoo00<007ooOol017oo00<007ooOol04Woo00<007ooOol0
Lgoo000EOol00`00Oomoo`1fOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`1dOol001Eo
o`03001oogoo07Ioo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo07Aoo`005Goo00<007oo
Ool0MWoo00<007ooOol01Goo00<007ooOol03goo00<007ooOol0MGoo000EOol00`00Oomoo`1fOol0
0`00Oomoo`05Ool00`00Oomoo`0>Ool00`00Oomoo`1fOol001Eoo`03001oogoo07Eoo`03001oogoo
00Ioo`03001oogoo00eoo`03001oogoo07Moo`005Goo00<007ooOol0MGoo00<007ooOol01goo00<0
07ooOol02goo00<007ooOol0N7oo000EOol2001fOol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`1iOol001Eoo`03001oogoo07Eoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo07Yo
o`005Goo00<007ooOol0MGoo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0Ngoo000EOol0
0`00Oomoo`1dOol00`00Oomoo`0<Ool7001nOol001Eoo`03001oogoo07Aoo`03001oogoo095oo`00
5Goo00<007ooOol0Lgoo00<007ooOol0TWoo000EOol00`00Oomoo`1cOol00`00Oomoo`2BOol000Uo
o`<000=oo`03001oogoo00=oo`03001oogoo07=oo`03001oogoo099oo`002Goo00<007ooOol00Woo
00<007oo000017oo00<007ooOol0LWoo00<007ooOol0Tgoo0004Ool30003Ool01`00Oomoogoo001o
o`0000Aoo`<0079oo`03001oogoo09=oo`002Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`1b
Ool00`00Oomoo`2COol000Uoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo079oo`03001o
ogoo09=oo`002Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0LGoo00<007ooOol0U7oo
000EOol00`00Oomoo`1aOol00`00Oomoo`2DOol001Eoo`03001oogoo075oo`03001oogoo09Aoo`00
5Goo00<007ooOol0L7oo00<007ooOol0UGoo000EOol00`00Oomoo`1`Ool00`00Oomoo`2EOol001Eo
o`03001oogoo06moo`03001oogoo09Ioo`005Goo0P00L7oo00<007ooOol0UWoo000EOol00`00Oomo
o`1^Ool00`00Oomoo`2GOol001Eoo`03001oogoo06ioo`03001oogoo09Moo`005Goo00<007ooOol0
KGoo00<007ooOol0V7oo000EOol00`00Oomoo`1]Ool00`00Oomoo`2HOol001Eoo`03001oogoo06ao
o`03001oogoo09Uoo`005Goo00<007ooOol0K7oo00<007ooOol0VGoo000EOol00`00Oomoo`1[Ool0
0`00Oomoo`2JOol001Eoo`03001oogoo06Yoo`03001oogoo09]oo`005Goo0P00Jgoo00<007ooOol0
Vgoo000EOol00`00Oomoo`1YOol00`00Oomoo`2LOol001Eoo`03001oogoo06Qoo`03001oogoo09eo
o`005Goo00<007ooOol0Igoo00<007ooOol0WWoo000EOol00`00Oomoo`1VOol00`00Oomoo`2OOol0
01Eoo`03001oogoo06Ioo`03001oogoo09moo`005Goo00<007ooOol0IGoo00<007ooOol0X7oo000E
Ool00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`05000VOol00`00Oomoo`02Ool20002Ool3
000WOol00`00Oomoo`02Ool01000Oomoogoo0P00:Goo00<007ooOol00Woo00<007ooOol00Woo0`00
9Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo000EOol00`00Oomoo`0ZOol00`00
Ool00008Ool00`00Oomoo`0UOol00`00Ool00003Ool01@00Oomoogoo0000:7oo00<007oo00002Goo
00<007ooOol09Goo00<007oo00002Goo00<007ooOol097oo00<007oo00001goo00<007oo000017oo
000EOol2000[Ool00`00Ool00008Ool00`00Oomoo`0UOol01000Ool007oo0P001Goo00<007ooOol0
9Goo00<007oo000027oo00<007ooOol09Woo00<007oo00001goo10009Goo00<007oo00002Goo00<0
07ooOol00Woo000EOol00`00Oomoo`0ZOol00`00Ool00008Ool00`00Oomoo`0UOol01000Ool00000
1goo00<007ooOol09Goo00<007oo00002Goo00<007ooOol09Goo00<007oo00001goo00<007oo0000
9Woo00<007oo00001goo0P001Goo000EOol00`00Oomoo`0ZOol00`00Ool00008Ool00`00Oomoo`0U
Ool00`00Ool00007Ool00`00Ool0000VOol00`00Ool00007Ool00`00Ool0000WOol00`00Ool00008
Ool2000VOol00`00Ool00007Ool00`00Oomoo`04Ool001Eoo`03001oogoo02]oo`03001oogoo00Io
o`8002Moo`8000Uoo`03001oogoo02Ioo`03001oogoo00Moo`03001oogoo02Moo`03001oogoo00Qo
o`03001oogoo02Eoo`03001oogoo00Ioo`<000Aoo`005Goo00<007ooOol0G7oo00<007ooOol0ZGoo
000EOol00`00Oomoo`1JOol2002/Ool001Eoo`03001oogoo05Qoo`800:ioo`005Goo00<007ooOol0
EGoo0`00/7oo000EOol00`00Oomoo`0JOol;000^Ool2002cOol001Eoo`03001oogoo015oo`T000]o
o``001moo`<00;Eoo`003Wooo`0040000goo000EOol70003Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`03OolE0004Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Oomoo`07Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo
000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0416348, -90.8981, 
  0.00194834, 0.54741}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2: Smoothing with a selected window sequence", "Subsection"],

Cell["\<\
In the typical final step of the design, the truncated impulse response is \
smoothed with a selected window sequence. The Hamming, Blackman and Kaiser \
windows are some of the more commonly used smoothing sequences. A 2D window \
sequence with a square or rectangular region of support is obtained by taking \
the outer product of two 1D sequences:\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`w\_R[n\_1, n\_2]\  = \ w[n\_1]\ \ w[n\_2]\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "Here the function ",
  StyleBox["DiscreteWindow2D", "Program"],
  " will be used to generate a desired 2D window sequence with rectangular \
support (according to Eq. 3). Rectangular region of support is invoked by \
specifying filter length as a list consisting of a pair of integers denoting \
the row and column dimensions of the filter. The desired impulse response is \
a product of ",
  Cell[BoxData[
      \(TraditionalForm\`h\_R\)]],
  " and the window sequence ",
  Cell[BoxData[
      \(TraditionalForm\`w\_R\)]],
  ". Here we choose a Hamming window."
}], "Text"],

Cell[BoxData[
    \(\(hR = \ hR\ *\ DiscreteWindow2D[{15, 15}, \ "\<Hamming\>"]; \)\)], 
  "Input",
  CellLabel->"In[46]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot3D[hR, PlotRange -> All]; \)\)], "Input",
  CellLabel->"In[47]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.19846 .17893 -5.85476 -9 ]
[.19846 .17893 .14524 0 ]
[.42923 .08816 -10.816 -9 ]
[.42923 .08816 1.18401 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.79412 .13786 0 -6.12234 ]
[.79412 .13786 6 2.87766 ]
[.89499 .29234 0 -5.97603 ]
[.89499 .29234 12 3.02397 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[.02091 .28522 -6 -2.7593 ]
[.02091 .28522 0 6.2407 ]
[.01123 .34584 -24 -2.81064 ]
[.01123 .34584 0 6.18936 ]
[.00117 .40889 -18 -2.86424 ]
[.00117 .40889 0 6.13576 ]
[-0.0093 .4745 -24 -2.92025 ]
[-0.0093 .4745 0 6.07975 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.20751 .18843 m
.21203 .19319 L
s
[(5)] .19846 .17893 .95159 1 Mshowa
.43745 .0984 m
.44155 .10351 L
s
[(10)] .42923 .08816 .80266 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(15)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.25192 .17104 m
.25459 .17394 L
s
.2971 .15335 m
.29972 .15629 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.4859 .07942 m
.48831 .08254 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.16384 .20553 m
.1666 .20834 L
s
.12091 .22234 m
.12371 .22511 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78177 .14231 m
.7756 .14454 L
s
[(5)] .79412 .13786 -1 .36052 Mshowa
.88252 .29643 m
.87629 .29847 L
s
[(10)] .89499 .29234 -1 .32801 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(15)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.8032 .17508 m
.79948 .1764 L
s
.82395 .20683 m
.82023 .20812 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.90091 .32455 m
.89716 .32575 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.75965 .10848 m
.75596 .10983 L
s
.7368 .07352 m
.73311 .0749 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03314 .28048 m
.03926 .27811 L
s
[(0)] .02091 .28522 1 -0.38682 Mshowa
.02352 .34123 m
.02966 .33893 L
s
[(0.05)] .01123 .34584 1 -0.37541 Mshowa
.01351 .40441 m
.01967 .40217 L
s
[(0.1)] .00117 .40889 1 -0.3635 Mshowa
.00309 .47016 m
.00928 .46798 L
s
[(0.15)] -0.0093 .4745 1 -0.35106 Mshowa
.125 Mabswid
.03125 .29244 m
.03492 .29103 L
s
.02934 .3045 m
.03301 .30309 L
s
.02741 .31665 m
.03109 .31525 L
s
.02547 .32889 m
.02915 .3275 L
s
.02155 .35367 m
.02523 .35229 L
s
.01956 .3662 m
.02325 .36483 L
s
.01756 .37884 m
.02125 .37748 L
s
.01554 .39157 m
.01924 .39022 L
s
.01145 .41735 m
.01516 .41601 L
s
.00939 .43039 m
.01309 .42906 L
s
.0073 .44354 m
.01101 .44222 L
s
.0052 .45679 m
.00891 .45548 L
s
.03503 .26861 m
.03869 .26718 L
s
.03689 .25683 m
.04056 .25539 L
s
.00095 .48363 m
.00467 .48234 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.662 .743 .911 r
.38235 .60182 .40448 .62216 .44144 .61121 .41963 .59063 Metetra
.663 .744 .91 r
.41963 .59063 .44144 .61121 .47891 .60008 .45744 .57915 Metetra
.666 .744 .909 r
.45744 .57915 .47891 .60008 .5169 .58871 .49578 .56724 Metetra
.663 .741 .908 r
.49578 .56724 .5169 .58871 .55543 .57727 .53466 .55546 Metetra
.651 .737 .912 r
.53466 .55546 .55543 .57727 .59451 .566 .57411 .54471 Metetra
.642 .742 .922 r
.57411 .54471 .59451 .566 .63416 .55482 .61418 .53466 Metetra
.65 .759 .929 r
.61418 .53466 .63416 .55482 .67438 .54319 .65484 .52347 Metetra
.67 .772 .926 r
.65484 .52347 .67438 .54319 .71515 .53081 .69602 .51001 Metetra
.68 .768 .918 r
.69602 .51001 .71515 .53081 .75649 .51797 .73772 .49538 Metetra
.673 .752 .91 r
.73772 .49538 .75649 .51797 .79844 .50519 .78005 .48142 Metetra
.662 .74 .908 r
.78005 .48142 .79844 .50519 .84103 .49257 .82309 .46849 Metetra
.659 .74 .909 r
.82309 .46849 .84103 .49257 .88427 .47985 .86682 .45567 Metetra
.661 .743 .91 r
.86682 .45567 .88427 .47985 .92815 .46686 .91119 .44237 Metetra
.663 .744 .91 r
.91119 .44237 .92815 .46686 .97268 .45363 .95622 .42873 Metetra
.662 .743 .91 r
.35966 .58091 .38235 .60182 .41963 .59063 .39726 .56937 Metetra
.662 .742 .91 r
.39726 .56937 .41963 .59063 .45744 .57915 .4354 .55767 Metetra
.662 .743 .91 r
.4354 .55767 .45744 .57915 .49578 .56724 .47409 .5458 Metetra
.662 .746 .913 r
.47409 .5458 .49578 .56724 .53466 .55546 .51333 .53376 Metetra
.662 .747 .913 r
.51333 .53376 .53466 .55546 .57411 .54471 .55315 .52155 Metetra
.662 .736 .905 r
.55315 .52155 .57411 .54471 .61418 .53466 .59354 .50915 Metetra
.662 .719 .891 r
.59354 .50915 .61418 .53466 .65484 .52347 .63453 .49657 Metetra
.662 .711 .884 r
.63453 .49657 .65484 .52347 .69602 .51001 .67613 .48381 Metetra
.662 .719 .891 r
.67613 .48381 .69602 .51001 .73772 .49538 .71835 .47086 Metetra
.662 .736 .905 r
.71835 .47086 .73772 .49538 .78005 .48142 .7612 .45771 Metetra
.662 .747 .913 r
.7612 .45771 .78005 .48142 .82309 .46849 .80471 .44436 Metetra
.662 .746 .913 r
.80471 .44436 .82309 .46849 .86682 .45567 .84888 .43081 Metetra
.662 .743 .91 r
.84888 .43081 .86682 .45567 .91119 .44237 .89373 .41705 Metetra
.662 .742 .91 r
.89373 .41705 .91119 .44237 .95622 .42873 .93927 .40307 Metetra
.665 .743 .908 r
.33637 .55938 .35966 .58091 .39726 .56937 .37432 .54729 Metetra
.659 .739 .909 r
.37432 .54729 .39726 .56937 .4354 .55767 .41278 .53562 Metetra
.647 .739 .916 r
.41278 .53562 .4354 .55767 .47409 .5458 .45179 .52499 Metetra
.659 .757 .922 r
.45179 .52499 .47409 .5458 .51333 .53376 .49142 .51286 Metetra
.708 .771 .902 r
.49142 .51286 .51333 .53376 .55315 .52155 .53162 .49518 Metetra
.726 .734 .857 r
.53162 .49518 .55315 .52155 .59354 .50915 .57224 .47354 Metetra
.685 .665 .825 r
.57224 .47354 .59354 .50915 .63453 .49657 .61336 .45597 Metetra
.623 .615 .822 r
.61336 .45597 .63453 .49657 .67613 .48381 .65534 .44741 Metetra
.59 .623 .853 r
.65534 .44741 .67613 .48381 .71835 .47086 .69831 .44304 Metetra
.616 .697 .901 r
.69831 .44304 .71835 .47086 .7612 .45771 .74191 .43473 Metetra
.663 .76 .922 r
.74191 .43473 .7612 .45771 .80471 .44436 .78589 .42078 Metetra
.676 .763 .916 r
.78589 .42078 .80471 .44436 .84888 .43081 .83042 .40524 Metetra
.665 .744 .909 r
.83042 .40524 .84888 .43081 .89373 .41705 .87573 .39071 Metetra
.66 .739 .908 r
.87573 .39071 .89373 .41705 .93927 .40307 .92183 .37659 Metetra
.665 .744 .909 r
.31246 .53737 .33637 .55938 .37432 .54729 .35075 .52492 Metetra
.658 .742 .911 r
.35075 .52492 .37432 .54729 .41278 .53562 .38956 .51298 Metetra
.644 .738 .917 r
.38956 .51298 .41278 .53562 .45179 .52499 .4289 .50226 Metetra
.66 .745 .913 r
.4289 .50226 .45179 .52499 .49142 .51286 .4689 .48981 Metetra
.712 .758 .889 r
.4689 .48981 .49142 .51286 .53162 .49518 .50953 .47102 Metetra
.739 .759 .868 r
.50953 .47102 .53162 .49518 .57224 .47354 .55059 .4477 Metetra
.705 .74 .879 r
.55059 .4477 .57224 .47354 .61336 .45597 .59211 .42908 Metetra
.614 .703 .908 r
.59211 .42908 .61336 .45597 .65534 .44741 .63448 .42082 Metetra
.558 .685 .924 r
.63448 .42082 .65534 .44741 .69831 .44304 .67788 .41741 Metetra
.604 .716 .923 r
.67788 .41741 .69831 .44304 .74191 .43473 .72196 .40949 Metetra
.664 .746 .911 r
.72196 .40949 .74191 .43473 .78589 .42078 .76642 .39511 Metetra
.678 .751 .906 r
.76642 .39511 .78589 .42078 .83042 .40524 .81143 .37892 Metetra
.666 .745 .909 r
.81143 .37892 .83042 .40524 .87573 .39071 .85725 .36392 Metetra
.66 .742 .911 r
.85725 .36392 .87573 .39071 .92183 .37659 .90388 .34942 Metetra
.657 .745 .915 r
.28789 .51511 .31246 .53737 .35075 .52492 .32647 .50316 Metetra
.669 .755 .915 r
.32647 .50316 .35075 .52492 .38956 .51298 .36569 .48973 Metetra
.692 .751 .896 r
.36569 .48973 .38956 .51298 .4289 .50226 .40558 .4735 Metetra
.665 .703 .876 r
.40558 .4735 .4289 .50226 .4689 .48981 .44591 .45995 Metetra
.552 .654 .903 r
.44591 .45995 .4689 .48981 .50953 .47102 .4867 .45777 Metetra
.195 .639 .946 r
.4867 .45777 .50953 .47102 .55059 .4477 .52841 .46383 Metetra
.278 0 0 r
.52841 .46383 .55059 .4477 .59211 .42908 .57113 .46047 Metetra
.122 0 0 r
.57113 .46047 .59211 .42908 .63448 .42082 .61423 .43648 Metetra
.44 .814 .562 r
.61423 .43648 .63448 .42082 .67788 .41741 .65735 .40278 Metetra
.759 .875 .931 r
.65735 .40278 .67788 .41741 .72196 .40949 .70107 .37721 Metetra
.657 .695 .874 r
.70107 .37721 .72196 .40949 .76642 .39511 .74598 .36315 Metetra
.634 .69 .885 r
.74598 .36315 .76642 .39511 .81143 .37892 .79188 .35183 Metetra
.655 .74 .912 r
.79188 .35183 .81143 .37892 .85725 .36392 .83834 .33761 Metetra
.667 .755 .916 r
.83834 .33761 .85725 .36392 .90388 .34942 .88543 .32179 Metetra
.641 .743 .923 r
.26262 .49248 .28789 .51511 .32647 .50316 .30145 .48166 Metetra
.689 .767 .911 r
.30145 .48166 .32647 .50316 .36569 .48973 .34117 .46582 Metetra
.752 .761 .86 r
.34117 .46582 .36569 .48973 .40558 .4735 .38184 .44024 Metetra
.67 .68 .85 r
.38184 .44024 .40558 .4735 .44591 .45995 .42249 .42501 Metetra
.062 .345 .82 r
.42249 .42501 .44591 .45995 .4867 .45777 .4629 .45236 Metetra
.814 .334 .057 r
.4629 .45236 .4867 .45777 .52841 .46383 .50481 .5126 Metetra
.621 .24 .301 r
.50481 .5126 .52841 .46383 .57113 .46047 .54909 .53865 Metetra
.184 0 .217 r
.54909 .53865 .57113 .46047 .61423 .43648 .59351 .48499 Metetra
.59351 .48499 .61423 .43648 .65735 .40278 .63636 .39605 Metetra
.917 .925 .802 r
.63636 .39605 .65735 .40278 .70107 .37721 .67943 .33967 Metetra
.644 .662 .852 r
.67943 .33967 .70107 .37721 .74598 .36315 .72476 .32645 Metetra
.556 .627 .878 r
.72476 .32645 .74598 .36315 .79188 .35183 .77174 .32393 Metetra
.636 .733 .918 r
.77174 .32393 .79188 .35183 .83834 .33761 .81894 .31139 Metetra
.68 .768 .918 r
.81894 .31139 .83834 .33761 .88543 .32179 .86645 .29358 Metetra
.633 .738 .924 r
.23667 .46894 .26262 .49248 .30145 .48166 .27577 .45853 Metetra
.697 .76 .901 r
.27577 .45853 .30145 .48166 .34117 .46582 .31596 .44125 Metetra
.775 .764 .843 r
.31596 .44125 .34117 .46582 .38184 .44024 .35735 .41056 Metetra
.68 .711 .872 r
.35735 .41056 .38184 .44024 .42249 .42501 .39837 .39426 Metetra
0 .03 .569 r
.39837 .39426 .42249 .42501 .4629 .45236 .43838 .43708 Metetra
.879 .443 .113 r
.43838 .43708 .4629 .45236 .50481 .5126 .47989 .52703 Metetra
.719 .248 .13 r
.47989 .52703 .50481 .5126 .54909 .53865 .52489 .5698 Metetra
.71 .882 .49 r
.52489 .5698 .54909 .53865 .59351 .48499 .57063 .49891 Metetra
.988 .894 .605 r
.57063 .49891 .59351 .48499 .63636 .39605 .61421 .37925 Metetra
.924 .841 .745 r
.61421 .37925 .63636 .39605 .67943 .33967 .65751 .30632 Metetra
.642 .693 .882 r
.65751 .30632 .67943 .33967 .72476 .32645 .70329 .29332 Metetra
.494 .627 .91 r
.70329 .29332 .72476 .32645 .77174 .32393 .75099 .29518 Metetra
.626 .728 .92 r
.75099 .29518 .77174 .32393 .81894 .31139 .79882 .28329 Metetra
.686 .762 .909 r
.79882 .28329 .81894 .31139 .86645 .29358 .84685 .26419 Metetra
.642 .736 .917 r
.21005 .44413 .23667 .46894 .27577 .45853 .24953 .4326 Metetra
.686 .741 .893 r
.24953 .4326 .27577 .45853 .31596 .44125 .29003 .41598 Metetra
.752 .761 .86 r
.29003 .41598 .31596 .44125 .35735 .41056 .33167 .38947 Metetra
.68 .786 .93 r
.33167 .38947 .35735 .41056 .39837 .39426 .37312 .37344 Metetra
0 .212 .675 r
.37312 .37344 .39837 .39426 .43838 .43708 .41369 .40051 Metetra
0 0 .411 r
.41369 .40051 .43838 .43708 .47989 .52703 .45531 .46093 Metetra
.349 .389 .762 r
.45531 .46093 .47989 .52703 .52489 .5698 .49993 .48672 Metetra
.731 .583 .69 r
.49993 .48672 .52489 .5698 .57063 .49891 .54592 .43162 Metetra
.821 .652 .673 r
.54592 .43162 .57063 .49891 .61421 .37925 .59079 .34079 Metetra
.832 .732 .754 r
.59079 .34079 .61421 .37925 .65751 .30632 .63539 .28299 Metetra
.643 .781 .947 r
.63539 .28299 .65751 .30632 .70329 .29332 .68172 .26887 Metetra
.51 .717 .966 r
.68172 .26887 .70329 .29332 .75099 .29518 .72961 .26555 Metetra
.636 .733 .918 r
.72961 .26555 .75099 .29518 .79882 .28329 .77788 .25207 Metetra
.678 .742 .899 r
.77788 .25207 .79882 .28329 .84685 .26419 .82656 .23324 Metetra
.657 .737 .909 r
.1827 .41833 .21005 .44413 .24953 .4326 .22265 .40493 Metetra
.668 .729 .895 r
.22265 .40493 .24953 .4326 .29003 .41598 .26336 .38998 Metetra
.692 .751 .896 r
.26336 .38998 .29003 .41598 .33167 .38947 .30486 .37213 Metetra
.661 .823 .961 r
.30486 .37213 .33167 .38947 .37312 .37344 .34677 .357 Metetra
.457 .765 .996 r
.34677 .357 .37312 .37344 .41369 .40051 .38883 .3535 Metetra
.484 .54 .839 r
.38883 .3535 .41369 .40051 .45531 .46093 .43163 .35841 Metetra
.565 .453 .685 r
.43163 .35841 .45531 .46093 .49993 .48672 .47583 .35363 Metetra
.616 .462 .65 r
.47583 .35363 .49993 .48672 .54592 .43162 .52109 .32765 Metetra
.66 .514 .675 r
.52109 .32765 .54592 .43162 .59079 .34079 .56668 .29169 Metetra
.704 .648 .791 r
.56668 .29169 .59079 .34079 .63539 .28299 .61267 .26403 Metetra
.646 .831 .971 r
.61267 .26403 .63539 .28299 .68172 .26887 .65961 .24813 Metetra
.614 .806 .974 r
.65961 .24813 .68172 .26887 .72961 .26555 .70755 .23499 Metetra
.655 .74 .912 r
.70755 .23499 .72961 .26555 .77788 .25207 .75621 .21884 Metetra
.666 .729 .897 r
.75621 .21884 .77788 .25207 .82656 .23324 .8056 .20101 Metetra
.665 .741 .907 r
.15455 .39205 .1827 .41833 .22265 .40493 .19494 .37739 Metetra
.658 .733 .905 r
.19494 .37739 .22265 .40493 .26336 .38998 .2359 .36321 Metetra
.644 .738 .917 r
.2359 .36321 .26336 .38998 .30486 .37213 .27741 .35025 Metetra
.658 .786 .942 r
.27741 .35025 .30486 .37213 .34677 .357 .31975 .33546 Metetra
.718 .805 .919 r
.31975 .33546 .34677 .357 .38883 .3535 .36311 .31403 Metetra
.717 .689 .822 r
.36311 .31403 .38883 .3535 .43163 .35841 .40718 .28785 Metetra
.646 .554 .736 r
.40718 .28785 .43163 .35841 .47583 .35363 .45155 .26651 Metetra
.588 .489 .709 r
.45155 .26651 .47583 .35363 .52109 .32765 .4964 .25586 Metetra
.57 .51 .749 r
.4964 .25586 .52109 .32765 .56668 .29169 .54218 .25017 Metetra
.608 .645 .861 r
.54218 .25017 .56668 .29169 .61267 .26403 .58897 .23975 Metetra
.663 .794 .945 r
.58897 .23975 .61267 .26403 .65961 .24813 .63652 .22257 Metetra
.679 .793 .935 r
.63652 .22257 .65961 .24813 .70755 .23499 .68479 .20346 Metetra
.666 .745 .909 r
.68479 .20346 .70755 .23499 .75621 .21884 .73394 .18552 Metetra
.659 .733 .904 r
.73394 .18552 .75621 .21884 .8056 .20101 .784 .16802 Metetra
.665 .744 .909 r
.12553 .36537 .15455 .39205 .19494 .37739 .16628 .35031 Metetra
.659 .743 .912 r
.16628 .35031 .19494 .37739 .2359 .36321 .20762 .33566 Metetra
.647 .739 .916 r
.20762 .33566 .2359 .36321 .27741 .35025 .24954 .32202 Metetra
.66 .741 .91 r
.24954 .32202 .27741 .35025 .31975 .33546 .29228 .30674 Metetra
.705 .753 .889 r
.29228 .30674 .31975 .33546 .36311 .31403 .33608 .28558 Metetra
.733 .765 .878 r
.33608 .28558 .36311 .31403 .40718 .28785 .38064 .26018 Metetra
.704 .767 .901 r
.38064 .26018 .40718 .28785 .45155 .26651 .42552 .23901 Metetra
.615 .744 .938 r
.42552 .23901 .45155 .26651 .4964 .25586 .47085 .22721 Metetra
.564 .718 .945 r
.47085 .22721 .4964 .25586 .54218 .25017 .51708 .21973 Metetra
.611 .727 .928 r
.51708 .21973 .54218 .25017 .58897 .23975 .56434 .20804 Metetra
.664 .742 .908 r
.56434 .20804 .58897 .23975 .63652 .22257 .61243 .19035 Metetra
.676 .747 .904 r
.61243 .19035 .63652 .22257 .68479 .20346 .6613 .1709 Metetra
.665 .744 .909 r
.6613 .1709 .68479 .20346 .73394 .18552 .71105 .15245 Metetra
.66 .743 .911 r
.71105 .15245 .73394 .18552 .784 .16802 .76172 .13432 Metetra
.662 .744 .911 r
.09564 .33798 .12553 .36537 .16628 .35031 .13673 .32275 Metetra
.662 .746 .912 r
.13673 .32275 .16628 .35031 .20762 .33566 .1785 .30727 Metetra
.662 .743 .91 r
.1785 .30727 .20762 .33566 .24954 .32202 .22095 .29153 Metetra
.661 .731 .901 r
.22095 .29153 .24954 .32202 .29228 .30674 .26411 .27553 Metetra
.661 .729 .9 r
.26411 .27553 .29228 .30674 .33608 .28558 .30799 .25926 Metetra
.663 .77 .93 r
.30799 .25926 .33608 .28558 .38064 .26018 .35262 .24272 Metetra
.65 .847 .975 r
.35262 .24272 .38064 .26018 .42552 .23901 .398 .2259 Metetra
.629 .882 .988 r
.398 .2259 .42552 .23901 .47085 .22721 .44416 .20878 Metetra
.65 .847 .975 r
.44416 .20878 .47085 .22721 .51708 .21973 .49113 .19137 Metetra
.663 .77 .93 r
.49113 .19137 .51708 .21973 .56434 .20804 .53891 .17366 Metetra
.661 .729 .9 r
.53891 .17366 .56434 .20804 .61243 .19035 .58754 .15563 Metetra
.661 .731 .901 r
.58754 .15563 .61243 .19035 .6613 .1709 .63703 .13728 Metetra
.662 .743 .91 r
.63703 .13728 .6613 .1709 .71105 .15245 .68741 .11861 Metetra
.662 .746 .912 r
.68741 .11861 .71105 .15245 .76172 .13432 .73871 .09959 Metetra
.662 .743 .911 r
.06486 .30969 .09564 .33798 .13673 .32275 .10632 .29405 Metetra
.663 .744 .91 r
.10632 .29405 .13673 .32275 .1785 .30727 .14848 .27801 Metetra
.666 .744 .909 r
.14848 .27801 .1785 .30727 .22095 .29153 .19138 .26141 Metetra
.663 .74 .908 r
.19138 .26141 .22095 .29153 .26411 .27553 .23496 .24485 Metetra
.651 .737 .912 r
.23496 .24485 .26411 .27553 .30799 .25926 .27918 .22931 Metetra
.642 .743 .922 r
.27918 .22931 .30799 .25926 .35262 .24272 .32413 .21441 Metetra
.652 .762 .93 r
.32413 .21441 .35262 .24272 .398 .2259 .36998 .19818 Metetra
.673 .778 .928 r
.36998 .19818 .398 .2259 .44416 .20878 .41675 .17939 Metetra
.682 .772 .919 r
.41675 .17939 .44416 .20878 .49113 .19137 .46432 .15924 Metetra
.673 .753 .911 r
.46432 .15924 .49113 .19137 .53891 .17366 .51267 .13969 Metetra
.662 .74 .908 r
.51267 .13969 .53891 .17366 .58754 .15563 .56186 .12112 Metetra
.659 .739 .909 r
.56186 .12112 .58754 .15563 .63703 .13728 .61195 .10254 Metetra
.661 .743 .91 r
.61195 .10254 .63703 .13728 .68741 .11861 .66296 .08332 Metetra
.663 .744 .91 r
.66296 .08332 .68741 .11861 .73871 .09959 .7149 .06359 Metetra
.662 .743 .91 r
.03314 .28049 .06486 .30969 .10632 .29405 .07498 .26432 Metetra
.662 .743 .91 r
.07498 .26432 .10632 .29405 .14848 .27801 .11753 .24784 Metetra
.663 .743 .91 r
.11753 .24784 .14848 .27801 .19138 .26141 .16081 .23099 Metetra
.662 .745 .912 r
.16081 .23099 .19138 .26141 .23496 .24485 .20482 .21396 Metetra
.659 .744 .913 r
.20482 .21396 .23496 .24485 .27918 .22931 .24955 .19699 Metetra
.656 .737 .909 r
.24955 .19699 .27918 .22931 .32413 .21441 .29506 .17999 Metetra
.658 .727 .9 r
.29506 .17999 .32413 .21441 .36998 .19818 .3414 .16238 Metetra
.663 .724 .894 r
.3414 .16238 .36998 .19818 .41675 .17939 .38861 .14382 Metetra
.666 .73 .897 r
.38861 .14382 .41675 .17939 .46432 .15924 .43666 .12462 Metetra
.665 .74 .906 r
.43666 .12462 .46432 .15924 .51267 .13969 .48556 .10535 Metetra
.662 .745 .912 r
.48556 .10535 .51267 .13969 .56186 .12112 .53533 .08611 Metetra
.661 .745 .912 r
.53533 .08611 .56186 .12112 .61195 .10254 .58603 .06661 Metetra
.662 .743 .91 r
.58603 .06661 .61195 .10254 .66296 .08332 .63766 .04667 Metetra
.662 .743 .91 r
.63766 .04667 .66296 .08332 .7149 .06359 .69026 .0263 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.20751 .18843 m
.21203 .19319 L
s
[(5)] .19846 .17893 .95159 1 Mshowa
.43745 .0984 m
.44155 .10351 L
s
[(10)] .42923 .08816 .80266 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(15)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.25192 .17104 m
.25459 .17394 L
s
.2971 .15335 m
.29972 .15629 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.4859 .07942 m
.48831 .08254 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.16384 .20553 m
.1666 .20834 L
s
.12091 .22234 m
.12371 .22511 L
s
.07869 .23888 m
.08153 .2416 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
_Woo1@000Woo00<007ooOol0F7oo0030Ool01`00Oomoogoo001oo`0005Uoo`00`7oo00<007ooOol0
0goo00<007ooOol0Egoo0030Ool01000Oomoogoo0P00FWoo0030Ool01@00Oomoogoo0000Fgoo002o
Ool20003Ool3001IOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00agoo0P00Egoo0035
Ool200000goo0000001FOol00<9oo`<000=oo`8005Ioo`00`7oo0P001Woo00<007oo0000EGoo002m
Ool30008Ool01000Oomoo`00E7oo002kOol2000;Ool01000Oomoo`00E7oo002hOol5000;Ool01@00
Oomoogoo0000Dgoo002eOol3000@Ool20003Ool00`00Oomoo`1@Ool00;=oo`80011oo`<00003E_d0
0000009oo`03001oogoo051oo`00/7oo0`0047oo0P0015Km0P000goo00<007ooOol0Cgoo002^Ool2
000@Ool30006E_d00`00E_d00002Ool2001@Ool00:]oo`D000eoo`<000UFo@03001Fo@0000=oo`03
001oogoo04ioo`00ZGoo0P003goo0`0035Km00@005KmE_d000=oo`03001oogoo04eoo`00YWoo0`00
3goo0P000UKm00<005KmE_d02UKm00D005KmE_eFo@00009oo`03001oogoo04eoo`00Y7oo0P003goo
0`0015Km00<005KmE_d02UKm00D005KmE_eFo@0000=oo`03001oogoo04aoo`00OGoo1@000Woo00<0
07ooOol06Woo0`003Woo0`0025Km00<005KmE_d02EKm00<005KmE_d00UKm00D007ooOomoo`0004eo
o`00Ogoo00L007ooOomoo`00Ool0000IOol4000=Ool2000<E_d00`00E_eFo@08E_d00`00E_eFo@02
E_d01@00Oomoogoo0000CGoo001oOol01`00Oomoogoo001oo`0001Ioo`<000ioo`<000iFo@03001F
oEKm00QFo@03001FoEKm009Fo@8000=oo`03001oogoo04Yoo`00Ogoo00L007ooOomoo`00Ool0000D
Ool2000?Ool20002E_d00`00E_eFo@0=E_d00`00E_eFo@07E_d00`00E_eFo@020002E_d01@00Oomo
ogoo0000Bgoo001oOol01`00Oomoogoo001oo`00015oo`<000ioo`<000EFo@03001FoEKm00eFo@03
001FoEKm00IFo@<000AFo@03001oogoo008004]oo`00OWoo0P0017oo00<007ooOol03Goo0`003Woo
0`0025Km00<005KmE_d03UKm00<005KmE_d00UKm10001eKm00D007ooOomoo`0004Yoo`00TWoo0P00
00=oo`00000037oo0P0035Km00<005KmE_d03EKm00<005KmE_d00P000eKm00<005KmE_d01UKm00D0
07ooOomoo`0004Uoo`00Sgoo0`003Woo0`003eKm00<005KmE_d035Km0`001EKm00<005KmE_d01UKm
00D007ooOomoo`0004Uoo`00SGoo0P003goo0P000UKm00<005KmE_d03UKm00<005KmE_d025Km0`00
0UKm00<005KmE_d00eKm00<005KmE_d01eKm00D007ooOomoo`0004Qoo`00RWoo0`003goo0P001EKm
00<005KmE_d03EKm00<005KmE_d015Km10001EKm00<005KmE_d015Km00<005KmE_d01eKm00D007oo
Oomoo`0004Moo`00R7oo0P003goo0`001eKm00<005KmE_d03UKm00<005KmE_d00`002UKm00<005Km
E_d00eKm00<005KmE_d01eKm00D007ooOomoo`0004Moo`00QGoo0`0000=oo`00Ool037oo0P002eKm
00<005KmE_d03EKm0`003UKm00<005KmE_d00UKm00<005KmE_d01eKm0P000goo00<007ooOol0A7oo
0023Ool20005Ool00`00Oomoo`07Ool3000>E_d00`00E_eFo@0:E_d20002E_d00`00E_eFo@0=E_d0
1@00E_eFoEKm00001UKm0`000UKm00D007ooOomoo`0004Eoo`00P7oo0`003goo0P000UKl00<005Km
E_d03EKm00<005KmE_d01UKm0`0015Km00<005KmE_d03EKm00D005KmE_eFo@00009Fo@@000EFo@03
001oogoo008004Eoo`00OWoo0P003goo0`001EKl00<005KmE_d035Km00<005KmE_d00eKm0`0025Km
00<005KmE_d03EKm00<005KmE_d00`002UKm00D007ooOomoo`0004Aoo`00Ngoo0`003Woo0`0025Kl
00<005KmE_d03EKm00<005KmE_d00P0035Km00<005KmE_d035Km10003EKm00D007ooOomoo`0004=o
o`00NGoo0P000Woo00<007ooOol02Woo0P0035Kl00<005KmE_d035Km0`003UKm00<005KmE_d02UKm
0P000UKm0P003UKm00@007ooOol000Qoo`03001oogoo03Qoo`00MWoo0`003Woo0`003eKl00<005Km
E_d02EKm0P000UKm00<005KmE_d03EKm00<005KmE_d01UKm0`0015Km0P003UKm00D007ooOomoo`00
00Ioo`03001oo`0003Uoo`00Lgoo0`003goo0P000UKl00<005KlE_`03UKl00<005KmE_d01UKm0P00
1EKm00<005KmE_d03EKm00<005KmE_d00UKm0`0025Km00<005KmE_d03EKm00@007ooOol000Qoo`03
001oogoo03Moo`00LGoo0P0047oo0P001EKl00<005KlE_`03EKl00<005KmE_d00eKm0`001eKm00<0
05KmE_d03EKm00<005KmE_d00P002eKm0P003UKm0P000Woo00<007ooOol00goo0P00>Woo001^Ool4
000>Ool30007E_`00`00E_aFo00>E_`00`00E_eFo@02000;E_d00`00E_eFo@0<E_d3000=E_d2000<
E_d20002E_d01000Oomoo`0017oo00<007ooOol0>Goo001/Ool2000@Ool2000;E_`00`00E_aFo00=
E_`3000>E_d00`00E_eFo@09E_d20002E_`00`00E_eFo@0;E_d00`00E_d00008E_d30004E_d00`00
Oomoo`020003Ool3000iOol006Uoo`<000moo`<000iFo003001Fo5Kl00YFo080009G7@03001FoEKm
00eFo@03001FoEKm00IFo@8000AFo003001FoEKm00]Fo@04001FoEKm0004E_d30008E_d4000oOol0
04Uoo`03001oogoo01]oo`80011oo`80009Fo003001Fo5Kl00eFo003001Fo5Kl00IFo0<000AG7@03
001FoEKm00eFo@03001FoEKm00=Fo@<000MFo003001FoEKm00YFo@04001FoEKm0002E_d2000;E_d0
1@00Oomoogoo0000?Woo0018Ool00`00Ool0000IOol3000@Ool20005E_`00`00E_aFo00<E_`00`00
E_aFo003E_`30008Ead00`00E_eFo@0=E_d00`00E_eFo@02000;E_`00`00E_eFo@09E_d00`00E_eF
o@03000>E_d01000Oomoo`00?Woo001:Ool00`00Oomoo`0EOol20002Ool00`00Oomoo`0;Ool30007
E_`00`00E_aFo00=E_`00`00E_aFo002000<Ead00`00E_eFo@0<E_d3000=E_`00`00E_eFo@0:E_d2
0002E_d00`00E_eFo@0<E_d01@00Oomoogoo0000?Goo0018Ool2000EOol3000@Ool2000;E_`00`00
E_aFo00<E_`3000?Ead00`00E_eFo@08E_d30002E_`00`00E_aFo00<E_`00`00E_eFo@06E_d40003
E_d00`00E_eFo@0=E_d01@00Oomoogoo0000?7oo0018Ool00`00Oomoo`0BOol2000@Ool3000>E_`0
0`00E_aFo009E_`20002Ead00`00EaeG7@0=Ead00`00E_eFo@04E_d40005E_`00`00E_aFo00=E_`0
0`00E_eFo@02E_d30003E_d00`00E_eFo@02E_d00`00E_eFo@0<E_d01@00Oomoogoo0000?7oo0018
Ool3000?Ool3000?Ool30002E_`00`00E_aFo00=E_`00`00E_aFo006E_`20005Ead00`00EaeG7@0=
Ead00`00E_eFo@03000:E_`00`00E_aFo00<E_`00`00E_eFo@020006E_d00`00E_eFo@03E_d00`00
E_eFo@0;E_d20003Ool00`00Oomoo`0iOol005Qoo`<000moo`8000IFo003001Fo5Kl00aFo003001F
o5Kl00=Fo0<000QG7@03001G7ELM00aG7@<000iFo003001Fo5Kl00]Fo0<000QFo@03001FoEKm00AF
o@03001FoEKm00MFo@<0009Fo005001oogooOol0000jOol005Eoo`<000moo`<000UFo003001Fo5Kl
00aFo003001Fo5Kl008000]G7@03001G7ELM00YG7@80009G7@03001Fo5Kl00aFo003001Fo5Kl00UF
o080009Fo003001FoEKm00IFo@03001FoEKm00AFo@03001FoEKm00AFo@<000EFo003001oogoo0080
03Yoo`00DWoo0`003goo0`003EKl00<005KlE_`02eKl0`003ULM00<005LMEad01eLM0P001ELM00<0
05KlE_`035Kl00<005KlE_`01UKl0P0015Kl00<005KmE_d01UKm00<005KmE_d01EKm00<005KmE_d0
0`002EKl00D007ooOomoo`0003Uoo`00D7oo0P003goo0`000U;m00<005KlE_`02eKl00<005KlE_`0
2EKl0P000ULM00<005LMEad03ELM00<005LMEad00eLM0`001eLM00<005KlE_`03EKl00<005KlE_`0
0UKl0`001eKl00<005KmE_d01EKm00<005KmE_d01EKm0`003EKl00D007ooOomoo`0003Qoo`00CGoo
0`003Woo0`001U;m00<005KlE_`02eKl00<005KlE_`01UKl0P001ELM00<005LMEad03ELM00<005LM
Ead00P002eLM00<005KlE_`035Kl00<005KlE_`00P002eKl00<005KmE_d015Km00<005KmE_d00eKm
0P000UKm00<005KlE_`035Kl00@007ooOol003Qoo`00Bgoo0P000Woo0P002Woo0`002E;m00<005Kl
E_`035Kl00<005KlE_`00eKl0P0025LM00<005LMEad035LM0`003ULM00<005KlE_`02eKl0`003UKl
00<005KmE_d00eKm00<005KmE_d00`0015Km00<005KlE_`035Kl00D007ooOomoo`0003Moo`00B7oo
0`003Goo0`003E;m00<005KlE_`035Kl00<005KlE_`00P002eLM00<005LMEad025LM0`000U=o00<0
05LMEad03ELM00<005KlE_`01eKl0`000UKm00<005KlE_`035Kl00<005KmE_d00eKm0`0025Km00<0
05KlE_`035Kl00D007ooOomoo`0003Ioo`00AWoo0P003Woo0P000UKm00<005;mD_d035;m00<005Kl
E_`02eKl0`003ULM00<005LMEad015LM0`001U=o00<005LMEad035LM00<005KlE_`015Kl0`001EKm
00<005KlE_`03EKl00<005KmE_d00`002UKm00<005KlE_`035Kl0P000Woo00<007ooOol0=7oo0013
Ool3000>Ool20005E_d00`00D_eBo@0<D_d00`00E_aFo007E_`30002Dad00`00EaeG7@0=Ead00`00
EaeG7@03000:Dgl00`00EaeG7@0<Ead00`00E_aFo0030009E_d00`00E_aFo00<E_`30002E_d00`00
E_eFo@09E_d00`00E_aFo009E_`20002E_`01000Oomoo`00=Goo0011Ool200000goo001oo`0<Ool2
0008E_d00`00D_eBo@0;D_d00`00E_aFo004E_`30006Dad00`00EaeG7@0<Ead3000>Dgl00`00EaeG
7@0;Ead3000=E_d00`00E_aFo009E_`20002Ecd01000E_eFo@002eKm00<005KlE_`01UKl0`0015Kl
00<007ooOol00P00=7oo000nOol3000?Ool2000;E_d00`00D_eBo@0;D_d00`00E_aFo003000:Dad0
0`00EaeG7@09Ead20002Dil2000>Dgl00`00EaeG7@06Ead40002C_d00`00E_eFo@0<E_d00`00E_aF
o006E_`20004Ecd01000E_eFo@0035Km00<005KlE_`00UKl0`0025Kl00@007ooOol003Aoo`00?7oo
0P003goo0`003UKm00<005;mD_d02U;m0`003U<M00<005LMEad01ULM0P001U>O00<005=oDgl035=o
00@005LMEaeG7@@000I>o@03001FoEKm00aFo@03001Fo5Kl00=Fo0<000MG?@03001Fo@0000aFo@03
001Fo5Kl008000]Fo005001oogooOol0000cOol003Uoo`<000ioo`<0009Fo@03001FoEKm00eFo@03
001BoE;m00EBo@@0009Bo@03001C7E<M00eC7@03001G7ELM00=G7@8000UCW`03001COe=o00YCO`D0
00]>o@03001FoEKm00aFo@03001Fo5Kl008000]G?@03001Fo@0000]Fo@<000iFo004001oogoo000c
Ool003Moo`<000ioo`8000IFo@03001FoEKm00eFo@03001BoE;m00@000MBo@03001C7E<M00eC7@03
001G7ELM008000aCW`8000ACO`H000=:gP03001>oDkm00]>o@03001FoEKm00]Fo@<000iG?@8000QF
o@<0009Bo@03001Fo5Kl00eFo004001oogoo000bOol003Aoo`<000ioo`<000UFo@03001FoEKm00aF
o@<000aBo@03001C7E<M00aC7@<000mCW`D000U:gP03001>oDkm00a>o@03001FoEKm00MFo@<0009G
?P03001G?ELm00aG?@8000EFo@<000EBo@03001Fo5Kl00eFo005001oogooOol0000aOol0035oo`<0
00ioo`<000eFo@03001FoEKm00QFo@<0009Bo@03001BoE;m00]Bo@03001C7E<M00QC7@<000=CO`80
00UCW`@0009>oP03001:gT[N00Y:gP03001>oDkm00]>o@03001FoEKm00AFo@<000IG?P03001G?ELm
00aG?@03001FoEKm00<000UBo@03001Fo5Kl00aFo080009oo`03001oogoo02moo`00;goo0P003Woo
0`000UKm00<005KmE_d035Km00<005KmE_d015Km0`001U;m00<005;mD_d02e;m00<005<MDad015<M
0`0025=o0P000e>O10001dkn00<004[NB]h02T[N00<004kmC_d02dkm00<005KmE_d00`002ULn00<0
05LmEcd02eLm0`003E;m00<005KlE_`02EKl0P000UKl00@007ooOol0031oo`00;7oo0`003Woo0P00
1UKm00<005KmE_d035Km00<005KmE_d00`002U;m00<005;mD_d02e;m00<005<MDad00`003E=o0`00
34kn00<004[NB]h02T[N00<004kmC_d02Tkm0`003ULn00<005LmEcd01ULm1@0000=??`00D_d03E;m
00<005KlE_`01UKl0P0015Kl00<007ooOol00P00;goo000ZOol20003Ool00`00Oomoo`08Ool30009
E_d00`00E_eFo@0;E_d3000=D_d00`00D_eBo@0;D_d3000>Dgl20002Fa`00`00C_i>oP0;C_h00`00
B]i:gP09B]h00`00C_e>o@06C_d40002CY/00`00EciG?P0=Ech01000EceG?ELm100014lo00<004lo
00003U;m00<005KlE_`00eKl0`001eKl00@007ooOol002moo`009goo0`003Goo0`0035Km00<005Km
E_d02EKm0P000UKm00<005;mD_d035;m00<005;mD_d01e;m0`000ULM0P002e=o0P001E/L00<004kn
C_h02dkn00<004[NB]h02D[N00@004kmC_e>o@@000M>V`03001G?ULn00aG?P@000M??`80009??`03
001BoE;m00aBo@03001Fo5Kl008000YFo005001oogooOol0000^Ool002Eoo`8000eoo`<0009Fo@03
001FoEKm00]Fo@03001FoEKm00IFo@8000EFo@03001BoE;m00aBo@03001BoE;m00ABo@8000MG7@80
00ICO`<000QK7003001>oTkn00]>oP03001:gT[N00A:gPP000a>V`03001G?ULn00QG?P<0009CG`03
001??dlo00=??`<0009??`04001??dlo000=D_d3000=E_`01@00Oomoogoo0000;Goo000SOol2000=
Ool20006E_d00`00E_eFo@0;E_d00`00E_eFo@03E_d20008E_d00`00D_eBo@0<D_d00`00D_eBo@03
000;Ead20002Dgl2000;Fa`00`00C_i>oP0;C_h70006BQL00`00CY]>V`0<CY/00`00EciG?P04Ech3
0006Del00`00Ccl000020005Ccl01@00Ccm??dlo00002E;m0`000U;m00<005KlE_`035Kl00@007oo
Ool002eoo`008goo0P002Woo0`002EKm00<005KmE_d02eKm00<005KmE_d00P002eKm00<005;mD_d0
2e;m0`0045LM0P003U/L00<004knC_h01Tkn100000=9mP00BQL02TXG00<004jKCY/03DjK00<005Ln
Ech00`0025=O0`002Dlo00@004loCcl000IBo@<000EBo@03001Fo5Kl00aFo005001oogooOol0000/
Ool002=oo`03001oo`0000Ioo`<000aFo@03001FoEKm00]Fo@<000iFo@03001BoE;m00MBo@<0009F
o003001G7ELM00aG7@800003Ga`005/L00iK7004001>oTknC_h40006BOH00`00BQM:5`09BQL00`00
CY]>V`0=CY/20008Del30003Del00`00Ccm??`07Ccl01000Ccm??`000U;m0`002E;m00<005KlE_`0
2eKl0P000goo00<007ooOol0:Goo000SOol2000017oo001oogoo0`000UKm00<005KmE_d02eKm00<0
05KmE_d01eKm0`000UKm00<005KmE_d03EKm00<005;mD_d015;m0P001UKl00<005LMEad02ULM00<0
05lLGa`00UlL00<005/LFa`035/L10002TWf00<004XGBQL02DXG00<004jKCY/02djK0P0000=JV@00
Del015=O0`001U=O400035;m00<005KlE_`02EKl0P000ULM00<007ooOol00P00:Woo000ROol00`00
Oomoo`02Ool20006E_d00`00E_eFo@0;E_d00`00E_eFo@04E_d20006E_d00`00E_eFo@0=E_d00`00
D_eBo@030009E_`00`00EaeG7@07Ead20006Ga`00`00FaaK7009Fa`200000e8g0019mP0;BOH00`00
BQM:5`0:BQL00`00CY]>V`08CY/20004FYT00`00DemCG`020006Del30002Dah00`00@]i2gP06@]h0
1@00@]i2gT;N00003E;m00<005KlE_`01UKl0P0015LM00D007ooOomoo`0002Yoo`008Woo00<007oo
00000P002EKm00<005KmE_d02eKm00<005KmE_d00`002EKm00<005KmE_d035Km0`003EKl00<005LM
Ead015LM0P002ElL00<005/LFa`01U/L0P00158g00<004WfBOH02TWf00<004XGBQL02TXG00<004jK
CY/01TjK00<005ZIFYT015ZI0`001U=O0P001U<N00<004;N@]h01T;N00@004;N@]h000iBo@03001F
o5Kl009Fo0<000MG7@05001oogooOol00005Ool50002Ool00`00Oomoo`0JOol0029oo`8000eFo@03
001FoEKm00YFo@<000eFo@8000UFo@<0009Fo003001Fo5Kl00aFo003001G7ELM009G7@03001O75lL
00YO7003001K75/L00=K708000IB=`030019mTWf00Y9mP03001:5dXG00Y:5`03001>VdjK00A>V`80
00AJV@<000=JV@03001CGe=O00<000UC7P030012gT;N00I2gP040012gT;N000=D_d00`00E_aFo002
000:Ead01@00Oomoogoo00001goo00L007ooOomoo`00Ool0000KOol0029oo`8000iFo@03001FoEKm
00MFo@80009Fo@03001FoEKm00eFo@03001FoEKm00AFo@8000IFo003001Fo5Kl00aFo004001G7@00
000>Ga`00`00FaaK70020008DSL00`00BOI9mP0:BOH00`00BQM:5`0;BQL01000CY]>VdjK0P000eZI
0`001eZI0P0035<N00<004;N@]h01d;N00@004;N@]h000aBo@<000eG7@05001oogooOol00006Ool0
1`00Oomoogoo001oo`0001]oo`0077oo00<007ooOol00goo00<007oo00003UKm00<005KmE_d00eKm
0`001EKm00<005KmE_d03EKm00<005KmE_d00`002EKl00<005KlE_`02eKl0P004ElL0P002U8g00<0
04WfBOH02dWf00<004XGBQL02TXG00@004jK0000009JV@<000UJV@03001Zn00000eC7P030012gT;N
00I2gP050012gT;N@]h00007D_d40002D_d00`00EaeG7@0<Ead01@00Oomoogoo00001Goo00L007oo
Oomoo`00Ool0000KOol001]oo`03001oo`0000Aoo`800003Ool005Km00eFo@03001FoEKm008000UF
o@03001FoEKm00aFo@<000aFo003001Fo5Kl00UFo080009K7003001O75lL00aO70<000aB=`030019
mTWf00Y9mP03001:5dXG00]:5`03001JV@00008000]JV@05001Zn6[hJ_P0000=Dah00`00@]i2gP06
@]h01000@]i2gP000e;m10001U;m00<005LMEad035LM00D007ooOomoo`0000Eoo`07001oogooOol0
07oo00006goo000KOol00`00Ool00003Ool00`00Oomoo`02Ool00`00E_eFo@0;E_d3000<E_d20009
E_d30002E_d00`00E_aFo00;E_`00`00E_aFo006E_`20005Fa`00`00GaaO700:Ga`01@00F]YJfU[J
00002e8g00<004WfBOH02TWf00<004XGBQL02TXG0`003UZI00D006[hJ_QZn00000eC7Q0000]Bo@03
001G7ELM00]G7@8000=oo`04001oogooOol20004Ool00`00Oomoo`0JOol001]oo`03001oo`0000=o
o`03001oogoo00=oo`03001FoEKm00MFo@<0009Fo@03001FoEKm00aFo@03001FoEKm00AFo@8000IF
o@03001Fo5Kl00]Fo003001Fo5Kl00=Fo08000QK7003001O75lL00MO708000AJfP03001B=e8g00UB
=`030019mTWf00]9mP03001:5dXG00I:5`<0009F5@03001JVEZI00]JV@03001Zn6[h00=Zn003001C
7U<N00IC7P@0009Bg003000nWCjM00DnW@05000nWCjM?Yd0000=D_d00`00EaeG7@07Ead30002Ead0
1@00Ool007oo00009Goo000KOol00`00Ool00003Ool20005Ool00`00E_eFo@04E_d20006E_d00`00
E_eFo@0<E_d00`00E_eFo@030009E_d00`00E_aFo00;E_`00`00E_aFo002000;Fa`00`00GaaO7004
Ga`20006F]X00`00DSMB=`09DSL00`00BOI9mP0;BOH00`00BQM:5`03BQL40004EQD00`00FYUJV@0:
FYT00`00J_QZn005J_P01000DaiC7U<N10001U;L00<003jM?Yd01SjM00@003jM?Yd000iBo@03001G
7ELM00=G7@<000EG7@05001oogooOol0000UOol001aoo`03001oogoo009oo`03001oogoo00Eoo`03
001FoEKm00<000UFo@03001FoEKm00]Fo@<000aFo@03001Fo5Kl00]Fo0<000iK7003001O75lL009O
7003001JfU[J00MJfP03001B=e8g00UB=`030019mTWf00Y9mP03001:5dXG00<0009:5`03001F5EHE
00AF5@03001JVEZI00QJV@03001Zn6[h00MZn0<000]Bg003000nWCjM00HnW@04000nWCjM000=D_d0
0`00EaeG7@030009Ead01@00Oomoogoo000097oo000QOol00`00Oomoo`06Ool2000=E_d00`00E_eF
o@07E_d30002E_d00`00E_eFo@0;E_d00`00E_aFo007E_`30002E_d00`00FaaK700=Fa`01000Ga`0
00002U[J00<0058gDSL02E8g00<004WfBOH02TWf0`0014XG00<005HEEQD01EHE00<005ZIFYT01eZI
00<006[hJ_P01f[h00<007MG000035;L00<003jM?Yd01cjM00@003jM?Yd000aBo@<000eG7@04001o
ogoo000TOol0025oo`8000Qoo`03001FoEKm00aFo@03001FoEKm00AFo@8000IFo@03001FoEKm00]F
o@03001Fo5Kl00AFo08000IFo@03001K75/L00aK708000aJfP03001B=e8g00UB=`030019mTWf00M9
mP<00003BOH004XG00=:5`03001F5EHE00MF5@03001JVEZI00IJV@03001Zn6[h00MZn003001gE`00
00eBg003000nWCjM00HnW@05000nWCjM?Yd00007D_d40002D_d00`00EaeG7@0<Ead01000Oomoo`00
8goo000QOol00`00Oomoo`08Ool00`00E_eFo@0<E_d00`00E_eFo@030009E_d00`00E_eFo@0;E_d0
0`00E_aFo0030009E_d00`00FaaK7009Fa`20002Fcd00`00F]YJfP0:F]X00`00DSMB=`09DSL00`00
BOI9mP04BOH20004BOH00`00BQM:5`02000:EQD00`00FYUJV@05FYT00`00J_QZn007J_P01@00MeMg
EgMG00003E;L00<003jM?Yd01SjM00@003jM?Yd000=Bo@@000IBo@03001G7ELM00aG7@05001oogoo
Ool0000ROol0021oo`03001oogoo00Yoo`03001FoEKm00]Fo@<000eFo@03001FoEKm00YFo@<000eF
o@03001K75/L00IK708000AK?@03001JfU[J00YJfP03001B=e8g00UB=`040019mTWfBOH30007BOH2
000=EQD00`00FYUJV@03FYT00`00J_QZn008J_P00`00MeMgE`02MeL00`00D]aBg00:D]`00`00?Ydn
W@05?Yd8000;D_d00`00EaeG7@0;Ead20002Ool00`00Oomoo`0POol0021oo`8000aoo`8000UFo@80
009Fo@03001FoEKm00aFo@03001FoEKm00EFo@@0009Bo@03001FoEKm00aFo@03001K75/L00=K7080
00MK?@03001JfU[J00UJfP03001B=e8g00UB=`@000Y9mP03001F5EHE00aF5@03001JVEZI009JV@03
001Zn6[h00QZn003001gEgMG00AgE`03001Bg5;L00UBg0P000=6W0040016W4JL000=D_d00`00EaeG
7@07Ead30002Ead01000Ool000008Goo000POol00`00Oomoo`0=Ool00`00E_eFo@03E_d30005E_d0
0`00E_eFo@0<E_d00`00E_eFo@040007D_d00`00E_eFo@0<E_d00`00FaaK70020009Fcd00`00F]YJ
fP0:F]X00`00DSMB=`06DSL3000;BOH3000?EQD01000FYUJV@002V[h00<007MGMeL01GMG00<005;L
D]`01E;L10000U:k00<004JLAY`01TJL00@004JLAY`000iBo@03001G7ELM00=G7@<000EG7@05001o
ogooOol0000POol0021oo`03001oogoo00ioo`03001FoEKm008000UFo@03001FoEKm00]Fo@<000aB
o@03001FoEKm00]Fo@<000aK?@03001JfU[J00UJfP03001B=e8g00=B=`<000=B=`030019mTWf00I9
mP80009=e003001F5EHE00eF5@04001JVEZI000:J_P00`00MeMgE`06MeL00`00D]aBg0040006D[/0
0`00AYa6W007AY`01000AYa6W0003E;m00<005LMEad00`002ELM00@007ooOol0021oo`0087oo0P00
47oo0P0035Km0P002EKm0P000UKm00<005;mD_d02e;m00<005KmE_d01eKm0`000ULn00<005/mFcd0
2e/m00<005[JF]X025[J00<0058gDSL00`001U8g00<004WfBOH01DWf00<004gDCM@00dgD00<005HE
EQD03EHE0P002V[h00<007MGMeL027MG0P002e:k00<004JLAY`01dJL00@004JLAY`000aBo@<000eG
7@04001oogoo000OOol0021oo`03001oogoo011oo`03001FoEKm00aFo@03001FoEKm00=Fo@<000EF
o@03001BoE;m00]Bo@03001FoEKm00AFo@8000IG?P03001K?E/m00YK?@03001JfU[J00QJfP<000UB
=`030019mTWf00=9mP8000I=e003001F5EHE00eF5@03001Zn6[h00QZn003001gEgMG00QgE`8000eB
^`030016W4JL00I6W0050016W4JLAY`00007D_d40002D_d00`00EaeG7@0<Ead01000Oomoo`007Woo
000;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0BOol00`00E_eFo@0<E_d00`00E_eFo@020009E_d00`00D_eBo@0;D_d00`00E_eFo@030009Ech2
000;Fcd00`00F]YJfP04F]X300000e[J001B=`09DSL01000BOI9mTWf0P0024gD00<005HEEQD03EHE
0P002F[h00<007MGMeL027MG00<007Ni000035:k00<004JLAY`01dJL00@004JLAY`000=Bo@@000IB
o@03001G7ELM00aG7@04001oogoo000NOol000Yoo`03001oo`0000Moo`03001oo`00009oo`03001o
o`0000=oo`03001oogoo01=oo`03001FoEKm00]Fo@<000aFo@8000]Bo@<000iG?P03001K?E/m00QK
?@04001JfU[JF]X30004F]X00`00DSMB=`09DSL3000:CM@00`00EQEF5@0<EQD00`00JYD00008J_P0
0`00MeMgE`08MeL01000MkUg^@003E:k00<004JLAY`01dJL00<004JL00000`002e;m00<005LMEad0
2eLM0P000Woo00<007ooOol06goo000:Ool00`00Ool00007Ool00`00Ool00004Ool01000Oomoogoo
0P005Goo0P002EKm0P000UKm00<005KmE_d035Km00<005;mD_d01E;m0`000U;m00<005LnEch03ELn
00<005/mFcd015/m2P001E[J00<0058gDSL00e8g1P003DgD00<005HEEQD02eHE00@006ZEJYD000MZ
n003001gEgMG00MgE`03001g^GNi009g^@03001B^e:k00]B^`030016W4JL00A6W0@0009Bg003001B
oE;m00]Bo@03001G7ELM00MG7@<0009Fo@04001oo`00000LOol000Yoo`03001oo`0000Moo`03001o
o`00009oo`8000Aoo`03001oogoo01Ioo`03001FoEKm00=Fo@<000EFo@03001FoEKm00aFo@03001B
oE;m00@000IBo@03001G?ULn00aG?PL00006>al00000000k7`0013hj2`001DWE00<004gDCM@02dgD
00<005HEEQD02UHE00<006ZEJYD00VZE00<006[hJ_P00f[h00<007MGMeL01gMG00<007NiMkT00gNi
00<005:kD[/02e:k00<004JLAY`010000e;L00@005;LD]`000iBo@03001G7ELM00=G7@<000EFo@04
001oogoo000LOol000Yoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00=oo`03001oogoo
01Moo`03001FoEKm008000UFo@03001FoEKm00]Fo@<000]Bo@8000UG?P<0009GGP800004>al00000
0004>al00`00?SXn>P07?SX00`00BME9e@08BMD00`00CMA=e00;CM@00`00EQEF5@0:EQD00`00JYEZ
U@02JYD00`00J_QZn002J_P00`00MeMgE`08MeL00`00MkUg^@04MkT00`00D[]B^`0:D[/30008D]`0
1000D]aBg0003E;m00<005LMEad00`002EKm00@007ooOol001]oo`002goo00<007ooOol01goo00@0
07ooOomoo`<000=oo`8001Uoo`8000aFo@03001FoEKm00MFo@<0009Fo003001BoE;m00]Bo@03001G
?ULn00AG?P8000IGGP8000Pk7`03000n>Shj00Hn>P030019eDWE00U9e@03001=e4gD00Y=e003001F
5EHE00UF5@03001ZUFZE00AZU@05001Zn6[hJ_P00009MeL00`00MkUg^@05MkT00`00D[]B^`07D[/3
0002E]/00`00D]aBg007D]`01000D]aBg00035;m0`0035Km00D007ooOomoo`0001Yoo`007goo00<0
07ooOol06Goo00<005KmE_d02eKm00<005KmE_d015Km0P001UKl00<005;mD_d02e;m00<005LnEch0
0`001EMN0`000UMN0P001S/O00<003hj?SX01chj00<004WEBMD024WE00<004gDCM@02TgD00<005HE
EQD02EHE00<006ZEJYD01FZE00<006[h00002GMG00<007NiMkT01gNi00<005:kD[/00e:k0`001EKK
00<005;LD]`025;L00@005;LD]`000MBo@@0009Fo@03001FoEKm00]Fo@04001oogoo000JOol001io
o`03001oogoo01]oo`03001FoEKm00]Fo@03001FoEKm00<000UFo003001BoE;m00YBo@<000EGGP<0
00IGGP8000Hk7`03000n>Shj00Hn>P030019eDWE00Q9e@03001=e4gD00]=e003001F5EHE00MF5@03
001ZUFZE00IZU@03001Zn00000QgE`03001g^GNi00Qg^@03001B^e:k00<000UFf`03001Bg5;L00MB
g004001Bg5;L0003D_d40007E_d00`00E_eFo@0:E_d01@00Oomoogoo00006Goo000NOol2000MOol0
0`00E_eFo@0:E_d3000=E_`00`00D_eBo@07D_d20002Fa`2000015MN000000001eMN0P000ULm0P00
13/O00<003hj?SX01Shj00<004WEBMD024WE00<004gDCM@02dgD00<005HEEQD01eHE00<006ZEJYD0
1fZE00<007MGMeL01gMG00<007NiMkT02GNi0P0035KK00<005;LD]`025;L00<005;L00000`002eKm
00<005KmE_d02UKm0P000goo00<007ooOol05Woo000NOol00`00Oomoo`0MOol00`00E_eFo@07E_d2
0002E_d00`00E_aFo00<E_`00`00D_eBo@03D_d30004Fa`40006Eeh30006Ecd00`00>alk7`02>al0
0`00?SXn>P05?SX00`00BME9e@08BMD00`00CMA=e00;CM@00`00EQEF5@06EQD00`00JYEZU@08JYD2
0007MeL00`00MkUg^@08MkT200000f=m001Ff`0<E]/00`00D]aBg006D]`30002Ea`00`00E_eFo@0;
E_d00`00E_eFo@05E_d40002E_d01000Ool0000067oo000NOol00`00Oomoo`0NOol00`00E_eFo@03
E_d30005E_d00`00E_aFo00<E_`00`00D_eBo@020004Fa`30004Fa`20002Eeh2000:Ecd20003>al0
0`00?SXn>P05?SX00`00BME9e@07BMD00`00CMA=e00;CM@00`00EQEF5@06EQD00`00JYEZU@07JYD0
1000Oi=oT`001GMG00<007NiMkT01gNi0P000f=m00<005KKE]/035KK00<005;LD]`00e;L0P000ULL
00@005LLEa`000iFo@03001FoEKm00@000MFo@04001oogoo000GOol001ioo`80021oo`03001FoEKm
008000UFo@03001Fo5Kl00]Fo0<000=K70<000UK708000eG?@<00003>al003hj00Hn>P030019eDWE
00Q9e@03001=e4gD00]=e003001F5EHE00AF5@03001ZUFZE00QZU@04001oTgnCOi<20002MeL00`00
MkUg^@06MkT20006Hgd00`00E]]Ff`0;E]/00`00D]aBg0030005Ea`01000EaaG70003EKm0`002eKm
00@007ooOol001Moo`007Woo00<007ooOol087oo0P0035Km00<005KlE_`01eKl0`000UKl10002U/L
0P0000=S6`00Ecd03ELm0`0000<k7`00?SX01Chj00<004WEBMD024WE00<004gDCM@02dgD00<005HE
EQD015HE00<006ZEJYD026ZE00<007nCOi<00gnC00<007MG00001WNi0P002F=m00<005KKE]/02UKK
0`002ELL00@005LLEa`000UFo@<0009Fo@03001FoEKm00YFo@04001oogoo000FOol001ioo`03001o
ogoo025oo`03001FoEKm00]Fo@03001Fo5Kl00AFo08000=Fo0@000]K7003001S6f<K009S6`03001G
?ELm00QG?@<0009Ff`<000Hn>P030019eDWE00Q9e@03001=e4gD00]=e003001F5EHE00=F5@03001Z
UFZE00QZU@03001oTgnC00EoT`<000=g^@8000aSO@03001FfeKK00IFf`<0009Fo@03001G75LL00QG
7004001G75LL0005E_d30005E_d00`00E_eFo@0;E_d01000Oomoo`005Goo000MOol00`00Ool0000S
Ool00`00E_eFo@0;E_d00`00E_aFo0030002E_`30004E_`00`00FaaK7006Fa`20006Ha/20006Ecd2
0005E]/200000`3E000n>P05?SX00`00BME9e@07BMD00`00CMA=e00;CM@00`00EQEF5@03EQD00`00
JYEZU@08JYD00`00Oi=oT`04Oi<7000>Hgd00`00E]]Ff`04E]/20005E_d00`00EaaG7008Ea`01000
EaaG70000UKm0`002EKm00<005KmE_d02UKm0P0000=oo`00Ool057oo000MOol2000UOol2000;E_d3
0002E_`30007E_`00`00FaaK7004Fa`2000:Ha/00`00EceG?@030008E]/200000`3E000n>P04?SX0
0`00BME9e@07BMD00`00CMA=e00;CM@00`00EQEF5@02EQD00`00JYEZU@09JYD00`00Oi=oT`04Oi<6
00000c]A0000000=Hgd00`00E]]Ff`030008E_d00`00EaaG7008Ea`00`00Ea`00002000<E_d00`00
E_eFo@07E_d30002E_d3000DOol000eoo`03001oogoo009oo`03001oogoo00D000=oo`03001oogoo
02Ioo`03001FoEKm00EFo@<0009Fo@<000]Fo003001K75/L009K7003001S6f<K00]S6`8000aFf`<0
00Dn>P030019eDWE00M9e@03001=e4gD00a=e005001F5EHEEQD0000:JYD00`00Oi=oT`04Oi<60004
>e400`00HgeSO@09Hgd4000<E_d00`00EaaG7006Ea`30002Ead00`00E_eFo@0;E_d00`00E_eFo@03
E_d30005E_d01000Oomoo`001Woo1@000Woo00<007ooOol00goo000<Ool00`00Ool00008Ool00`00
Oomoo`03Ool00`00Oomoo`0WOol00`00E_eFo@040002E_d300000eKm001Fo00<E_`01000Fa`00000
3F<K00<006<J00003EKK0`0013hj00<004WEBMD024WE00<004gDCM@02dgD00@005HEEQD000]ZU@03
001oTgnC00AoT`@000LkD@8000=SO@H000=>g@03001FoEKm00]Fo@03001G75LL00=G708000=G7@04
001G7ELM000<E_d00`00E_eFo@030009E_d00`00Ool00008Ool01`00Oomoogoo001oo`0000Aoo`00
37oo00<007oo000027oo00<007ooOol00goo0P00:Goo0P0015Km0P001EKm00<005KlE_`02UKl0P00
3F<K0P000f<J00<005KKE]/02UKK0P0000<0e@00?SX00Shj00<004WEBMD024WE00<004gDCM@02dgD
00@005HEEQD000YZU@03001oTgnC00AoT`@000DkD@P000Y>g@03001FoEKm00YFo@03001G75LL00<0
00EG7@04001G7ELM000<E_d3000<E_d01000Oomoo`001goo00<007ooOol00goo00<007ooOol00Woo
000<Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`0YOol00`00E_d000020008E_d00`00
E_aFo007E_`20002E_`00`00Ha]S6`09Ha/00`00HaYS6P04HaX00`00E]]Ff`0:E]/30004?SX00`00
BME9e@07BMD00`00CMA=e00;CM@00`00EQD0000;JYD00`00Oi=oT`04Oi<90006A[d00`00C]e>g@09
C]d00`00E_eFo@0:E_d30009Ead01000EaeG7@001eKm10000UKm00<005KmE_d02eKm00@007ooOol0
00Ioo`04001oogooOol20005Ool000aoo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo02Uo
o`<000aFo@03001Fo5Kl00=Fo0<000EFo003001S6f<K00MS6`03001S6V<J00ES6P03001FfeKK00YF
f`@000<n>P030019eDWE00M9e@03001=e4gD00a=e08000]ZU@03001oTgnC00=oT`@00003C]d004Jm
00U6_@03001>gDkM00Y>g@03001FoEKm00EFo@@0009G7@03001G7ELM00QG7@04001G7ELM0002E_d4
0007E_d00`00E_eFo@0:E_d01000Oomoo`001Woo00D007ooOomoo`0000Ioo`003Goo00<007ooOol0
1Woo0P0017oo0P009goo0`000goo00<005KmE_d02UKm00<005KlE_`00P002EKl0P001V<K00<006<J
HaX01f<J00<005KKE]/01eKK0P000UJk0`000Shj00<004WEBMD01dWE00<004gDCM@034gD00<006ZE
JYD02FZE00<007nCOi<017nC0P000dkM00<004JmA[d02DJm00<004kMC]d02TkM00<005KmE_d01000
1eLM00<005LMEad01eLM00<005LMEad00`002eKm00<005KmE_d02UKm0P0000=oo`00000017oo0P00
0goo0`0017oo000LOol00`00Oomoo`0SOol30007Ool00`00E_eFo@09E_d3000=E_`01000Ha]S6f<K
0P002f<J00<005KKE]/00eKK0`0015Jk00<000Ej00000Shj00<004WEBMD024WE00<004gDCM@02dgD
00<006ZEJYD02FZE00<007nCOi<00gnC0P001DkM00<004JmA[d02DJm00<004kMC]d02DkM0`002eLM
00<005LMEad01eLM0`000UKm00<005KmE_d02UKm00<005KmE_d01EKm10000UKm0`0047oo000LOol0
0`00Oomoo`0POol3000;Ool00`00E_eFo@05E_d30002D_d00`00E_aFo00<E_`00`00Ha/0000>HaX0
0`00E]]Ff`020008E[/00`001GX00002?SX00`00BME9e@07BMD00`00CMA=e00:CM@2000;JYD00`00
Oi=oT`03Oi<00`00C]e>g@05C]d00`00A[e6_@09A[d00`00C]e>g@04C]d40002C]`00`00EaeG7@0:
Ead00`00EaeG7@04Ead20002E_d01000E_eFo@003EKm00<005KmE_d010001UKm00<007oo000047oo
000LOol2000NOol3000?Ool00`00E_eFo@040006D_d00`00E_aFo00<E_`00`00HaYS6P0>HaX2000;
E[/300000chj0019e@08BMD00`00CMA=e009CM@01000GUINEP002FZE00<007nCOi<00gnC00<004kM
C]d01dkM00<004JmA[d024Jm00<004kMC]d010001dkL00<005LMEad02ULM00<005LMEad00`001EKm
00@005KmE_d000aFo@<000]Fo@80011oo`0077oo00<007ooOol06Woo0`004goo0P002e;m00<005Kl
E_`02EKl0P0000=K7000HaX036<J0P0000=S6`00E[/02UJk00D000Ej000n>P0000U9e@03001=e4gD
00Q=e005001NEUiFGUH00009JYD00`00Oi=oT`03Oi<00`00C]e>g@07C]d00`00A[e6_@04A[d7000;
C]`00`00EaeG7@0:Ead30008E_d01000E_eFo@002EKm0`000UKm00<005KmE_d02UKm0P003goo000L
Ool00`00Oomoo`0GOol3000GOol00`00D_eBo@0:D_d00`00E_aFo006E_`20004Fa`00`00HaYS6P08
HaX20003Ha/00`00E[]F^`0:E[/40009BMD00`00CMA=e008CM@01@00GUINEUiF00002FZE00<007nC
Oi<00WnC00<004kMC]d01dkM20001TYk00<004kLC]`02TkL00<005LMEad01ELM10000UKm00<005Km
E_d01eKm00@005KmE_d000EFo@<000EFo@03001FoEKm00YFo@8000moo`006goo00<007ooOol05Goo
0`006goo00<005;mD_d02U;m00<005KlE_`00eKl0P001e/L00<006<JHaX01F<J0P001V<K00<005Jk
E[/02UJk100024WE00<004gDCM@01dgD00<005iFGUH00eiF00<006ZEJYD01FZE00<007nCOi<00gnC
00@004kMC]e>g@H000=>NP03001:NdYk00Q:N`03001>g4kL00]>g003001G7ELM00@000IFo@03001F
oEKm00QFo@03001Fo@00009Fo@<000UFo@03001FoEKm00UFo@8000moo`006goo0P004goo0`007goo
0P002e;m00<005KlE_`00P002U/L00<006<JHaX00V<J0P002F<K00<005JkE[/02EJk10002DWE00<0
04gDCM@01DgD00<005iFGUH015iF00<006ZEJYD01FZE00<007nCOi<00WnC1@002Dij00<004YkBW/0
2DYk00<004kLC]`02TkL0`002eKm00<005KmE_d025Km100035Km00<005KmE_d01UKm0`0000=oo`00
Ool03Woo000KOol00`00Oomoo`0?Ool3000TOol00`00D_eBo@07D_d4000=Fa`01000HaX0000036<K
00<005JkE[/025Jk10002DWE00<004gDCM@014gD00<005iFGUH01EiF00<006ZEJYD01FZE00<007nC
Oi<00WnC00@005JjE[X000]>NP03001:NdYk00U:N`03001>g4kL00I>g0<0009Fo003001FoEKm00YF
o@03001FoEKm00AFo@@0009Fo@03001FoEKm00]Fo@03001FoEKm00=Fo@8000Aoo`03001oogoo00eo
o`006goo00<007ooOol03Goo0P00:7oo00@005;mD_eBo@D000=Bo@03001K75/L00]K708000iS6`03
001F^eJk00EF^`<0009Fg0@000M9e@03001=e4gD00==e003001NEUiF00MNEP03001ZUFZE00=ZU@03
001oTgnC009oT`05001F^UJjE[X0000;CWX00`00BW]:N`0:BW/00`00C]a>g003C]`20005E_`00`00
E_eFo@0:E_d00`00E_eFo@040004E_d01000E_eFo@0035Km00<005KmE_d00`001Woo00<007ooOol0
3Goo000KOol2000;Ool3000[Ool30009D_d00`00FaaK7008Fa`20002Fad00`00Ha]S6`0<Ha/00`00
E[]F^`040005E]`01@0000d002fH00001TWE00<004gDCM@00TgD00<005iFGUH025iF00<006ZEJYD0
0fZE00<007nCOi<00WnC00<005JjE[X00UJj00<004ijCWX02Dij00<004YkBW/02DYk00<004kLC]`0
0`0025Kl00<005KmE_d02EKm0`002EKm00<005Km000035Km0`002Goo00<007ooOol03Goo000KOol0
0`00Oomoo`07Ool3000_Ool00`00D_eBo@09D_d20005Fa`30005Fad00`00Ha]S6`0;Ha/3000:E]`2
0002;IP20004BMD01@00CMA=e4gD000035iF00D006ZEJYEZU@0000AoT`03001F^UJj00=F^P03001>
NTij00U>NP03001:NdYk00U:N`<000aFo003001FoEKm00AFo@@0009Fo@03001FoEKm00QFo@03001F
o@0000MFo@@000eoo`03001oogoo00aoo`001Woo00<007ooOol00Woo00<007ooOol01@000Woo00<0
07ooOol00Woo00<007ooOol01Goo0`00<goo00<005;mD_d02U;m00<005/LFa`00P002E/M00<006<K
Ha/01f<K0`000U/L00<005KLE]`025KL0P0012fH0P000TWE00D004gDCMA=e00000aNEP05001ZUFZE
JYD00004Oi<00`00E[YF^P04E[X00`00CWY>NP09CWX00`00BW]:N`04BW/40002E_`00`00E_aFo00:
E_`00`00E_eFo@040007E_d00`00E_eFo@07E_d01000E_eFo@000UKm10004Goo00<007ooOol037oo
0005Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000=oo`03001oogoo009oo`<003Moo`03001B
oE;m00UBo@<000aK7@03001S6f<K00AS6`8000EK7003001Fg5KL00UFg08000D]V0060019eDWE001=
e0003EiF00D006ZEJYEZU@0000=oT`03001F^UJj00IF^P03001>NTij00Q>NP03001:NdYk00@000MF
o003001Fo5Kl00UFo0<000]Fo@03001FoEKm00QFo@03001Fo@00008001Eoo`03001oogoo00aoo`00
1Goo00<007oo000027oo00<007ooOol00goo00@007ooOomoo`D003]oo`03001BoE;m00EBo@<0009B
o@03001K7E/M00]K7@03001S6f<K00<000QK7003001Fg5KL00QFg08000H]V0@000mNEP03001ZU@00
00AoT`03001F^UJj00IF^P03001>NTij00Q>NP<000]Fo003001Fo5Kl00MFo080009G7@03001FoEKm
00YFo@03001FoEKm00EFo@@001Qoo`03001oogoo00aoo`001Goo00<007oo000027oo00@007ooOomo
o`8000Aoo`8003moo`03001BoE;m00@000IBo@03001K7E/M00YK7@<000]K7003001Fg5KL00UFg003
000]V2fH00H]V003001NEUiF00iNEP03001ZU@00009oT`8000YF^P03001>NTij00A>NP<0009Fg003
001Fo5Kl00YFo003001Fo5Kl00=Fo0<000EG7@03001FoEKm00YFo@03001FoEKm00@000=oo`03001o
ogoo01Ioo`03001oogoo00aoo`001Goo00<007oo000027oo00D007ooOomoo`0000Ioo`03001oogoo
03ioo`8000]Bo@8000QK7@80009G7@03001K75/L00YK7003001Fg5KL00IFg0@000L]V003001NEUiF
00iNEP04001ZU@00Oi<2000;E[X00`00CWY>NP040005E]`00`00E_aFo00;E_`00`00E_aFo0020008
Ead00`00E_eFo@0:E_d30008Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool000Ioo`03001oogoo00Io
o`8000=oo`<000Eoo`8003moo`03001BoE;m00]Bo@03001K7E/M00=K7@8000EG7@03001K75/L00YK
7003001Fg5KL00=Fg08000=Fo@03000]V2fH00H]V003001NEUiF00iNEP<00003Fhl005Jj00YF^P<0
00YFg003001Fo5Kl00YFo0<000]G7@03001FoEKm00EFo@@000aoo`03001oogoo01Aoo`03001oogoo
00aoo`007Woo00<007ooOol0?Goo00<005;mD_d02e;m00<005/MFad00P0025LM0P002U/L00<005KL
E]`00`001EKm0P001bfH00<005iFGUH03UiF00H005^?Fhl005kk0006E[X40002E_`00`00E]aFg009
E]`00`00E_aFo006E_`30002Ead00`00EaeG7@0:Ead00`00E_eFo@04000AOol00`00Oomoo`0DOol0
0`00Oomoo`0;Ool001moo`03001oogoo03eoo`8000]Bo@<000aG7@03001K75/L00IK70@000QFo@80
00L]V003001NEUiF00eNEP04001KSe^?0002G_/00`00E[YF^P040006E_`00`00E]aFg00:E]`00`00
E_aFo003E_`20005Ead00`00EaeG7@0:Ead3000EOol00`00Oomoo`0DOol00`00Oomoo`0;Ool0021o
o`03001oogoo03ioo`03001BoE;m00EBo@<0009Fo@03001G7ELM00]G7@04001K75/LFa`40003D_d0
0`00E_eFo@07E_d00`00;IP]V006;IP00`00GUINEP0<GUH00`00Fhl00003G_/3000;E_`00`00E]aF
g009E]`00`00E_aFo0030008Ead00`00EaeG7@06Ead3000IOol00`00Oomoo`0COol00`00Oomoo`0;
Ool0025oo`8003moo`03001BoE;m00@000IFo@03001G7ELM00YG7@@000QBo@03001FoEKm00IFo@80
00L]V003001NEUiF00]NEP04001KS`00G_/30002E_`00`00E_aFo00:E_`00`00E]aFg008E]`3000<
Ead00`00EaeG7@03Ead2000MOol00`00Oomoo`0BOol00`00Oomoo`0;Ool002=oo`03001oogoo03eo
o`8000]Fo@8000MG7@<0009Fo@03001BoE;m00QBo@8000MFo@03000]V2fH00D]V003001NEUiF00]N
EP04001KS`000005E_`00`00E_aFo00;E_`00`00E]aFg004E]`30002Ead00`00EaeG7@0:Ead00`00
EaeG7@03000POol00`00Oomoo`0AOol00`00Oomoo`0;Ool002Aoo`03001oogoo03eoo`03001FoEKm
00]Fo@03001G7ELM00@000IFo@03001BoE;m00UBo@03001FoEKm00D000P]V003001NEUiF00UNEP03
001KS`0000QFo003001Fo5Kl00YFo003001Fg5KL00@000IG7@03001G7ELM00UG7@<002=oo`03001o
ogoo015oo`03001oogoo00]oo`009Goo00<007ooOol0?Goo00<005KmE_d02UKm0`002UKm00<005;m
D_d02E;m0`001ELM00<002fH;IP01BfH00<005iFGUH025iF00<005^?00002UKl00<005KlE_`02EKl
0`002eLM00<005LMEad01ELM0`009goo00<007ooOol047oo00<007ooOol02goo000VOol00`00Oomo
o`0mOol20007E_d30002E_d00`00E_eFo@09E_d00`00D_eBo@05D_d30002D_d00`00EaeG7@03Ead0
0`00;IP]V005;IP00`00GUINEP08GUH3000;E_`00`00E_aFo004E_`40002Dad00`00EaeG7@0:Ead0
0`00EaeG7@04000[Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool002Moo`8003moo`03001FoEKm00@0
00IFo@03001FoEKm00UFo@03001BoE;m00@000IBo@03001G7ELM00=G7@03000]V2fH00D]V003001N
EUiF00INEP04001KS`00000;E_`00`00E_aFo0040007Dad00`00EaeG7@09Ead3000_Ool00`00Oomo
o`0@Ool00`00Oomoo`0:Ool002Uoo`03001oogoo03eoo`8000]Fo@03001FoEKm00QFo@<000]Bo@03
001G7ELM00=G7@03000]V2fH00@]V003001NEUiF00ENEP03001KS`00009Fo@03001Fo5Kl00MFo0@0
00aC7@03001G7ELM00EG7@<003=oo`03001oogoo00moo`03001oogoo00Yoo`00:Woo00<007ooOol0
?Goo00<005KmE_d02UKm00<005KmE_d015Km0`000UKm00<005;mD_d02U;m00<005LMEad00eLM00<0
02fH;IP00bfH00<005iFGUH01EiF0P0015Km00@005KlE_aFo0D000=Bo@03001C7E<M00]C7@03001G
7ELM00@003Moo`03001oogoo00ioo`03001oogoo00Yoo`00:goo00<007ooOol0?Goo00<005KmE_d0
2UKm00<005KmE_d00`001UKm00<005;mD_d02U;m00<005LMEad010001BfH00<005iFGUH00eiF0P00
1EKm10002E;m00<005<MDad02U<M0`00?7oo00<007ooOol03Goo00<007ooOol02Woo000/Ool2000n
Ool00`00E_eFo@09E_d3000:E_d00`00D_eBo@09D_d30004E_d00`00;IP]V002;IP00`00GUINEP03
GUH01000E_eFoEKm0`000U;m00<005;mD_d02E;m00<005<MDad01E<M1000?goo00<007ooOol03Goo
00<007ooOol02Woo000^Ool00`00Oomoo`0lOol00`00E_eFo@05E_d30002E_d00`00E_eFo@09E_d0
0`00D_eBo@05D_d30002E_d00`00E_eFo@03E_d20002;IP00`00GUINEP02GUH50006D_d00`00D_eB
o@09D_d00`00DaeC7@040014Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool002moo`03001oogoo03ao
o`03001FoEKm00@000IFo@03001FoEKm00UFo@03001BoE;m00@000IFo@03001FoEKm00AFo@04000]
V2fH0002GUH2000:D_d00`00D_eBo@09D_d30019Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool0031o
o`03001oogoo03aoo`8000YFo@03001FoEKm00UFo@<000]Fo@03001FoEKm00AFo@03000]V000009N
EP8000]Bo@03001BoE;m00EBo@<004eoo`03001oogoo00]oo`03001oogoo00Uoo`00<Goo0P00?Goo
00<005KmE_d02EKm00<005KmE_d01EKm0`000UKm00<005KmE_d02UKm00<005KmE_d01P0000ENEP00
E_eFo@0000]Bo@03001BoE;m00@0051oo`03001oogoo00]oo`03001oogoo00Uoo`00<goo00<007oo
Ool0>goo00<005KmE_d02EKm00<005KmE_d010001UKm00<005KmE_d02EKm0`001EKm0`000eKm00<0
05;mD_d025;m0`00EGoo00<007ooOol02Woo00<007ooOol02Goo000dOol00`00Oomoo`0kOol00`00
E_eFo@08E_d3000;E_d20006E_d30002E_d00`00E_eFo@04E_d00`00E_eFo@03E_d00`00D_eBo@04
D_d3001IOol00`00Oomoo`09Ool00`00Oomoo`09Ool003Eoo`03001oogoo03]oo`03001FoEKm00AF
o@<0009Fo@03001FoEKm00]Fo@03001FoEKm00<000IFo@03001FoEKm00YFo@03001BoE;m00<005ao
o`03001oogoo00Uoo`03001oogoo00Uoo`00=Woo00<007ooOol0>goo00<005KmE_d00`001UKm00<0
05KmE_d02UKm0`002UKm0P002EKm1000H7oo00<007ooOol027oo00<007ooOol02Goo000gOol2000l
Ool2000:E_d20007E_d30002E_d00`00E_eFo@0:E_d01000E_eFoEKm1@00IGoo00<007ooOol01goo
00<007ooOol02Goo000iOol00`00Oomoo`0jOol00`00E_eFo@0:E_d00`00E_eFo@040006E_d00`00
E_eFo@09E_d4001[Ool00`00Oomoo`07Ool00`00Oomoo`08Ool003Yoo`03001oogoo03Yoo`03001F
oEKm00UFo@<000]Fo@03001FoEKm00EFo@<006moo`03001oogoo00Moo`03001oogoo00Qoo`00>goo
00<007ooOol0>Woo0P001UKm0`000UKm00<005KmE_d02UKm00<005KmE_d01000Lgoo00<007ooOol0
1Woo00<007ooOol027oo000lOol2000lOol00`00E_eFo@030006E_d00`00E_eFo@09E_d3001hOol0
0`00Oomoo`05Ool00`00Oomoo`08Ool003ioo`03001oogoo03Yoo`8000YFo@8000IFo@<007aoo`03
001oogoo00Aoo`03001oogoo00Qoo`00?goo00<007ooOol0>Woo00<005KmE_d02UKm00<005KmE_d0
0`00Ogoo00<007ooOol017oo00<007ooOol027oo0010Ool00`00Oomoo`0jOol00`00E_eFo@09E_d3
0023Ool00`00Oomoo`03Ool00`00Oomoo`08Ool0045oo`8003]oo`03001FoEKm00EFo@<008Moo`03
001oogoo00=oo`03001oogoo00Moo`00@goo00<007ooOol0>Goo00<005KmE_d01000RWoo00<007oo
Ool00goo00<007ooOol01goo0014Ool00`00Oomoo`0iOol2002?Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool004Eoo`03001oogoo03Qoo`03001oogoo08moo`05001oogooOol00009Ool004Ioo`03001o
ogoo03Moo`03001oogoo091oo`04001oogoo0009Ool004Moo`8003Moo`03001oogoo091oo`04001o
ogoo0009Ool004Uoo`03001oogoo03Aoo`03001oogoo095oo`03001oo`0000Uoo`00BWoo00<007oo
Ool0<goo00<007ooOol0TWoo00<007oo000027oo001;Ool00`00Oomoo`0bOol00`00Oomoo`2COol2
0008Ool004aoo`80039oo`03001oogoo09=oo`8000Qoo`00CWoo00<007ooOol0;goo00<007ooOol0
Tgoo0P0027oo001?Ool00`00Oomoo`0^Ool00`00Oomoo`2?Ool4000:Ool0051oo`03001oogoo02eo
o`03001oogoo08]oo`@000ioo`00DGoo0P00;Goo00<007ooOol0Qgoo10004Woo001COol00`00Oomo
o`0ZOol00`00Oomoo`23Ool4000FOol005Aoo`03001oogoo02Uoo`03001oogoo081oo`<001Yoo`00
EGoo00<007ooOol0:7oo00<007ooOol0O7oo10007Goo001FOol00`00Oomoo`0WOol00`00Oomoo`1h
Ool4000QOol005Moo`8002Moo`03001oogoo07Aoo`@002Eoo`00FGoo00<007ooOol097oo00<007oo
Ool0L7oo1000:Goo001JOol00`00Oomoo`0SOol00`00Oomoo`1]Ool3000]Ool005]oo`03001oogoo
029oo`03001oogoo06Uoo`@0031oo`00G7oo0P008Woo00<007ooOol0IGoo1000=7oo001NOol00`00
Oomoo`0NOol00`00Oomoo`1ROol4000hOol005moo`03001oogoo01eoo`03001oogoo05ioo`@003ao
o`00H7oo00<007ooOol077oo00<007ooOol0Fgoo0`00@7oo001QOol2000LOol00`00Oomoo`1GOol4
0013Ool006=oo`03001oogoo01Uoo`03001oogoo05=oo`@004Moo`00I7oo00<007ooOol067oo00<0
07ooOol0Cgoo1000Bgoo001UOol00`00Oomoo`0GOol00`00Oomoo`1;Ool4001?Ool006Ioo`03001o
ogoo01Ioo`03001oogoo04Qoo`<005=oo`00Igoo0P005Woo00<007ooOol0A7oo1000EWoo001YOol0
0`00Oomoo`0COol00`00Oomoo`10Ool4001JOol006Yoo`03001oogoo019oo`03001oogoo03aoo`@0
05ioo`00Jgoo00<007ooOol04Goo00<007ooOol0>7oo1000HWoo001/Ool2000AOol00`00Oomoo`0e
Ool3001VOol006ioo`03001oogoo00ioo`03001oogoo035oo`@006Uoo`00Kgoo00<007ooOol03Goo
00<007ooOol0;Goo1000KGoo001`Ool00`00Oomoo`0<Ool00`00Oomoo`0YOol4001aOol0075oo`80
00aoo`03001oogoo02Eoo`@007Eoo`00Lgoo00<007ooOol02Goo00<007ooOol08Woo0`00NGoo001d
Ool00`00Oomoo`08Ool00`00Oomoo`0NOol4001lOol007Eoo`03001oogoo00Moo`03001oogoo01Yo
o`@0081oo`00MWoo00<007ooOol01Woo00<007ooOol05Woo1000Q7oo001gOol20006Ool00`00Oomo
o`0BOol40028Ool007Uoo`03001oogoo00=oo`03001oogoo00moo`<008aoo`00NWoo00<007ooOol0
0Woo00<007ooOol02goo1000Sgoo001kOol01@00Oomoogoo00002Goo1000Tgoo001lOol200000goo
001oo`04Ool4002GOol007ioo`800003Ool00000008009]oo`00Ogoo0P00Wgoo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0991483, -0.00851284, 
  0.00376186, 0.00376186}}]
}, Open  ]],

Cell[TextData[StyleBox[
"The frequency spectrum may be quickly verified with a 32-point DFT."]], 
  "Text"],

Cell[BoxData[
    \(\(H = Abs[DFT[ZeroPad[hR, {0, 17}, {0, 17}]]]*32^2; \)\)], "Input",
  CellLabel->"In[48]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot3D[H, PlotRange -> All]; \)\)], "Input",
  CellLabel->"In[49]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.20131 .17781 -11.698 -9 ]
[.20131 .17781 .302 0 ]
[.40909 .09608 -10.8909 -9 ]
[.40909 .09608 1.10907 0 ]
[.63425 .0076 -10.0839 -9 ]
[.63425 .0076 1.91614 0 ]
[.79552 .14001 0 -6.12026 ]
[.79552 .14001 12 2.87974 ]
[.88711 .28027 0 -5.98728 ]
[.88711 .28027 12 3.01272 ]
[.96711 .40279 0 -5.87447 ]
[.96711 .40279 12 3.12553 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01572 .31771 -24 -2.78679 ]
[.01572 .31771 0 6.21321 ]
[.00703 .37215 -18 -2.83297 ]
[.00703 .37215 0 6.16703 ]
[-0.00196 .42851 -24 -2.88096 ]
[-0.00196 .42851 0 6.11904 ]
[-0.01127 .4869 -6 -2.93086 ]
[-0.01127 .4869 0 6.06914 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.21035 .18732 m
.21487 .19208 L
s
[(10)] .20131 .17781 .94967 1 Mshowa
.41738 .10625 m
.42153 .11134 L
s
[(20)] .40909 .09608 .81515 1 Mshowa
.64163 .01845 m
.64532 .02387 L
s
[(30)] .63425 .0076 .68064 1 Mshowa
.125 Mabswid
.25047 .17161 m
.25314 .1745 L
s
.29122 .15565 m
.29385 .15859 L
s
.33262 .13945 m
.3352 .14242 L
s
.37466 .12298 m
.3772 .12599 L
s
.46079 .08926 m
.46322 .09235 L
s
.5049 .07199 m
.50728 .07512 L
s
.54973 .05443 m
.55206 .0576 L
s
.5953 .03659 m
.59757 .0398 L
s
.17084 .20279 m
.17359 .20561 L
s
.13192 .21803 m
.13471 .22081 L
s
.09359 .23304 m
.09641 .23578 L
s
.05583 .24783 m
.05869 .25053 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78318 .14446 m
.777 .14668 L
s
[(10)] .79552 .14001 -1 .36006 Mshowa
.87465 .28439 m
.86842 .28645 L
s
[(20)] .88711 .28027 -1 .33051 Mshowa
.95456 .40662 m
.94829 .40854 L
s
[(30)] .96711 .40279 -1 .30544 Mshowa
.125 Mabswid
.80252 .17404 m
.7988 .17536 L
s
.82131 .20279 m
.81759 .20409 L
s
.83959 .23075 m
.83586 .23202 L
s
.85736 .25793 m
.85363 .25919 L
s
.89149 .31014 m
.88774 .31135 L
s
.90788 .33521 m
.90413 .33641 L
s
.92384 .35963 m
.92009 .36081 L
s
.9394 .38343 m
.93564 .38459 L
s
.76327 .11401 m
.75957 .11536 L
s
.74277 .08265 m
.73908 .08403 L
s
.72165 .05034 m
.71797 .05174 L
s
.69987 .01704 m
.6962 .01846 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02798 .31304 m
.03412 .31071 L
s
[(0.25)] .01572 .31771 1 -0.38071 Mshowa
.01934 .36759 m
.02549 .36531 L
s
[(0.5)] .00703 .37215 1 -0.37045 Mshowa
.01039 .42406 m
.01656 .42184 L
s
[(0.75)] -0.00196 .42851 1 -0.35979 Mshowa
.00112 .48258 m
.00731 .48042 L
s
[(1)] -0.01127 .4869 1 -0.3487 Mshowa
.125 Mabswid
.03469 .27073 m
.03836 .26931 L
s
.03303 .2812 m
.0367 .27978 L
s
.03136 .29175 m
.03503 .29033 L
s
.02968 .30236 m
.03335 .30095 L
s
.02628 .3238 m
.02996 .32241 L
s
.02456 .33464 m
.02825 .33325 L
s
.02283 .34554 m
.02652 .34416 L
s
.02109 .35653 m
.02478 .35515 L
s
.01757 .37873 m
.02127 .37737 L
s
.0158 .38994 m
.01949 .38859 L
s
.01401 .40124 m
.01771 .39989 L
s
.01221 .41261 m
.01591 .41127 L
s
.00856 .4356 m
.01227 .43427 L
s
.00672 .44722 m
.01043 .4459 L
s
.00487 .45892 m
.00858 .45761 L
s
.003 .47071 m
.00671 .4694 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.654 .762 .929 r
.38758 .79686 .39807 .80547 .41557 .80057 .40516 .7919 Metetra
.649 .761 .931 r
.40516 .7919 .41557 .80057 .43319 .79584 .42284 .78711 Metetra
.672 .766 .921 r
.42284 .78711 .43319 .79584 .45093 .79005 .44067 .78126 Metetra
.795 .781 .84 r
.44067 .78126 .45093 .79005 .46892 .77553 .45876 .76665 Metetra
.88 .765 .73 r
.45876 .76665 .46892 .77553 .48712 .74296 .47711 .73394 Metetra
.908 .749 .672 r
.47711 .73394 .48712 .74296 .50526 .69251 .49546 .68329 Metetra
.914 .745 .658 r
.49546 .68329 .50526 .69251 .52306 .63704 .51347 .62763 Metetra
.904 .752 .682 r
.51347 .62763 .52306 .63704 .5405 .59227 .5311 .58269 Metetra
.866 .765 .749 r
.5311 .58269 .5405 .59227 .55783 .56534 .54855 .55564 Metetra
.775 .766 .845 r
.54855 .55564 .55783 .56534 .57525 .55278 .56607 .54301 Metetra
.654 .738 .912 r
.56607 .54301 .57525 .55278 .59287 .54795 .58376 .53811 Metetra
.674 .744 .904 r
.58376 .53811 .59287 .54795 .61058 .54212 .60155 .53222 Metetra
.663 .741 .908 r
.60155 .53222 .61058 .54212 .62841 .5368 .61946 .52683 Metetra
.665 .742 .907 r
.61946 .52683 .62841 .5368 .64635 .53136 .63748 .52133 Metetra
.664 .741 .908 r
.63748 .52133 .64635 .53136 .66441 .52593 .65562 .51584 Metetra
.664 .741 .908 r
.65562 .51584 .66441 .52593 .68259 .52047 .67387 .51031 Metetra
.663 .741 .908 r
.67387 .51031 .68259 .52047 .70089 .51499 .69225 .50476 Metetra
.663 .741 .908 r
.69225 .50476 .70089 .51499 .7193 .50947 .71075 .49918 Metetra
.662 .741 .908 r
.71075 .49918 .7193 .50947 .73784 .50397 .72937 .49361 Metetra
.664 .742 .908 r
.72937 .49361 .73784 .50397 .75649 .49834 .74811 .48792 Metetra
.653 .737 .912 r
.74811 .48792 .75649 .49834 .77531 .49323 .76701 .48274 Metetra
.672 .745 .905 r
.76701 .48274 .77531 .49323 .79417 .48711 .78597 .47654 Metetra
.469 .654 .941 r
.78597 .47654 .79417 .48711 .81385 .48887 .80572 .47826 Metetra
0 .256 .76 r
.80572 .47826 .81385 .48887 .83513 .50544 .82704 .49481 Metetra
.651 .2 0 r
.82704 .49481 .83513 .50544 .85865 .54056 .85058 .52996 Metetra
.765 .327 0 r
.85058 .52996 .85865 .54056 .884 .5871 .87594 .57657 Metetra
.704 .257 0 r
.87594 .57657 .884 .5871 .9096 .62889 .90156 .61842 Metetra
0 .104 .634 r
.90156 .61842 .9096 .62889 .93379 .65237 .92581 .64192 Metetra
.361 .614 .947 r
.92581 .64192 .93379 .65237 .95617 .65711 .94828 .64661 Metetra
.621 .749 .938 r
.94828 .64661 .95617 .65711 .97764 .65269 .96987 .64213 Metetra
.644 .759 .933 r
.96987 .64213 .97764 .65269 .99913 .64715 .99148 .63651 Metetra
.656 .741 .913 r
.37701 .78711 .38758 .79686 .40516 .7919 .39465 .78209 Metetra
.651 .74 .914 r
.39465 .78209 .40516 .7919 .42284 .78711 .41241 .77724 Metetra
.673 .746 .905 r
.41241 .77724 .42284 .78711 .44067 .78126 .4303 .77133 Metetra
.788 .763 .831 r
.4303 .77133 .44067 .78126 .45876 .76665 .44849 .75668 Metetra
.874 .755 .729 r
.44849 .75668 .45876 .76665 .47711 .73394 .467 .72397 Metetra
.904 .743 .672 r
.467 .72397 .47711 .73394 .49546 .68329 .48554 .67337 Metetra
.911 .741 .659 r
.48554 .67337 .49546 .68329 .51347 .62763 .50377 .61776 Metetra
.902 .749 .682 r
.50377 .61776 .51347 .62763 .5311 .58269 .52158 .57286 Metetra
.865 .764 .749 r
.52158 .57286 .5311 .58269 .54855 .55564 .53917 .54579 Metetra
.775 .765 .845 r
.53917 .54579 .54855 .55564 .56607 .54301 .55678 .53311 Metetra
.654 .738 .912 r
.55678 .53311 .56607 .54301 .58376 .53811 .57455 .52815 Metetra
.674 .744 .904 r
.57455 .52815 .58376 .53811 .60155 .53222 .59241 .52219 Metetra
.663 .741 .908 r
.59241 .52219 .60155 .53222 .61946 .52683 .61039 .51675 Metetra
.665 .742 .907 r
.61039 .51675 .61946 .52683 .63748 .52133 .6285 .51118 Metetra
.664 .741 .908 r
.6285 .51118 .63748 .52133 .65562 .51584 .64672 .50562 Metetra
.664 .741 .908 r
.64672 .50562 .65562 .51584 .67387 .51031 .66505 .50003 Metetra
.663 .741 .908 r
.66505 .50003 .67387 .51031 .69225 .50476 .68351 .49441 Metetra
.663 .741 .908 r
.68351 .49441 .69225 .50476 .71075 .49918 .70209 .48876 Metetra
.662 .741 .908 r
.70209 .48876 .71075 .49918 .72937 .49361 .7208 .48313 Metetra
.664 .742 .908 r
.7208 .48313 .72937 .49361 .74811 .48792 .73962 .47736 Metetra
.653 .737 .912 r
.73962 .47736 .74811 .48792 .76701 .48274 .75861 .47211 Metetra
.672 .744 .905 r
.75861 .47211 .76701 .48274 .78597 .47654 .77766 .46585 Metetra
.47 .655 .941 r
.77766 .46585 .78597 .47654 .80572 .47826 .79748 .46747 Metetra
0 .261 .764 r
.79748 .46747 .80572 .47826 .82704 .49481 .81885 .4839 Metetra
.642 .192 0 r
.81885 .4839 .82704 .49481 .85058 .52996 .84238 .51888 Metetra
.755 .318 0 r
.84238 .51888 .85058 .52996 .87594 .57657 .86771 .56529 Metetra
.684 .242 0 r
.86771 .56529 .87594 .57657 .90156 .61842 .89333 .60695 Metetra
0 .132 .665 r
.89333 .60695 .90156 .61842 .92581 .64192 .91761 .63031 Metetra
.389 .608 .936 r
.91761 .63031 .92581 .64192 .94828 .64661 .94016 .6349 Metetra
.626 .729 .921 r
.94016 .6349 .94828 .64661 .96987 .64213 .96185 .63033 Metetra
.647 .739 .916 r
.96185 .63033 .96987 .64213 .99148 .63651 .98357 .62463 Metetra
.647 .616 .805 r
.3667 .76851 .37701 .78711 .39465 .78209 .38437 .76343 Metetra
.644 .615 .806 r
.38437 .76343 .39465 .78209 .41241 .77724 .40215 .7585 Metetra
.657 .62 .802 r
.40215 .7585 .41241 .77724 .4303 .77133 .42007 .75257 Metetra
.736 .653 .767 r
.42007 .75257 .4303 .77133 .44849 .75668 .4383 .73832 Metetra
.822 .684 .711 r
.4383 .73832 .44849 .75668 .467 .72397 .4569 .70685 Metetra
.868 .7 .672 r
.4569 .70685 .467 .72397 .48554 .67337 .47558 .65829 Metetra
.885 .712 .662 r
.47558 .65829 .48554 .67337 .50377 .61776 .49398 .60491 Metetra
.883 .728 .685 r
.49398 .60491 .50377 .61776 .52158 .57286 .51196 .5617 Metetra
.852 .75 .75 r
.51196 .5617 .52158 .57286 .53917 .54579 .52968 .53552 Metetra
.769 .759 .844 r
.52968 .53552 .53917 .54579 .55678 .53311 .54738 .5231 Metetra
.654 .738 .911 r
.54738 .5231 .55678 .53311 .57455 .52815 .56522 .51805 Metetra
.674 .744 .903 r
.56522 .51805 .57455 .52815 .59241 .52219 .58316 .51205 Metetra
.663 .741 .908 r
.58316 .51205 .59241 .52219 .61039 .51675 .60123 .50654 Metetra
.665 .742 .907 r
.60123 .50654 .61039 .51675 .6285 .51118 .61941 .5009 Metetra
.664 .741 .908 r
.61941 .5009 .6285 .51118 .64672 .50562 .63771 .49528 Metetra
.664 .741 .908 r
.63771 .49528 .64672 .50562 .66505 .50003 .65613 .48962 Metetra
.663 .741 .908 r
.65613 .48962 .66505 .50003 .68351 .49441 .67467 .48394 Metetra
.663 .741 .908 r
.67467 .48394 .68351 .49441 .70209 .48876 .69333 .47822 Metetra
.662 .741 .908 r
.69333 .47822 .70209 .48876 .7208 .48313 .71212 .47251 Metetra
.664 .741 .908 r
.71212 .47251 .7208 .48313 .73962 .47736 .73104 .46667 Metetra
.653 .738 .911 r
.73104 .46667 .73962 .47736 .75861 .47211 .75011 .46133 Metetra
.672 .744 .905 r
.75011 .46133 .75861 .47211 .77766 .46585 .76925 .45502 Metetra
.482 .661 .94 r
.76925 .45502 .77766 .46585 .79748 .46747 .78912 .45624 Metetra
0 .301 .794 r
.78912 .45624 .79748 .46747 .81885 .4839 .81044 .47161 Metetra
0 0 .424 r
.81044 .47161 .81885 .4839 .84238 .51888 .8338 .50469 Metetra
.648 .237 0 r
.8338 .50469 .84238 .51888 .86771 .56529 .85886 .54864 Metetra
0 0 .485 r
.85886 .54864 .86771 .56529 .89333 .60695 .88421 .58799 Metetra
.078 .29 .774 r
.88421 .58799 .89333 .60695 .91761 .63031 .90833 .60986 Metetra
.504 .544 .83 r
.90833 .60986 .91761 .63031 .94016 .6349 .93086 .61385 Metetra
.63 .608 .81 r
.93086 .61385 .94016 .6349 .96185 .63033 .95258 .60913 Metetra
.642 .614 .806 r
.95258 .60913 .96185 .63033 .98357 .62463 .97435 .60333 Metetra
.62 .506 .702 r
.35718 .73164 .3667 .76851 .38437 .76343 .37478 .72649 Metetra
.619 .506 .703 r
.37478 .72649 .38437 .76343 .40215 .7585 .3925 .72147 Metetra
.625 .51 .702 r
.3925 .72147 .40215 .7585 .42007 .75257 .41036 .71558 Metetra
.671 .538 .694 r
.41036 .71558 .42007 .75257 .4383 .73832 .42852 .7026 Metetra
.742 .584 .679 r
.42852 .7026 .4383 .73832 .4569 .70685 .44704 .67492 Metetra
.798 .623 .665 r
.44704 .67492 .4569 .70685 .47558 .65829 .46571 .63256 Metetra
.83 .655 .664 r
.46571 .63256 .47558 .65829 .49398 .60491 .48416 .58592 Metetra
.841 .685 .689 r
.48416 .58592 .49398 .60491 .51196 .5617 .50224 .5479 Metetra
.823 .721 .752 r
.50224 .5479 .51196 .5617 .52968 .53552 .52007 .5245 Metetra
.754 .746 .845 r
.52007 .5245 .52968 .53552 .54738 .5231 .53787 .51295 Metetra
.656 .739 .911 r
.53787 .51295 .54738 .5231 .56522 .51805 .55578 .50778 Metetra
.672 .742 .903 r
.55578 .50778 .56522 .51805 .58316 .51205 .5738 .50179 Metetra
.663 .741 .908 r
.5738 .50179 .58316 .51205 .60123 .50654 .59195 .4962 Metetra
.665 .741 .907 r
.59195 .4962 .60123 .50654 .61941 .5009 .61021 .4905 Metetra
.664 .741 .908 r
.61021 .4905 .61941 .5009 .63771 .49528 .62859 .48481 Metetra
.664 .741 .908 r
.62859 .48481 .63771 .49528 .65613 .48962 .64709 .47909 Metetra
.663 .741 .908 r
.64709 .47909 .65613 .48962 .67467 .48394 .66571 .47333 Metetra
.663 .741 .908 r
.66571 .47333 .67467 .48394 .69333 .47822 .68446 .46754 Metetra
.663 .741 .908 r
.68446 .46754 .69333 .47822 .71212 .47251 .70334 .46175 Metetra
.664 .741 .908 r
.70334 .46175 .71212 .47251 .73104 .46667 .72234 .45585 Metetra
.655 .738 .911 r
.72234 .45585 .73104 .46667 .75011 .46133 .7415 .45037 Metetra
.671 .743 .904 r
.7415 .45037 .75011 .46133 .76925 .45502 .76073 .44404 Metetra
.512 .676 .938 r
.76073 .44404 .76925 .45502 .78912 .45624 .7806 .44422 Metetra
.088 .401 .856 r
.7806 .44422 .78912 .45624 .81044 .47161 .80171 .4566 Metetra
0 .058 .619 r
.80171 .4566 .81044 .47161 .8338 .50469 .82456 .48417 Metetra
0 .008 .584 r
.82456 .48417 .8338 .50469 .85886 .54864 .84887 .52092 Metetra
.049 .19 .69 r
.84887 .52092 .85886 .54864 .88421 .58799 .87344 .55359 Metetra
.391 .382 .73 r
.87344 .55359 .88421 .58799 .90833 .60986 .89701 .57123 Metetra
.558 .473 .715 r
.89701 .57123 .90833 .60986 .93086 .61385 .91927 .57363 Metetra
.612 .502 .704 r
.91927 .57363 .93086 .61385 .95258 .60913 .94089 .56859 Metetra
.618 .505 .703 r
.94089 .56859 .95258 .60913 .97435 .60333 .96257 .56264 Metetra
.605 .46 .658 r
.34861 .67659 .35718 .73164 .37478 .72649 .36606 .67136 Metetra
.605 .46 .658 r
.36606 .67136 .37478 .72649 .3925 .72147 .38362 .66622 Metetra
.608 .462 .658 r
.38362 .66622 .3925 .72147 .41036 .71558 .40132 .66044 Metetra
.633 .48 .657 r
.40132 .66044 .41036 .71558 .42852 .7026 .41929 .64958 Metetra
.681 .515 .655 r
.41929 .64958 .42852 .7026 .44704 .67492 .43757 .62814 Metetra
.729 .555 .656 r
.43757 .62814 .44704 .67492 .46571 .63256 .45603 .59603 Metetra
.766 .594 .666 r
.45603 .59603 .46571 .63256 .48416 .58592 .47437 .56063 Metetra
.786 .637 .696 r
.47437 .56063 .48416 .58592 .50224 .5479 .49246 .53135 Metetra
.78 .687 .761 r
.49246 .53135 .50224 .5479 .52007 .5245 .51036 .51268 Metetra
.731 .731 .85 r
.51036 .51268 .52007 .5245 .53787 .51295 .52825 .50268 Metetra
.658 .739 .91 r
.52825 .50268 .53787 .51295 .55578 .50778 .54623 .49734 Metetra
.67 .741 .903 r
.54623 .49734 .55578 .50778 .5738 .50179 .56433 .49139 Metetra
.663 .741 .908 r
.56433 .49139 .5738 .50179 .59195 .4962 .58255 .48573 Metetra
.664 .741 .907 r
.58255 .48573 .59195 .4962 .61021 .4905 .60089 .47998 Metetra
.664 .741 .908 r
.60089 .47998 .61021 .4905 .62859 .48481 .61936 .47422 Metetra
.664 .741 .908 r
.61936 .47422 .62859 .48481 .64709 .47909 .63794 .46843 Metetra
.664 .741 .908 r
.63794 .46843 .64709 .47909 .66571 .47333 .65665 .4626 Metetra
.663 .741 .908 r
.65665 .4626 .66571 .47333 .68446 .46754 .67549 .45673 Metetra
.663 .741 .908 r
.67549 .45673 .68446 .46754 .70334 .46175 .69445 .45086 Metetra
.664 .741 .908 r
.69445 .45086 .70334 .46175 .72234 .45585 .71354 .44489 Metetra
.657 .739 .91 r
.71354 .44489 .72234 .45585 .7415 .45037 .73277 .43922 Metetra
.669 .741 .904 r
.73277 .43922 .7415 .45037 .76073 .44404 .7521 .43291 Metetra
.559 .697 .933 r
.7521 .43291 .76073 .44404 .7806 .44422 .77193 .43137 Metetra
.307 .528 .904 r
.77193 .43137 .7806 .44422 .80171 .4566 .79268 .43875 Metetra
.098 .313 .789 r
.79268 .43875 .80171 .4566 .82456 .48417 .81471 .45714 Metetra
.173 .276 .73 r
.81471 .45714 .82456 .48417 .84887 .52092 .8378 .48203 Metetra
.364 .346 .705 r
.8378 .48203 .84887 .52092 .87344 .55359 .86112 .50375 Metetra
.504 .41 .681 r
.86112 .50375 .87344 .55359 .89701 .57123 .88377 .51455 Metetra
.576 .445 .665 r
.88377 .51455 .89701 .57123 .91927 .57363 .90555 .51439 Metetra
.601 .458 .659 r
.90555 .51439 .91927 .57363 .94089 .56859 .92692 .50891 Metetra
.604 .46 .658 r
.92692 .50891 .94089 .56859 .96257 .56264 .94838 .50277 Metetra
.601 .45 .648 r
.34048 .61627 .34861 .67659 .36606 .67136 .35775 .61097 Metetra
.601 .45 .649 r
.35775 .61097 .36606 .67136 .38362 .66622 .37514 .6057 Metetra
.603 .451 .649 r
.37514 .6057 .38362 .66622 .40132 .66044 .39265 .60006 Metetra
.617 .461 .648 r
.39265 .60006 .40132 .66044 .41929 .64958 .41036 .59149 Metetra
.646 .484 .65 r
.41036 .59149 .41929 .64958 .43757 .62814 .42833 .57686 Metetra
.681 .516 .656 r
.42833 .57686 .43757 .62814 .45603 .59603 .44647 .55604 Metetra
.712 .555 .674 r
.44647 .55604 .45603 .59603 .47437 .56063 .46459 .5332 Metetra
.734 .603 .711 r
.46459 .5332 .47437 .56063 .49246 .53135 .4826 .51379 Metetra
.736 .664 .78 r
.4826 .51379 .49246 .53135 .51036 .51268 .50054 .50051 Metetra
.705 .72 .861 r
.50054 .50051 .51036 .51268 .52825 .50268 .5185 .49227 Metetra
.66 .74 .909 r
.5185 .49227 .52825 .50268 .54623 .49734 .53657 .48676 Metetra
.667 .74 .904 r
.53657 .48676 .54623 .49734 .56433 .49139 .55475 .48087 Metetra
.663 .741 .908 r
.55475 .48087 .56433 .49139 .58255 .48573 .57305 .47513 Metetra
.664 .741 .907 r
.57305 .47513 .58255 .48573 .60089 .47998 .59147 .46932 Metetra
.664 .741 .908 r
.59147 .46932 .60089 .47998 .61936 .47422 .61001 .46349 Metetra
.664 .741 .908 r
.61001 .46349 .61936 .47422 .63794 .46843 .62868 .45763 Metetra
.664 .741 .908 r
.62868 .45763 .63794 .46843 .65665 .4626 .64748 .45173 Metetra
.663 .741 .908 r
.64748 .45173 .65665 .4626 .67549 .45673 .6664 .44579 Metetra
.663 .741 .908 r
.6664 .44579 .67549 .45673 .69445 .45086 .68545 .43983 Metetra
.664 .741 .908 r
.68545 .43983 .69445 .45086 .71354 .44489 .70462 .43379 Metetra
.66 .74 .909 r
.70462 .43379 .71354 .44489 .73277 .43922 .72394 .42791 Metetra
.667 .74 .905 r
.72394 .42791 .73277 .43922 .7521 .43291 .74337 .42165 Metetra
.607 .718 .924 r
.74337 .42165 .7521 .43291 .77193 .43137 .76314 .41815 Metetra
.489 .626 .912 r
.76314 .41815 .77193 .43137 .79268 .43875 .78349 .41985 Metetra
.398 .492 .839 r
.78349 .41985 .79268 .43875 .81471 .45714 .80463 .4279 Metetra
.425 .425 .755 r
.80463 .4279 .81471 .45714 .8378 .48203 .82643 .43958 Metetra
.497 .419 .699 r
.82643 .43958 .8378 .48203 .86112 .50375 .84841 .44929 Metetra
.554 .432 .668 r
.84841 .44929 .86112 .50375 .88377 .51455 .87008 .45267 Metetra
.587 .444 .654 r
.87008 .45267 .88377 .51455 .90555 .51439 .89132 .44977 Metetra
.599 .449 .649 r
.89132 .44977 .90555 .51439 .92692 .50891 .91241 .44382 Metetra
.601 .45 .649 r
.91241 .44382 .92692 .50891 .94838 .50277 .9336 .43747 Metetra
.607 .467 .665 r
.33195 .56655 .34048 .61627 .35775 .61097 .34909 .56118 Metetra
.607 .467 .665 r
.34909 .56118 .35775 .61097 .37514 .6057 .36635 .55579 Metetra
.608 .468 .665 r
.36635 .55579 .37514 .6057 .39265 .60006 .38372 .55023 Metetra
.615 .473 .665 r
.38372 .55023 .39265 .60006 .41036 .59149 .40124 .54343 Metetra
.631 .487 .668 r
.40124 .54343 .41036 .59149 .42833 .57686 .41895 .53405 Metetra
.653 .511 .678 r
.41895 .53405 .42833 .57686 .44647 .55604 .4368 .52202 Metetra
.676 .548 .701 r
.4368 .52202 .44647 .55604 .46459 .5332 .45472 .50907 Metetra
.694 .599 .746 r
.45472 .50907 .46459 .5332 .4826 .51379 .47265 .49753 Metetra
.699 .665 .813 r
.47265 .49753 .4826 .51379 .50054 .50051 .49061 .48857 Metetra
.683 .72 .877 r
.49061 .48857 .50054 .50051 .5185 .49227 .50864 .48175 Metetra
.662 .74 .908 r
.50864 .48175 .5185 .49227 .53657 .48676 .52678 .47608 Metetra
.665 .74 .906 r
.52678 .47608 .53657 .48676 .55475 .48087 .54504 .47022 Metetra
.663 .741 .908 r
.54504 .47022 .55475 .48087 .57305 .47513 .56342 .4644 Metetra
.664 .741 .908 r
.56342 .4644 .57305 .47513 .59147 .46932 .58193 .45854 Metetra
.664 .741 .908 r
.58193 .45854 .59147 .46932 .61001 .46349 .60055 .45264 Metetra
.664 .741 .908 r
.60055 .45264 .61001 .46349 .62868 .45763 .61931 .4467 Metetra
.664 .741 .908 r
.61931 .4467 .62868 .45763 .64748 .45173 .63819 .44072 Metetra
.664 .741 .908 r
.63819 .44072 .64748 .45173 .6664 .44579 .65719 .43471 Metetra
.663 .741 .908 r
.65719 .43471 .6664 .44579 .68545 .43983 .67633 .42866 Metetra
.664 .741 .908 r
.67633 .42866 .68545 .43983 .70462 .43379 .6956 .42255 Metetra
.662 .741 .908 r
.6956 .42255 .70462 .43379 .72394 .42791 .715 .41649 Metetra
.665 .74 .906 r
.715 .41649 .72394 .42791 .74337 .42165 .73453 .41024 Metetra
.64 .732 .915 r
.73453 .41024 .74337 .42165 .76314 .41815 .75428 .40515 Metetra
.597 .685 .904 r
.75428 .40515 .76314 .41815 .78349 .41985 .77435 .40226 Metetra
.558 .599 .851 r
.77435 .40226 .78349 .41985 .80463 .4279 .79483 .40204 Metetra
.552 .522 .776 r
.79483 .40204 .80463 .4279 .82643 .43958 .81566 .40331 Metetra
.569 .483 .718 r
.81566 .40331 .82643 .43958 .84841 .44929 .83665 .40367 Metetra
.588 .469 .686 r
.83665 .40367 .84841 .44929 .87008 .45267 .8576 .40131 Metetra
.601 .467 .671 r
.8576 .40131 .87008 .45267 .89132 .44977 .87845 .39628 Metetra
.606 .467 .666 r
.87845 .39628 .89132 .44977 .91241 .44382 .89933 .38996 Metetra
.607 .467 .665 r
.89933 .38996 .91241 .44382 .9336 .43747 .92034 .38343 Metetra
.625 .523 .718 r
.32247 .53467 .33195 .56655 .34909 .56118 .33958 .52923 Metetra
.625 .523 .718 r
.33958 .52923 .34909 .56118 .36635 .55579 .35679 .52376 Metetra
.625 .523 .718 r
.35679 .52376 .36635 .55579 .38372 .55023 .37411 .51821 Metetra
.628 .525 .718 r
.37411 .51821 .38372 .55023 .40124 .54343 .39156 .51233 Metetra
.635 .533 .722 r
.39156 .51233 .40124 .54343 .41895 .53405 .40915 .50576 Metetra
.646 .552 .734 r
.40915 .50576 .41895 .53405 .4368 .52202 .42685 .49849 Metetra
.66 .586 .761 r
.42685 .49849 .4368 .52202 .45472 .50907 .44466 .49096 Metetra
.671 .635 .805 r
.44466 .49096 .45472 .50907 .47265 .49753 .46257 .48375 Metetra
.674 .689 .856 r
.46257 .48375 .47265 .49753 .49061 .48857 .48056 .47717 Metetra
.669 .727 .893 r
.48056 .47717 .49061 .48857 .50864 .48175 .49866 .47111 Metetra
.663 .741 .908 r
.49866 .47111 .50864 .48175 .52678 .47608 .51688 .46531 Metetra
.664 .74 .907 r
.51688 .46531 .52678 .47608 .54504 .47022 .53522 .45944 Metetra
.664 .741 .908 r
.53522 .45944 .54504 .47022 .56342 .4644 .55368 .45355 Metetra
.664 .741 .908 r
.55368 .45355 .56342 .4644 .58193 .45854 .57226 .44762 Metetra
.664 .741 .908 r
.57226 .44762 .58193 .45854 .60055 .45264 .59098 .44165 Metetra
.664 .741 .908 r
.59098 .44165 .60055 .45264 .61931 .4467 .60981 .43563 Metetra
.664 .741 .908 r
.60981 .43563 .61931 .4467 .63819 .44072 .62878 .42958 Metetra
.664 .741 .908 r
.62878 .42958 .63819 .44072 .65719 .43471 .64787 .42349 Metetra
.663 .741 .908 r
.64787 .42349 .65719 .43471 .67633 .42866 .6671 .41736 Metetra
.664 .741 .908 r
.6671 .41736 .67633 .42866 .6956 .42255 .68646 .41118 Metetra
.663 .741 .908 r
.68646 .41118 .6956 .42255 .715 .41649 .70595 .40498 Metetra
.664 .74 .907 r
.70595 .40498 .715 .41649 .73453 .41024 .72557 .3987 Metetra
.658 .739 .91 r
.72557 .3987 .73453 .41024 .75428 .40515 .74535 .39269 Metetra
.647 .719 .901 r
.74535 .39269 .75428 .40515 .77435 .40226 .76532 .3872 Metetra
.635 .673 .869 r
.76532 .3872 .77435 .40226 .79483 .40204 .78549 .38236 Metetra
.626 .614 .819 r
.78549 .38236 .79483 .40204 .81566 .40331 .80586 .37787 Metetra
.622 .566 .771 r
.80586 .37787 .81566 .40331 .83665 .40367 .82637 .3731 Metetra
.622 .538 .739 r
.82637 .3731 .83665 .40367 .8576 .40131 .84698 .3676 Metetra
.624 .526 .724 r
.84698 .3676 .8576 .40131 .87845 .39628 .86768 .3614 Metetra
.625 .523 .719 r
.86768 .3614 .87845 .39628 .89933 .38996 .88849 .35483 Metetra
.625 .523 .718 r
.88849 .35483 .89933 .38996 .92034 .38343 .90945 .34817 Metetra
.652 .629 .815 r
.31209 .51721 .32247 .53467 .33958 .52923 .32922 .5117 Metetra
.652 .63 .815 r
.32922 .5117 .33958 .52923 .35679 .52376 .34647 .50615 Metetra
.652 .63 .815 r
.34647 .50615 .35679 .52376 .37411 .51821 .36382 .50057 Metetra
.652 .63 .815 r
.36382 .50057 .37411 .51821 .39156 .51233 .38129 .49495 Metetra
.653 .634 .819 r
.38129 .49495 .39156 .51233 .40915 .50576 .39888 .48928 Metetra
.655 .646 .829 r
.39888 .48928 .40915 .50576 .42685 .49849 .41658 .48356 Metetra
.658 .668 .848 r
.41658 .48356 .42685 .49849 .44466 .49096 .43439 .4778 Metetra
.662 .695 .871 r
.43439 .4778 .44466 .49096 .46257 .48375 .45233 .47201 Metetra
.663 .721 .891 r
.45233 .47201 .46257 .48375 .48056 .47717 .47038 .46619 Metetra
.664 .736 .904 r
.47038 .46619 .48056 .47717 .49866 .47111 .48856 .46034 Metetra
.664 .741 .908 r
.48856 .46034 .49866 .47111 .51688 .46531 .50685 .45446 Metetra
.664 .741 .908 r
.50685 .45446 .51688 .46531 .53522 .45944 .52527 .44853 Metetra
.664 .741 .908 r
.52527 .44853 .53522 .45944 .55368 .45355 .54381 .44257 Metetra
.664 .741 .908 r
.54381 .44257 .55368 .45355 .57226 .44762 .56248 .43656 Metetra
.664 .741 .908 r
.56248 .43656 .57226 .44762 .59098 .44165 .58128 .43052 Metetra
.664 .741 .908 r
.58128 .43052 .59098 .44165 .60981 .43563 .6002 .42443 Metetra
.664 .741 .908 r
.6002 .42443 .60981 .43563 .62878 .42958 .61925 .4183 Metetra
.664 .741 .908 r
.61925 .4183 .62878 .42958 .64787 .42349 .63844 .41213 Metetra
.664 .741 .908 r
.63844 .41213 .64787 .42349 .6671 .41736 .65775 .40592 Metetra
.664 .741 .908 r
.65775 .40592 .6671 .41736 .68646 .41118 .6772 .39966 Metetra
.664 .741 .908 r
.6772 .39966 .68646 .41118 .70595 .40498 .69678 .39336 Metetra
.664 .741 .908 r
.69678 .39336 .70595 .40498 .72557 .3987 .7165 .38702 Metetra
.663 .741 .908 r
.7165 .38702 .72557 .3987 .74535 .39269 .73636 .38064 Metetra
.663 .736 .904 r
.73636 .38064 .74535 .39269 .76532 .3872 .75636 .37422 Metetra
.663 .72 .892 r
.75636 .37422 .76532 .3872 .78549 .38236 .7765 .36776 Metetra
.661 .695 .871 r
.7765 .36776 .78549 .38236 .80586 .37787 .79678 .36127 Metetra
.658 .667 .848 r
.79678 .36127 .80586 .37787 .82637 .3731 .8172 .35473 Metetra
.654 .646 .829 r
.8172 .35473 .82637 .3731 .84698 .3676 .83777 .34812 Metetra
.652 .634 .819 r
.83777 .34812 .84698 .3676 .86768 .3614 .85849 .34147 Metetra
.652 .63 .815 r
.85849 .34147 .86768 .3614 .88849 .35483 .87935 .33476 Metetra
.652 .63 .815 r
.87935 .33476 .88849 .35483 .90945 .34817 .90036 .328 Metetra
.663 .75 .915 r
.30111 .50746 .31209 .51721 .32922 .5117 .31831 .50188 Metetra
.663 .75 .915 r
.31831 .50188 .32922 .5117 .34647 .50615 .33562 .49627 Metetra
.663 .75 .915 r
.33562 .49627 .34647 .50615 .36382 .50057 .35305 .49062 Metetra
.664 .75 .914 r
.35305 .49062 .36382 .50057 .38129 .49495 .37059 .4849 Metetra
.665 .75 .914 r
.37059 .4849 .38129 .49495 .39888 .48928 .38825 .47911 Metetra
.666 .749 .912 r
.38825 .47911 .39888 .48928 .41658 .48356 .40603 .47322 Metetra
.666 .747 .911 r
.40603 .47322 .41658 .48356 .43439 .4778 .42393 .46728 Metetra
.666 .745 .909 r
.42393 .46728 .43439 .4778 .45233 .47201 .44194 .46133 Metetra
.665 .743 .908 r
.44194 .46133 .45233 .47201 .47038 .46619 .46008 .45538 Metetra
.664 .742 .908 r
.46008 .45538 .47038 .46619 .48856 .46034 .47833 .44944 Metetra
.664 .741 .908 r
.47833 .44944 .48856 .46034 .50685 .45446 .4967 .44349 Metetra
.664 .741 .908 r
.4967 .44349 .50685 .45446 .52527 .44853 .5152 .43749 Metetra
.664 .741 .908 r
.5152 .43749 .52527 .44853 .54381 .44257 .53383 .43145 Metetra
.664 .741 .908 r
.53383 .43145 .54381 .44257 .56248 .43656 .55258 .42537 Metetra
.664 .741 .908 r
.55258 .42537 .56248 .43656 .58128 .43052 .57146 .41925 Metetra
.664 .741 .908 r
.57146 .41925 .58128 .43052 .6002 .42443 .59047 .41308 Metetra
.664 .741 .908 r
.59047 .41308 .6002 .42443 .61925 .4183 .60961 .40688 Metetra
.664 .741 .908 r
.60961 .40688 .61925 .4183 .63844 .41213 .62888 .40063 Metetra
.664 .741 .908 r
.62888 .40063 .63844 .41213 .65775 .40592 .64828 .39433 Metetra
.664 .741 .908 r
.64828 .39433 .65775 .40592 .6772 .39966 .66783 .388 Metetra
.664 .741 .908 r
.66783 .388 .6772 .39966 .69678 .39336 .6875 .38162 Metetra
.664 .741 .908 r
.6875 .38162 .69678 .39336 .7165 .38702 .70732 .37519 Metetra
.663 .741 .908 r
.70732 .37519 .7165 .38702 .73636 .38064 .72727 .36874 Metetra
.662 .741 .909 r
.72727 .36874 .73636 .38064 .75636 .37422 .74737 .36229 Metetra
.661 .742 .91 r
.74737 .36229 .75636 .37422 .7765 .36776 .76762 .35585 Metetra
.661 .743 .911 r
.76762 .35585 .7765 .36776 .79678 .36127 .78801 .34939 Metetra
.661 .746 .913 r
.78801 .34939 .79678 .36127 .8172 .35473 .80855 .34286 Metetra
.662 .748 .914 r
.80855 .34286 .8172 .35473 .83777 .34812 .82923 .33623 Metetra
.663 .749 .914 r
.82923 .33623 .83777 .34812 .85849 .34147 .85006 .32951 Metetra
.663 .75 .915 r
.85006 .32951 .85849 .34147 .87935 .33476 .87103 .32271 Metetra
.663 .75 .915 r
.87103 .32271 .87935 .33476 .90036 .328 .89216 .31586 Metetra
.663 .732 .9 r
.29005 .49662 .30111 .50746 .31831 .50188 .30732 .49097 Metetra
.663 .732 .9 r
.30732 .49097 .31831 .50188 .33562 .49627 .3247 .48529 Metetra
.663 .732 .9 r
.3247 .48529 .33562 .49627 .35305 .49062 .34219 .47957 Metetra
.663 .732 .9 r
.34219 .47957 .35305 .49062 .37059 .4849 .35981 .47381 Metetra
.664 .732 .901 r
.35981 .47381 .37059 .4849 .38825 .47911 .37753 .46801 Metetra
.664 .733 .902 r
.37753 .46801 .38825 .47911 .40603 .47322 .39538 .46217 Metetra
.664 .735 .903 r
.39538 .46217 .40603 .47322 .42393 .46728 .41335 .45628 Metetra
.664 .738 .905 r
.41335 .45628 .42393 .46728 .44194 .46133 .43143 .45036 Metetra
.664 .74 .907 r
.43143 .45036 .44194 .46133 .46008 .45538 .44964 .44441 Metetra
.664 .741 .908 r
.44964 .44441 .46008 .45538 .47833 .44944 .46797 .43841 Metetra
.664 .741 .908 r
.46797 .43841 .47833 .44944 .4967 .44349 .48643 .43238 Metetra
.664 .741 .908 r
.48643 .43238 .4967 .44349 .5152 .43749 .50501 .42631 Metetra
.664 .741 .908 r
.50501 .42631 .5152 .43749 .53383 .43145 .52371 .42019 Metetra
.664 .741 .908 r
.52371 .42019 .53383 .43145 .55258 .42537 .54255 .41403 Metetra
.664 .741 .908 r
.54255 .41403 .55258 .42537 .57146 .41925 .56151 .40783 Metetra
.664 .741 .908 r
.56151 .40783 .57146 .41925 .59047 .41308 .58061 .40159 Metetra
.664 .741 .908 r
.58061 .40159 .59047 .41308 .60961 .40688 .59984 .39531 Metetra
.664 .741 .908 r
.59984 .39531 .60961 .40688 .62888 .40063 .6192 .38898 Metetra
.664 .741 .908 r
.6192 .38898 .62888 .40063 .64828 .39433 .6387 .3826 Metetra
.664 .741 .908 r
.6387 .3826 .64828 .39433 .66783 .388 .65833 .37618 Metetra
.664 .741 .908 r
.65833 .37618 .66783 .388 .6875 .38162 .6781 .36972 Metetra
.664 .741 .908 r
.6781 .36972 .6875 .38162 .70732 .37519 .69801 .36321 Metetra
.664 .741 .908 r
.69801 .36321 .70732 .37519 .72727 .36874 .71806 .35666 Metetra
.663 .741 .908 r
.71806 .35666 .72727 .36874 .74737 .36229 .73825 .35006 Metetra
.663 .74 .907 r
.73825 .35006 .74737 .36229 .76762 .35585 .75859 .34342 Metetra
.663 .738 .905 r
.75859 .34342 .76762 .35585 .78801 .34939 .77907 .33674 Metetra
.663 .735 .903 r
.77907 .33674 .78801 .34939 .80855 .34286 .7997 .33 Metetra
.663 .733 .902 r
.7997 .33 .80855 .34286 .82923 .33623 .82048 .32322 Metetra
.663 .732 .901 r
.82048 .32322 .82923 .33623 .85006 .32951 .84141 .31638 Metetra
.663 .732 .9 r
.84141 .31638 .85006 .32951 .87103 .32271 .86249 .30949 Metetra
.663 .732 .9 r
.86249 .30949 .87103 .32271 .89216 .31586 .88372 .30255 Metetra
.664 .742 .908 r
.27883 .4862 .29005 .49662 .30732 .49097 .29616 .48049 Metetra
.664 .742 .908 r
.29616 .48049 .30732 .49097 .3247 .48529 .31361 .47473 Metetra
.664 .742 .908 r
.31361 .47473 .3247 .48529 .34219 .47957 .33118 .46895 Metetra
.664 .742 .908 r
.33118 .46895 .34219 .47957 .35981 .47381 .34886 .46311 Metetra
.664 .742 .908 r
.34886 .46311 .35981 .47381 .37753 .46801 .36666 .45724 Metetra
.664 .742 .908 r
.36666 .45724 .37753 .46801 .39538 .46217 .38458 .45131 Metetra
.664 .742 .908 r
.38458 .45131 .39538 .46217 .41335 .45628 .40262 .44535 Metetra
.664 .742 .908 r
.40262 .44535 .41335 .45628 .43143 .45036 .42079 .43935 Metetra
.664 .741 .908 r
.42079 .43935 .43143 .45036 .44964 .44441 .43907 .43331 Metetra
.664 .741 .908 r
.43907 .43331 .44964 .44441 .46797 .43841 .45748 .42724 Metetra
.664 .741 .908 r
.45748 .42724 .46797 .43841 .48643 .43238 .47602 .42113 Metetra
.664 .741 .908 r
.47602 .42113 .48643 .43238 .50501 .42631 .49468 .41498 Metetra
.664 .741 .908 r
.49468 .41498 .50501 .42631 .52371 .42019 .51347 .40879 Metetra
.664 .741 .908 r
.51347 .40879 .52371 .42019 .54255 .41403 .53239 .40255 Metetra
.664 .741 .908 r
.53239 .40255 .54255 .41403 .56151 .40783 .55144 .39628 Metetra
.664 .741 .908 r
.55144 .39628 .56151 .40783 .58061 .40159 .57063 .38995 Metetra
.664 .741 .908 r
.57063 .38995 .58061 .40159 .59984 .39531 .58994 .38359 Metetra
.664 .741 .908 r
.58994 .38359 .59984 .39531 .6192 .38898 .60939 .37717 Metetra
.664 .741 .908 r
.60939 .37717 .6192 .38898 .6387 .3826 .62898 .37072 Metetra
.664 .741 .908 r
.62898 .37072 .6387 .3826 .65833 .37618 .64871 .36422 Metetra
.664 .741 .908 r
.64871 .36422 .65833 .37618 .6781 .36972 .66858 .35767 Metetra
.664 .741 .908 r
.66858 .35767 .6781 .36972 .69801 .36321 .68858 .35108 Metetra
.663 .741 .908 r
.68858 .35108 .69801 .36321 .71806 .35666 .70873 .34444 Metetra
.663 .741 .908 r
.70873 .34444 .71806 .35666 .73825 .35006 .72902 .33776 Metetra
.663 .741 .908 r
.72902 .33776 .73825 .35006 .75859 .34342 .74946 .33104 Metetra
.663 .741 .908 r
.74946 .33104 .75859 .34342 .77907 .33674 .77005 .32427 Metetra
.663 .742 .908 r
.77005 .32427 .77907 .33674 .7997 .33 .79079 .31745 Metetra
.663 .742 .908 r
.79079 .31745 .7997 .33 .82048 .32322 .81167 .31058 Metetra
.663 .742 .908 r
.81167 .31058 .82048 .32322 .84141 .31638 .83271 .30365 Metetra
.664 .742 .908 r
.83271 .30365 .84141 .31638 .86249 .30949 .8539 .29667 Metetra
.664 .742 .908 r
.8539 .29667 .86249 .30949 .88372 .30255 .87524 .28963 Metetra
.664 .74 .907 r
.26747 .47556 .27883 .4862 .29616 .48049 .28488 .46978 Metetra
.664 .74 .907 r
.28488 .46978 .29616 .48049 .31361 .47473 .30239 .46396 Metetra
.664 .74 .907 r
.30239 .46396 .31361 .47473 .33118 .46895 .32003 .45809 Metetra
.664 .74 .907 r
.32003 .45809 .33118 .46895 .34886 .46311 .33779 .45219 Metetra
.664 .74 .907 r
.33779 .45219 .34886 .46311 .36666 .45724 .35566 .44625 Metetra
.664 .74 .907 r
.35566 .44625 .36666 .45724 .38458 .45131 .37365 .44027 Metetra
.664 .741 .907 r
.37365 .44027 .38458 .45131 .40262 .44535 .39177 .43425 Metetra
.664 .741 .908 r
.39177 .43425 .40262 .44535 .42079 .43935 .41001 .42818 Metetra
.664 .741 .908 r
.41001 .42818 .42079 .43935 .43907 .43331 .42837 .42208 Metetra
.664 .741 .908 r
.42837 .42208 .43907 .43331 .45748 .42724 .44686 .41593 Metetra
.664 .741 .908 r
.44686 .41593 .45748 .42724 .47602 .42113 .46548 .40975 Metetra
.664 .741 .908 r
.46548 .40975 .47602 .42113 .49468 .41498 .48422 .40352 Metetra
.664 .741 .908 r
.48422 .40352 .49468 .41498 .51347 .40879 .5031 .39724 Metetra
.664 .741 .908 r
.5031 .39724 .51347 .40879 .53239 .40255 .5221 .39093 Metetra
.664 .741 .908 r
.5221 .39093 .53239 .40255 .55144 .39628 .54124 .38457 Metetra
.664 .741 .908 r
.54124 .38457 .55144 .39628 .57063 .38995 .56051 .37816 Metetra
.664 .741 .908 r
.56051 .37816 .57063 .38995 .58994 .38359 .57992 .37171 Metetra
.664 .741 .908 r
.57992 .37171 .58994 .38359 .60939 .37717 .59946 .36522 Metetra
.664 .741 .908 r
.59946 .36522 .60939 .37717 .62898 .37072 .61914 .35868 Metetra
.664 .741 .908 r
.61914 .35868 .62898 .37072 .64871 .36422 .63896 .35209 Metetra
.664 .741 .908 r
.63896 .35209 .64871 .36422 .66858 .35767 .65893 .34546 Metetra
.664 .741 .908 r
.65893 .34546 .66858 .35767 .68858 .35108 .67903 .33878 Metetra
.664 .741 .908 r
.67903 .33878 .68858 .35108 .70873 .34444 .69928 .33205 Metetra
.664 .741 .908 r
.69928 .33205 .70873 .34444 .72902 .33776 .71967 .32527 Metetra
.663 .741 .908 r
.71967 .32527 .72902 .33776 .74946 .33104 .74021 .31845 Metetra
.663 .741 .908 r
.74021 .31845 .74946 .33104 .77005 .32427 .7609 .31158 Metetra
.663 .741 .907 r
.7609 .31158 .77005 .32427 .79079 .31745 .78174 .30466 Metetra
.664 .74 .907 r
.78174 .30466 .79079 .31745 .81167 .31058 .80273 .29768 Metetra
.664 .74 .907 r
.80273 .29768 .81167 .31058 .83271 .30365 .82388 .29066 Metetra
.664 .74 .907 r
.82388 .29066 .83271 .30365 .8539 .29667 .84518 .28358 Metetra
.664 .74 .907 r
.84518 .28358 .8539 .29667 .87524 .28963 .86664 .27645 Metetra
.664 .741 .908 r
.25597 .46485 .26747 .47556 .28488 .46978 .27345 .45899 Metetra
.664 .741 .908 r
.27345 .45899 .28488 .46978 .30239 .46396 .29104 .4531 Metetra
.664 .741 .908 r
.29104 .4531 .30239 .46396 .32003 .45809 .30874 .44716 Metetra
.664 .741 .908 r
.30874 .44716 .32003 .45809 .33779 .45219 .32657 .44119 Metetra
.664 .741 .908 r
.32657 .44119 .33779 .45219 .35566 .44625 .34452 .43517 Metetra
.664 .741 .908 r
.34452 .43517 .35566 .44625 .37365 .44027 .36259 .42912 Metetra
.664 .741 .908 r
.36259 .42912 .37365 .44027 .39177 .43425 .38078 .42302 Metetra
.664 .741 .908 r
.38078 .42302 .39177 .43425 .41001 .42818 .3991 .41688 Metetra
.664 .741 .908 r
.3991 .41688 .41001 .42818 .42837 .42208 .41754 .4107 Metetra
.664 .741 .908 r
.41754 .4107 .42837 .42208 .44686 .41593 .43611 .40448 Metetra
.664 .741 .908 r
.43611 .40448 .44686 .41593 .46548 .40975 .45481 .39821 Metetra
.664 .741 .908 r
.45481 .39821 .46548 .40975 .48422 .40352 .47363 .3919 Metetra
.664 .741 .908 r
.47363 .3919 .48422 .40352 .5031 .39724 .49259 .38555 Metetra
.664 .741 .908 r
.49259 .38555 .5031 .39724 .5221 .39093 .51168 .37915 Metetra
.664 .741 .908 r
.51168 .37915 .5221 .39093 .54124 .38457 .53091 .37271 Metetra
.664 .741 .908 r
.53091 .37271 .54124 .38457 .56051 .37816 .55027 .36622 Metetra
.664 .741 .908 r
.55027 .36622 .56051 .37816 .57992 .37171 .56977 .35969 Metetra
.664 .741 .908 r
.56977 .35969 .57992 .37171 .59946 .36522 .5894 .35311 Metetra
.664 .741 .908 r
.5894 .35311 .59946 .36522 .61914 .35868 .60918 .34648 Metetra
.664 .741 .908 r
.60918 .34648 .61914 .35868 .63896 .35209 .62909 .33981 Metetra
.664 .741 .908 r
.62909 .33981 .63896 .35209 .65893 .34546 .64915 .33309 Metetra
.664 .741 .908 r
.64915 .33309 .65893 .34546 .67903 .33878 .66935 .32632 Metetra
.664 .741 .908 r
.66935 .32632 .67903 .33878 .69928 .33205 .6897 .3195 Metetra
.664 .741 .908 r
.6897 .3195 .69928 .33205 .71967 .32527 .71019 .31263 Metetra
.664 .741 .908 r
.71019 .31263 .71967 .32527 .74021 .31845 .73084 .30572 Metetra
.664 .741 .908 r
.73084 .30572 .74021 .31845 .7609 .31158 .75163 .29875 Metetra
.664 .741 .908 r
.75163 .29875 .7609 .31158 .78174 .30466 .77258 .29173 Metetra
.664 .741 .908 r
.77258 .29173 .78174 .30466 .80273 .29768 .79368 .28466 Metetra
.664 .741 .908 r
.79368 .28466 .80273 .29768 .82388 .29066 .81494 .27754 Metetra
.664 .741 .908 r
.81494 .27754 .82388 .29066 .84518 .28358 .83635 .27036 Metetra
.664 .741 .908 r
.83635 .27036 .84518 .28358 .86664 .27645 .85792 .26313 Metetra
.664 .741 .908 r
.24433 .454 .25597 .46485 .27345 .45899 .26187 .44808 Metetra
.664 .741 .908 r
.26187 .44808 .27345 .45899 .29104 .4531 .27953 .44211 Metetra
.664 .741 .908 r
.27953 .44211 .29104 .4531 .30874 .44716 .29731 .4361 Metetra
.664 .741 .908 r
.29731 .4361 .30874 .44716 .32657 .44119 .31521 .43005 Metetra
.664 .741 .908 r
.31521 .43005 .32657 .44119 .34452 .43517 .33323 .42396 Metetra
.664 .741 .908 r
.33323 .42396 .34452 .43517 .36259 .42912 .35138 .41783 Metetra
.664 .741 .908 r
.35138 .41783 .36259 .42912 .38078 .42302 .36965 .41165 Metetra
.664 .741 .908 r
.36965 .41165 .38078 .42302 .3991 .41688 .38804 .40544 Metetra
.664 .741 .908 r
.38804 .40544 .3991 .41688 .41754 .4107 .40657 .39918 Metetra
.664 .741 .908 r
.40657 .39918 .41754 .4107 .43611 .40448 .42522 .39288 Metetra
.664 .741 .908 r
.42522 .39288 .43611 .40448 .45481 .39821 .444 .38653 Metetra
.664 .741 .908 r
.444 .38653 .45481 .39821 .47363 .3919 .46291 .38014 Metetra
.664 .741 .908 r
.46291 .38014 .47363 .3919 .49259 .38555 .48195 .3737 Metetra
.664 .741 .908 r
.48195 .3737 .49259 .38555 .51168 .37915 .50113 .36722 Metetra
.664 .741 .908 r
.50113 .36722 .51168 .37915 .53091 .37271 .52044 .3607 Metetra
.664 .741 .908 r
.52044 .3607 .53091 .37271 .55027 .36622 .53989 .35412 Metetra
.664 .741 .908 r
.53989 .35412 .55027 .36622 .56977 .35969 .55948 .34751 Metetra
.664 .741 .908 r
.55948 .34751 .56977 .35969 .5894 .35311 .57921 .34084 Metetra
.664 .741 .908 r
.57921 .34084 .5894 .35311 .60918 .34648 .59908 .33412 Metetra
.664 .741 .908 r
.59908 .33412 .60918 .34648 .62909 .33981 .61909 .32736 Metetra
.664 .741 .908 r
.61909 .32736 .62909 .33981 .64915 .33309 .63924 .32055 Metetra
.664 .741 .908 r
.63924 .32055 .64915 .33309 .66935 .32632 .65954 .31369 Metetra
.664 .741 .908 r
.65954 .31369 .66935 .32632 .6897 .3195 .67999 .30678 Metetra
.664 .741 .908 r
.67999 .30678 .6897 .3195 .71019 .31263 .70059 .29982 Metetra
.664 .741 .908 r
.70059 .29982 .71019 .31263 .73084 .30572 .72134 .29281 Metetra
.664 .741 .908 r
.72134 .29281 .73084 .30572 .75163 .29875 .74224 .28575 Metetra
.664 .741 .908 r
.74224 .28575 .75163 .29875 .77258 .29173 .76329 .27863 Metetra
.664 .741 .908 r
.76329 .27863 .77258 .29173 .79368 .28466 .7845 .27147 Metetra
.664 .741 .908 r
.7845 .27147 .79368 .28466 .81494 .27754 .80587 .26425 Metetra
.664 .741 .908 r
.80587 .26425 .81494 .27754 .83635 .27036 .8274 .25697 Metetra
.664 .741 .908 r
.8274 .25697 .83635 .27036 .85792 .26313 .84908 .24964 Metetra
.664 .741 .908 r
.23255 .44303 .24433 .454 .26187 .44808 .25016 .43703 Metetra
.664 .741 .908 r
.25016 .43703 .26187 .44808 .27953 .44211 .26789 .43099 Metetra
.664 .741 .908 r
.26789 .43099 .27953 .44211 .29731 .4361 .28574 .4249 Metetra
.664 .741 .908 r
.28574 .4249 .29731 .4361 .31521 .43005 .30371 .41878 Metetra
.664 .741 .908 r
.30371 .41878 .31521 .43005 .33323 .42396 .32181 .41261 Metetra
.664 .741 .908 r
.32181 .41261 .33323 .42396 .35138 .41783 .34003 .4064 Metetra
.664 .741 .908 r
.34003 .4064 .35138 .41783 .36965 .41165 .35838 .40015 Metetra
.664 .741 .908 r
.35838 .40015 .36965 .41165 .38804 .40544 .37685 .39385 Metetra
.664 .741 .908 r
.37685 .39385 .38804 .40544 .40657 .39918 .39545 .38751 Metetra
.664 .741 .908 r
.39545 .38751 .40657 .39918 .42522 .39288 .41418 .38113 Metetra
.664 .741 .908 r
.41418 .38113 .42522 .39288 .444 .38653 .43305 .3747 Metetra
.664 .741 .908 r
.43305 .3747 .444 .38653 .46291 .38014 .45204 .36822 Metetra
.664 .741 .908 r
.45204 .36822 .46291 .38014 .48195 .3737 .47117 .3617 Metetra
.664 .741 .908 r
.47117 .3617 .48195 .3737 .50113 .36722 .49044 .35514 Metetra
.664 .741 .908 r
.49044 .35514 .50113 .36722 .52044 .3607 .50984 .34853 Metetra
.664 .741 .908 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
.664 .741 .908 r
.52938 .34187 .53989 .35412 .55948 .34751 .54906 .33516 Metetra
.664 .741 .908 r
.54906 .33516 .55948 .34751 .57921 .34084 .56888 .32841 Metetra
.664 .741 .908 r
.56888 .32841 .57921 .34084 .59908 .33412 .58884 .3216 Metetra
.664 .741 .908 r
.58884 .3216 .59908 .33412 .61909 .32736 .60895 .31475 Metetra
.664 .741 .908 r
.60895 .31475 .61909 .32736 .63924 .32055 .6292 .30785 Metetra
.664 .741 .908 r
.6292 .30785 .63924 .32055 .65954 .31369 .6496 .30089 Metetra
.664 .741 .908 r
.6496 .30089 .65954 .31369 .67999 .30678 .67015 .29389 Metetra
.664 .741 .908 r
.67015 .29389 .67999 .30678 .70059 .29982 .69085 .28684 Metetra
.664 .741 .908 r
.69085 .28684 .70059 .29982 .72134 .29281 .71171 .27973 Metetra
.664 .741 .908 r
.71171 .27973 .72134 .29281 .74224 .28575 .73271 .27257 Metetra
.664 .741 .908 r
.73271 .27257 .74224 .28575 .76329 .27863 .75388 .26536 Metetra
.664 .741 .908 r
.75388 .26536 .76329 .27863 .7845 .27147 .7752 .2581 Metetra
.664 .741 .908 r
.7752 .2581 .7845 .27147 .80587 .26425 .79668 .25078 Metetra
.664 .741 .908 r
.79668 .25078 .80587 .26425 .8274 .25697 .81832 .2434 Metetra
.664 .741 .908 r
.81832 .2434 .8274 .25697 .84908 .24964 .84012 .23597 Metetra
.664 .741 .908 r
.22061 .43193 .23255 .44303 .25016 .43703 .23829 .42585 Metetra
.664 .741 .908 r
.23829 .42585 .25016 .43703 .26789 .43099 .25609 .41973 Metetra
.664 .741 .908 r
.25609 .41973 .26789 .43099 .28574 .4249 .27402 .41357 Metetra
.664 .741 .908 r
.27402 .41357 .28574 .4249 .30371 .41878 .29206 .40737 Metetra
.664 .741 .908 r
.29206 .40737 .30371 .41878 .32181 .41261 .31024 .40112 Metetra
.664 .741 .908 r
.31024 .40112 .32181 .41261 .34003 .4064 .32853 .39483 Metetra
.664 .741 .908 r
.32853 .39483 .34003 .4064 .35838 .40015 .34696 .38849 Metetra
.664 .741 .908 r
.34696 .38849 .35838 .40015 .37685 .39385 .36551 .38211 Metetra
.664 .741 .908 r
.36551 .38211 .37685 .39385 .39545 .38751 .38419 .37569 Metetra
.664 .741 .908 r
.38419 .37569 .39545 .38751 .41418 .38113 .40301 .36922 Metetra
.664 .741 .908 r
.40301 .36922 .41418 .38113 .43305 .3747 .42195 .36271 Metetra
.664 .741 .908 r
.42195 .36271 .43305 .3747 .45204 .36822 .44103 .35615 Metetra
.664 .741 .908 r
.44103 .35615 .45204 .36822 .47117 .3617 .46025 .34955 Metetra
.664 .741 .908 r
.46025 .34955 .47117 .3617 .49044 .35514 .4796 .3429 Metetra
.664 .741 .908 r
.4796 .3429 .49044 .35514 .50984 .34853 .49909 .3362 Metetra
.664 .741 .908 r
.49909 .3362 .50984 .34853 .52938 .34187 .51872 .32945 Metetra
.664 .741 .908 r
.51872 .32945 .52938 .34187 .54906 .33516 .5385 .32265 Metetra
.664 .741 .908 r
.5385 .32265 .54906 .33516 .56888 .32841 .55841 .31581 Metetra
.664 .741 .908 r
.55841 .31581 .56888 .32841 .58884 .3216 .57847 .30891 Metetra
.664 .741 .908 r
.57847 .30891 .58884 .3216 .60895 .31475 .59867 .30197 Metetra
.664 .741 .908 r
.59867 .30197 .60895 .31475 .6292 .30785 .61903 .29497 Metetra
.664 .741 .908 r
.61903 .29497 .6292 .30785 .6496 .30089 .63953 .28793 Metetra
.664 .741 .908 r
.63953 .28793 .6496 .30089 .67015 .29389 .66018 .28083 Metetra
.664 .741 .908 r
.66018 .28083 .67015 .29389 .69085 .28684 .68099 .27368 Metetra
.663 .741 .908 r
.68099 .27368 .69085 .28684 .71171 .27973 .70195 .26648 Metetra
.663 .741 .908 r
.70195 .26648 .71171 .27973 .73271 .27257 .72306 .25922 Metetra
.663 .741 .908 r
.72306 .25922 .73271 .27257 .75388 .26536 .74433 .25191 Metetra
.664 .741 .908 r
.74433 .25191 .75388 .26536 .7752 .2581 .76577 .24455 Metetra
.664 .741 .908 r
.76577 .24455 .7752 .2581 .79668 .25078 .78736 .23713 Metetra
.664 .741 .908 r
.78736 .23713 .79668 .25078 .81832 .2434 .80912 .22965 Metetra
.664 .741 .908 r
.80912 .22965 .81832 .2434 .84012 .23597 .83104 .22211 Metetra
.664 .742 .909 r
.20852 .42074 .22061 .43193 .23829 .42585 .22627 .41458 Metetra
.664 .742 .909 r
.22627 .41458 .23829 .42585 .25609 .41973 .24415 .40839 Metetra
.664 .742 .909 r
.24415 .40839 .25609 .41973 .27402 .41357 .26214 .40215 Metetra
.664 .742 .909 r
.26214 .40215 .27402 .41357 .29206 .40737 .28026 .39586 Metetra
.664 .742 .909 r
.28026 .39586 .29206 .40737 .31024 .40112 .29851 .38953 Metetra
.664 .742 .908 r
.29851 .38953 .31024 .40112 .32853 .39483 .31689 .38314 Metetra
.664 .742 .908 r
.31689 .38314 .32853 .39483 .34696 .38849 .33539 .37671 Metetra
.664 .742 .908 r
.33539 .37671 .34696 .38849 .36551 .38211 .35403 .37023 Metetra
.664 .742 .908 r
.35403 .37023 .36551 .38211 .38419 .37569 .37279 .36372 Metetra
.664 .741 .908 r
.37279 .36372 .38419 .37569 .40301 .36922 .39169 .35716 Metetra
.664 .741 .908 r
.39169 .35716 .40301 .36922 .42195 .36271 .41072 .35057 Metetra
.664 .741 .908 r
.41072 .35057 .42195 .36271 .44103 .35615 .42988 .34392 Metetra
.664 .741 .908 r
.42988 .34392 .44103 .35615 .46025 .34955 .44918 .33723 Metetra
.664 .741 .908 r
.44918 .33723 .46025 .34955 .4796 .3429 .46862 .33049 Metetra
.664 .741 .908 r
.46862 .33049 .4796 .3429 .49909 .3362 .48821 .3237 Metetra
.664 .741 .908 r
.48821 .3237 .49909 .3362 .51872 .32945 .50793 .31686 Metetra
.664 .741 .908 r
.50793 .31686 .51872 .32945 .5385 .32265 .52779 .30998 Metetra
.664 .741 .908 r
.52779 .30998 .5385 .32265 .55841 .31581 .5478 .30304 Metetra
.664 .741 .908 r
.5478 .30304 .55841 .31581 .57847 .30891 .56796 .29605 Metetra
.664 .741 .908 r
.56796 .29605 .57847 .30891 .59867 .30197 .58826 .28901 Metetra
.664 .741 .908 r
.58826 .28901 .59867 .30197 .61903 .29497 .60871 .28192 Metetra
.664 .741 .908 r
.60871 .28192 .61903 .29497 .63953 .28793 .62932 .27478 Metetra
.663 .741 .908 r
.62932 .27478 .63953 .28793 .66018 .28083 .65007 .26759 Metetra
.663 .741 .908 r
.65007 .26759 .66018 .28083 .68099 .27368 .67098 .26035 Metetra
.663 .741 .908 r
.67098 .26035 .68099 .27368 .70195 .26648 .69205 .25306 Metetra
.663 .742 .908 r
.69205 .25306 .70195 .26648 .72306 .25922 .71328 .24572 Metetra
.663 .742 .909 r
.71328 .24572 .72306 .25922 .74433 .25191 .73466 .23832 Metetra
.663 .742 .909 r
.73466 .23832 .74433 .25191 .76577 .24455 .75621 .23086 Metetra
.664 .742 .909 r
.75621 .23086 .76577 .24455 .78736 .23713 .77792 .22334 Metetra
.664 .742 .909 r
.77792 .22334 .78736 .23713 .80912 .22965 .79979 .21576 Metetra
.664 .742 .909 r
.79979 .21576 .80912 .22965 .83104 .22211 .82183 .20812 Metetra
.664 .741 .907 r
.19629 .40931 .20852 .42074 .22627 .41458 .21411 .40308 Metetra
.664 .741 .907 r
.21411 .40308 .22627 .41458 .24415 .40839 .23205 .3968 Metetra
.664 .741 .907 r
.23205 .3968 .24415 .40839 .26214 .40215 .25012 .39048 Metetra
.664 .741 .907 r
.25012 .39048 .26214 .40215 .28026 .39586 .26832 .38412 Metetra
.664 .741 .907 r
.26832 .38412 .28026 .39586 .29851 .38953 .28664 .3777 Metetra
.664 .741 .907 r
.28664 .3777 .29851 .38953 .31689 .38314 .3051 .37124 Metetra
.664 .741 .908 r
.3051 .37124 .31689 .38314 .33539 .37671 .32368 .36473 Metetra
.664 .741 .908 r
.32368 .36473 .33539 .37671 .35403 .37023 .34239 .35818 Metetra
.664 .741 .908 r
.34239 .35818 .35403 .37023 .37279 .36372 .36124 .35159 Metetra
.664 .741 .908 r
.36124 .35159 .37279 .36372 .39169 .35716 .38022 .34495 Metetra
.664 .741 .908 r
.38022 .34495 .39169 .35716 .41072 .35057 .39933 .33826 Metetra
.664 .741 .908 r
.39933 .33826 .41072 .35057 .42988 .34392 .41858 .33153 Metetra
.664 .741 .908 r
.41858 .33153 .42988 .34392 .44918 .33723 .43797 .32475 Metetra
.664 .741 .908 r
.43797 .32475 .44918 .33723 .46862 .33049 .4575 .31792 Metetra
.664 .741 .908 r
.4575 .31792 .46862 .33049 .48821 .3237 .47717 .31104 Metetra
.664 .741 .908 r
.47717 .31104 .48821 .3237 .50793 .31686 .49699 .30411 Metetra
.664 .741 .908 r
.49699 .30411 .50793 .31686 .52779 .30998 .51695 .29713 Metetra
.664 .741 .908 r
.51695 .29713 .52779 .30998 .5478 .30304 .53705 .2901 Metetra
.664 .741 .908 r
.53705 .2901 .5478 .30304 .56796 .29605 .5573 .28302 Metetra
.664 .741 .908 r
.5573 .28302 .56796 .29605 .58826 .28901 .57771 .27588 Metetra
.664 .741 .908 r
.57771 .27588 .58826 .28901 .60871 .28192 .59826 .26869 Metetra
.664 .741 .908 r
.59826 .26869 .60871 .28192 .62932 .27478 .61897 .26145 Metetra
.664 .741 .908 r
.61897 .26145 .62932 .27478 .65007 .26759 .63983 .25416 Metetra
.663 .741 .908 r
.63983 .25416 .65007 .26759 .67098 .26035 .66084 .24681 Metetra
.663 .741 .908 r
.66084 .24681 .67098 .26035 .69205 .25306 .68202 .23942 Metetra
.663 .741 .908 r
.68202 .23942 .69205 .25306 .71328 .24572 .70335 .23197 Metetra
.663 .741 .908 r
.70335 .23197 .71328 .24572 .73466 .23832 .72485 .22446 Metetra
.663 .741 .908 r
.72485 .22446 .73466 .23832 .75621 .23086 .74651 .21689 Metetra
.663 .741 .907 r
.74651 .21689 .75621 .23086 .77792 .22334 .76833 .20926 Metetra
.664 .741 .907 r
.76833 .20926 .77792 .22334 .79979 .21576 .79032 .20157 Metetra
.664 .741 .907 r
.79032 .20157 .79979 .21576 .82183 .20812 .81249 .19382 Metetra
.664 .751 .915 r
.18384 .3983 .19629 .40931 .21411 .40308 .20173 .39199 Metetra
.664 .751 .915 r
.20173 .39199 .21411 .40308 .23205 .3968 .21975 .38564 Metetra
.664 .751 .915 r
.21975 .38564 .23205 .3968 .25012 .39048 .2379 .37923 Metetra
.664 .751 .915 r
.2379 .37923 .25012 .39048 .26832 .38412 .25618 .37276 Metetra
.665 .751 .914 r
.25618 .37276 .26832 .38412 .28664 .3777 .27458 .36619 Metetra
.666 .75 .913 r
.27458 .36619 .28664 .3777 .3051 .37124 .29312 .35953 Metetra
.667 .748 .911 r
.29312 .35953 .3051 .37124 .32368 .36473 .3118 .3528 Metetra
.666 .745 .909 r
.3118 .3528 .32368 .36473 .34239 .35818 .3306 .34606 Metetra
.665 .743 .908 r
.3306 .34606 .34239 .35818 .36124 .35159 .34953 .33932 Metetra
.664 .742 .908 r
.34953 .33932 .36124 .35159 .38022 .34495 .36859 .33257 Metetra
.664 .741 .908 r
.36859 .33257 .38022 .34495 .39933 .33826 .38779 .3258 Metetra
.664 .741 .908 r
.38779 .3258 .39933 .33826 .41858 .33153 .40713 .31897 Metetra
.664 .741 .908 r
.40713 .31897 .41858 .33153 .43797 .32475 .42661 .3121 Metetra
.664 .741 .908 r
.42661 .3121 .43797 .32475 .4575 .31792 .44623 .30518 Metetra
.664 .741 .908 r
.44623 .30518 .4575 .31792 .47717 .31104 .46599 .29821 Metetra
.664 .741 .908 r
.46599 .29821 .47717 .31104 .49699 .30411 .4859 .29118 Metetra
.664 .741 .908 r
.4859 .29118 .49699 .30411 .51695 .29713 .50595 .28411 Metetra
.664 .741 .908 r
.50595 .28411 .51695 .29713 .53705 .2901 .52615 .27698 Metetra
.664 .741 .908 r
.52615 .27698 .53705 .2901 .5573 .28302 .5465 .2698 Metetra
.664 .741 .908 r
.5465 .2698 .5573 .28302 .57771 .27588 .56701 .26257 Metetra
.664 .741 .908 r
.56701 .26257 .57771 .27588 .59826 .26869 .58766 .25528 Metetra
.664 .741 .908 r
.58766 .25528 .59826 .26869 .61897 .26145 .60847 .24794 Metetra
.663 .741 .908 r
.60847 .24794 .61897 .26145 .63983 .25416 .62944 .24057 Metetra
.662 .741 .909 r
.62944 .24057 .63983 .25416 .66084 .24681 .65056 .23318 Metetra
.661 .742 .91 r
.65056 .23318 .66084 .24681 .68202 .23942 .67185 .22579 Metetra
.661 .744 .911 r
.67185 .22579 .68202 .23942 .70335 .23197 .69331 .21838 Metetra
.661 .746 .913 r
.69331 .21838 .70335 .23197 .72485 .22446 .71493 .21088 Metetra
.662 .749 .914 r
.71493 .21088 .72485 .22446 .74651 .21689 .73671 .20328 Metetra
.663 .75 .915 r
.73671 .20328 .74651 .21689 .76833 .20926 .75866 .19557 Metetra
.664 .751 .915 r
.75866 .19557 .76833 .20926 .79032 .20157 .78077 .18777 Metetra
.664 .751 .915 r
.78077 .18777 .79032 .20157 .81249 .19382 .80306 .17991 Metetra
.663 .733 .902 r
.17133 .38615 .18384 .3983 .20173 .39199 .1893 .37976 Metetra
.663 .733 .902 r
.1893 .37976 .20173 .39199 .21975 .38564 .20739 .37332 Metetra
.663 .733 .902 r
.20739 .37332 .21975 .38564 .2379 .37923 .22561 .36684 Metetra
.663 .733 .902 r
.22561 .36684 .2379 .37923 .25618 .37276 .24395 .3603 Metetra
.663 .734 .902 r
.24395 .3603 .25618 .37276 .27458 .36619 .26243 .35371 Metetra
.664 .735 .903 r
.26243 .35371 .27458 .36619 .29312 .35953 .28104 .34706 Metetra
.664 .737 .904 r
.28104 .34706 .29312 .35953 .3118 .3528 .29978 .34036 Metetra
.664 .739 .906 r
.29978 .34036 .3118 .3528 .3306 .34606 .31866 .33362 Metetra
.664 .74 .907 r
.31866 .33362 .3306 .34606 .34953 .33932 .33767 .32684 Metetra
.664 .741 .908 r
.33767 .32684 .34953 .33932 .36859 .33257 .35682 .32003 Metetra
.664 .741 .908 r
.35682 .32003 .36859 .33257 .38779 .3258 .3761 .31316 Metetra
.664 .741 .908 r
.3761 .31316 .38779 .3258 .40713 .31897 .39553 .30625 Metetra
.664 .741 .908 r
.39553 .30625 .40713 .31897 .42661 .3121 .41509 .29928 Metetra
.664 .741 .908 r
.41509 .29928 .42661 .3121 .44623 .30518 .4348 .29227 Metetra
.664 .741 .908 r
.4348 .29227 .44623 .30518 .46599 .29821 .45466 .2852 Metetra
.664 .741 .908 r
.45466 .2852 .46599 .29821 .4859 .29118 .47466 .27808 Metetra
.664 .741 .908 r
.47466 .27808 .4859 .29118 .50595 .28411 .49481 .27091 Metetra
.664 .741 .908 r
.49481 .27091 .50595 .28411 .52615 .27698 .51511 .26369 Metetra
.664 .741 .908 r
.51511 .26369 .52615 .27698 .5465 .2698 .53556 .25641 Metetra
.664 .741 .908 r
.53556 .25641 .5465 .2698 .56701 .26257 .55616 .24907 Metetra
.664 .741 .908 r
.55616 .24907 .56701 .26257 .58766 .25528 .57692 .24169 Metetra
.664 .741 .908 r
.57692 .24169 .58766 .25528 .60847 .24794 .59783 .23424 Metetra
.663 .741 .908 r
.59783 .23424 .60847 .24794 .62944 .24057 .6189 .22675 Metetra
.663 .741 .908 r
.6189 .22675 .62944 .24057 .65056 .23318 .64013 .2192 Metetra
.663 .74 .907 r
.64013 .2192 .65056 .23318 .67185 .22579 .66153 .21161 Metetra
.663 .738 .906 r
.66153 .21161 .67185 .22579 .69331 .21838 .68309 .20397 Metetra
.663 .736 .904 r
.68309 .20397 .69331 .21838 .71493 .21088 .70481 .19626 Metetra
.663 .735 .903 r
.70481 .19626 .71493 .21088 .73671 .20328 .7267 .18849 Metetra
.663 .734 .902 r
.7267 .18849 .73671 .20328 .75866 .19557 .74876 .18064 Metetra
.663 .733 .902 r
.74876 .18064 .75866 .19557 .78077 .18777 .771 .17273 Metetra
.663 .733 .902 r
.771 .17273 .78077 .18777 .80306 .17991 .7934 .16476 Metetra
.624 .884 .989 r
.15773 .382 .17133 .38615 .1893 .37976 .17581 .37552 Metetra
.624 .884 .989 r
.17581 .37552 .1893 .37976 .20739 .37332 .19402 .36901 Metetra
.626 .884 .988 r
.19402 .36901 .20739 .37332 .22561 .36684 .21236 .36241 Metetra
.638 .886 .986 r
.21236 .36241 .22561 .36684 .24395 .3603 .23086 .35545 Metetra
.665 .885 .979 r
.23086 .35545 .24395 .3603 .26243 .35371 .24954 .34776 Metetra
.693 .869 .965 r
.24954 .34776 .26243 .35371 .28104 .34706 .2684 .33934 Metetra
.704 .837 .946 r
.2684 .33934 .28104 .34706 .29978 .34036 .2874 .33063 Metetra
.697 .798 .928 r
.2874 .33063 .29978 .34036 .31866 .33362 .30648 .32226 Metetra
.682 .767 .915 r
.30648 .32226 .31866 .33362 .33767 .32684 .32563 .31452 Metetra
.67 .748 .909 r
.32563 .31452 .33767 .32684 .35682 .32003 .34488 .30732 Metetra
.663 .741 .908 r
.34488 .30732 .35682 .32003 .3761 .31316 .36425 .30038 Metetra
.664 .742 .908 r
.36425 .30038 .3761 .31316 .39553 .30625 .38377 .29335 Metetra
.664 .741 .908 r
.38377 .29335 .39553 .30625 .41509 .29928 .40342 .28629 Metetra
.664 .741 .908 r
.40342 .28629 .41509 .29928 .4348 .29227 .42322 .27918 Metetra
.664 .741 .908 r
.42322 .27918 .4348 .29227 .45466 .2852 .44317 .27202 Metetra
.664 .741 .908 r
.44317 .27202 .45466 .2852 .47466 .27808 .46327 .2648 Metetra
.664 .741 .908 r
.46327 .2648 .47466 .27808 .49481 .27091 .48351 .25753 Metetra
.664 .741 .908 r
.48351 .25753 .49481 .27091 .51511 .26369 .50391 .25021 Metetra
.663 .741 .908 r
.50391 .25021 .51511 .26369 .53556 .25641 .52446 .24283 Metetra
.664 .741 .908 r
.52446 .24283 .53556 .25641 .55616 .24907 .54516 .23539 Metetra
.663 .741 .908 r
.54516 .23539 .55616 .24907 .57692 .24169 .56602 .22792 Metetra
.664 .742 .908 r
.56602 .22792 .57692 .24169 .59783 .23424 .58704 .22036 Metetra
.658 .739 .91 r
.58704 .22036 .59783 .23424 .6189 .22675 .60823 .21305 Metetra
.646 .74 .917 r
.60823 .21305 .6189 .22675 .64013 .2192 .6296 .20629 Metetra
.63 .749 .933 r
.6296 .20629 .64013 .2192 .66153 .21161 .65118 .20018 Metetra
.616 .773 .956 r
.65118 .20018 .66153 .21161 .68309 .20397 .67297 .19441 Metetra
.609 .811 .978 r
.67297 .19441 .68309 .20397 .70481 .19626 .69494 .18834 Metetra
.612 .849 .988 r
.69494 .18834 .70481 .19626 .7267 .18849 .71707 .18151 Metetra
.619 .873 .99 r
.71707 .18151 .7267 .18849 .74876 .18064 .73933 .17393 Metetra
.623 .882 .989 r
.73933 .17393 .74876 .18064 .771 .17273 .76175 .16596 Metetra
.624 .883 .989 r
.76175 .16596 .771 .17273 .7934 .16476 .78434 .15788 Metetra
.029 0 0 r
.14208 .39302 .15773 .382 .17581 .37552 .16036 .38646 Metetra
.029 0 0 r
.16036 .38646 .17581 .37552 .19402 .36901 .17876 .37988 Metetra
.02 0 0 r
.17876 .37988 .19402 .36901 .21236 .36241 .19731 .37311 Metetra
.19731 .37311 .21236 .36241 .23086 .35545 .21612 .36502 Metetra
.21612 .36502 .23086 .35545 .24954 .34776 .23528 .35422 Metetra
.585 .935 .765 r
.23528 .35422 .24954 .34776 .2684 .33934 .25477 .34063 Metetra
.77 .985 .902 r
.25477 .34063 .2684 .33934 .2874 .33063 .2744 .32609 Metetra
.783 .906 .927 r
.2744 .32609 .2874 .33063 .30648 .32226 .29395 .31301 Metetra
.733 .818 .917 r
.29395 .31301 .30648 .32226 .32563 .31452 .31339 .30261 Metetra
.687 .763 .909 r
.31339 .30261 .32563 .31452 .34488 .30732 .33279 .29445 Metetra
.662 .741 .909 r
.33279 .29445 .34488 .30732 .36425 .30038 .35224 .28747 Metetra
.665 .743 .908 r
.35224 .28747 .36425 .30038 .38377 .29335 .37185 .28028 Metetra
.663 .741 .908 r
.37185 .28028 .38377 .29335 .40342 .28629 .39159 .27313 Metetra
.664 .742 .908 r
.39159 .27313 .40342 .28629 .42322 .27918 .41149 .26592 Metetra
.664 .741 .908 r
.41149 .26592 .42322 .27918 .44317 .27202 .43153 .25865 Metetra
.664 .741 .908 r
.43153 .25865 .44317 .27202 .46327 .2648 .45172 .25134 Metetra
.664 .741 .908 r
.45172 .25134 .46327 .2648 .48351 .25753 .47206 .24397 Metetra
.664 .741 .908 r
.47206 .24397 .48351 .25753 .50391 .25021 .49255 .23654 Metetra
.663 .741 .908 r
.49255 .23654 .50391 .25021 .52446 .24283 .5132 .22907 Metetra
.664 .741 .908 r
.5132 .22907 .52446 .24283 .54516 .23539 .53401 .22152 Metetra
.662 .741 .909 r
.53401 .22152 .54516 .23539 .56602 .22792 .55497 .21401 Metetra
.665 .743 .908 r
.55497 .21401 .56602 .22792 .58704 .22036 .5761 .20628 Metetra
.64 .733 .915 r
.5761 .20628 .58704 .22036 .60823 .21305 .59741 .19976 Metetra
.586 .726 .94 r
.59741 .19976 .60823 .21305 .6296 .20629 .61898 .19551 Metetra
.48 .728 .98 r
.61898 .19551 .6296 .20629 .65118 .20018 .64088 .19403 Metetra
.292 .722 .969 r
.64088 .19403 .65118 .20018 .67297 .19441 .66311 .19407 Metetra
.066 .629 .752 r
.66311 .19407 .67297 .19441 .69494 .18834 .68558 .19316 Metetra
.037 0 0 r
.68558 .19316 .69494 .18834 .71707 .18151 .70816 .1894 Metetra
.043 0 0 r
.70816 .1894 .71707 .18151 .73933 .17393 .7308 .18284 Metetra
.032 0 0 r
.7308 .18284 .73933 .17393 .76175 .16596 .75353 .17491 Metetra
.03 0 0 r
.75353 .17491 .76175 .16596 .78434 .15788 .77644 .16676 Metetra
.343 0 .173 r
.12366 .42316 .14208 .39302 .16036 .38646 .14224 .41652 Metetra
.344 0 .173 r
.14224 .41652 .16036 .38646 .17876 .37988 .16095 .4099 Metetra
.336 0 .168 r
.16095 .4099 .17876 .37988 .19731 .37311 .17983 .40287 Metetra
.266 0 .127 r
.17983 .40287 .19731 .37311 .21612 .36502 .19916 .39275 Metetra
.058 0 0 r
.19916 .39275 .21612 .36502 .23528 .35422 .2192 .37621 Metetra
.2192 .37621 .23528 .35422 .25477 .34063 .23984 .35313 Metetra
.767 .963 .661 r
.23984 .35313 .25477 .34063 .2744 .32609 .26061 .32794 Metetra
.878 .973 .842 r
.26061 .32794 .2744 .32609 .29395 .31301 .28102 .30637 Metetra
.807 .869 .893 r
.28102 .30637 .29395 .31301 .31339 .30261 .30093 .29124 Metetra
.716 .781 .903 r
.30093 .29124 .31339 .30261 .33279 .29445 .32053 .28142 Metetra
.66 .741 .91 r
.32053 .28142 .33279 .29445 .35224 .28747 .34006 .27443 Metetra
.667 .744 .908 r
.34006 .27443 .35224 .28747 .37185 .28028 .35976 .26704 Metetra
.663 .741 .908 r
.35976 .26704 .37185 .28028 .39159 .27313 .3796 .2598 Metetra
.664 .742 .908 r
.3796 .2598 .39159 .27313 .41149 .26592 .39959 .25247 Metetra
.664 .741 .908 r
.39959 .25247 .41149 .26592 .43153 .25865 .41972 .24511 Metetra
.664 .741 .908 r
.41972 .24511 .43153 .25865 .45172 .25134 .44001 .23769 Metetra
.664 .741 .908 r
.44001 .23769 .45172 .25134 .47206 .24397 .46045 .23021 Metetra
.663 .741 .908 r
.46045 .23021 .47206 .24397 .49255 .23654 .48104 .22269 Metetra
.663 .741 .908 r
.48104 .22269 .49255 .23654 .5132 .22907 .50179 .21512 Metetra
.664 .742 .908 r
.50179 .21512 .5132 .22907 .53401 .22152 .5227 .20746 Metetra
.66 .74 .909 r
.5227 .20746 .53401 .22152 .55497 .21401 .54377 .19995 Metetra
.667 .744 .908 r
.54377 .19995 .55497 .21401 .5761 .20628 .565 .19202 Metetra
.606 .719 .925 r
.565 .19202 .5761 .20628 .59741 .19976 .58645 .18698 Metetra
.441 .67 .959 r
.58645 .18698 .59741 .19976 .61898 .19551 .60826 .18736 Metetra
.008 .49 .869 r
.60826 .18736 .61898 .19551 .64088 .19403 .6306 .19439 Metetra
.466 0 0 r
.6306 .19439 .64088 .19403 .66311 .19407 .65349 .20523 Metetra
.528 .019 0 r
.65349 .20523 .66311 .19407 .68558 .19316 .67674 .21399 Metetra
.455 .02 .122 r
.67674 .21399 .68558 .19316 .70816 .1894 .70005 .21608 Metetra
.383 0 .163 r
.70005 .21608 .70816 .1894 .7308 .18284 .72327 .21155 Metetra
.349 0 .172 r
.72327 .21155 .7308 .18284 .75353 .17491 .7465 .20379 Metetra
.345 0 .173 r
.7465 .20379 .75353 .17491 .77644 .16676 .76989 .19559 Metetra
.392 .049 .26 r
.10312 .46523 .12366 .42316 .14224 .41652 .12208 .45851 Metetra
.393 .051 .261 r
.12208 .45851 .14224 .41652 .16095 .4099 .14116 .45186 Metetra
.384 .042 .256 r
.14116 .45186 .16095 .4099 .17983 .40287 .16045 .44453 Metetra
.297 0 .211 r
.16045 .44453 .17983 .40287 .19916 .39275 .18046 .43174 Metetra
.031 0 .058 r
.18046 .43174 .19916 .39275 .2192 .37621 .20166 .40767 Metetra
.20166 .40767 .2192 .37621 .23984 .35313 .22387 .37226 Metetra
.863 .946 .585 r
.22387 .37226 .23984 .35313 .26061 .32794 .24619 .33342 Metetra
.941 .953 .752 r
.24619 .33342 .26061 .32794 .28102 .30637 .26773 .30113 Metetra
.867 .879 .844 r
.26773 .30113 .28102 .30637 .30093 .29124 .28825 .28009 Metetra
.747 .793 .89 r
.28825 .28009 .30093 .29124 .32053 .28142 .3081 .26821 Metetra
.658 .74 .911 r
.3081 .26821 .32053 .28142 .34006 .27443 .32771 .26125 Metetra
.67 .746 .907 r
.32771 .26125 .34006 .27443 .35976 .26704 .34751 .25362 Metetra
.663 .741 .908 r
.34751 .25362 .35976 .26704 .3796 .2598 .36744 .24629 Metetra
.664 .742 .908 r
.36744 .24629 .3796 .2598 .39959 .25247 .38752 .23884 Metetra
.664 .741 .908 r
.38752 .23884 .39959 .25247 .41972 .24511 .40775 .23137 Metetra
.664 .741 .908 r
.40775 .23137 .41972 .24511 .44001 .23769 .42813 .22385 Metetra
.664 .741 .908 r
.42813 .22385 .44001 .23769 .46045 .23021 .44867 .21627 Metetra
.663 .741 .908 r
.44867 .21627 .46045 .23021 .48104 .22269 .46936 .20864 Metetra
.663 .741 .908 r
.46936 .20864 .48104 .22269 .50179 .21512 .49022 .20098 Metetra
.664 .742 .908 r
.49022 .20098 .50179 .21512 .5227 .20746 .51123 .1932 Metetra
.657 .739 .91 r
.51123 .1932 .5227 .20746 .54377 .19995 .53241 .18572 Metetra
.669 .746 .908 r
.53241 .18572 .54377 .19995 .565 .19202 .55375 .17756 Metetra
.559 .698 .934 r
.55375 .17756 .565 .19202 .58645 .18698 .57533 .1744 Metetra
.201 .537 .925 r
.57533 .1744 .58645 .18698 .60826 .18736 .59738 .18061 Metetra
.494 0 0 r
.59738 .18061 .60826 .18736 .6306 .19439 .62018 .19845 Metetra
.725 .208 0 r
.62018 .19845 .6306 .19439 .65349 .20523 .64382 .22319 Metetra
.672 .222 .176 r
.64382 .22319 .65349 .20523 .67674 .21399 .66798 .24461 Metetra
.554 .157 .243 r
.66798 .24461 .67674 .21399 .70005 .21608 .69216 .25447 Metetra
.45 .089 .26 r
.69216 .25447 .70005 .21608 .72327 .21155 .71609 .25267 Metetra
.4 .056 .261 r
.71609 .25267 .72327 .21155 .7465 .20379 .73992 .24519 Metetra
.395 .052 .261 r
.73992 .24519 .7465 .20379 .76989 .19559 .76392 .23698 Metetra
.364 .004 .213 r
.0825 .5025 .10312 .46523 .12208 .45851 .10181 .49569 Metetra
.367 .006 .214 r
.10181 .49569 .12208 .45851 .14116 .45186 .12124 .48902 Metetra
.352 0 .206 r
.12124 .48902 .14116 .45186 .16045 .44453 .14092 .48139 Metetra
.199 0 .121 r
.14092 .48139 .16045 .44453 .18046 .43174 .16159 .46609 Metetra
.16159 .46609 .18046 .43174 .20166 .40767 .18395 .43495 Metetra
.833 .909 .503 r
.18395 .43495 .20166 .40767 .22387 .37226 .20774 .38811 Metetra
.972 .928 .636 r
.20774 .38811 .22387 .37226 .24619 .33342 .2316 .33681 Metetra
.962 .892 .713 r
.2316 .33681 .24619 .33342 .26773 .30113 .25427 .29485 Metetra
.889 .85 .798 r
.25427 .29485 .26773 .30113 .28825 .28009 .2754 .26853 Metetra
.768 .791 .872 r
.2754 .26853 .28825 .28009 .3081 .26821 .2955 .25482 Metetra
.656 .739 .911 r
.2955 .25482 .3081 .26821 .32771 .26125 .31519 .24786 Metetra
.672 .746 .906 r
.31519 .24786 .32771 .26125 .34751 .25362 .33509 .24001 Metetra
.663 .741 .908 r
.33509 .24001 .34751 .25362 .36744 .24629 .35511 .23258 Metetra
.665 .742 .908 r
.35511 .23258 .36744 .24629 .38752 .23884 .37529 .22502 Metetra
.664 .741 .908 r
.37529 .22502 .38752 .23884 .40775 .23137 .39561 .21744 Metetra
.664 .741 .908 r
.39561 .21744 .40775 .23137 .42813 .22385 .41609 .20981 Metetra
.663 .741 .908 r
.41609 .20981 .42813 .22385 .44867 .21627 .43673 .20213 Metetra
.663 .741 .908 r
.43673 .20213 .44867 .21627 .46936 .20864 .45752 .19439 Metetra
.663 .741 .908 r
.45752 .19439 .46936 .20864 .49022 .20098 .47848 .18664 Metetra
.664 .742 .908 r
.47848 .18664 .49022 .20098 .51123 .1932 .4996 .17874 Metetra
.655 .738 .911 r
.4996 .17874 .51123 .1932 .53241 .18572 .52088 .17127 Metetra
.671 .746 .907 r
.52088 .17127 .53241 .18572 .55375 .17756 .54233 .16289 Metetra
.512 .676 .939 r
.54233 .16289 .55375 .17756 .57533 .1744 .56403 .16137 Metetra
0 .377 .837 r
.56403 .16137 .57533 .1744 .59738 .18061 .58626 .17277 Metetra
.671 .151 0 r
.58626 .17277 .59738 .18061 .62018 .19845 .60942 .20032 Metetra
.807 .324 .043 r
.60942 .20032 .62018 .19845 .64382 .22319 .63364 .23775 Metetra
.755 .302 .175 r
.63364 .23775 .64382 .22319 .66798 .24461 .65857 .27094 Metetra
.615 .195 .221 r
.65857 .27094 .66798 .24461 .69216 .25447 .68352 .2881 Metetra
.461 .076 .223 r
.68352 .2881 .69216 .25447 .71609 .25267 .70811 .28888 Metetra
.379 .016 .216 r
.70811 .28888 .71609 .25267 .73992 .24519 .73251 .28166 Metetra
.37 .009 .215 r
.73251 .28166 .73992 .24519 .76392 .23698 .75707 .27343 Metetra
.17 0 0 r
.0638 .52076 .0825 .5025 .10181 .49569 .08336 .51387 Metetra
.178 0 0 r
.08336 .51387 .10181 .49569 .12124 .48902 .10304 .50714 Metetra
.135 0 0 r
.10304 .50714 .12124 .48902 .14092 .48139 .123 .49929 Metetra
.123 .49929 .14092 .48139 .16159 .46609 .14414 .48236 Metetra
.883 .972 .662 r
.14414 .48236 .16159 .46609 .18395 .43495 .16736 .44672 Metetra
.98 .902 .662 r
.16736 .44672 .18395 .43495 .20774 .38811 .1923 .39265 Metetra
.971 .847 .661 r
.1923 .39265 .20774 .38811 .2316 .33681 .21731 .33359 Metetra
.944 .823 .695 r
.21731 .33359 .2316 .33681 .25427 .29485 .24083 .28567 Metetra
.885 .81 .769 r
.24083 .28567 .25427 .29485 .2754 .26853 .26242 .25609 Metetra
.776 .781 .857 r
.26242 .25609 .2754 .26853 .2955 .25482 .28272 .24123 Metetra
.654 .739 .912 r
.28272 .24123 .2955 .25482 .31519 .24786 .3025 .23423 Metetra
.674 .746 .905 r
.3025 .23423 .31519 .24786 .33509 .24001 .3225 .22621 Metetra
.663 .741 .908 r
.3225 .22621 .33509 .24001 .35511 .23258 .34261 .21868 Metetra
.665 .742 .908 r
.34261 .21868 .35511 .23258 .37529 .22502 .36288 .211 Metetra
.664 .741 .908 r
.36288 .211 .37529 .22502 .39561 .21744 .3833 .20331 Metetra
.664 .741 .908 r
.3833 .20331 .39561 .21744 .41609 .20981 .40388 .19557 Metetra
.663 .741 .908 r
.40388 .19557 .41609 .20981 .43673 .20213 .42461 .18778 Metetra
.663 .741 .908 r
.42461 .18778 .43673 .20213 .45752 .19439 .44551 .17993 Metetra
.662 .741 .908 r
.44551 .17993 .45752 .19439 .47848 .18664 .46657 .17208 Metetra
.664 .742 .908 r
.46657 .17208 .47848 .18664 .4996 .17874 .48779 .16406 Metetra
.653 .738 .911 r
.48779 .16406 .4996 .17874 .52088 .17127 .50918 .15655 Metetra
.672 .746 .906 r
.50918 .15655 .52088 .17127 .54233 .16289 .53074 .14799 Metetra
.481 .661 .941 r
.53074 .14799 .54233 .16289 .56403 .16137 .55254 .14743 Metetra
0 .282 .774 r
.55254 .14743 .56403 .16137 .58626 .17277 .57488 .16192 Metetra
.701 .214 0 r
.57488 .16192 .58626 .17277 .60942 .20032 .5982 .19537 Metetra
.83 .359 0 r
.5982 .19537 .60942 .20032 .63364 .23775 .62271 .24063 Metetra
.812 .332 .056 r
.62271 .24063 .63364 .23775 .65857 .27094 .64806 .28116 Metetra
.674 .169 .037 r
.64806 .28116 .65857 .27094 .68352 .2881 .67348 .30291 Metetra
.402 0 0 r
.67348 .30291 .68352 .2881 .70811 .28888 .69852 .30529 Metetra
.209 0 0 r
.69852 .30529 .70811 .28888 .73251 .28166 .72334 .29819 Metetra
.184 0 0 r
.72334 .29819 .73251 .28166 .75707 .27343 .74831 .28989 Metetra
.541 .904 .965 r
.04737 .5194 .0638 .52076 .08336 .51387 .06707 .51241 Metetra
.53 .9 .964 r
.06707 .51241 .08336 .51387 .10304 .50714 .0869 .5056 Metetra
.584 .919 .968 r
.0869 .5056 .10304 .50714 .123 .49929 .10702 .4976 Metetra
.828 .941 .9 r
.10702 .4976 .123 .49929 .14414 .48236 .12843 .48 Metetra
.928 .855 .75 r
.12843 .48 .14414 .48236 .16736 .44672 .15213 .4426 Metetra
.94 .799 .677 r
.15213 .4426 .16736 .44672 .1923 .39265 .17772 .38579 Metetra
.936 .777 .661 r
.17772 .38579 .1923 .39265 .21731 .33359 .20339 .32378 Metetra
.918 .774 .686 r
.20339 .32378 .21731 .33359 .24083 .28567 .22741 .27361 Metetra
.874 .78 .754 r
.22741 .27361 .24083 .28567 .26242 .25609 .24931 .24279 Metetra
.777 .771 .848 r
.24931 .24279 .26242 .25609 .28272 .24123 .26977 .22744 Metetra
.654 .738 .912 r
.26977 .22744 .28272 .24123 .3025 .23423 .28963 .22036 Metetra
.674 .745 .904 r
.28963 .22036 .3025 .23423 .3225 .22621 .30973 .2122 Metetra
.663 .741 .908 r
.30973 .2122 .3225 .22621 .34261 .21868 .32993 .20457 Metetra
.665 .742 .907 r
.32993 .20457 .34261 .21868 .36288 .211 .3503 .19678 Metetra
.664 .741 .908 r
.3503 .19678 .36288 .211 .3833 .20331 .37082 .18898 Metetra
.664 .741 .908 r
.37082 .18898 .3833 .20331 .40388 .19557 .39149 .18113 Metetra
.663 .741 .908 r
.39149 .18113 .40388 .19557 .42461 .18778 .41233 .17323 Metetra
.663 .741 .908 r
.41233 .17323 .42461 .18778 .44551 .17993 .43333 .16527 Metetra
.662 .741 .908 r
.43333 .16527 .44551 .17993 .46657 .17208 .45449 .1573 Metetra
.664 .742 .908 r
.45449 .1573 .46657 .17208 .48779 .16406 .47582 .14917 Metetra
.653 .737 .912 r
.47582 .14917 .48779 .16406 .50918 .15655 .49731 .14157 Metetra
.672 .745 .905 r
.49731 .14157 .50918 .15655 .53074 .14799 .51899 .13286 Metetra
.47 .655 .941 r
.51899 .13286 .53074 .14799 .55254 .14743 .54087 .13257 Metetra
0 .255 .758 r
.54087 .13257 .55254 .14743 .57488 .16192 .56326 .14811 Metetra
.678 .213 0 r
.56326 .14811 .57488 .16192 .5982 .19537 .5866 .18363 Metetra
.802 .348 0 r
.5866 .18363 .5982 .19537 .62271 .24063 .61115 .23169 Metetra
.782 .305 0 r
.61115 .23169 .62271 .24063 .64806 .28116 .6366 .27486 Metetra
.58 .029 0 r
.6366 .27486 .64806 .28116 .67348 .30291 .66221 .29824 Metetra
.055 .594 .852 r
.66221 .29824 .67348 .30291 .69852 .30529 .68747 .30114 Metetra
.479 .875 .963 r
.68747 .30114 .69852 .30529 .72334 .29819 .71253 .29399 Metetra
.52 .896 .963 r
.71253 .29399 .72334 .29819 .74831 .28989 .73776 .28558 Metetra
.652 .785 .945 r
.03203 .50833 .04737 .5194 .06707 .51241 .05182 .50125 Metetra
.647 .783 .947 r
.05182 .50125 .06707 .51241 .0869 .5056 .07174 .49434 Metetra
.673 .789 .936 r
.07174 .49434 .0869 .5056 .10702 .4976 .09196 .48624 Metetra
.802 .799 .849 r
.09196 .48624 .10702 .4976 .12843 .48 .11353 .46843 Metetra
.886 .775 .733 r
.11353 .46843 .12843 .48 .15213 .4426 .13751 .43065 Metetra
.913 .755 .672 r
.13751 .43065 .15213 .4426 .17772 .38579 .16349 .37329 Metetra
.917 .749 .658 r
.16349 .37329 .17772 .38579 .20339 .32378 .18958 .31071 Metetra
.906 .754 .682 r
.18958 .31071 .20339 .32378 .22741 .27361 .21393 .26008 Metetra
.867 .767 .75 r
.21393 .26008 .22741 .27361 .24931 .24279 .23605 .22897 Metetra
.775 .767 .845 r
.23605 .22897 .24931 .24279 .26977 .22744 .25664 .21345 Metetra
.654 .738 .912 r
.25664 .21345 .26977 .22744 .28963 .22036 .27659 .20627 Metetra
.674 .745 .904 r
.27659 .20627 .28963 .22036 .30973 .2122 .29678 .198 Metetra
.663 .741 .908 r
.29678 .198 .30973 .2122 .32993 .20457 .31707 .19026 Metetra
.665 .742 .907 r
.31707 .19026 .32993 .20457 .3503 .19678 .33754 .18236 Metetra
.664 .741 .908 r
.33754 .18236 .3503 .19678 .37082 .18898 .35815 .17445 Metetra
.664 .741 .908 r
.35815 .17445 .37082 .18898 .39149 .18113 .37893 .16649 Metetra
.663 .741 .908 r
.37893 .16649 .39149 .18113 .41233 .17323 .39987 .15847 Metetra
.663 .741 .908 r
.39987 .15847 .41233 .17323 .43333 .16527 .42097 .15039 Metetra
.662 .741 .908 r
.42097 .15039 .43333 .16527 .45449 .1573 .44223 .14231 Metetra
.664 .742 .908 r
.44223 .14231 .45449 .1573 .47582 .14917 .46367 .13406 Metetra
.653 .737 .912 r
.46367 .13406 .47582 .14917 .49731 .14157 .48527 .12634 Metetra
.672 .745 .905 r
.48527 .12634 .49731 .14157 .51899 .13286 .50706 .11751 Metetra
.469 .654 .941 r
.50706 .11751 .51899 .13286 .54087 .13257 .52903 .11715 Metetra
0 .255 .76 r
.52903 .11715 .54087 .13257 .56326 .14811 .55144 .13275 Metetra
.655 .202 0 r
.55144 .13275 .56326 .14811 .5866 .18363 .57473 .16849 Metetra
.77 .33 0 r
.57473 .16849 .5866 .18363 .61115 .23169 .59921 .21688 Metetra
.717 .265 0 r
.59921 .21688 .61115 .23169 .6366 .27486 .62463 .26038 Metetra
0 .088 .611 r
.62463 .26038 .6366 .27486 .66221 .29824 .65028 .28391 Metetra
.338 .624 .957 r
.65028 .28391 .66221 .29824 .68747 .30114 .67567 .28677 Metetra
.617 .771 .954 r
.67567 .28677 .68747 .30114 .71253 .29399 .70089 .2795 Metetra
.642 .782 .948 r
.70089 .2795 .71253 .29399 .73776 .28558 .72628 .27095 Metetra
.653 .766 .932 r
.01662 .49596 .03203 .50833 .05182 .50125 .0365 .48878 Metetra
.648 .765 .934 r
.0365 .48878 .05182 .50125 .07174 .49434 .0565 .48177 Metetra
.672 .77 .924 r
.0565 .48177 .07174 .49434 .09196 .48624 .07682 .47356 Metetra
.796 .784 .841 r
.07682 .47356 .09196 .48624 .11353 .46843 .09855 .4556 Metetra
.881 .767 .731 r
.09855 .4556 .11353 .46843 .13751 .43065 .12279 .4176 Metetra
.909 .75 .672 r
.12279 .4176 .13751 .43065 .16349 .37329 .14913 .35995 Metetra
.915 .745 .658 r
.14913 .35995 .16349 .37329 .18958 .31071 .1756 .29707 Metetra
.904 .752 .682 r
.1756 .29707 .18958 .31071 .21393 .26008 .20027 .24621 Metetra
.866 .765 .749 r
.20027 .24621 .21393 .26008 .23605 .22897 .2226 .21491 Metetra
.775 .766 .845 r
.2226 .21491 .23605 .22897 .25664 .21345 .24332 .19927 Metetra
.654 .738 .912 r
.24332 .19927 .25664 .21345 .27659 .20627 .26336 .19198 Metetra
.674 .744 .904 r
.26336 .19198 .27659 .20627 .29678 .198 .28364 .1836 Metetra
.663 .741 .908 r
.28364 .1836 .29678 .198 .31707 .19026 .30403 .17574 Metetra
.665 .742 .907 r
.30403 .17574 .31707 .19026 .33754 .18236 .32459 .16773 Metetra
.664 .741 .908 r
.32459 .16773 .33754 .18236 .35815 .17445 .3453 .15971 Metetra
.664 .741 .908 r
.3453 .15971 .35815 .17445 .37893 .16649 .36618 .15163 Metetra
.663 .741 .908 r
.36618 .15163 .37893 .16649 .39987 .15847 .38722 .14349 Metetra
.663 .741 .908 r
.38722 .14349 .39987 .15847 .42097 .15039 .40843 .1353 Metetra
.662 .741 .908 r
.40843 .1353 .42097 .15039 .44223 .14231 .4298 .12709 Metetra
.664 .742 .908 r
.4298 .12709 .44223 .14231 .46367 .13406 .45135 .11872 Metetra
.653 .737 .912 r
.45135 .11872 .46367 .13406 .48527 .12634 .47306 .11089 Metetra
.672 .745 .905 r
.47306 .11089 .48527 .12634 .50706 .11751 .49496 .10193 Metetra
.469 .654 .941 r
.49496 .10193 .50706 .11751 .52903 .11715 .51701 .10146 Metetra
0 .255 .76 r
.51701 .10146 .52903 .11715 .55144 .13275 .53944 .117 Metetra
.652 .2 0 r
.53944 .117 .55144 .13275 .57473 .16849 .56268 .15273 Metetra
.766 .328 0 r
.56268 .15273 .57473 .16849 .59921 .21688 .58707 .20117 Metetra
.707 .259 0 r
.58707 .20117 .59921 .21688 .62463 .26038 .61243 .24469 Metetra
0 .1 .629 r
.61243 .24469 .62463 .26038 .65028 .28391 .63811 .2682 Metetra
.356 .615 .949 r
.63811 .2682 .65028 .28391 .67567 .28677 .66361 .27097 Metetra
.62 .753 .941 r
.66361 .27097 .67567 .28677 .70089 .2795 .68898 .26355 Metetra
.644 .763 .936 r
.68898 .26355 .70089 .2795 .72628 .27095 .71453 .25486 Metetra
.653 .77 .934 r
.00095 .48363 .01662 .49596 .0365 .48878 .02092 .47635 Metetra
.648 .768 .936 r
.02092 .47635 .0365 .48878 .0565 .48177 .04101 .46924 Metetra
.673 .774 .926 r
.04101 .46924 .0565 .48177 .07682 .47356 .06143 .46092 Metetra
.798 .787 .843 r
.06143 .46092 .07682 .47356 .09855 .4556 .08331 .4428 Metetra
.883 .768 .731 r
.08331 .4428 .09855 .4556 .12279 .4176 .10782 .40454 Metetra
.91 .751 .672 r
.10782 .40454 .12279 .4176 .14913 .35995 .13454 .34654 Metetra
.915 .746 .658 r
.13454 .34654 .14913 .35995 .1756 .29707 .16141 .28332 Metetra
.905 .752 .682 r
.16141 .28332 .1756 .29707 .20027 .24621 .18641 .23216 Metetra
.866 .766 .749 r
.18641 .23216 .20027 .24621 .2226 .21491 .20896 .20066 Metetra
.775 .766 .845 r
.20896 .20066 .2226 .21491 .24332 .19927 .22981 .18488 Metetra
.654 .738 .912 r
.22981 .18488 .24332 .19927 .26336 .19198 .24994 .17748 Metetra
.674 .745 .904 r
.24994 .17748 .26336 .19198 .28364 .1836 .27032 .16898 Metetra
.663 .741 .908 r
.27032 .16898 .28364 .1836 .30403 .17574 .2908 .16102 Metetra
.665 .742 .907 r
.2908 .16102 .30403 .17574 .32459 .16773 .31146 .15289 Metetra
.664 .741 .908 r
.31146 .15289 .32459 .16773 .3453 .15971 .33227 .14475 Metetra
.664 .741 .908 r
.33227 .14475 .3453 .15971 .36618 .15163 .35325 .13655 Metetra
.663 .741 .908 r
.35325 .13655 .36618 .15163 .38722 .14349 .37439 .1283 Metetra
.663 .741 .908 r
.37439 .1283 .38722 .14349 .40843 .1353 .3957 .11998 Metetra
.662 .741 .908 r
.3957 .11998 .40843 .1353 .4298 .12709 .41718 .11166 Metetra
.664 .742 .908 r
.41718 .11166 .4298 .12709 .45135 .11872 .43884 .10316 Metetra
.653 .737 .912 r
.43884 .10316 .45135 .11872 .47306 .11089 .46065 .0952 Metetra
.672 .745 .905 r
.46065 .0952 .47306 .11089 .49496 .10193 .48267 .08612 Metetra
.469 .654 .941 r
.48267 .08612 .49496 .10193 .51701 .10146 .5048 .08555 Metetra
0 .254 .759 r
.5048 .08555 .51701 .10146 .53944 .117 .52725 .10104 Metetra
.654 .202 0 r
.52725 .10104 .53944 .117 .56268 .15273 .55044 .1368 Metetra
.767 .329 0 r
.55044 .1368 .56268 .15273 .58707 .20117 .57474 .18533 Metetra
.71 .261 0 r
.57474 .18533 .58707 .20117 .61243 .24469 .60004 .22895 Metetra
0 .097 .625 r
.60004 .22895 .61243 .24469 .63811 .2682 .62575 .25246 Metetra
.353 .617 .95 r
.62575 .25246 .63811 .2682 .66361 .27097 .65136 .25513 Metetra
.619 .757 .944 r
.65136 .25513 .66361 .27097 .68898 .26355 .67688 .24758 Metetra
.643 .767 .938 r
.67688 .24758 .68898 .26355 .71453 .25486 .7026 .23874 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.21035 .18732 m
.21487 .19208 L
s
[(10)] .20131 .17781 .94967 1 Mshowa
.41738 .10625 m
.42153 .11134 L
s
[(20)] .40909 .09608 .81515 1 Mshowa
.64163 .01845 m
.64532 .02387 L
s
[(30)] .63425 .0076 .68064 1 Mshowa
.125 Mabswid
.25047 .17161 m
.25314 .1745 L
s
.29122 .15565 m
.29385 .15859 L
s
.33262 .13945 m
.3352 .14242 L
s
.37466 .12298 m
.3772 .12599 L
s
.46079 .08926 m
.46322 .09235 L
s
.5049 .07199 m
.50728 .07512 L
s
.54973 .05443 m
.55206 .0576 L
s
.5953 .03659 m
.59757 .0398 L
s
.17084 .20279 m
.17359 .20561 L
s
.13192 .21803 m
.13471 .22081 L
s
.09359 .23304 m
.09641 .23578 L
s
.05583 .24783 m
.05869 .25053 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[49]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
]Goo0P0017oo00<007ooOol0HWoo002gOol01P00Oomoo`00Ool006=oo`00]Woo00L007ooOomoo`00
Ool0001SOol00;Moo`06001oogoo001oo`00Hgoo002eOol00`00Ool00002Ool00`00Ool0001SOol0
0;Ioo`03001oogoo009oo`03001oogoo069oo`00bGoo0P00EGoo0037Ool200000goo0000001DOol0
0<Aoo`<000=oo`8005Aoo`00`Woo0P001Woo00<007oo0000Dgoo002nOol40008Ool01000Ool00000
DWoo002mOol2000;Ool01000Oomoo`00DWoo002jOol30002Ool00`00Oomoo`08Ool01@00Oomoogoo
0000DGoo002gOol3000@Ool00`00Oomoo`02Ool00`00Oomoo`1>Ool00;Eoo`8001Aoo`05001oogoo
Ool0001@Ool00;9oo`<001Ioo`03001oogoo009oo`03001oogoo04eoo`00/7oo0P0000=oo`00Ool0
5Woo00<007ooOol00goo00<007ooOol0C7oo002]Ool3000KOol00`00Oomoo`03Ool00`00Oomoo`1<
Ool00:]oo`8001ioo`03001oogoo00Aoo`03001oogoo04]oo`00Z7oo0`0087oo00<007ooOol017oo
0P00C7oo002VOol2000SOol00`00Oomoo`05Ool00`00Oomoo`1:Ool00:=oo`<00003Ool007oo029o
o`03001oogoo00Ioo`03001oogoo04Uoo`00XGoo0P00:7oo00<007ooOol01goo00<007ooOol0B7oo
001jOol30003Ool00`00Oomoo`0KOol3000ZOol00`00Oomoo`07Ool00`00Oomoo`18Ool007Yoo`03
001oogoo009oo`03001oo`0001Uoo`<002eoo`03001oogoo00Qoo`03001oogoo04Moo`00Ngoo00L0
07ooOomoo`00Ool0000GOol3000_Ool00`00Oomoo`08Ool00`00Oomoo`17Ool007]oo`07001oogoo
Ool007oo000057oo0`00<Woo00<007ooOol02Goo00<007ooOol0AWoo001jOol00`00Ool00002Ool0
0`00Ool0000BOol2000eOol00`00Oomoo`09Ool20017Ool007]oo`03001oogoo009oo`03001oogoo
00ioo`/002moo`03001oogoo00Yoo`03001oogoo04Eoo`00Sgoo1@000UKl00<003jN?Yh00cjN0P00
;Goo00<007ooOol02goo00<007ooOol0A7oo002<Ool50005E_`00`00?YhnWP03?Yh00`000AP0000]
Ool00`00Oomoo`0;Ool00`00Oomoo`13Ool008Yoo`@0009Bo@03001Fo5Kl00AFo003000nWSjN00<n
WP0400016000000[Ool00`00Oomoo`0;Ool00`00Oomoo`13Ool008Moo`D000EBo@03001Fo5Kl00=F
o0P000816003001oogoo02Qoo`03001oogoo00aoo`03001oogoo049oo`00Q7oo0`0000Eoo`00001F
o@0000IBo@03001Fo5Kl0080009Fo003000nWSjN00<nWP8000030AP007oo02Qoo`03001oogoo00eo
o`03001oogoo045oo`00PWoo0`0000=oo`0000000eKm00<005;mD_d015;m0`0015Kl00<003jN?Yh0
0cjN00@0004H000002Uoo`03001oogoo00eoo`03001oogoo045oo`00Ogoo0`0000Aoo`00000000IF
o@03001BoE;m00<0009Bo@03001Fo5Kl00=Fo003000nWSjN00<nWP0400016000000XOol00`00Oomo
o`0>Ool20011Ool007eoo`80009oo`80009Fo@03001FoEKm00EFo@8000EBo@03001Fo5Kl00=Fo0P0
00816003001oogoo02Eoo`03001oogoo00ioo`80045oo`00NWoo0`0000Aoo`00000000AFo@03001F
oEKm00=Fo@800003E_d005;m00EBo@03001Fo5Kl0080009Fo003000nWSjN00<nWP@002Ioo`03001o
ogoo00moo`03001oogoo03moo`00N7oo1P000UKm00<005KmE_d00eKm00<005KmE_d00P000eKm00<0
05;mD_d015;m0`0015Kl00<003jN?Yh00cjN00@0004H000002Ioo`03001oogoo011oo`03001oogoo
00Aoo`D0009oo`03001oogoo031oo`00MGoo1P001EKm00<005KmE_d00eKm0`001UKm00<005;mD_d0
0`000U;m00<005KlE_`00eKl00<003jN?Yh00cjN00@0004H000002Eoo`03001oogoo015oo`03001o
ogoo00Eoo`07001oogooOol007oo0000<Goo001cOol200000goo00000002E_d00`00E_eFo@04E_d0
0`00E_eFo@020002E_d00`00E_eFo@05E_d20005D_d00`00E_aFo003E_`800000`4H0000000TOol0
0`00Oomoo`0AOol00`00Oomoo`05Ool01`00Oomoogoo001oo`00035oo`00L7oo1P0015Km00<005Km
E_d015Km0`001EKm00<005KmE_d00UKm0P0000=Fo@00D_d01E;m00<005KlE_`00P000UKl00<003jN
?Yh00cjN10008goo00<007ooOol04Woo00<007ooOol017oo00L007ooOomoo`00Ool0000aOol006io
o`D0009Fo@03001FoEKm00=Fo@03001FoEKm00<0009Fo@03001FoEKm00AFo@04001Fo@000003E_d0
0`00D_eBo@04D_d30004E_`00`00?YhnWP03?Yh010000AP000008goo00<007ooOol04goo00<007oo
Ool00goo00L007ooOomoo`00Ool0000aOol006]oo`D000EFo@03001FoEKm00=Fo@<000EFo@03001F
oEKm00AFo@8000IFo@03001BoE;m00<0009Bo@03001Fo5Kl00=Fo003000nWSjN00<nWP0400016000
000ROol00`00Oomoo`0COol20003Ool20004Ool00`00Oomoo`0`Ool0049oo`D0009oo`03001oogoo
01eoo`@0009Fo@03001FoEKm00AFo@03001FoEKm0080009Fo@03001FoEKm00AFo@03001FoEKm00<0
009Fo@03001FoEKm00=Fo@<000EBo@03001Fo5Kl00=Fo0/0025oo`03001oogoo019oo`<003aoo`00
A7oo00L007ooOomoo`00Ool0000KOol50004E_d00`00E_eFo@04E_d30005E_d00`00E_eFo@03E_d3
0006E_d00`00E_eFo@020002E_d00`00D_eBo@04D_d00`00E_aFo0020002E_`00`00?[hn_P03?[h4
000POol00`00Oomoo`0EOol00`00Oomoo`0iOol004Aoo`07001oogooOol007oo000067oo1@000UKm
00<005KmE_d00eKm00<005KmE_d00`000UKm00<005KmE_d015Km00<005KmE_d00P000UKm00<005Km
E_d015Km0`0015Km00<005;mD_d015;m0`0015Kl00<003jn?[h013jn0`008Goo00<007ooOol057oo
00<007ooOol0>Goo0014Ool01`00Oomoogoo001oo`0001Ioo`@000EFo@03001FoEKm00=Fo@<000EF
o@03001FoEKm00AFo@<000EFo@03001FoEKm00<0009Fo@03001FoEKm00=Fo@03001BoE;m00<0009B
o@03001Fo5Kl00=Fo003000n_Sjn008n_PD0021oo`03001oogoo019oo`@003Yoo`00A7oo00L007oo
Oomoo`00Ool0000COol40002E_d00`00E_eFo@04E_d00`00E_eFo@020002E_d00`00E_eFo@04E_d0
0`00E_eFo@030002E_d00`00E_eFo@04E_d20005E_d00`00E_eFo@03E_d30005D_d00`00E_aFo003
E_`50002@[h4000OOol00`00Oomoo`0?Ool40002Cil2000iOol004=oo`8000Aoo`03001oogoo011o
o`@000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm009Fo@800003
E_d005Km00EFo@03001FoEKm0080009Fo@03001BoE;m00ABo@03001Fo5Kl0080009Fo@030012_T:n
00=2_PD001eoo`03001oogoo00aoo`T00003E_`007oo03Qoo`00FGoo1@0000=Fo000E_d01EKm00<0
05KmE_d00P000UKm00<005KmE_d015Km00<005KmE_d00P000UKm00<005KmE_d015Km00@005Km0000
00=Fo@03001FoEKm00AFo@<000AFo@03001BoE;m00ABo@<000AFo@030012_T:n00=2_P@00003F<00
07oo01]oo`03001oogoo00Yoo`H00003;0D005Kl00AFo003001oogoo03Ioo`00Egoo0P0000=oo`00
00000eKl00<005KmE_d015Km0`0015Km00<005KmE_d015Km0`0015Km00<005KmE_d015Km0P001UKm
00<005KmE_d00`000UKm00<005KmE_d00eKm00<005;mD_d00`000U;m00<005KmE_d00eKm00<004:n
@[h00T:n1@0000=H`00000006Woo00<007ooOol01goo1P000b`500<005KlE_`015Kl0P00=goo001D
Ool300000goo00000006E_`00`00E_eFo@030002E_d00`00E_eFo@03E_d00`00E_eFo@030002E_d0
0`00E_eFo@03E_d00`00E_eFo@030002E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d30005
D_d00`00E_eFo@03E_d500000dKM0000000400000eB0001oo`0HOol00`00Oomoo`04Ool600000b`5
000/1@03;0D20005E_`2000gOol0059oo`80009oo`80009Bo@03001Fo5Kl00=Fo0<000EFo@03001F
oEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000IFo@03001FoEKm0080009Fo@03001FoEKm00AFo@03
001FoEKm0080009Fo@03001BoE;m00ABo@03001FoEKm0080009Fo@030016gDKM0096g@H00003E800
000001Moo`03001oogoo00L000</1@03000/1B`500</1@80009Fo0<00003Ead0000003Ioo`00CWoo
10000Woo0P001E;m00<005KlE_`00P000UKl00<005KmE_d015Km00<005KmE_d00P000UKm00<005Km
E_d015Km00<005KmE_d00P000UKm00<005KmE_d015Km0`001EKm00<005KmE_d00eKm0`0015Km00<0
05;mD_d015;m0`001EKm00@004KMA]e6g@D00003F<0005B000<001=oo`T00003<0D002`500</1@03
000/1B`500</1@@000EG7@8003Eoo`00CGoo100000Eoo`00001S6`0000EBo@<000EFo003001FoEKm
00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@80009Fo@80009Fo@03001FoEKm00AFo@03001FoEKm
0080009Fo@03001FoEKm00=Fo@03001BoE;m00<0009Fo@03001FoEKm00=Fo@X00003F<0005B000@0
00ioo`@0000310000000008000<`1@03000/1B`500</1@03000/1B`5008/1@80009G7@03001G7ELM
00=G7@8003Eoo`00BWoo0`0017oo00<006<KHa/00V<K00<005;mD_d00P000U;m00<005KlE_`015Kl
00<005KmE_d00P000UKm00<005KmE_d015Km00<005KmE_d00P000UKm00<005KmE_d015Km0`0015Km
00<005KmE_d015Km0`0015Km00<005KmE_d00eKm0`001UKm00<005KmE_d00P000UKm00<004kmC_d0
100000=UH00000000eB000<003`000004`0000<h0`00<0D00c0500<002`5;0D00b`500@002`5;0D/
1@8000=G7@03001G7ELM00=G7@<003Aoo`00Agoo0`001Goo0P001V<K0P001E;m00<005KlE_`00eKl
0`0015Km00<005KmE_d015Km0`001EKm00<005KmE_d00`000UKm00<005KmE_d00eKm00<005KmE_d0
0`000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d015Km0`0015Km00@004kmC_e>
o@L0009DP0<00003G<00000000Dh00030010040000=00004000h0cP3>0<20005<0D00`00;0D/1@02
;0D00`00;0D0000200000c0X001G7@03Ead00`00EaeG7@020002E_d2000cOol004Aoo`<000Moo`03
001S6f<K00ES6`03001S6`0000IBo@03001Fo5Kl0080009Fo003001FoEKm00=Fo@03001FoEKm00<0
009Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000EFo@03
001FoEKm00<0009Fo@03001FoEKm00=Fo@03001>oDkm00@00003IF0006UP0080009U@@04001L`5c0
G<020002>0000`00@0100004@0001000>0<h0cP30P001C0500@002`5;0D/1@<000@`:003001G7ELM
009G7@<000AFo@<0039oo`00@Woo10001goo00<006lG000016<K0P000V<K00<005;mD_d015;m0`00
15Kl00<005KmE_d00eKm0`001UKm00<005KmE_d00P000UKm00<005KmE_d015Km00<005KmE_d00P00
0UKm00<005KmE_d015Km00<005KmE_d00P000UKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm
0`0000=Bo@0000000`000VUP00D006E1ID5U@@0000AL`0<000E00003000h0cP3008h0`8000@`1@03
000/1@0000800003<2P0030X00@`:003001G7@0000800003E_d005Km00EFo@80039oo`00@7oo0P00
2Woo00@006lGKaM_5`800003Ha/006<K00AS6`03001BoE;m00<0009Bo@03001Fo5Kl00=Fo003001F
oEKm0080009Fo@03001FoEKm00AFo@<000AFo@03001FoEKm00AFo@<000AFo@03001FoEKm00AFo@<0
00EFo@03001FoEKm0080009Fo@03001FoEKm00AFo@03001FoEKm0080009Fo@03001Bo@0000<00004
IF0006UP0004ID401@00G<1L`5c000000UCU0`000T0000<003P3>0<00SP30P000c050`00130X00<0
030X<2P00c0X0P001EKm00<005KmE_d00eKm0`00<Goo000mOol3000<Ool00`00KaM_5`03KaL00`00
Ha]S6`05Ha/20005D_d00`00E_aFo003E_`30005E_d20002E_d20002E_d00`00E_eFo@03E_d00`00
E_eFo@030002E_d00`00E_eFo@03E_d00`00E_eFo@030002E_d00`00E_eFo@03E_d30004E_d00`00
E_eFo@04E_d30004E_d00`00D_eBo@050002JF000`00ID5U@@02ID401000G<1L`0001ECU10000cP3
00<0030500000P0000<hB000<2P0130X00<0030X<2P00c0X00<005KmE_d015Km00<005KmE_d00`00
0UKm00<007ooOol0;goo000jOol3000>Ool00`00KaM_5`03KaL00`00KaL00005Ha/00`00Ha/00006
D_d00`00E_aFo0020002E_`00`00E_eFo@04E_d30004E_d00`00E_eFo@03E_d30005E_d00`00E_eF
o@03E_d30006E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d00`00E_eFo@030002E_d00`00E_eF
o@03E_d01000D_d005T00P0000EUH000JF1YH00000AU@@8000MDi@030014YdBW00D000@hB003000`
:30X00<`:003000`:30X008`:003001Fo@0000EFo@<000EFo@80031oo`00>7oo10003Woo00<006lG
KaL00flG00@006lGKaL000=S6`8000=S6`03001BoE;m00=Bo@<000EFo080009Fo@80009Fo@03001F
oEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm00AFo@03001FoEKm0080009Fo@03001FoEKm00AF
o@<000AFo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@P0009YH003001U@FE100=U@@03001D
iECU00ADi@030014YdBW00A4Y`8000<hB003000`:30X00@`:003000`:30X008`:003001Fo@00009F
o@<0009Fo@03001FoEKm00=Fo@80031oo`00=Woo0P004Goo00<006lGKaL016lG00L006lGKaM_5`00
Ha/00006Ha/00`00D_eBo@020002D_d00`00E_aFo004E_`30004E_d00`00E_eFo@03E_d30005E_d0
0`00E_eFo@03E_d30005E_d00`00E_eFo@030002E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d0
0`00E_eFo@04E_d00`00E_eFo@020002E_d200001ET0000006EP00000VUP00L006E1ID5U@@00HBD0
0005E>D00`00A:M4Y`04A:L20003>4P00`00<2P`:003<2P00`00<2P`:003<2P50006E_d00`00E_eF
o@020002E_d00`00Oomoo`0]Ool003=oo`<001=oo`03001_5flG00=_5`03001_5flG00=_5`03001S
6f<K00IS6`8000EBo@03001Fo5Kl00<0009Fo003001FoEKm00=Fo@03001FoEKm0080009Fo@03001F
oEKm00AFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00=Fo@<000AFo@03
001FoEKm00AFo@<000EFo@H000=YH003001U@@0000=Q9@03001DiECU009Di@030014YdBW00=4Y`03
000hB00000<hB003000`:30X00<`:003000`:30X00<`:005001FoEKmE_d00006E_d30004E_d2000^
Ool0031oo`<001Eoo`03001_5flG00=_5`03001_5flG00=_5`03001_5`0000IS6`03001S6`0000EB
o@<000EFo003001FoEKm00=Fo@<000AFo@03001FoEKm00AFo@<000EFo@03001FoEKm0080009Fo@03
001FoEKm00AFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm00<0009Fo@03001FoEKm
00=Fo@D00007IF0006UPJF0006E10000164U00D005CUE>EDi@0000E4Y`03000hB00000<hB003000`
:30X00<`:003000`:30X00<`:003001FoEKm009Fo@03001FoEKm00<00003E_d005Km00EFo@03001o
ogoo02aoo`00;Woo10005Woo0P000flG00<006lGKaL00flG00D006lGKaM_5`0000=S6`8000=S6`03
001BoE;m0080009Bo@03001Fo5Kl00AFo003001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm
00<0009Fo@03001FoEKm00=Fo@<000AFo@03001FoEKm00AFo@<000AFo@03001FoEKm00=Fo@<000EF
o@03001FoEKm00<0009Fo@D0009YH08000IQ9@03001Di@0000I4Y`03000hB00000<hB003000`:30X
00<`:003000`:30X008`:08000AFo@<000EFo@03001FoEKm00=Fo@8002eoo`00:goo0`006Goo00<0
07<ELaD00P0000=_5`00KaL016lG00<006lGKaL00VlG00<006<K00001V<K0P001E;m00<005KlE_`0
0eKl0`001EKm00@005KmE_eFo@@000IFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm
00<0009Fo@03001FoEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm00=Fo@<000EFo@05001Fo@00
001U80020002ID400`00HBEQ9@04HBD20006A:L30003>4P00`00<2P`:003<2P00`00<2P000020000
0b`6001Fo@0300000eKm001Fo@05E_d00`00E_eFo@030002E_d00`00Oomoo`0ZOol002Uoo`8001ao
o`03001c5G<E009c5@03001_5flG00=_5`03001_5flG00A_5`03001S6f<K00AS6`03001S6`0000IB
o@03001Fo5Kl0080009Fo003001FoEKm00=Fo@@000=Fo@03001FoEKm00AFo@<000AFo@03001FoEKm
00=Fo@<000IFo@04001FoEKmE_d40005E_d00`00E_eFo@020002E_d00`00E_eFo@04E_d01P00E_d0
0000IB0000=U@@03001Q9F4U00AQ9@040014YdBWA:L700000cQ8000`:004<2P30004;0H20005E_d0
0`00E_eFo@03E_d30005E_d00`00Oomoo`0ZOol002Ioo`<001eoo`03001c5G<E009c5@03001c5@00
00=_5`03001_5flG00A_5`03001_600000=S6`8000=S6`03001BoE;m00=Bo@<000EFo003001FoEKm
0080009Fo@03001FoEKm00=Fo@80009Fo@80009Fo@03001FoEKm00=Fo@03001FoEKm0080009Fo@03
001FoEKm00AFo@@000=Fo@03001FoEKm00=Fo@<000AFo@03001FoEKm00AFo@H000=U@@03001Q9F4U
00AQ9@@00004Dah000000002Dah01000>4P0030X100000<`1P00;0H00b`600<005Km00001EKm00<0
05KmE_d00`000UKm00<005KmE_d00eKm0P00:goo000TOol200000goo001oo`0MOol00`00LaEc5@02
LaD00`00LaD00002KaL00`00KaM_5`04KaL01`00KaQ_66lH001S6`0000IS6`03001BoE;m0080009B
o@03001Fo5Kl00=Fo0<000AFo@03001FoEKm00AFo@<000AFo@03001FoEKm00=Fo@<000EFo@03001F
oEKm00<00003E_d005Km00EFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm00<0009F
o@L00003ID40064U009Q9@<00004Cah000000005Dah40005<0H00`00;0H/1P02;0H00`00E_d00005
E_d30005E_d00`00E_eFo@0300000eKm0000000ZOol0029oo`80025oo`03001c5G<E009c5@07001c
5G<ELaD006lG00001VlG00<006lHKaP00VlH00<006<KHa/01V<K0P001E;m00<005KlE_`00P000UKm
00<005KmE_d00eKm00<005KmE_d00`000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005Km
E_d00eKm0`001EKm00<005KmE_d00eKm0`0015Km00<005KmE_d00eKm0`001EKm00<005Km00000P00
0Rin1@000TlN0P0000=?7P00Dah01U<N0P001C0600<002`6;0H00b`600@005KmE_d0009Fo@80009F
o@03001FoEKm00=Fo@<000EFo@8002Uoo`008Goo0`008Goo00<007<ELaD00W<E00<007<ELaD00W<E
00<006lGKaL016lG00<006lHKaP00VlH00<007<h00001F<K0P0000=S>`00D_d015;m0`0015Km00<0
05KmE_d00eKm0`001EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00P000UKm00<005KmE_d00eKm
00<005KmE_d00`000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d00eKm1@001Rin
0`0014lN00<005<NDah0100000=C7@000000130600<002`6;0H00b`600<005Km00000`001EKm00<0
05KmE_d00P000UKm00<005KmE_d00eKm0P00:Goo000ROol00`00Ool0000OOol00`00LaEc5@02LaD0
0`00LaEc5@03LaD20004KaL00`00KaQ_6002KaP01@00LcQc>7<h00000V<K0P0016<k00<005;mD_d0
0P000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d015Km00<005KmE_d00P000UKm
00<005KmE_d00eKm0`0015Km00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm0`001EKm00<005Km
E_d00P000UKm00@005Km0000008^OP@000I?7P<000IC7@03000`1S06008`1P03000/1R`600</1P80
00=Fo@03001FoEKm00=Fo@<000AFo@03001FoEKm00=Fo@<000Moo`<000=oo`03001oogoo01Qoo`00
6goo00<007ooOol017oo00@007ooOol001ioo`03001c5G<E009c5@03001c5G<E009c5@04001c5G<E
0002KaL00`00KaQ_6003KaP00`00LcQc>002LcP20007Hc/20004E_d00`00E_eFo@03E_d30005E_d0
0`00E_eFo@02E_d40005E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d0
0`00E_eFo@04E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d30004E_d00`00E_d000050002;Wh0
0`00Cai?7P030002Cah00`00DaeC7@04Dad20003<0H00`00;0H/1P02;0H00`00E_eFo@03E_d00`00
E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@020002E_d00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Ool0000IOol001Yoo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo01Yoo`03001c5G<E
009c5@03001c5G<E00=c5@07001c5G<ELaD006lG000016lH00<007<hLcP00W<h00<007=i00001F<k
0P0000=O?000E_d015Km00<005KmE_d00P000UKm00<005KmE_d00eKm1@000eKm00<005KmE_d00eKm
0`0015Km00<005KmE_d00eKm0`001EKm00<005KmE_d00UKm10001EKm00<005KmE_d00P000UKm00<0
05KmE_d00UKm1P000Rin1@001TlN00<005<MDad015<M0P000S0600<002`6;0H00R`600<005KmE_d0
0eKm0`001EKm00<005KmE_d00eKm0`0015Km0P001goo00L007ooOomoo`00Ool0000IOol001Yoo`03
001oo`0000Aoo`03001oogoo00=oo`03001oogoo01Uoo`03001c5G<E009c5@03001c5G<E009c5@03
001c5G<E00=c5@03001_66lH009_6003001c>7<h00=c>003001cNG=i00800003Hc/0000000=O?003
001FoEKm00=Fo@<000EFo@03001FoEKm0080009Fo@03001FoEKm00AFo@03001FoEKm0080009Fo@03
001FoEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm00=Fo@D000=Fo@03001FoEKm00=Fo@<000AF
o@03001Fo@0000800003E_d0000000<000H^OP03001?7TlN00E?7P03001C7E<M00<00004Dch00000
0004;0H30002E_d20002E_d00`00E_eFo@03E_d00`00E_eFo@030002E_d00`00E_eFo@02E_d30006
Ool01`00Oomoogoo001oo`0001Uoo`006Woo00<007oo000017oo0P001Goo00<007ooOol05goo00<0
07<ELaD00W<E00<007<ELaD00g<E00<007<ELaD00g<E0P000VlH00<007<hLcP00g<h00<007=iLgT0
0g=i00<005llGc`015ll00<005KmE_d00P000UKm00<005KmE_d00eKm0`001EKm00<005KmE_d00eKm
0`0015Km00<005KmE_d00eKm0`001EKm00<005KmE_d00P000UKm00<005KmE_d00eKm00<005KmE_d0
0`0000=Fo@00E_d00eKm0`000UKm0P000UKm00@005Km000000D^OP03001?7TlN00E?7P<000EC?P80
0003;0H0000000800004E_d000000005E_d01000E_eFoEKm10001EKm00<005KmE_d00P000UKm00<0
07ooOol00goo00<007oo00000Woo00<007oo00006Goo000JOol00`00Ool00004Ool00`00Oomoo`05
Ool2000GOol00`00LaEc5@02LaD00`00LaEc5@02LaD00`00LaEc5@03LaD01P00MaEg5@00KaP000Ac
>003001cNG=i00=cN@03001_V`0000EO?0<000EFo@03001FoEKm0080009Fo@03001FoEKm00AFo@03
001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm00=Fo@<000AFo@03
001FoEKm00=Fo@<000EFo@04001Fo@000002E_d30005E_d00`00E_d000040002;Wh00`00Cai?7P04
0002Cah00`00DciC?P03Dch3000350020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d3
0004E_d30004Ool00`00Oomoo`02Ool00`00Oomoo`0HOol001]oo`03001oogoo00=oo`03001oogoo
00Moo`03001oogoo01Aoo`80009c5@03001c5G<E00=c5@03001c5G<E00=c5@05001g5GLEMaD00004
LcP00`00LgUcN@03LgT01@00Ki]_VfnK00000Ull0P000U/L00<005KmE_d00eKm0`0015Km00<005Km
E_d015Km0`001EKm00@005KmE_eFo@@000EFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03001F
oEKm0080009Fo@03001FoEKm009Fo@<00004E_d000000002E_d00`00E_eFo@03E_d50002:Wh50006
Cah00`00DciC?P04Dch300000a@0001Fo@03E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_eF
o@0300000eKm001Fo@05E_d2000TOol0021oo`8000Yoo`03001oogoo019oo`03001fm@00009c5@03
001c5G<E009c5@03001c5G<E00=c5@06001g5GLEMaD007]F0P000W<h00<007=iLgT00W=i00<006nK
Ki/00fnK0P001E/L00<005KmE_d00P000UKm00<005KmE_d00eKm00<005KmE_d00`000UKm00<005Km
E_d00eKm10000eKm00<005KmE_d00eKm0`0015Km00<005KmE_d00eKm0`001EKm20001EKm00<005Km
E_d00`0000=Fo@00E_d00UKm00<002Yn:Wh00bYn00<004lNCah01DlN00<005<nDch00`0000=3WP00
@ih00P0015Km0`001EKm00<005KmE_d00UKm0`001EKm00<005KmE_d00eKm0P0097oo000POol00`00
Oomoo`0:Ool00`00Oomoo`0AOol00`00M_Efm@020005LaD00`00LaEc5@03LaD01@00MaEg5GLE0000
0g]F0P0017=i00<006nKKi/00fnK00<006Ml00001E/L0`001EKm00@005KmE_eFo@@000IFo@03001F
oEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm0080
009Fo@04001FoEKmE_d60003E_d00`00E_eFo@03E_d30005E_d01@00E_eFoEKm000012Yn00<004lN
Cah01DlN0`000T>N100000AFo@00E_eFo@800003E_d005Km00EFo@03001FoEKm0080009Fo@03001F
oEKm00=Fo@03001FoEKm00<0009Fo@03001oogoo025oo`0087oo00<007ooOol02goo00<007ooOol0
3goo00<007KeM_D00WKe00<007<ELaD00W<E00<007<ELaD00g<E00D007LEMaEg5@0000AkEP06001k
UP00001cN@0016nK0P000fMl00<005/LFa`00P000ULM00<005KmE_d00eKm10000eKm00<005KmE_d0
15Km0`0015Km00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@000EFo@D0009Fo@03001FoEKm00=F
o@03001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm00D0008ZOP03001?7TlN00@0008oOP<0
00=Fo@03001Fo@00008000AFo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d40005E_d2000ROol0
021oo`8000eoo`03001oogoo00ioo`03001fmGKe009fm@8000=c5@03001c5G<E00=c5@05001g5GLE
MaD00004NeH01000NiIkUW^F0P000fnK00<006MlIg`016Ml0P001ELM00<005KmE_d00P000UKm00<0
05KmE_d00eKm00<005KmE_d00`000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d0
0eKm10000eKm00<005KmE_d01P0015Km00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@000=Fo@L0
00<oOP<0009Fo@03001FoEKm00<0009Fo@03001FoEKm009Fo@03001FoEKm00<0009Fo@03001FoEKm
00=Fo@@000=Fo@03001FoEKm00=Fo@80029oo`0087oo00<007ooOol03Goo00<007ooOol037oo00<0
07KeM_D00WKe00<007KeM_D00`001G<E00D007LEMaEg5@0000AkEP05001kUW^FNiH00002NmP30005
Ig`200000emM001G7@04Ead30004E_d00`00E_eFo@03E_d30005E_d00`00E_eFo@03E_d30005E_d0
0`00E_eFo@020002E_d00`00E_eFo@03E_d200000eKm00000002E_d00`00E_eFo@03E_d00`00E_eF
o@020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d80005E_d30003E_d00`00E_d00003
E_d40005E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_eFo@030002E_`00`00Oomoo`0OOol0
021oo`8000moo`03001oogoo00]oo`03001fmGKe009fm@03001fmGKe009fm@03001c5G<E00=c5@05
001g5GLEMaD00004NeH01@00NiIkUW^F00000g_H00D007?j000006Ml008000AOG@03001G7ELM0080
009Fo@03001FoEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm00AFo@03001FoEKm0080009Fo@03
001FoEKm00=Fo@<000AFo@03001FoEKm00H000EFo@04001FoEKmE_d40005E_d00`00E_eFo@020002
E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d01P00
E_eFoEKm001Fo@@000=Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm009Fo@<000EFo080021oo`00
7goo0P004Goo00<007ooOol02Goo00<007KeM_D00WKe00<007KeM_D00gKe0P000g<E00D007LEMaEg
5@0000AkEP05001kUW^FNiH00003NmP00`00LoYcnP02LoX00`00GeeOG@04Ged30004E_d00`00E_eF
o@03E_d30005E_d00`00E_eFo@02E_d40005E_d00`00E_eFo@0200000eKm001Fo@04E_d300000eKm
00000002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d30004E_d00`00E_eFo@03E_d30005
E_d01000E_eFoEKm10001EKm00<005KmE_d00P0000=Fo@00E_d01EKm00<005KmE_d00P000UKm00<0
05KmE_d00eKm00<005KmE_d00P000UKl00<005KlE_`00eKl0P0087oo000:Ool00`00Oomoo`02Ool0
1000Oomoogoo0`000goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol027oo00<007KeM_D0
0WKe00<007KeM_D00WKe00@007KeM_D0009c5@05001g5GLEMaD00004NeH01000NiIkUP000g_H00@0
07?jLoYcnP800003Iid00000009OG@80009G7@03001FoEKm00=Fo@03001FoEKm0080009Fo@03001F
oEKm00=Fo@D000=Fo@03001FoEKm00=Fo@<000AFo@03001Fo@0000800004E_d000000004E_d00`00
E_eFo@0300000eKm001Fo@05E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d00`00E_eFo@020002
E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d30002E_d00`00E_d00005E_d30005E_d01000
E_eFoEKm10001EKl00<005KlE_`00P0000=Fo@0000007goo0009Ool00`00Ool00007Ool00`00Oomo
o`02Ool00`00Ool00004Ool2000COol00`00Oomoo`07Ool00`00M_Efm@02M_D00`00M_Efm@02M_D0
1000M_EfmGKe0P000gLE00<007]FNeH00W]F00D007^FNiIkUP0000=kf004001cnP000004Iid30005
Ead01000E_eFoEKm10001EKm00<005KmE_d00P000UKm00<005KmE_d00eKm00<005KmE_d00`000UKm
00@005KmE_eFo@<00004E_d000000002E_d00`00E_eFo@02E_d30005E_d00`00E_eFo@03E_d30004
E_d00`00E_eFo@02E_d40004E_d00`00E_eFo@0300000eKm001Fo@04E_d00`00E_eFo@030002E_d0
1000E_eFoEKm0P000UKm0`000UKm00<005KmE_d00eKm10000eKl00<005KlE_`00eKl0`0015Km0P00
7Woo0009Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00
Oomoo`05Ool00`00M_Efm@02M_D00`00M_Efm@02M_D00`00M_Efm@03M_D01@00MaEg5GLE000017]F
00@007^FNiH000=kf0@000=WW@80009K?@03001G7ELM00AG7@<000=Fo@03001FoEKm00=Fo@<000AF
o@03001FoEKm00=Fo@<000EFo@P000EFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm
00<0009Fo@03001FoEKm009Fo@D000=Fo@03001FoEKm009Fo@<000EFo@03001FoEKm009Fo@<000EF
o@04001FoEKmE_d40005E_d00`00E_eFo@0300000eKl001Fo004E_`00`00E_aFo0030002E_d00`00
E_eFo@02E_d2000NOol000Uoo`03001oo`0000Qoo`04001oogooOol20005Ool00`00Oomoo`0DOol0
0`00Oomoo`04Ool00`00M_Efm@02M_D00`00M_Efm@02M_D00`00M_Efm@03M_D40004NeH01P00NiIk
UW^F001kf0@0009So0<000EK?@80009G7@800003E_d005Km00AFo@03001FoEKm0080009Fo@03001F
oEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm009Fo@D000=Fo@03001FoEKm00=Fo@<000EFo@04
001FoEKmE_d40005E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d00`00
E_eFo@03E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d4000015Km001Fo@001EKm0`001EKl00<0
05KlE_`00UKl0`001EKm00@005KmE_eFo@@001eoo`002Goo00<007oo00001goo00<007oo00000Woo
00<007ooOol00goo0P005goo00<007ooOol00Woo00<007KeM_D00gKe00D007KeM_Efm@0000Efm@04
001g5GLEMaD20003NeH00`00NiH000060003Ho`00`00Feh00006Fcd30004E_d00`00E_eFo@03E_d2
0005E_d01000E_eFoEKm10001EKm1@000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005Km
E_d00eKm10000eKm00<005KmE_d00eKm0`0015Km00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@0
00EFo@03001FoEKm00800003E_d005Km00=Fo@03001Fo@00009Fo@80009Fo003001Fo5Kl00=Fo003
001Fo5Kl0080009Fo@03001FoEKm00=Fo@@000=BVP8001aoo`002Woo00<007ooOol01goo00@007oo
Oomoo`<000Aoo`03001oogoo01Ioo`05001oogooOol00004M_D00`00M_Efm@02M_D00`00M_Efm@03
M_D01P00MaEg5GLE001oM@H0009_dP8000=So08000=KGP80009K?@80009Fo003001FoEKm00=Fo@03
001FoEKm00800003E_d005Km00AFo@@000=Fo@04001FoEKmE_d50004E_d00`00E_eFo@03E_d30005
E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d00`00
E_eFo@020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d30004E_d01P00E_eFoEKm001F
o@<000AFo003001Fo5Kl009Fo0@000AFo@03001FoEKm00<00003DYX005:J00ABVP8001aoo`007Woo
00<007ooOol067oo0`001GKe00D007KeM_Efm@0000Efm@05001g5GLEMaD00004OgD01@00OkAo]000
Km801P001U]N0`001EKl00@005KmE_eFo@@000AFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@D0
009Fo@03001FoEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm00=Fo@<000AFo@03001FoEKm00=F
o@<000EFo@04001FoEKmE_d40005E_d00`00E_eFo@0200000eKm001Fo@05E_d00`00E_eFo@020002
E_d00`00E_eFo@02E_d00`00E_eFo@030002E_`00`00E_aFo002E_`50003E_d00`00E_eFo@02E_d3
0005DYX00`00DYYBVP03DYX2000KOol001ioo`8001]oo`03001fmGKe009fm@03001fmGKe009fm@03
001fmGKe00=fm@05001g5GLEMaD00003OgD01@00OkAo]000Km800P0000=;^00000000U]n0P000U]N
0P000UKl00<005KlE_`00eKl10000eKm00<005KmE_d00eKm0P001EKm00<005Km00001@001EKm00@0
05KmE_eFo@@000EFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm0080009Fo@03001F
oEKm00=Fo@@000=Fo@03001FoEKm00=Fo@<000AFo@03001FoEKm00=Fo@<000AFo@04001FoEKmE_d4
0003E_`00`00E_`00002E_`20002E_d00`00E_eFo@03E_d00`00E_eFo@020002DYX00`00DYYBVP03
DYX00`00DYYBVP03DYX00`00Ool0000JOol001ioo`03001oogoo01Yoo`8000=fm@03001fmGKe009f
m@03001fmGKe009fm@05001g5GLEMaD00004OgD00`00OkAo]0050004Fgh40005E_`00`00E_aFo002
0002E_d00`00E_eFo@03E_d00`00E_eFo@0200000eKm001Fo@03E_d50003E_d00`00E_eFo@03E_d4
0003E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm10001EKm00<005KmE_d00P0000=Fo@00E_d0
1EKm00<005KmE_d00P000UKm00<005KmE_d00UKm00<005KmE_d00`000UKm00<005KmE_d00UKm1000
0eKm00<005KlE_`00UKl100015Km00<005KmE_d00eKm0`0015:J00<005:JDYX00e:J00<005:JDYX0
0e:J0`006Woo000NOol00`00Oomoo`0IOol01000MaEg5@000WKe00D007KeM_Efm@0000Efm@05001g
5GLEMaD00003OgD00`00OkAo]0030003Eil40003E_`00`00E_aFo003E_`30005E_d01000E_eFoEKm
100015Km1@000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d00eKm00<005KmE_d0
0P000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00eKm0`0015Km00<005KmE_d00eKm0`0015Km
00@005KmE_eFo@@000EFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03001Fo5Kl0080009Fo@03
001FoEKm00=Fo@03001FoEKm00800003DYX005:J00EBVP03001BVU:J00=BVP03001BVP0000800004
CQH007oo000IOol001eoo`8001]oo`04001g5GLEMaD20004M_D00`00M_Efm@02M_D00`00MaEg5@02
MaD01P00OgEoMGme001o]08000=GW`80009Fo003001Fo5Kl00=Fo003001Fo5Kl0080009Fo@03001F
oEKm00=Fo@@000=Fo@04001FoEKmE_d40004E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm1000
1EKm00<005KmE_d00P000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d00UKm00<0
05KmE_d00`000UKm00<005KmE_d00UKm10000eKm00<005KmE_d00eKm0`0015Km00<005KmE_d00eKm
0`000UKm00<005Km000015Km100015:J00<005:JDYX00e:J00@005:JDYYBVP@000A>5P04001oogoo
000HOol001ioo`03001oogoo01Qoo`03001g5GLE00=g5@05001fmGKeM_D00005M_D01@00MaEg5GLE
00000gme00D007ndOk@005>O00<000AFo003001Fo5Kl00=Fo0<000EFo@03001FoEKm0080009Fo@03
001FoEKm00=Fo@D00003E_d005Km00AFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@@000=Fo@03
001FoEKm00=Fo@<000AFo@03001FoEKm00=Fo@<000AFo@04001FoEKmE_d40005E_d00`00E_eFo@02
0002E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d0
1000E_eFoEKm1P000UJk00<005:JDYX00e:J00<005:JDYX00e:J10000ThG00<004hFCQH014hF0`00
67oo000MOol00`00Ool0000IOol00`00MaEg5@03MaD20002M_D00`00M_Efm@03M_D01@00MaEg5GLE
00000gme00<007nd00000P000UKl00<005KlE_`00eKl00<005KlE_`00P000UKm00<005KmE_d00eKm
0`0015Km00<005KmE_d01P0015Km00@005KmE_eFo@@000EFo@03001FoEKm0080009Fo@03001FoEKm
00=Fo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm009Fo@@0
00=Fo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d40004E_d00`00E_eFo@02E_d40004E_d00`00
E_eFo@0300000eKK001F^`04E[/00`00DYYBVP03DYX00`00DYX0000200000dhG001>5`04CQL00`00
CQI>5P03CQH01000Oomoo`005goo000MOol2000IOol00`00MaEg5@03MaD00`00M_Efm@020005M_D0
1@00MaEg5GLE00000gme00@007ndOk@000EFo004001Fo5KlE_`40005E_d00`00E_eFo@020002E_d0
0`00E_eFo@02E_d300000eKm00000002E_d00`00E_eFo@03E_d30003E_d00`00E_eFo@03E_d30005
E_d01000E_eFoEKm10001EKm00@005KmE_eFo@@000AFo@03001FoEKm0080009Fo@03001FoEKm00=F
o@03001FoEKm0080009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm009Fo@D000=Fo@03001FoEKm
009Fo@<0009Ff`03001Ff`0000EF^`04001BVU:JDYX40005CQL00`00CQM>5`02CQL00`00CQI>5P03
CQH01000Oomoo`005goo000=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`0HOol00`00MaEg5@03MaD01@00M_EfmGKe00001GKe00D007LEMaEg5@0000=oM@04001o]000
0006E_`30003Ead00`00E_eFo@03E_d30005E_d80005E_d00`00E_eFo@0200000eKm001Fo@04E_d0
0`00E_eFo@020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@02
E_d30005E_d01000E_eFoEKm10001EKm00<005KmE_d00P0000=Fo@00E_d015Km00<005KmE_d00P00
0UKm00<005KmE_d00eKm00<005KmE_d00P0000=Fo000E]/00eKK00<005KK000015Jk10000Thg00<0
04hGCQL014hG00<004hGCQL00ThG00<004hFCQH00dhF00D007ooOomoo`0001Ioo`0037oo00<007oo
00001goo00<007oo000017oo0P0067oo00<007LEMaD00gLE00<007KeM_D00WKe0P000gKe00<007LE
MaD00WLE00H007meOgD007nd0002E_`20002E_`200000eLM001G7@04Ead00`00E_eFo@020002E_d0
1000E_eFoEKm1P000eKm00<005KmE_d00eKm0`0015Km00@005KmE_eFo@@000EFo@03001FoEKm0080
009Fo@03001FoEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm009Fo@03001FoEKm0080009Fo@03
001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@<000AFo@03001FoEKm009Fo@<000EFo@04001FoEKm
E_d40004E_`00`00E]]Ff`02E]/20002E[/200000diH001>=`04CSL00`00CQM>5`03CQL00`00CQM>
5`03CQL00`00CQI>5P03CQH01@00Oomoogoo00005Goo000<Ool00`00Ool00009Ool00`00Oomoo`02
Ool00`00Oomoo`0GOol00`00MaEg5@03MaD01@00M_EfmGKe00000WLE00@007KeM_D000=g5@04001o
MGmeOgD30003E_`30004Ead20003Ead30005E_d50002E_d00`00E_eFo@03E_d00`00E_eFo@020002
E_d00`00E_eFo@02E_d40003E_d00`00E_eFo@03E_d30004E_d00`00E_eFo@03E_d30004E_d01000
E_eFoEKm10001EKm00<005KmE_d00P000UKm00<005KmE_d00UKm00<005KmE_d00`000UKm00<005Km
E_d00UKm00<005KmE_d00P000UKm00<005KmE_d00eKm10000eKl00<005KlE_`00UKl00<005KKE]/0
0UKK100014iH00<004hgCSL00Thg00<004hGCQL014hG00<004hGCQL00ThG00<004hFCQH00dhF00D0
07ooOomoo`0001Eoo`0037oo00<007oo00001goo0P001Goo00<007ooOol05Woo00<007LEMaD00gLE
00<007KeM_D00WKe00@007LEMaEg5@8000Ag5@03001oMGme00<0009Fo080009G7@03001G7ELM00=G
7@@0009Fo@04001FoEKmE_d50005E_d01000E_eFoEKm100015Km00<005KmE_d00P000UKm00<005Km
E_d00eKm00<005KmE_d00P000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d00UKm
10000eKm00<005KmE_d00eKm0`0015Km00@005KmE_eFo@@000EFo@04001FoEKmE_d40005E_d00`00
E_eFo@020002E_d00`00E_aFo002E_`01000E_aFo5Kl1P0000=BNP0000001DiH00<004hgCSL00Thg
00<004hGCQL014hG00<004hGCQL00ThG00<004hFCQH00ThF0P000goo0P0057oo000<Ool00`00Ool0
0007Ool00`00Oomoo`03Ool2000HOol00`00MaEg5@03MaD01@00M_EfmGKe00001GLE0P000WLE00<0
07meOgD01P001ELM00<005LMEad00P000UKm00<005KmE_d00UKm1@000UKm00<005KmE_d00eKm1000
0eKm00<005KmE_d00eKm0P001EKm00@005KmE_eFo@@000EFo@04001FoEKmE_d40004E_d00`00E_eF
o@020002E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d00`00E_eFo@02E_d40003E_d00`00E_eF
o@03E_d40003E_d00`00E_eFo@03E_d30004E_d01000E_aFo5Kl1@000e:k00<0059jDWX00U9j0P00
14iH00<004hgCSL00dhg00<004hGCQL00dhG00<004hGCQL00dhG00H004hF000004gE0005Ool00`00
Oomoo`05Ool20004Ool00`00Oomoo`03Ool000eoo`03001oogoo00Ioo`<000=oo`03001oogoo01Io
o`03001g5GLE00=g5@03001fmGKe009fm@03001g5GLE009g5@03001k=G/e00H00004Jk0005LMEad2
0003Ead40005E_d70005E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d00`00E_eFo@0200000eKm
001Fo@04E_d40003E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@02E_d30005E_d01000E_eFoEKm
100015Km00<005KmE_d00P000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d00UKm
00<005KmE_d00`000UKm00<005KmE_d00UKm10000e;l00<005:kD[/00U:k00<0059jDWX00e9j00<0
04iHCUP00diH00<004hgCSL00Thg00<004hGCQL014hG00<004hGCQL0100014gE00<007ooOol00Woo
00<007ooOol01goo00H007ooOol007oo0004Ool001aoo`03001oogoo01Ioo`03001g5GLE00=g5@03
001fmGKe009fm@03001g5GLE009g5@05001k=G/eNcD00003OiD20004Ead40003E_d01000E_eFoEKm
1P000UKm00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@000AFo@03001FoEKm0080009Fo@03001F
oEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm009Fo@03001FoEKm0080009Fo@03001FoEKm00=F
o@@000=Fo@03001FoEKm009Fo@<000EFo@04001FoEKmE_d40004E_d01000E_eFoEKm10001EKm00<0
05KmE_d00P0000=Fo@00D_`015;l00<005:kD[/00e:k00<0059jDWX00U9j00<004iHCUP00diH00<0
04hgCSL00Thg00<004hGCQL00dhG10000TgE00<004gECMD00dgE00<007ooOol00goo00<007ooOol0
1Goo00L007ooOomoo`00Ool00004Ool001aoo`8001Ioo`03001g5GLE00=g5@03001fmGKe009fm@03
001g5GLE009g5@03001k=G/e009k=@03001oUGnE00<0009G7@80009Fo@03001FoEKm00=Fo@D0009F
o@03001FoEKm009Fo@03001FoEKm0080009Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm00=Fo@80
00EFo@04001FoEKmE_d40004E_d01000E_eFoEKm10001EKm00<005KmE_d00P000UKm00<005KmE_d0
0UKm00<005KmE_d00P000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00UKm10000eKm00<005Km
E_d00eKm0`0015Km00<005;lD_`00e;l00<005:kD[/00U:k00<0059jDWX00e9j00<004iHCUP00diH
00<004hgCSL00Thg00<004hG00000P0000==e@00CMD00dgE00<004gECMD00dgE00<007ooOol017oo
00<007ooOol01Goo00H007ooOol007oo0004Ool001aoo`03001oogoo01Eoo`03001g5GLE00=g5@03
001fmGKe009fm@03001g5GLE009g5@05001k=G/eNcD00003OiD200000eLM00000005E_d00`00E_d0
00050005E_d01000E_eFoEKm0`001EKm00<005KmE_d00P000UKm00<005KmE_d00eKm00<005KmE_d0
0P0000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm0`000eKm00<005KmE_d00eKm0`0015Km00@0
05KmE_eFo@@000EFo@03001FoEKm0080009Fo@03001FoEKm009Fo@03001FoEKm0080009Fo@03001F
oEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm009Fo@03001Bo5;l009Bo1T000A=e@03001=eDgE
00==e@03001=eDgE009=e@03001oogoo00Aoo`03001oogoo00=oo`03001oo`00009oo`03001oo`00
00Aoo`0077oo00<007ooOol057oo00<007<G00000gLE00<007KeM_D00WKe00<007LEMaD00WLE00<0
07/eNcD00W/e00<007nEOiD0100000=Fo@00E_d015Km10000eKm00<005KmE_d00eKm10000UKm00<0
05KmE_d00eKm0`001EKm00@005KmE_eFo@@000AFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03
001FoEKm00800003E_d005Km00AFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@<000=Fo@03001F
oEKm00=Fo@<000AFo@04001FoEKmE_d40005E_d01000E_eFoEKm100015Km00@005KmE_eFo@H0009>
_0030016NdIk0096N`03001664HH009660030019mP0000=9mP030019mDWe0099m@03001=eDgE00A=
e@03001=eDgE009=e@03001=eDgE00==e@03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00=oo`006goo0P005Woo00@007<GLaL0009g5@03001fmGKe009fm@03001g5GLE009g
5@05001k=G/eNcD00003OiD20004E_d600000eKm001Fo@04E_d00`00E_eFo@020002E_d00`00E_eF
o@02E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@02E_d30005E_d01000
E_eFoEKm100015Km00@005KmE_eFo@@000EFo@03001FoEKm00800003E_d005Km00AFo@03001FoEKm
0080009Fo@03001FoEKm009Fo@@000=Fo@03001FoEKm00=Fo@@000=Fo@03001FoEKm009Fo@@000=B
o@03001>_4jl00=>_0030016NdIk0096N`03001664HH0096608000=9mP030019mDWe0099m@03001=
eDgE00A=e@03001=eDgE009=e@03001=eDgE00==e@03001oogoo00=oo`03001oo`0000moo`006goo
00<007ooOol057oo00<007<GLaL00W<G0P001GKe00D007LEMaEg5@0000Ak=@03001oUGnE00<000=F
o@D000AFo@04001FoEKmE_d40005E_d01000E_eFoEKm0`001EKm00<005KmE_d00P000UKm00<005Km
E_d00UKm00<005KmE_d00P000UKm00<005KmE_d00eKm10000eKm00<005KmE_d00UKm10000eKm00<0
05KmE_d00eKm0`0015Km00@005KmE_eFo@@000AFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@03
001FoEKm0080009Fo@03001FoEKm009Fo@03001FoEKm0080009Fo003001BoE;m00=Bo@03001>_4jl
009>_0030016NdIk0096N`03001664HH009660030019mP0000=9mP030019mDWe0099m@03001=eDgE
00==e@03001=eDgE009=e@03001=eDgE00==e@03001oogoo00Eoo`03001oogoo00eoo`006goo00<0
07ooOol057oo00<007<GLaL00g<G00<007KeM_D00WKe00<007LEMaD00WLE00D007/eNcEk=@0000=o
U@03001oogoo00D0009Fo@03001FoEKm00=Fo@<000=Fo@03001FoEKm00=Fo@@0009Fo@8000=Fo@@0
00EFo@04001FoEKmE_d30005E_d00`00E_eFo@020002E_d00`00E_eFo@02E_d00`00E_eFo@020002
E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d00`00E_eFo@02E_d40003E_d00`00E_eFo@02E_d3
0005E_d01000E_eFoEKm100015Km00@005KmE_eFo@@000EFo004001BoE;mD_d80003AW/00`00AQQ6
6002AQP01000BOI9mP000TWf00<004WeBOD00TWe00<004gECMD00dgE00<004gECMD00TgE00<004gE
CMD014gE00<007ooOol01Goo00<007ooOol037oo000KOol2000DOol00`00LaMc5`03LaL00`00LaL0
0003M_D01@00MaEg5GLE000017/e00<007nEOiD0100000=oo`0000001EKm00<005KmE_d00P0000=F
o@00E_d015Km00<005KmE_d00P000UKm00<005KmE_d00eKm0`000eKm00<005KmE_d00eKm10000UKm
00<005KmE_d00eKm0`001EKm00@005KmE_eFo@<000EFo@04001FoEKmE_d40004E_d00`00E_eFo@02
0002E_d00`00E_eFo@02E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d40003E_d00`00E_eFo@02
E_d40003E_d00`00E_aFo003E_`40003C]d01000?YdnWCjM0`0000=6N`00AQP00dHH00@004WfBOH0
0099mP030019mDWe0099m@03001=eDgE00==e@03001=eDgE00==e@03001=eDgE00==e@03001oogoo
00Ioo`03001oogoo00]oo`006goo00<007ooOol04Woo00<007<GLaL017<G00<007<GLaL00`0017LE
00H007/eNcEk=@00OiD30005Ool00`00E_eFo@03E_d30004E_d01000E_eFoEKm10001EKm00<005Km
E_d00P0000=Fo@00E_d015Km00<005KmE_d00P000UKm00<005KmE_d00UKm00<005KmE_d00P000UKm
00<005KmE_d00eKm10000UKm00<005KmE_d00eKm10000eKm00@005KmE_eFo@@000EFo@04001FoEKm
E_d30005E_d00`00E_eFo@020002E_d00`00E_eFo@02E_d00`00E_eFo@020002E_d00`00E_eFo@03
E_d00`00E_aFo0020002E_`00`00C]e>g@02C]d00`00?YdnW@02?Yd00`00<OX000020004AQP01P00
BOI9mP00BOH000A9m@03001=eDgE00A=e@03001=eDgE009=e@03001=eDgE00==e@03001oogoo00Io
o`03001oogoo00]oo`001Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol04Woo00<007<GLaL00g<G00<007<GLaL00g<G00D007LEMaEg5@0000Ak=@80
0003OiD0000000Ioo`03001FoEKm0080009Fo@03001FoEKm00=Fo@<000=Fo@03001FoEKm00=Fo@<0
00AFo@04001FoEKmE_d40004E_d01000E_eFoEKm10001EKm00<005KmE_d00P000UKm00<005KmE_d0
0UKm00<005KmE_d00P000UKm00<005KmE_d00UKm10000eKm00<005KmE_d00eKm10000UKm00<005Km
E_d00eKm0`0015Km00@005KmE_eFo@@000EFo@04001FoEKmE_d40004E_`01000C]e>gDkM10000SjM
00D0037j<OXanP0000A660070019mTWfBOH004Wf000014We00<004gECMD00dgE00<004gECMD00TgE
00<004gECMD00dgE00<007ooOol01Woo0P0037oo0005Ool00`00Ool00008Ool01`00Oomoogoo001o
o`0000=oo`8001=oo`03001c5g<G00Ac5`03001c5g<G009c5`03001c5`00009g5@03001k=@000080
00=oU@03001oogoo00Ioo`8000EFo@03001FoEKm00800003E_d005Km00AFo@03001FoEKm0080009F
o@03001FoEKm00=Fo@<000=Fo@03001FoEKm00=Fo@<000=Fo@8000=Fo@@000AFo@04001FoEKmE_d4
0004E_d00`00E_eFo@020002E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d00`00E_eFo@02E_d0
0`00E_eFo@020002E_d00`00E_eFo@02E_d40003E_d00`00E_eFo@03E_d40003E_d01000E_aFo5Kl
1@000TKM00H002HL000003jM0002<OX30002AQP00`00BOI9mP02BOH20004BOD00`00CME=e@03CMD0
0`00CME=e@02CMD00`00CME=e@04CMD00`00Oomoo`02Ool300000goo001oo`0;Ool000Eoo`03001o
o`0000Qoo`03001oogoo00=oo`05001oogooOol0000DOol00`00LaMc5`03LaL00`00LaMc5`03LaL0
0`00LaMc5`040002NcD01000OiD000002Woo0P000eKm100015Km00@005KmE_eFo@@000EFo@03001F
oEKm00800003E_d005Km00AFo@03001FoEKm00800003E_d005Km00AFo@@000=Fo@03001FoEKm009F
o@@000=Fo@03001FoEKm00=Fo@8000EFo@04001FoEKmE_d40004E_d01000E_eFoEKm100015Km00<0
05KmE_d00P000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d00UKm10000eKl00<0
04KMA]d00TKM00<002HL9Q`00P000c7j00H003Fh000004HH0003BOH20004BOD00`00CME=e@03CMD0
0`00CME=e@03CMD00`00CME=e@02CMD60004Ool00`00Oomoo`0:Ool000Eoo`03001oo`0000Uoo`03
001oogoo008000Aoo`03001oogoo015oo`03001c5g<G00=c5`03001c5g<G00=c5`03001c5`0000@0
009k=@@000eoo`<000=Fo@03001FoEKm00=Fo@<000=Fo@03001FoEKm00=Fo@<000AFo@04001FoEKm
E_d40004E_d00`00E_eFo@020002E_d00`00E_eFo@02E_d00`00E_eFo@020002E_d00`00E_eFo@03
E_d00`00E_eFo@0200000eKm001Fo@04E_d40003E_d00`00E_eFo@02E_d40003E_d01000E_eFoEKm
10001EKm00@005KmE_eFo@@000AFo@03001FoEKm0080009Fo@03001Fo5Kl009Fo0030016gDKM0096
g@03000V72HL008V7004000anS7j0003=KP30003BOH00`00BOE9m@02BOD00`00CME=e@04CMD00`00
CME=e@02CMD00`00CMD0000200000dgD001oo`07Ool00`00Oomoo`0:Ool000Eoo`03001oo`0000Mo
o`03001oo`00009oo`03001oogoo00=oo`80015oo`03001W>P0000Ac5`03001c5g<G009c5`<0009c
5`03001gMgMg00<0009cm@03001oogoo00aoo`03001FoEKm00=Fo@03001FoEKm00800003E_d005Km
00AFo@03001FoEKm0080009Fo@03001FoEKm00=Fo@<000=Fo@03001FoEKm00=Fo@8000EFo@04001F
oEKmE_d30005E_d01000E_eFoEKm100015Km00<005KmE_d00P000UKm00<005KmE_d00UKm00<005Km
E_d00P000UKm00<005KmE_d00eKm0`000eKm00<005KmE_d00eKm10000eKm00@005KmE_eFo@@000AF
o@04001Fo5KlE_`800039Q`20002<OX01P00=KPe^3Fh000m]P<00003BOH004We00=9m@03001=eDgE
00==e@03001=eDgE00@000A=e003001oogoo00Moo`03001oogoo00Uoo`001Woo00<007ooOol01Woo
0`000Woo0`000goo00<007ooOol03goo00D006LjIcYW>P00009c5`03001c5g<G00<000Ec5`05001g
MgMgMgL00002LoD00`00Oomoo`0>Ool01000E_eFoEKm100015Km00@005KmE_eFo@@000EFo@03001F
oEKm00800003E_d005Km00AFo@03001FoEKm00800003E_d005Km00AFo@@0009Fo@03001FoEKm00=F
o@@000=Fo@04001FoEKmE_d40004E_d01000E_eFoEKm10001EKm00<005KmE_d00P0000=Fo@00E_d0
15Km00<005KmE_d00P000UKm00<005KmE_d00UKm10000eKm00<005KmE_d00UKm10000eKl00<004:n
@[h00T:n0P000RHL100013Fh00@003ff?KHm]P@00099m@04001=eDgECMD50002CM@00`00CMA=e004
CM@00`00Oomoo`06Ool00`00Oomoo`09Ool001Yoo`03001oogoo00eoo`8000EW>P03001c5`000080
009c5`03001c5g<G009c5`03001gMgMg009gM`03001cm@00019oo`<000=Fo@03001FoEKm00=Fo@<0
00=Fo@8000=Fo@@000AFo@04001FoEKmE_d40004E_d00`00E_eFo@020002E_`00`00E_eFo@02E_d0
0`00E_eFo@020002E_d00`00E_eFo@03E_d30003E_d00`00E_eFo@03E_d30003E_d20003E_d40004
E_d01000E_eFoEKm100015Km00<005KmE_d00P000UKm00<005KmE_d00UKm00<005KmE_d00P000U;m
00<005KlE_`00UKl00<004:n@[h00T:n00<000VK00000P000PeI0P000cFh00<003ff?KH00Sff0P00
00=5]@00000010000TWD00<004gDCM@00TgD00<004gDCM@014gD00<007ooOol01Woo00<007ooOol0
2Goo000IOol2000>Ool00`00IcYW>P05IcX30003LaL00`00LaMc5`03LaL01`00MgMgMgMg001cm@00
01Aoo`03001FoEKm00=Fo@03001FoEKm00800003E_d005Km00AFo@@000=Fo@03001FoEKm009Fo@@0
00=Fo@04001FoEKmE_d40004E_`01000E_eFoEKm10001EKm00<005KmE_d00P0000=Fo@00E_d015Km
00<005KmE_d00P0000=Fo@00E_d015Km10000eKm00<005KmE_d00UKm10000eKm00<005KmE_d00UKm
0`0015Km00@005KmE_eFo@@000ABo@04001Fo5KlE_`800022I/200023ET01@00=KPe^3Fh000013ff
00<004Fe00000TFe00<004WDBM@00dWD00<004gDCM@00dgD00<004gDCM@00dgD00<007ooOol01Woo
00<007ooOol02Goo000IOol00`00Oomoo`0;Ool20005IcX400001FLj001c5g<G00001G<G00<007Mg
MgL00WMg00<007?e00005Goo00@005KmE_eFo@@000AFo@03001FoEKm0080009Fo@03001FoEKm009F
o@03001FoEKm0080009Fo@03001FoEKm00=Fo@<000=Fo003001Fo5Kl00=Fo0<000=Fo@8000=Fo@@0
00AFo@04001FoEKmE_d40004E_d00`00E_eFo@020002E_d00`00E_eFo@02E_d00`00E_eFo@020002
E_d00`00E_eFo@02E_d00`00E_eFo@020002E_d00`00E_eFo@02E_d40003E_d00`00D_eBo@02D_d4
0003E_`00`00?[hn_P02?[h2000010VK000000eI0P000SFh00<003ff?KH00cff00D004Fe0015]@00
00I9e003001=e4gD009=e003001=e4gD00==e003001oogoo00Ioo`03001oogoo00Uoo`006Goo00<0
07ooOol02Goo0P000ULM00<006Lj00000P0000=W>P00IcX00fLj00<007<G000017<G00<007MgMgL0
0WMg00<007?e00005goo0`000eKm0P000eKm0`001EKm00@005KmE_eFo@<000EFo@03001FoEKm0080
0003E_`005Kl00AFo003001Fo5Kl00800003E_d005Km00AFo@@000=Fo003001FoEKm009Fo@@000=F
o@04001FoEKmE_d40004E_d01000E_eFoEKm100015Km00@005KmE_eFo@@000AFo@03001FoEKm0080
009Fo@03001FoEKm009Fo@03001BoE;m0080009Bo@03001Fo5Kl009Fo0@0008n_P8000042I/00000
3ET20002=KP00`00?KHm]P02?KH00`00AKD00002AKD00`00BMA9e003BM@00`00CMA=e002CM@00`00
CMA=e004CM@00`00Oomoo`05Ool00`00Oomoo`09Ool001Uoo`8000Moo`<000=G7@@00003IcX00000
00IW>P03001c5g<G00=c5`07001gMgMgMgL007?e00006Goo00<005KmE_d00eKm10000UKm00<005Km
E_d00eKm10000UKm0P000eKm100015Kl00@005KlE_aFo0@000AFo@03001FoEKm0080009Fo003001F
o5Kl009Fo003001FoEKm0080009Fo@03001FoEKm009Fo@@000=Fo@03001FoEKm009Fo@@000=Fo@03
001FoEKm009Fo@@000=Fo@04001FoEKmE_d40004E_d01000E_eFoEKm100015;m00<005KlE_`00P00
0UKl00<003jN00001@0000L0<`00000E5`00=KP00004?KH01P00AKE5]@00AKD000E9e003001=e4gD
009=e003001=e4gD00A=e003001oogoo00Eoo`03001oogoo00Uoo`006Goo00<007ooOol00goo0`00
0U<M10000eLM0P001fLj00<006Lk00000g<G00<007MgMgL00WMg0P006goo00<005KmE_d00P000UKm
00<005KmE_d00UKm00<005KmE_d00P000UKm00<005KmE_d00eKm0`000eKl00<005KlE_`00eKl0`00
0eKm0P000eKm0`0015Kl00@005KlE_aFo0@000AFo@03001FoEKm0080009Fo003001FoEKm009Fo@03
001FoEKm0080009Fo@03001FoEKm009Fo@03001FoEKm0080009Fo@03001FoEKm00=Fo@<000=Fo@03
001FoEKm00=Fo@<000=Fo@8000=Bo@<000EFo003000nWSjN008nWP050001>@00000=F@0200000cFh
000m]P03?KH01000AKE5]DFe0P001DWD00<004gDCM@00dgD00<004gDCM@00dgD00<007ooOol01Woo
00<007ooOol027oo000IOol00`00Oomoo`030003Dad50002Ead20002Ead00`00IcYW>P03IcX01000
Ic]W>fLk0P0000=c5`00MgL00WMg0P007Goo0P001EKm00@005KmE_eFo@<000EFo@03001FoEKm0080
0003E_`005Kl00AFo003001Fo5Kl00800003E_d005Km00AFo@@0009Ff`03001Fo5Kl00=Fo0<000=F
o08000=Fo@<000EFo004001FoEKmE_d30005E_d01000E_eFoEKm0`001EKm00<005KmE_d00P0000=F
o@00E_d015Km00<005KmE_d00P0000=Fo@00E_d015Km10000U;m00<005KlE_`00eKl100000<nWP00
0000100000<E5`00000013ff00<004FeAKD00TFe00<004WDBM@014WD00<004gDCM@00TgD00<004gD
CM@00dgD00<007ooOol01Woo00<007ooOol027oo000HOol01000Ool000000U<M00@005<M000000AC
7@<000EG7@05001W>VLjIcX00006Ic/20003MgL00`00Oomoo`0MOol00`00E_eFo@03E_d40002E_d2
0003E_d40004E_`01000E_aFo5Kl100015Km00<005KmE_d00P0000=F^`00E]/015KK00<005KlE_`0
0P0000=Ff`00E_`015Kl10000UKm00<005KlE_`00eKl10000UKm0P000eKm1@000UKm0P000eKm1000
15Km00@005KmE_eFo@@000AFo@03001FoEKm0080009Fo@03001BoE;m009Bo@03001Fo5Kl0080009F
o003000nWP00008000030AP0000c008000035AL0000000@m]P040015]DFeAKD20005BM@00`00CMA=
e002CM@00`00CMA=e004CM@00`00Oomoo`05Ool00`00Oomoo`08Ool001Qoo`8000=C7@@0009C7@<0
009C7@03001G7ELM00AG7@03001W>P0000IW>`03001[g6_L00<0025oo`03001FoEKm0080009Fo@03
001FoEKm00=Fo@<000=Fo003001Fo5Kl009Fo0@000=Fo@04001FoEKmE_d40004E[/00`00E]]Ff`02
E]/30004E]/00`00E_aFo0020002E_`00`00E_eFo@02E_d00`00E_aFo0020002E_`00`00E_eFo@02
E_d40003E_d00`00E_eFo@02E_d40003E_d00`00E_eFo@02E_d40003E_d01000E_eFoEKm100015Km
00@005;mD_eBo@@000AFo003000nWSjN008nWP050001600003<000025AL00`00?KHm]P02?KH00`00
AKE5]@02AKD00`00BMA9e003BM@00`00CMA=e002CM@00`00CMA=e004CM@00`00Oomoo`05Ool00`00
Oomoo`08Ool0011oo`D000=oo`D000=C7@<000IC7@03001G7ELM00=G7@8000IW>`03001[g6_L009[
g003001oogoo025oo`8000EFo@03001FoEKm00800003E_`005Kl00=Fo003001Fo5Kl0080009Fo@03
001FoEKm00=Fo@<000=BVP03001F^eJk009F^`03001FfeKK00800003EYT005KK00EFf`8000AFo004
001FoEKmE_d40004E_`00`00E_eFo@020002E_d00`00E_eFo@02E_d00`00E_eFo@020002E_d00`00
E_eFo@02E_d00`00E_eFo@020002E_d00`00E_eFo@02E_d40003E_d00`00E_eFo@02E_d40003D_d0
1000E_aFo5Kl300000<E5`0000000cff00<004FeAKD00TFe0P0014WD00<004gDCM@00dgD00<004gD
CM@00dgD00<007ooOol01Goo00<007ooOol027oo000BOol00`00Oomoo`03Ool40002Dad20002Dad0
0`00DaeC7@05Dad00`00EaeG7@020002Ecd00`00Ic]W>`02Ic/01000Jma[g6_L0P009Goo0P000eKm
100015Kl00@005KlE_aFo0<000EFo@03001FoEKm00800003DYX005:J00=BVP03001F^eJk00=F^`80
00AFV@04001FfeKKE]/200000eZj001Fo004E_`30003E_d00`00E_aFo002E_`30004E_d01000E_eF
oEKm100015Km00@005KmE_eFo@@000AFo@03001FoEKm0080009Fo@03001FoEKm009Fo@03001FoEKm
0080009Fo@03001BoE;m009Bo@@000Qoo`@0008E5`80008m]P030015]DFe0095]@8000E9e003001=
e4gD009=e003001=e4gD00==e003001oogoo00Eoo`03001oogoo00Qoo`004Woo00<007ooOol017oo
00<007ooOol00P001E<M00<005<MDad015<M0`001ELm0P0000=W>`00Jm`00V_L00<007ooOol09goo
0`000eKl00<005KlE_`00UKl10000UKm0P000eKm10000e:J00<005:JDYX00e:J00<005JkE[/00P00
00=FF000EYT00eJI00@005KK000000AJ^P03001Fo5Kl00800003F_/005Km00=Fo@03001Fo5Kl0080
009Fo003001FoEKm00=Fo@<000=Fo@04001FoEKmE_d50003E_d01000E_eFoEKm100015Km00@005Km
E_eFo@@000AFo@03001BoE;m008000eoo`@000035AL002ef00800003?KH004Fe00=5]@8000A9e003
001=e4gD009=e003001=e4gD00A=e003001oogoo00Aoo`03001oogoo00Qoo`004Woo00<007ooOol0
1Goo0P0000=oo`00Dad01E<M00<005<MDad00`000U<n00<005LmEcd015Lm1P00:goo00<005KlE_`0
0UKl00<005KlE_`00P000UKm00<005KmE_d00eKm0`000U:J00<005:JDYX00e:J00<005:JDYX00U:J
0`000eIH00<005JIEYT00eJI00<005ZjF[X01EZj0P0015[k00@005KmE_eFo@<000EFo003001FoEKm
00800003E_d005Km00AFo@<000=Fo@03001FoEKm00=Fo@<000=Fo@04001FoEKmE_d50003E_d01000
E_eFoEKm100047oo0`0000<E5`00;GH00Ref0P0014Fe00<004WD00000dWD00<004gDCM@00TgD00<0
04gDCM@014gD00<007ooOol017oo00<007ooOol027oo000BOol00`00Oomoo`07Ool01000Ool00000
0e<M10001U<n0P000ULm0P000T^n0P00;Woo00@005KlE_aFo0<000EFo@03001FoEKm00800003DYX0
05:J00=BVP03001BVU:J009BVP03001BVU:J00800003DSL005IH00AFF007001FVEJIEYT005Yg0000
1EZj00<005jh000015[k10000UKm0P000eKl100015Km00<005KmE_d00P0000=Fo@00E_d015Km00<0
05KmE_d00P0000=Fo@00E_d015Km0`000eKm00<005KmE_d00UKm10005Goo100012ef00<004FeAKD0
0TFe00@004WDBM@00099e003001=e4gD00==e004001=e4gDCM@30007Ool00`00Oomoo`07Ool0015o
o`8000Yoo`03001oogoo00<000=C?P8000EC?PP0035oo`<0009Fo@8000=Fo@@000=BVP03001BVU:J
009BVP04001BVU:JDYX40004DSL00`00EUQFF002EUP01000EYT000000UYg00@005ZjF[YJ^P80009N
^003001Jne[k0080009Nn`03001FoEKm009Fo@@000=Fo004001FoEKmE_d40004E_d01000E_eFoEKm
100015Km00<005KmE_d00P0000=Fo@00E_d00eKm00<005KmE_d00P006Woo00@0000B000000<]MP<0
0095]@040019e4WD0003BM@01000CMA=e4gD1@000TgE00<007ooOol01Goo00<007ooOol01goo000N
Ool01000Oomoo`001U<n1@000d>N0P00=Goo00<005KmE_d00eKm0`000U:J00<005:JDYX00e:J00<0
05:JDYX00U:J0`000U8g00<0058gDSL00e8g00<005IHEUP00eIH00<005YgFWL00eYg00<005Zj0000
1Ejh0P0015kk00<005KmE_d00P000U;m00<005KlE_`00UKl10000eKm00<005KmE_d00UKm10000eKm
00@005KmE_eFo@@000AFo@04001FoEKmE_d3000MOol30003;GH00`00@KE1]@0200001DFe0019e4WD
00000TWD00H004gD000004gE0005CMD00`00Oomoo`05Ool00`00Oomoo`07Ool001moo`800003Ool0
0000009C?P8000A7WP@003Qoo`03001FoEKm00800003DYX005:J00=BVP03001BVU:J009BVP03001B
VU:J00<000EB=`03001B=e8g009B=`04001FF5IHEUP30006FWL00`00G[QN^003G[P00`00H[P00005
G_/20004D_d00`00E_aFo0020002E_`00`00E_eFo@02E_d00`00E_eFo@020002E_d00`00E_eFo@02
E_d40003E_d01000E_eFoEKm1@0087oo00<0000B000012ef00@0046e@KE1]@T000==e@03001=eDgE
00A=e@03001oogoo00Aoo`03001oogoo00Moo`008Goo00<007ooOol00`0014NN0P00?7oo0P000e:J
00<005:JDYX00U:J00@005:JDYYBVP@000=B5P03001B=e8g009B=`03001B=e8g00=B=`<000=F=P03
001JMeYg009JM`03001NMP0000=N^004001R^6:h0004G_/01000H_/000000e;m0`0015Kl00@005Km
E_eFo@@000AFo@03001FoEKm0080009Fo@03001FoEKm009Fo@@002Ioo`<000<]MP030011]D6e0091
]@030019eDWE0099e@8000E=e@03001=eDgE00==e@03001oogoo00Aoo`03001oogoo00Moo`008Woo
00<007ooOol00Woo1000?goo00<005:JDYX00U:J00<005:JDYX00U:J0`000ThF00<0058FDQH00U8F
00<0058gDSL00e8g00<0058gDSL00U8g00<005HfESH00eHf00D005YgFWMJM`00009NMP05001N^5jh
G[P00003H[P01000G_/0000016;k0`000U;m0P000eKl10000eKm00@005KmE_eFo@@000AFo@03001F
oEKm008002Yoo`0300004P0000<]MP030011]D6e0091]@030019eDWE0099e@8000E=e@03001=eDgE
00==e@03001oogoo00Aoo`03001oogoo00Moo`008goo00<007ooOol0A7oo00<005:JDYX00U:J00<0
05:JDYX00`0014hF00<0058FDQH00U8F00<0058gDSL00e8g00@0058gDSMB=`8000EF=P04001JMeYg
0004GWH00`00G[P00005H[P00`00H_]Rn`02H_/200000f<K001Bo@03D_d40002E_`00`00E_eFo@03
E_d30003E_d01000E_eFoEKm1000;Goo0`000Ref00<0046e@KD00d6e00<004WEBMD00TWE0P0014gE
00<004gECMD00dgE00<007ooOol017oo00<007ooOol01goo000TOol20015Ool01000DYYBVU:J0`00
0dhF00<004hFCQH00ThF00<0058FDQH00U8F00<0058gDSL00e8g0`000U8E00<005HfESH00eHf0P00
1Uif00<006:hH[P00f:h00@006[h001Rn`8000=S6`03001BoE;m0080009Bo@03001Fo5Kl009Fo003
001FoEKm00800003E_d005Km00AFo@<0035oo`0300004P0000<]MP030011]D6e0091]@030019eDWE
00=9e@03001=eDgE009=e@03001=eDgE00==e@03001oogoo00Eoo`03001oogoo00Ioo`009Woo00<0
07ooOol0@goo0`0000=>5P00CQH00dhF00<004hFCQH00ThF00<0058FDQH00U8F00<0058gDSL00U8g
0P00158E00<005HfESH00eHf00<005ifGWH015if0P0016:h00D006[hJ_QZn00000IS6`8000ABo@04
001Fo5KlE_`40004E_d00`00E_eFo@02000eOol30002;GH00`00@KE1]@02@KD00`00BME9e@03BMD0
0`00CME=e@03CMD00`00CME=e@03CMD00`00Oomoo`04Ool00`00Oomoo`06Ool002Moo`03001oogoo
049oo`05001>5ThFCQH00004CQH00`00CQI>5P02CQH00`00DQIB5P03DQH01P00DSL00000DOD000AB
5@03001F=UHf009F=P8000INMP03001VUP00009R^007001Zn6[hJ_P006kg000016<K00@006<K0000
00=Bo@@000=Fo004001FoEKmE_d4000gOol2000010CF000]MP00146e00<004WEBMD00dWE0P0014gE
00<004gECMD00dgE00<007ooOol017oo00<007ooOol01Woo000XOol00`00Oomoo`11Ool00`00CQI>
5P02CQH00`00CQI>5P02CQH01@00CQI>5ThF0000158F0`000e7e00<0058EDQD00e8E00L005HfESIF
=P00FSD00004GWH01000IYIVUP000V:h00D006[hJ_QZn000009^m`04001S6`000004Ha/30002D_d0
0`00E_aFo003E_`3000lOol00`001=H4eP020004@KD00`00BME9e@03BMD00`00CMD00003CMD00`00
CME=e@03CMD00`00Oomoo`04Ool00`00Oomoo`06Ool002Uoo`03001oogoo045oo`05001>5ThFCQH0
0004CQH00`00CQI>5P02CQH01P00DQH00000COD000EAm@03001B5E8E009B5@04001F=UHf0002FSD0
1@00GWINMUif000016JF0P000f[h00<006kgK_L00Vkg00<006<KHa/00f<K00<006<K000015;m00<0
05KlE_`00P00?goo0P0000@4eP00;GH000A1]@030019eDWE00=9e@03001=e@00009=e@03001=eDgE
00==e@03001oogoo00Aoo`03001oogoo00Ioo`00:Woo0P00@Goo00D004hFCQI>5P0000A>5P03001>
5ThF009>5P8000==m@03001AmE7e00=Am@03001B5E8E009B5@03001F=P0000AJ=@04001NMUif0004
IYH00`00J_QZn002J_P01`00K_M^mfkg001_5`00009S6`80009S6`04001BoE;mD_d40012Ool00`00
1=H4eP020004@KD00`00BME9e@03BMD00`00CMD00003CMD00`00CME=e@02CMD00`00Oomoo`04Ool0
0`00Oomoo`06Ool002aoo`03001oogoo03ioo`05001>5ThFCQH00005CQH00`00CQH000020004COD0
0`00DOEAm@03DOD00`00DQEB5@03DQD20004FSD00`00GWH00004IYH00`00J[H00002J_P00`00K_M^
m`02K_L01@00KaL006<K00001F<K0`00Agoo00@000CF1=H000A1]@030019eDWE00=9e@04001=eDgE
0002CMD00`00CME=e@03CMD00`00Oomoo`03Ool00`00Oomoo`06Ool002eoo`03001oogoo03eoo`03
001>5ThF009>5P03001>5ThF00@0009=e@03001=mDge00==m@03001AmE7e009Am@03001B5E8E00=B
5@03001J=EXe00AJ=@8000AVUP06001Z]VZf001Zn0000fkg00D006lGKaM_5`0000AS6`8004Yoo`03
0004ePCF008000=1]@030019eDWE00=9e@07001=eDgECMD004gE00001DgE00<007ooOol017oo00<0
07ooOol01Goo000^Ool00`00Oomoo`0mOol00`00CQI>5P040002CMD00`00CME=e@02CMD00`00COE=
m@02COD00`00DOEAm@02DOD00`00DQEB5@02DQD20006FSD00`00IYIVUP02IYH00`00J[IZ]P02J[H0
1@00K_M^mfkg00000flG00@006lG001S6`8004eoo`030004ePCF00800091]@030019eDWE00=9e@03
001=eDgE009=e@8000A=e@8000Ioo`03001oogoo00Eoo`00;goo0P00?Goo0`0000==e@00CMD00dgE
00<004gECMD00TgE00<004geCOD00Tge00<0057eDOD00U7e00L0058EDQEB5@00EQ@00005FSD20004
IYH00`00J[IZ]P02J[H200000fkg001_5`03KaL01000KaM_5`00D7oo00@000CF000aU`800003@KD0
04WE00A9e@08001=eDgECMD004gE001=e@800003CQH007oo00Eoo`03001oogoo00Eoo`00<Goo00<0
07ooOol0>Woo00D004gECME=e@0000A=e@03001=eDgE009=e@03001=mDge009=m@03001AmE7e00=A
m@03001B5@0000=F5003001J=EXe009J=@03001RM@00009VUP03001Z]VZf009Z]P05001bm@00K_L0
0003KaL01000KaM_5`00DGoo00<000CF00000c6G0P001DWE00@004gECME=e@@000A>5P03001oogoo
00=oo`03001oogoo00Eoo`00<Woo00<007ooOol0>Goo00<004gECMD00TgE00<004gECMD00TgE00D0
04gECME=e@0000A=m@03001AmE7e00=Am@8000AF5005001J=EXeFSD00002HWD01000IYIVUP0016Zf
00@007;eL_D000A_5`04001_5flG001BOol00`001=H00003<IL:0002CQH00`00CQI>5P03CQH00`00
Oomoo`03Ool00`00Oomoo`05Ool003=oo`03001oogoo03Qoo`03001=eDgE009=e@03001=eDgE009=
e@03001=eDgE009=e@05001=mDgeCOD00005DOD00`00EQAF5003EQ@01@00FSEJ=EXe00000V9e00<0
06JF000016Zf00@007;eL_Ebm@80009_5`04001_5flG001DOol20003<IL00`00AOI5mP03AOH00`00
CQI>5P03CQH20004CQH00`00Oomoo`03Ool00`00Oomoo`05Ool003Aoo`8003Uoo`05001=eDgECMD0
0004CMD00`00CME=e@02CMD00`00COE=m@02COD01000DOEAmE7e0P001EHD00@005XeFSD000ARM@80
00AZ]P04001bmG;e0002L_D00`00KaL00002KaL00`00Oomoo`1BOol20004<IL00`00AOI5mP03AOH0
0`00CQI>5P03CQH00`00CQI>5P02CQH00`00Oomoo`03Ool00`00Oomoo`05Ool003Ioo`03001oogoo
03Ioo`05001=eDgECMD00004CMD00`00CME=e@02CMD00`00COE=m@02COD01P00DOD00000DO@000EF
5004001J=EXe0004HWD00`00J[IZ]P02J[H01@00L_EbmG;e00000g;e00@006lGKaL005Ioo`8000<a
U`030015mTGf00=5mP03001>5ThF00=>5P8000A>5P03001oogoo00=oo`03001oogoo00Aoo`00=goo
00<007ooOol0=Goo00<004gECMD00TgE00D004gECME=e@0000A=e@03001=mDge009=m@8000=Am003
001F55HD00AF508000ERM@8000=Z]P04001bmG;e0004L_D200000flG001oo`1EOol20003<IL00`00
AOI5mP03AOH00`00CQI>5P03CQH00`00CQH00003CQH00`00Oomoo`03Ool00`00Oomoo`04Ool003Qo
o`03001oogoo03Aoo`03001=eDgE009=e@05001=eDgECMD00005CMD01@00COE=mDge00001E7d00<0
05HDEQ@00eHD0P00169e00<006ZE00000VZf00D007;eL_Ebm@0000=bm@04001c5G<E001HOol20002
<IL00`00AOI5mP03AOH00`00CQI>5P04CQH20003CQH00`00Oomoo`03Ool00`00Oomoo`04Ool003Uo
o`8003Aoo`03001=eDgE009=e@03001=eDgE009=e@03001=eDgE009=e@03001=m@00008000EAm003
001F55HD00=F5003001RMF9e00=RM@06001ZUFZE001Z]P000W;e00<007;eL_D00W;e00@007<ELaD0
05Qoo`<0008aU`030015mTGf00=5mP03001>5ThF00=>5P03001>5P00009>5P03001oogoo00=oo`03
001oogoo00Aoo`00>goo00<007ooOol0<Goo00<004gECMD00TgE00<004gECMD00TgE00@004gECME=
e@<0009=e003001Am57d00=Am003001F55HD009F508000ERM@03001ZUFZE008000=bm@05001bmG;e
L_D00002LaD00`00Oomoo`1HOol01@002CP0036G00001DGf00<004hFCQH00dhF00@004hFCQH0009>
5P03001oogoo009oo`03001oogoo00Aoo`00?7oo00<007ooOol0<Goo00<004gECMD00TgE00H004gE
CME=e@00CMD200000dgD001=e003CM@00`00DOAAm002DO@00`00EQAF5002EQ@00`00GS@00003HWD0
0`00JYEZU@02JYD01@00L_EbmG;e00000g;e00@007<ELaD005Yoo`8000032CP0000000E5mP03001>
5ThF00A>5P03001>5ThF00<000Aoo`03001oogoo00Aoo`00?Goo00<007ooOol0<7oo00<004gECMD0
0TgE00<004gECMD00`000dgD00<004gDCM@00TgD00<0057dDO@00U7d00D005HDEQAF5000009N=005
001RMF9eHWD00004JYD01000L_Ebm@000g;e00@007<ELaD005aoo`030009>0Th008000A5mP03001>
5ThF00=>5PD0009BN@05001oogooOol00006Ool003ioo`80031oo`03001=eDgE00D00003CM@004gD
00==e003001=e4gD009=e003001Am57d009Am004001F55HD0003GS@01@00HWERMF9e00000fZE00D0
07;E001bm@0000=bm@04001c5G<E001MOol00`002CP9>0030003AOH00`00CQH0000200000e9i001B
N@02DWT00`00DWT00003Ool00`00Oomoo`04Ool0041oo`03001oogoo02eoo`<0009=e005001=e4gD
CM@00004CM@00`00CMA=e002CM@00`00DOAAm003DO@00`00EQ@00003GS@01@00HWERMF9e00000fZE
00@007;E000000=bm@04001c5G<E001OOol01@002CP9>000@SX01@001E9i00L0059iDWUBN@00DWT0
0003Ool00`00Oomoo`03Ool0045oo`03001oogoo02aoo`03001=e4gD009=e005001=e4gDCM@00005
CM@01@00CMA=e4gD00001E7d0P001Ehd00<0069e000016ZE00@007;EL]D000=bm@04001c5G<E001P
Ool30005@SX00`00DWUBN@03DWT01`00DWUBNE9i001BN@0000=oo`03001oogoo00=oo`00@Woo00<0
07ooOol0:goo00<004gDCM@00TgD00<004gDCM@00TgD00<004gDCM@00TgD00<004gDCM@00TgD00<0
057dDO@00U7d0P001Ehd00<0069e00000fZE00@007;EL]Ebe@@000=c5@03001oogoo05moo`<000A2
>P03001BNE9i00=BN@03001BNE9i009BN@<0009oo`03001oogoo00=oo`00@goo0P00:goo00<004gD
CM@00TgD00<004gDCM@00TgD00<004gDCM@00TgD00<004gDCM@00TgD00<0057dDO@00U7d00<005hd
GS@015hd00<0069e00000fZE00@007;EL]D000=fm@04001c5G<E001ROol30005@SX00`00DWUBN@03
DWT00`00DWT000040002Ool00`00Oomoo`03Ool004Eoo`03001oogoo02Qoo`03001=e4gD00==e005
001=e4gDCM@00004CM@00`00CMA=e002CM@01000DOAAm57d0P001ehd00D006ZEJYEZU@0000=be@04
001fmGKeM_D200000g<E001oo`1ROol50002@SX01000DWUBNE9i100015;m0P0000=oo`00Ool017oo
0016Ool00`00Oomoo`0XOol00`00CMA=e002CM@01@00CMA=e4gD000014gD00<004gDCM@00TgD00@0
057dDOAAm08000MN=005001ZUFZEJYD00003L]D01@00M_Efm@00M_D00P00IGoo0`0000<bO@000000
10000e;m00<005;mD_d00U;m0P0000=oo`00Ool017oo0017Ool00`00Oomoo`0WOol00`00CMA=e002
CM@01@00CMA=e4gD000014gD00<004gDCM@00TgD00@0057dDO@0009F5003001N=5hd00=N=08000=Z
U@05001beG;EL]D00002M_D01000M_Efm@00IWoo0P001C9m00<005;mD_d00U;m00<005;mD_d00U;m
10001Goo0018Ool2000WOol00`00CMA=e002CM@01@00CMA=e4gD000014gD00<004gDCM@00dgD0P00
0eHD00<005hdGS@00ehd00D006Ie001ZU@0000=be@05001fmGKeM_D00002M_D00`00Oomoo`1UOol4
0002<Wd01000D_eBoE;m1P000U<M0`0017oo001:Ool00`00Oomoo`0TOol00`00CMA=e002CM@01@00
CMA=e4gD000014gD00<004gDCM@00dgD0P000eHD00<005hdGS@00Uhd00H006IeIWD006ZE0003L]D0
1000M_Efm@000WKe00<007ooOol0Igoo0P0000<^OP00000010000dkn00<005<MDad00e<M0P0017oo
001;Ool00`00Oomoo`0SOol00`00CMA=e002CM@01@00CMA=e4gD00001DgD00<004gDCM@00TgD00<0
05HDEQ@00UHD00<005hdGS@00Uhd00H006IeIWD006ZE0003L]D01000M_Efm@000WKe00<007ooOol0
J7oo00<002in;Wh00bin00<004knC_h00Tkn00<005<MDad01@0017oo001<Ool00`00Oomoo`0ROol0
0`00CMA=e002CM@00`00CMA=e002CM@00`00CMA=e002CM@00`00CMA=e0030005EQ@01000GSAN=000
16Ie00D007;EL]Ebe@0000=fm@04001fmGKe001[Ool30002;Wh01000C_i>oTkn10000goo0P0017oo
001=Ool00`00Oomoo`0QOol00`00CMA=e002CM@00`00CMA=e002CM@00`00CMA=e002CM@30002DOD0
0`00EQAF5003EQ@01000GSAN=00016Ie00D007;EL]Ebe@00009fm@05001fmGKeM_D0001^Ool60003
Ool40006Ool004ioo`80025oo`03001=e4gD00==e005001=e4gDCM@00002CM@30004DOD00`00EQAF
5003EQ@00`00GS@00005IWD20002L]D01000M_Efm@000WKe00<007ooOol0LWoo10002Woo001@Ool0
0`00Oomoo`0OOol00`00CMA=e002CM@01000CMA=e4gD0`000TgE00<0057eDOD00e7e00<005HDEQ@0
0UHD00<005hd000016Ie00<006kE00000W;E00@007KeM_D0009fm@03001oogoo06ioo`@000ioo`00
DGoo00<007ooOol07Woo00<004gDCM@00TgD00<004gD00000P0014gE00<0057eDOD00e7e00<005HD
EQ@00eHD00<006IeIWD00fIe00<006kEK]D00P000WKe00D007KeM_Efm@0006aoo`@0019oo`00DWoo
00<007ooOol07Goo00<004gDCM@010000TgE00<004gECMD00TgE00<0057eDOD00e7e00<005HDEQ@0
0eHD00<006IeIWD00VIe00<006kEK]D00VkE00@007KeM_D0009fm@03001oogoo06Qoo`<001Ioo`00
Dgoo0P007Goo0`000TgE00<004gECMD00TgE00<004gECMD00TgE00<0057eDOD00U7e00<005HDEQ@0
0UHD0P0016Ie00<006kEK]D00VkE0P0000Efm@00M_Efm@0006Ioo`@001Uoo`00EGoo00<007ooOol0
6Woo00<004gECMD00TgE00<004gECMD00TgE00<004gECMD00TgE00<0057eDOD00U7e00<005HDEQ@0
0UHD0P0016Ie00H006kEK]E^e@00L_D20003M_D00`00Oomoo`1POol4000MOol005Ioo`03001oogoo
01Uoo`03001=eDgE009=e@03001=eDgE009=e@03001=eDgE009=e@03001AmE7e009Am@05001F55HD
EQ@00002GUD01000IWEVM@0016kE00@007;eL_D000=fm@03001oogoo05aoo`@0025oo`00Egoo00<0
07ooOol06Goo00<004gECMD00TgE00D004gECME=e@0000A=e@03001AmE7e009Am@04001F55HD0003
GUD01000IWEVM@000fkE00@007;eL_Ebm@@005]oo`@002Eoo`00F7oo0P006Goo00<004gECMD00TgE
00D004gECME=e@0000A=e@03001AmE7e00=Am@03001F500000=NE@04001VMFIe0003K]D01000L_Eb
m@000gKe00<007ooOol0EWoo0`00:Goo001JOol00`00Oomoo`0FOol00`00CME=e@02CMD00`00CME=
e@02CMD01@00CME=eDgE00001E7e0P0015iE00<006Ie000016kE00@007;eL_D000=fm@03001oogoo
059oo`@002aoo`00Fgoo00<007ooOol05Goo00<004gECMD00TgE00<004gECMD00TgE00D004gECME=
e@0000EAm@8000ENE@8000=^e@05001bmG;eL_D00002M_D00`00Oomoo`1?Ool4000`Ool005aoo`03
001oogoo01Aoo`03001=eDgE009=e@03001=eDgE009=e@03001=eDgE009=e@03001AmE7e009Am@03
001NEEiE00ANE@03001^eFkE009^e@04001bmG;e0003M_D00`00Oomoo`1;Ool4000dOol005eoo`80
01Eoo`05001=eDgECMD00004CMD00`00CME=e@02CMD00`00DOEAm@030006GUD00`00K]E^e@02K]D0
1000L_Ebm@000WKe00<007ooOol0B7oo1000>7oo001OOol00`00Oomoo`0BOol01@00CME=eDgE0000
14gE00<004gECMD00TgE0`000eHf00<005iEGUD00UiE00<006Zf00000VkE00D007;eL_Ebm@00009f
m@03001oogoo04Eoo`<003aoo`00H7oo00<007ooOol04Goo00<004gECMD00TgE00<004gECMD00TgE
00D004gECME=e@0000EF=P03001NEEiE009NE@03001Z]P00009^e@05001bmG;eL_D00002M_D00`00
Oomoo`11Ool4000oOol0065oo`03001oogoo011oo`03001=eDgE009=e@03001=eDgE009=e@03001=
e@00008000EF=P05001NEEiEGUD00003J[H20003L_D01000M_Efm@00@7oo1000@goo001ROol2000A
Ool01@00CME=eDgE00000TgE10000dhF00<005HfESH00eHf00@005iEGUD000AZ]P05001bmG;eL_D0
0002M_D00`00Oomoo`0jOol40017Ool006Aoo`03001oogoo00ioo`03001=eDgE00@0009>5P03001>
5ThF009>5P03001F=UHf00=F=P03001NE@0000AZ]P03001_5`00009bm@04001fmGKe000hOol4001;
Ool006Eoo`03001oogoo00eoo`<00003CQH004hF00=>5P03001>5ThF009>5P03001F=UHf00=F=P03
001NE@0000AZ]P03001_5flG0080009fm@03001oogoo03Aoo`<004moo`00IWoo00<007ooOol037oo
00<004hFCQH00ThF00<004hFCQH00ThF00D004hFCQI>5P0000IF=P03001Z]VZf009Z]P03001_5flG
009_5`04001fmGKe000bOol4001BOol006Moo`8000aoo`03001>5ThF009>5P03001>5ThF009>5P03
001>5ThF009>5P03001F=UHf00=F=P03001Z]VZf009Z]P06001_5flGKaL007<G0P00;goo1000EWoo
001YOol00`00Oomoo`0:Ool01@00CQI>5ThF000014hF00<004hFCQH00ThF00<005HfESH00UHf0P00
0fZf00<006lGKaL00VlG00@007<GLaL002]oo`@005Yoo`00JWoo00<007ooOol02Goo00<004hFCQH0
0ThF00D004hFCQI>5P0000A>5P03001F=UHf0080009NV004001Z]VZf0003KaL01000LaMc5`00:7oo
1000GWoo001[Ool00`00Oomoo`08Ool00`00CQI>5P02CQH00`00CQI>5P02CQH00`00CQI>5P02CQH2
0004GYP00`00J[H00003KaL01@00LaMc5g<G000097oo1000HWoo001/Ool20008Ool00`00CQI>5P02
CQH00`00CQI>5P02CQH00`00CQI>5P030006GYP20003KaL01000LaMc5`008Woo0`00IWoo001^Ool0
0`00Oomoo`05Ool00`00CQI>5P03CQH00`00CQI>5P040002EWT00`00GYQNV004GYP01@00KaM_5flG
00000g<G00<007ooOol077oo1000JGoo001_Ool00`00Oomoo`05Ool01000CQI>5ThF10000U9i00<0
05IiEWT00UIi00@005jHGYQNV0800005IaX00000KaL00002LaL00`00Oomoo`0IOol4001]Ool0071o
o`03001oogoo00Aoo`06001>5P00001BN@00159i00<005IiEWT00UIi00@005jH000000EW6P05001c
5g<GLaL0000GOol4001aOol0075oo`03001oogoo00=oo`8000ABN@03001BNE9i009BN@03001FNEIi
009FN@03001W6VLJ00AW6P05001W6P00LaL0000DOol4001eOol0079oo`8000Aoo`03001BNE9i009B
N@03001BNE9i009BN@03001FNEIi00800003E_`006LJ009W6P80009W6P03001c5`00015oo`<007Uo
o`00M7oo00D007ooOomoo`0000EBN@03001BNE9i00@000AFo003001W6P0000EW6P03001oogoo00ao
o`@007aoo`00MGoo00D007ooOomoo`0000ABN@<000=Bo@03001Fo5Kl00=Fo003001W6VLJ00=W6P03
001oogoo00Uoo`@0081oo`00MWoo00@007ooOol0009BN@800003D_d005;m00ABo@03001Fo5Kl0080
0004Ead00000IaX20008Ool40024Ool007Moo`800003Ool0000000ABo@04001BoE;mD_d40004Ead2
0006Ool40028Ool007Uoo`03001oo`0000=Bo@D000=C7@03001G7ELM008000Eoo`<008aoo`00NWoo
00<007oo00000P000e<M0P000e<M0`000goo1000Sgoo001kOol01000Ool000000e<M1@000Woo1000
Tgoo001lOol2000017oo000000000goo1000Ugoo001nOol200000goo00000002002KOol007moo`80
09moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0901396, 0.0104855, 
  0.00367783, 0.00367783}}]
}, Open  ]],

Cell[TextData[{
  StyleBox[
  "A profile of the power spectrum of the filter is shown below. A comparison \
with the magnitude response of the rectangularly truncated impulse response \
"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`h\)]]],
  StyleBox[" reveals a significant improvement in stopband attenuation."]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListMagnitudePlot[hR[\([8]\)]]; \)\)], "Input",
  CellLabel->"In[43]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.90476 0.640493 0.00468207 [
[.21429 .60458 -9 -9 ]
[.21429 .60458 9 0 ]
[.40476 .60458 -9 -9 ]
[.40476 .60458 9 0 ]
[.59524 .60458 -9 -9 ]
[.59524 .60458 9 0 ]
[.78571 .60458 -9 -9 ]
[.78571 .60458 9 0 ]
[.97619 .60458 -9 -9 ]
[.97619 .60458 9 0 ]
[.01131 .07864 -24 -4.5 ]
[.01131 .07864 0 4.5 ]
[.01131 .17229 -24 -4.5 ]
[.01131 .17229 0 4.5 ]
[.01131 .26593 -18 -4.5 ]
[.01131 .26593 0 4.5 ]
[.01131 .35957 -18 -4.5 ]
[.01131 .35957 0 4.5 ]
[.01131 .45321 -18 -4.5 ]
[.01131 .45321 0 4.5 ]
[.01131 .54685 -18 -4.5 ]
[.01131 .54685 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .62333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .61708 m
.21429 .62333 L
s
[(0.1)] .21429 .60458 0 1 Mshowa
.40476 .61708 m
.40476 .62333 L
s
[(0.2)] .40476 .60458 0 1 Mshowa
.59524 .61708 m
.59524 .62333 L
s
[(0.3)] .59524 .60458 0 1 Mshowa
.78571 .61708 m
.78571 .62333 L
s
[(0.4)] .78571 .60458 0 1 Mshowa
.97619 .61708 m
.97619 .62333 L
s
[(0.5)] .97619 .60458 0 1 Mshowa
.125 Mabswid
.0619 .61708 m
.0619 .62083 L
s
.1 .61708 m
.1 .62083 L
s
.1381 .61708 m
.1381 .62083 L
s
.17619 .61708 m
.17619 .62083 L
s
.25238 .61708 m
.25238 .62083 L
s
.29048 .61708 m
.29048 .62083 L
s
.32857 .61708 m
.32857 .62083 L
s
.36667 .61708 m
.36667 .62083 L
s
.44286 .61708 m
.44286 .62083 L
s
.48095 .61708 m
.48095 .62083 L
s
.51905 .61708 m
.51905 .62083 L
s
.55714 .61708 m
.55714 .62083 L
s
.63333 .61708 m
.63333 .62083 L
s
.67143 .61708 m
.67143 .62083 L
s
.70952 .61708 m
.70952 .62083 L
s
.74762 .61708 m
.74762 .62083 L
s
.82381 .61708 m
.82381 .62083 L
s
.8619 .61708 m
.8619 .62083 L
s
.9 .61708 m
.9 .62083 L
s
.9381 .61708 m
.9381 .62083 L
s
.25 Mabswid
0 .61708 m
1 .61708 L
s
.02381 .07864 m
.03006 .07864 L
s
[(-120)] .01131 .07864 1 0 Mshowa
.02381 .17229 m
.03006 .17229 L
s
[(-100)] .01131 .17229 1 0 Mshowa
.02381 .26593 m
.03006 .26593 L
s
[(-80)] .01131 .26593 1 0 Mshowa
.02381 .35957 m
.03006 .35957 L
s
[(-60)] .01131 .35957 1 0 Mshowa
.02381 .45321 m
.03006 .45321 L
s
[(-40)] .01131 .45321 1 0 Mshowa
.02381 .54685 m
.03006 .54685 L
s
[(-20)] .01131 .54685 1 0 Mshowa
.125 Mabswid
.02381 .10205 m
.02756 .10205 L
s
.02381 .12546 m
.02756 .12546 L
s
.02381 .14888 m
.02756 .14888 L
s
.02381 .1957 m
.02756 .1957 L
s
.02381 .21911 m
.02756 .21911 L
s
.02381 .24252 m
.02756 .24252 L
s
.02381 .28934 m
.02756 .28934 L
s
.02381 .31275 m
.02756 .31275 L
s
.02381 .33616 m
.02756 .33616 L
s
.02381 .38298 m
.02756 .38298 L
s
.02381 .40639 m
.02756 .40639 L
s
.02381 .4298 m
.02756 .4298 L
s
.02381 .47662 m
.02756 .47662 L
s
.02381 .50003 m
.02756 .50003 L
s
.02381 .52344 m
.02756 .52344 L
s
.02381 .05523 m
.02756 .05523 L
s
.02381 .03182 m
.02756 .03182 L
s
.02381 .00841 m
.02756 .00841 L
s
.02381 .57026 m
.02756 .57026 L
s
.02381 .59367 m
.02756 .59367 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.03053 .60332 L
.03279 .60332 L
.03527 .60332 L
.0379 .60331 L
.04262 .60331 L
.05205 .6033 L
.06244 .60329 L
.08274 .60326 L
.0881 .60326 L
.09394 .60325 L
.09952 .60324 L
.10458 .60324 L
.10712 .60324 L
.10986 .60324 L
.11137 .60324 L
.11276 .60324 L
.11417 .60324 L
.11549 .60324 L
.11662 .60324 L
.11784 .60324 L
.11853 .60324 L
.11919 .60324 L
.12042 .60324 L
.12171 .60324 L
.12291 .60324 L
.12422 .60324 L
.12562 .60324 L
.12789 .60324 L
.13034 .60324 L
.13477 .60324 L
.14 .60324 L
.14255 .60324 L
.14487 .60324 L
.14601 .60324 L
.14725 .60324 L
.14842 .60324 L
.14949 .60324 L
.15064 .60324 L
.1519 .60324 L
.15321 .60324 L
.15444 .60324 L
.15509 .60324 L
.15579 .60324 L
.15708 .60324 L
.15833 .60324 L
Mistroke
.15949 .60324 L
.16211 .60324 L
.16491 .60324 L
.16765 .60323 L
.17061 .60323 L
.17323 .60322 L
.17598 .60321 L
.18121 .60319 L
.18601 .60317 L
.19098 .60313 L
.19551 .6031 L
.20039 .60305 L
.20568 .60298 L
.21511 .60283 L
.22403 .60264 L
.23346 .60238 L
.24384 .60201 L
.25469 .60151 L
.26487 .60092 L
.28509 .59938 L
.30361 .59746 L
.32257 .59489 L
.34328 .59131 L
.36457 .58668 L
.38389 .58155 L
.42299 .5681 L
.46303 .54926 L
.50154 .52496 L
.52107 .50962 L
.54252 .48964 L
.56315 .46608 L
.58197 .43864 L
.59197 .42004 L
.60146 .39752 L
.60665 .38144 L
.61147 .36183 L
.61398 .34819 L
.61542 .3384 L
.61675 .32739 L
.61814 .31228 L
.61887 .30182 L
.61964 .2873 L
.62095 .23879 L
.62168 .18123 L
.62236 .2512 L
.62361 .28757 L
.62493 .3065 L
.62608 .31742 L
.62735 .32634 L
.6297 .33805 L
Mistroke
.63189 .34578 L
.63446 .35245 L
.6368 .35707 L
.63951 .36117 L
.64208 .36415 L
.64428 .36615 L
.64663 .36782 L
.64885 .36904 L
.65086 .36987 L
.65201 .37025 L
.65323 .37057 L
.65457 .37084 L
.65579 .37102 L
.65694 .37113 L
.65801 .37118 L
.65918 .37119 L
.66044 .37114 L
.66166 .37103 L
.66235 .37095 L
.66301 .37086 L
.66573 .37033 L
.66809 .36969 L
.67062 .36882 L
.6764 .36618 L
.68169 .36301 L
.6915 .3553 L
.70182 .34447 L
.71137 .33144 L
.71662 .32268 L
.72158 .31299 L
.7262 .30225 L
.7312 .28783 L
.73342 .28007 L
.73576 .27045 L
.73776 .2605 L
.73995 .24684 L
.74126 .23628 L
.74248 .22378 L
.74365 .20737 L
.74489 .17842 L
.74611 .01472 L
.74725 .17276 L
.74828 .1985 L
.74939 .21465 L
.75062 .22676 L
.75197 .23644 L
.75337 .24418 L
.75468 .24997 L
.75703 .25805 L
.75954 .26453 L
Mistroke
.7619 .26924 L
.76447 .27327 L
.76673 .2761 L
.76913 .27852 L
.77129 .28027 L
.77367 .2818 L
.77583 .28288 L
.77786 .28366 L
.7791 .28403 L
.78043 .28435 L
.78168 .28458 L
.78281 .28473 L
.78351 .2848 L
.78415 .28485 L
.78486 .28488 L
.7856 .28489 L
.78685 .28487 L
.78757 .28483 L
.78823 .28478 L
.78951 .28464 L
.79072 .28446 L
.79299 .284 L
.79543 .28334 L
.79809 .28243 L
.80276 .28038 L
.80771 .2776 L
.81662 .27112 L
.82598 .26222 L
.83608 .25 L
.84561 .23539 L
.85435 .21832 L
.85945 .20592 L
.86427 .19159 L
.86694 .182 L
.86982 .16951 L
.87245 .15511 L
.87362 .14721 L
.87487 .13707 L
.87606 .12502 L
.87715 .11042 L
.87825 .08859 L
.87929 .04641 L
.88049 .04692 L
.88161 .08807 L
.88284 .10873 L
.88414 .1224 L
.88542 .13184 L
.8868 .13957 L
.88801 .14498 L
.8893 .14968 L
Mistroke
.89173 .15659 L
.89397 .16134 L
.89634 .16519 L
.89851 .1679 L
.901 .17028 L
.90337 .17194 L
.90443 .17253 L
.90555 .17305 L
.90757 .17377 L
.90869 .17405 L
.90974 .17425 L
.91089 .17439 L
.91214 .17446 L
.91339 .17446 L
.91456 .17439 L
.91584 .17424 L
.91655 .17413 L
.9172 .174 L
.91995 .17331 L
.92254 .1724 L
.92711 .17027 L
.93206 .1673 L
.95158 .15135 L
.95692 .14674 L
.96266 .14238 L
.96544 .14064 L
.96808 .13929 L
.97044 .13837 L
.97178 .13798 L
.97302 .1377 L
.97375 .13758 L
.97456 .13749 L
.9754 .13743 L
.97619 .13741 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[43]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomo
o`2kOol00`00Oomoo`14Ool001]oo`03001oogoo0;]oo`03001oogoo04Aoo`006goo00<007ooOol0
^goo00<007ooOol0A7oo000KOol00`00Oomoo`2kOol00`00Oomoo`14Ool001]oo`800;aoo`03001o
ogoo04Aoo`006goo00<007ooOol0^goo00<007ooOol0A7oo000KOol00`00Oomoo`2kOol00`00Oomo
o`14Ool001]oo`03001oogoo0;]oo`03001oogoo04Aoo`006goo00<007ooOol0^goo00<007ooOol0
87oo00<007ooOol08Goo000KOol00`00Oomoo`2kOol00`00Oomoo`0POol00`00Oomoo`0QOol001]o
o`03001oogoo0;]oo`03001oogoo021oo`03001oogoo025oo`006goo0P00_7oo00<007ooOol087oo
00<007ooOol08Goo000KOol00`00Oomoo`2kOol00`00Oomoo`0POol00`00Oomoo`0QOol001]oo`03
001oogoo0;]oo`03001oogoo021oo`03001oogoo025oo`006goo00<007ooOol0^goo00<007ooOol0
87oo0P008Woo0009Ool5000017oo000000000goo00<007ooOol00goo00<007ooOol0^goo00<007oo
Ool087oo0P008Woo000;Ool01@00Oomoogoo000017oo00<007oo000017oo00<007ooOol0^goo00<0
07ooOol087oo0P008Woo0005Ool30003Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`80
0;aoo`03001oogoo021oo`80029oo`002goo00<007ooOol00Woo00L007ooOomoo`00Ool00004Ool0
0`00Oomoo`2kOol00`00Oomoo`0POol2000ROol000]oo`07001oogooOol007oo00000Woo00<007oo
000017oo00<007ooOol0^goo00<007ooOol087oo0P008Woo000:Ool20004Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2kOol00`00Oomoo`0POol2000ROol001]oo`03001oogoo0;]oo`03
001oogoo021oo`80029oo`006goo00<007ooOol0^goo00<007ooOol07goo00<007oo00008Woo000K
Ool2002lOol00`00Oomoo`0OOol00`00Ool0000ROol001]oo`03001oogoo0;]oo`03001oogoo01mo
o`03001oo`00029oo`006goo00<007ooOol0^goo00<007ooOol07goo00<007oo00008Woo000KOol0
0`00Oomoo`2kOol00`00Oomoo`0OOol00`00Ool0000ROol001]oo`03001oogoo0;]oo`03001oogoo
01moo`03001oo`00029oo`006goo00<007ooOol0^goo00<007ooOol07goo00<007oo00008Woo000K
Ool2002lOol00`00Oomoo`0OOol00`00Ool0000ROol001]oo`03001oogoo0;]oo`03001oogoo01mo
o`04001oogoo000QOol001]oo`03001oogoo0;]oo`03001oogoo01moo`04001oogoo000QOol001]o
o`03001oogoo0;]oo`03001oogoo01moo`04001oogoo000EOol30009Ool001]oo`03001oogoo0;]o
o`03001oogoo01moo`04001oogoo000COol2000<Ool001]oo`03001oogoo0;]oo`03001oogoo01io
o`05001oogooOol0000BOol00`00Oomoo`0<Ool001]oo`800;aoo`03001oogoo01ioo`03001oogoo
009oo`03001oogoo00ioo`03001oogoo00eoo`006goo00<007ooOol0^goo00<007ooOol07Woo00<0
07ooOol00Woo00<007ooOol03Goo00<007ooOol03Woo000KOol00`00Oomoo`2kOol00`00Oomoo`0N
Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool001]oo`03001oogoo0;]oo`03001o
ogoo01ioo`03001oogoo00=oo`03001oogoo00Uoo`80019oo`002Goo1@000Woo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol0^goo00<007ooOol07Goo00<007ooOol017oo00<007ooOol027oo
00<007ooOol04Woo000;Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`03001oogoo0;]o
o`03001oogoo01eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo01=oo`001Goo0`000goo
00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool2002lOol00`00Oomoo`0MOol00`00Oomoo`06
Ool20003Ool3000FOol000]oo`07001oogooOol007oo00000Woo00<007oo000017oo00<007ooOol0
^goo00<007ooOol07Goo00<007ooOol01goo1@0067oo000;Ool01`00Oomoogoo001oo`00009oo`03
001oo`0000Aoo`03001oogoo0;]oo`03001oogoo01eoo`03001oogoo02Aoo`002Woo0P0017oo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol0VWoo00<007ooOol07Woo00<007ooOol07Goo00<0
07ooOol097oo000KOol00`00Oomoo`2JOol00`00Oomoo`0NOol2000MOol00`00Oomoo`0UOol001]o
o`03001oogoo09Yoo`03001oogoo01ioo`8001eoo`03001oogoo02Eoo`006goo00<007ooOol0VWoo
00<007ooOol07Goo00<007oo00007Goo00<007ooOol09Goo000KOol2002KOol00`00Oomoo`0MOol0
0`00Ool0000LOol00`00Oomoo`0VOol001]oo`03001oogoo09Yoo`03001oogoo01eoo`03001oo`00
01aoo`03001oogoo02Ioo`006goo00<007ooOol0VWoo00<007ooOol07Goo00<007oo000077oo00<0
07ooOol09Woo000KOol00`00Oomoo`2JOol00`00Oomoo`0MOol00`00Ool0000KOol00`00Oomoo`0W
Ool001]oo`03001oogoo09Yoo`03001oogoo01eoo`03001oo`0001]oo`03001oogoo02Moo`006goo
00<007ooOol0VWoo00<007ooOol07Goo00<007oo00006Woo00<007ooOol0:7oo000KOol2002KOol0
0`00Oomoo`0MOol00`00Ool0000JOol00`00Oomoo`0XOol001]oo`03001oogoo09Yoo`03001oogoo
01eoo`03001oo`0001Uoo`03001oogoo02Uoo`006goo00<007ooOol0VWoo00<007ooOol07Goo00<0
07oo00006Goo00<007ooOol0:Goo000KOol00`00Oomoo`2JOol00`00Oomoo`0MOol00`00Ool0000H
Ool00`00Oomoo`0ZOol001]oo`03001oogoo09Yoo`03001oogoo01eoo`03001oo`0001Qoo`03001o
ogoo02Yoo`006goo00<007ooOol0VWoo00<007ooOol07Goo00<007oo00005goo00<007ooOol0:goo
000KOol2002KOol00`00Oomoo`0LOol01@00Oomoogoo00005Woo00<007ooOol0:goo000KOol00`00
Oomoo`2JOol00`00Oomoo`0LOol01@00Oomoogoo00005Goo00<007ooOol0;7oo000KOol00`00Oomo
o`2JOol00`00Oomoo`0LOol01@00Oomoogoo00005Goo00<007ooOol0;7oo000KOol00`00Oomoo`2J
Ool00`00Oomoo`0LOol01@00Oomoogoo000057oo00<007ooOol0;Goo000@Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2JOol00`00Oomoo`0LOol00`00Oomoo`02Ool00`00Oomoo`0@Ool0
0`00Oomoo`0^Ool000moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo09Yoo`03001oogoo
01aoo`03001oogoo009oo`03001oogoo00moo`03001oogoo02moo`002Woo0`000Woo00<007oo0000
0Woo00<007oo000017oo0P00Vgoo00<007ooOol06goo00<007ooOol00goo00<007ooOol03Goo0P00
<Woo000@Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo09Yoo`03001oogoo01]oo`03001oogoo
00Aoo`03001oogoo00]oo`03001oogoo039oo`003goo00<007oo00000Woo00<007oo000017oo00<0
07ooOol0VWoo0P0077oo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0<goo000@Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`2JOol2000LOol00`00Oomoo`05Ool20009Ool00`00
Oomoo`0dOol001]oo`03001oogoo09Yoo`8001aoo`03001oogoo00Moo`8000Eoo`8003Moo`006goo
00<007ooOol0VWoo0P006goo00<007ooOol02Goo1P00>Goo000KOol2002KOol2000KOol00`00Oomo
o`18Ool001]oo`03001oogoo09Yoo`8001]oo`03001oogoo04Qoo`006goo00<007ooOol0VGoo00<0
07oo00006Woo00<007ooOol0BGoo000KOol00`00Oomoo`2IOol00`00Ool0000JOol00`00Oomoo`19
Ool001]oo`03001oogoo09Uoo`03001oo`0001Yoo`03001oogoo04Uoo`006goo00<007ooOol0VGoo
00<007oo00006Goo00<007ooOol0BWoo000KOol2002JOol00`00Ool0000HOol00`00Oomoo`1;Ool0
01]oo`03001oogoo09Uoo`03001oo`0001Qoo`03001oogoo04]oo`006goo00<007ooOol0VGoo00<0
07oo00005goo00<007ooOol0C7oo000KOol00`00Oomoo`2IOol00`00Ool0000GOol00`00Oomoo`1<
Ool001]oo`03001oogoo09Uoo`04001oogoo000EOol00`00Oomoo`1=Ool001]oo`03001oogoo09Uo
o`04001oogoo000EOol00`00Oomoo`1=Ool001]oo`8009Yoo`04001oogoo000DOol00`00Oomoo`1>
Ool001]oo`03001oogoo09Uoo`04001oogoo000COol00`00Oomoo`1?Ool001]oo`03001oogoo09Uo
o`04001oogoo000COol00`00Oomoo`1?Ool001]oo`03001oogoo09Qoo`03001oogoo009oo`03001o
ogoo00moo`03001oogoo051oo`006goo00<007ooOol0V7oo00<007ooOol00Woo00<007ooOol03Woo
00<007ooOol0DGoo000?Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`2HOol00`00Oomoo`03Ool0
0`00Oomoo`0=Ool00`00Oomoo`1AOol000moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo
09Moo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo059oo`002Woo0`000Woo00<007oo0000
0Woo00<007oo000017oo0P00V7oo00<007ooOol01Goo00<007ooOol02Goo0P00EGoo000?Ool20003
Ool00`00Ool00004Ool00`00Oomoo`2GOol00`00Oomoo`06Ool00`00Oomoo`06Ool2001GOol000mo
o`03001oogoo009oo`03001oo`0000Aoo`03001oogoo09Moo`03001oogoo00Moo`8000=oo`<005Uo
o`0047oo0P000goo00<007ooOol00goo00<007ooOol0UWoo00<007ooOol02Goo1000G7oo000KOol0
0`00Oomoo`2FOol00`00Oomoo`1YOol001]oo`03001oogoo09Ioo`03001oogoo06Uoo`006goo0P00
Ugoo00<007ooOol0JGoo000KOol00`00Oomoo`2FOol00`00Oomoo`1YOol001]oo`03001oogoo09Eo
o`03001oogoo06Yoo`006goo00<007ooOol0UGoo00<007ooOol0JWoo000KOol00`00Oomoo`2EOol0
0`00Oomoo`1ZOol001]oo`03001oogoo09Aoo`03001oogoo06]oo`006goo0P00UGoo00<007ooOol0
Jgoo000KOol00`00Oomoo`2COol00`00Oomoo`1/Ool001]oo`03001oogoo09=oo`03001oogoo06ao
o`006goo00<007ooOol0TWoo00<007ooOol0KGoo000KOol00`00Oomoo`2BOol00`00Oomoo`1]Ool0
01]oo`03001oogoo095oo`03001oogoo06ioo`006goo0P00TWoo00<007ooOol0KWoo000KOol00`00
Oomoo`2@Ool00`00Oomoo`1_Ool001]oo`03001oogoo091oo`03001oogoo06moo`006goo00<007oo
Ool0Sgoo00<007ooOol0L7oo000@Ool30002Ool00`00Oomoo`03Ool00`00Oomoo`2?Ool00`00Oomo
o`1`Ool0015oo`06001oogoo001oo`0017oo00<007ooOol0SWoo00<007ooOol0LGoo000:Ool30002
Ool4000017oo001oo`0017oo0P00SWoo00<007ooOol0LWoo000?Ool00`00Ool00002Ool00`00Ool0
0004Ool00`00Oomoo`2=Ool00`00Oomoo`1bOol0011oo`80009oo`03001oo`0000Aoo`03001oogoo
08aoo`03001oogoo07=oo`004Goo00D007ooOomoo`0000Eoo`03001oogoo08aoo`03001oogoo07=o
o`006goo00<007ooOol0Rgoo00<007ooOol0M7oo000KOol00`00Oomoo`2:Ool00`00Oomoo`1eOol0
01]oo`8008Yoo`03001oogoo07Ioo`006goo00<007ooOol0R7oo00<007ooOol0Mgoo000KOol00`00
Oomoo`27Ool00`00Oomoo`1hOol001]oo`03001oogoo08Ioo`03001oogoo07Uoo`006goo00<007oo
Ool0QGoo00<007ooOol0NWoo000KOol00`00Oomoo`24Ool00`00Oomoo`1kOol001]oo`03001oogoo
08=oo`03001oogoo07aoo`006goo0P00Pgoo00<007ooOol0OGoo000KOol00`00Oomoo`21Ool00`00
Oomoo`1nOol001]oo`03001oogoo081oo`03001oogoo07moo`006goo00<007ooOol0Ogoo00<007oo
Ool0P7oo000KOol00`00Oomoo`1mOol20023Ool001]oo`03001oogoo07aoo`03001oogoo08=oo`00
6goo0P00O7oo00<007ooOol0Q7oo000KOol00`00Oomoo`1iOol20027Ool001]oo`03001oogoo07Qo
o`03001oogoo08Moo`006goo00<007ooOol0MWoo0P00RWoo000?Ool30003Ool00`00Oomoo`03Ool0
0`00Oomoo`1dOol2002<Ool000moo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo07=oo`03
001oogoo08aoo`002Woo0`000goo00L007ooOomoo`00Ool00004Ool2001bOol2002?Ool0011oo`07
001oogooOol007oo000017oo00<007ooOol0L7oo00<007ooOol0Sgoo000?Ool00`00Ool00002Ool0
0`00Ool00004Ool00`00Oomoo`1^Ool2002BOol0011oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo06aoo`8009Aoo`006goo00<007ooOol0JWoo0P00UWoo000KOol00`00Oomoo`1XOol2002H
Ool001]oo`8006Ioo`<009Yoo`006goo00<007ooOol0:Goo00<007ooOol00Woo00<007ooOol01@00
9Woo00<007ooOol00Woo1`009Woo00<007ooOol00Woo00@007ooOomoo`8002Moo`03001oogoo009o
o`03001oogoo009oo`<002Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`006goo
00<007ooOol0:7oo00<007oo000027oo00<007ooOol09Goo00<007oo000010000goo00<007ooOol0
9Goo00<007oo00002Goo00<007ooOol08goo00<007oo00002Goo00<007ooOol08goo00<007oo0000
1goo00<007oo000017oo000KOol00`00Oomoo`0XOol00`00Ool00008Ool00`00Oomoo`0TOol40008
Ool00`00Oomoo`0TOol00`00Ool00008Ool00`00Oomoo`0TOol00`00Ool00007Ool4000TOol00`00
Ool00009Ool00`00Oomoo`02Ool001]oo`03001oogoo02Qoo`03001oo`0000Qoo`03001oogoo01mo
o`D00004Ool007oo0008Ool00`00Oomoo`0TOol00`00Ool00009Ool00`00Oomoo`0SOol00`00Ool0
0007Ool00`00Ool0000UOol00`00Ool00007Ool20005Ool001]oo`03001oogoo02Qoo`03001oo`00
00Qoo`03001oogoo01eoo`8000Ioo`03001oo`0000Moo`03001oo`0002Eoo`03001oo`0000Moo`03
001oo`0002Eoo`03001oo`0000Qoo`8002Eoo`03001oo`0000Moo`03001oogoo00Aoo`006goo0P00
:Woo00<007ooOol01Woo0P006goo10002Goo00<007ooOol01goo00<007ooOol09Goo00<007ooOol0
1goo00<007ooOol09Goo00<007ooOol027oo00<007ooOol097oo00<007ooOol01Woo0`0017oo000K
Ool00`00Oomoo`15Ool:002cOol001]oo`03001oogoo03Ioo`l00;eoo`006goo>@00c7oo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`005Gooo`002@000goo000KOol00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool004eoo`03001oogoo02moo`03001oogoo02moo`03001oogoo02moo`03001oogoo031oo`03
001oogoo00Moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0544294, -142.01, 
  0.00199436, 0.811346}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.3 2D WINDOW METHOD WITH CIRCULAR SUPPORT", "Section"],

Cell[CellGroupData[{

Cell["\<\
Step 1: Evaluation of the ideal response with circular symmetry\
\>", "Subsection"],

Cell["\<\
A 2D lowpass filter with circular support will be designed. The filter \
specification is the same as in previous section. The infinite impulse \
response sequence of the ideal, circularly symmetric lowpass filter is given \
by (Dudgeon and Mersereau, 1984) as \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`h\_I[n\_1, n\_2]\  = \ 
        \(\[Omega]\_C\/\(2  \[Pi]\)\) 
          \(\(J\_1\)(\(\[Omega]\_C\) \@\(n\_1\^2 + n\_2\^2\))
              \)\/\@\(n\_1\^2 + n\_2\^2\)\)]],
  ", "
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_1\)( . )\)]],
  " is the Bessel function of the first kind of order 1 and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_C\ \)\)]],
  "is the cutoff frequency. Also, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(h\_I\)(0, 0)\  = \ \[Omega]\_C\^2\/\(4  \[Pi]\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(wc = 0.4  \[Pi]; \ L = 15; \n
    lowC = Table[
        If[n1 == 0\  && \ n2 == 0, \n\t\twc\^2\/\(4  \[Pi]\ \), 
          wc\/\(2  \[Pi]\ \@\(n1^2 + n2^2\)\)*
            BesselJ[1, wc\ \@\(n1^2 + n2^2\)]], \n
        \t\t\t{n1, \(-\((L - 1)\)\)/2, \((L - 1)\)/2}, {n2, 
          \(-\((L - 1)\)\)/2, \((L - 1)\)/2}]; \)], "Input",
  CellLabel->"In[56]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot3D[lowC, PlotRange -> All]; \)\)], "Input",
  CellLabel->"In[57]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.19846 .17893 -5.85476 -9 ]
[.19846 .17893 .14524 0 ]
[.42923 .08816 -10.816 -9 ]
[.42923 .08816 1.18401 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.79412 .13786 0 -6.12234 ]
[.79412 .13786 6 2.87766 ]
[.89499 .29234 0 -5.97603 ]
[.89499 .29234 12 3.02397 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[.02021 .28956 -6 -2.76297 ]
[.02021 .28956 0 6.23703 ]
[.00808 .36557 -24 -2.82738 ]
[.00808 .36557 0 6.17262 ]
[-0.00465 .4454 -18 -2.89537 ]
[-0.00465 .4454 0 6.10463 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.20751 .18843 m
.21203 .19319 L
s
[(5)] .19846 .17893 .95159 1 Mshowa
.43745 .0984 m
.44155 .10351 L
s
[(10)] .42923 .08816 .80266 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(15)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.25192 .17104 m
.25459 .17394 L
s
.2971 .15335 m
.29972 .15629 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.4859 .07942 m
.48831 .08254 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.16384 .20553 m
.1666 .20834 L
s
.12091 .22234 m
.12371 .22511 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78177 .14231 m
.7756 .14454 L
s
[(5)] .79412 .13786 -1 .36052 Mshowa
.88252 .29643 m
.87629 .29847 L
s
[(10)] .89499 .29234 -1 .32801 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(15)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.8032 .17508 m
.79948 .1764 L
s
.82395 .20683 m
.82023 .20812 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.90091 .32455 m
.89716 .32575 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.75965 .10848 m
.75596 .10983 L
s
.7368 .07352 m
.73311 .0749 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03245 .28483 m
.03858 .28247 L
s
[(0)] .02021 .28956 1 -0.38601 Mshowa
.02038 .361 m
.02653 .35871 L
s
[(0.05)] .00808 .36557 1 -0.37169 Mshowa
.00771 .44099 m
.01389 .43879 L
s
[(0.1)] -0.00465 .4454 1 -0.35658 Mshowa
.125 Mabswid
.03009 .29977 m
.03376 .29836 L
s
.0277 .31485 m
.03138 .31346 L
s
.02528 .33009 m
.02897 .3287 L
s
.02285 .34547 m
.02653 .34408 L
s
.0179 .37668 m
.02159 .37532 L
s
.01539 .39252 m
.01909 .39117 L
s
.01285 .40852 m
.01655 .40717 L
s
.01029 .42467 m
.014 .42334 L
s
.0348 .27003 m
.03847 .26861 L
s
.03712 .25537 m
.04079 .25394 L
s
.0051 .45747 m
.00881 .45616 L
s
.00246 .47413 m
.00617 .47282 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.631 .716 .908 r
.38247 .59894 .40451 .62134 .44151 .60834 .41962 .59086 Metetra
.565 .747 .963 r
.41962 .59086 .44151 .60834 .47892 .5995 .4573 .58633 Metetra
.546 .793 .99 r
.4573 .58633 .47892 .5995 .51689 .59319 .49566 .58077 Metetra
.608 .825 .983 r
.49566 .58077 .51689 .59319 .55552 .58671 .5347 .5712 Metetra
.668 .807 .95 r
.5347 .5712 .55552 .58671 .59476 .57843 .5743 .55806 Metetra
.682 .763 .913 r
.5743 .55806 .59476 .57843 .63459 .56824 .61442 .54378 Metetra
.67 .726 .891 r
.61442 .54378 .63459 .56824 .67498 .55675 .65512 .53055 Metetra
.653 .709 .888 r
.65512 .53055 .67498 .55675 .71591 .54432 .69649 .5192 Metetra
.641 .716 .902 r
.69649 .5192 .71591 .54432 .75736 .53058 .73859 .50893 Metetra
.647 .753 .926 r
.73859 .50893 .75736 .53058 .79923 .51484 .78129 .49751 Metetra
.676 .811 .948 r
.78129 .49751 .79923 .51484 .84147 .49717 .82435 .48242 Metetra
.712 .855 .95 r
.82435 .48242 .84147 .49717 .8842 .47925 .8676 .46312 Metetra
.722 .847 .94 r
.8676 .46312 .8842 .47925 .92778 .46386 .91121 .44261 Metetra
.69 .786 .923 r
.91121 .44261 .92778 .46386 .97256 .45276 .95581 .4257 Metetra
.555 .734 .959 r
.35968 .58034 .38247 .59894 .41962 .59086 .39699 .57658 Metetra
.536 .779 .987 r
.39699 .57658 .41962 .59086 .4573 .58633 .43503 .57185 Metetra
.645 .812 .963 r
.43503 .57185 .4573 .58633 .49566 .58077 .47387 .56039 Metetra
.716 .769 .895 r
.47387 .56039 .49566 .58077 .5347 .5712 .51331 .54217 Metetra
.715 .706 .84 r
.51331 .54217 .5347 .5712 .5743 .55806 .55315 .52174 Metetra
.69 .658 .813 r
.55315 .52174 .5743 .55806 .61442 .54378 .59342 .50338 Metetra
.663 .629 .806 r
.59342 .50338 .61442 .54378 .65512 .53055 .63427 .48875 Metetra
.639 .613 .808 r
.63427 .48875 .65512 .53055 .69649 .5192 .67586 .478 Metetra
.614 .606 .819 r
.67586 .478 .69649 .5192 .73859 .50893 .71836 .47105 Metetra
.597 .616 .841 r
.71836 .47105 .73859 .50893 .78129 .49751 .76182 .4663 Metetra
.609 .665 .879 r
.76182 .4663 .78129 .49751 .82435 .48242 .80599 .45937 Metetra
.664 .758 .92 r
.80599 .45937 .82435 .48242 .8676 .46312 .85034 .44551 Metetra
.723 .837 .935 r
.85034 .44551 .8676 .46312 .91121 .44261 .89458 .42457 Metetra
.731 .839 .931 r
.89458 .42457 .91121 .44261 .95581 .4257 .93919 .40246 Metetra
.516 .75 .981 r
.33612 .5639 .35968 .58034 .39699 .57658 .37371 .56091 Metetra
.637 .798 .96 r
.37371 .56091 .39699 .57658 .43503 .57185 .4123 .55026 Metetra
.735 .763 .876 r
.4123 .55026 .43503 .57185 .47387 .56039 .4517 .52891 Metetra
.736 .699 .815 r
.4517 .52891 .47387 .56039 .51331 .54217 .49151 .50328 Metetra
.701 .652 .798 r
.49151 .50328 .51331 .54217 .55315 .52174 .53159 .48179 Metetra
.666 .634 .808 r
.53159 .48179 .55315 .52174 .59342 .50338 .57214 .46657 Metetra
.655 .646 .829 r
.57214 .46657 .59342 .50338 .63427 .48875 .61329 .4537 Metetra
.658 .659 .84 r
.61329 .4537 .63427 .48875 .67586 .478 .65506 .44039 Metetra
.639 .639 .834 r
.65506 .44039 .67586 .478 .71836 .47105 .69758 .42946 Metetra
.593 .599 .827 r
.69758 .42946 .71836 .47105 .76182 .4663 .74126 .42495 Metetra
.56 .585 .836 r
.74126 .42495 .76182 .4663 .80599 .45937 .78622 .42481 Metetra
.586 .639 .871 r
.78622 .42481 .80599 .45937 .85034 .44551 .83185 .42039 Metetra
.673 .752 .911 r
.83185 .42039 .85034 .44551 .89458 .42457 .87728 .40492 Metetra
.739 .831 .921 r
.87728 .40492 .89458 .42457 .93919 .40246 .92241 .38133 Metetra
.571 .768 .972 r
.31186 .54693 .33612 .5639 .37371 .56091 .34992 .54081 Metetra
.723 .776 .894 r
.34992 .54081 .37371 .56091 .4123 .55026 .38921 .52145 Metetra
.757 .721 .819 r
.38921 .52145 .4123 .55026 .4517 .52891 .42918 .49265 Metetra
.716 .671 .805 r
.42918 .49265 .4517 .52891 .49151 .50328 .46925 .46896 Metetra
.625 .648 .853 r
.46925 .46896 .49151 .50328 .53159 .48179 .50958 .46027 Metetra
.476 .691 .962 r
.50958 .46027 .53159 .48179 .57214 .46657 .55069 .4609 Metetra
.372 .81 .958 r
.55069 .4609 .57214 .46657 .61329 .4537 .59265 .45507 Metetra
.577 .942 .895 r
.59265 .45507 .61329 .4537 .65506 .44039 .63493 .43412 Metetra
.769 .949 .935 r
.63493 .43412 .65506 .44039 .69758 .42946 .67736 .40651 Metetra
.701 .774 .908 r
.67736 .40651 .69758 .42946 .74126 .42495 .72066 .3882 Metetra
.572 .621 .862 r
.72066 .3882 .74126 .42495 .78622 .42481 .76567 .38523 Metetra
.529 .585 .855 r
.76567 .38523 .78622 .42481 .83185 .42039 .81221 .38769 Metetra
.601 .668 .886 r
.81221 .38769 .83185 .42039 .87728 .40492 .85898 .3805 Metetra
.713 .784 .907 r
.85898 .3805 .87728 .40492 .92241 .38133 .90508 .35946 Metetra
.643 .771 .941 r
.28699 .52773 .31186 .54693 .34992 .54081 .32566 .51667 Metetra
.758 .753 .847 r
.32566 .51667 .34992 .54081 .38921 .52145 .36568 .48992 Metetra
.754 .708 .809 r
.36568 .48992 .38921 .52145 .42918 .49265 .40607 .46003 Metetra
.641 .668 .86 r
.40607 .46003 .42918 .49265 .46925 .46896 .44617 .44916 Metetra
.014 .449 .869 r
.44617 .44916 .46925 .46896 .50958 .46027 .4866 .46636 Metetra
.65 .125 0 r
.4866 .46636 .50958 .46027 .55069 .4609 .52844 .49431 Metetra
.507 .081 .166 r
.52844 .49431 .55069 .4609 .59265 .45507 .57169 .50035 Metetra
.156 0 .076 r
.57169 .50035 .59265 .45507 .63493 .43412 .61507 .46718 Metetra
.61507 .46718 .63493 .43412 .67736 .40651 .6577 .41149 Metetra
.83 .999 .795 r
.6577 .41149 .67736 .40651 .72066 .3882 .70046 .3662 Metetra
.683 .788 .929 r
.70046 .3662 .72066 .3882 .76567 .38523 .74502 .34931 Metetra
.511 .602 .881 r
.74502 .34931 .76567 .38523 .81221 .38769 .79189 .35203 Metetra
.539 .622 .883 r
.79189 .35203 .81221 .38769 .85898 .3805 .83974 .3517 Metetra
.673 .738 .9 r
.83974 .3517 .85898 .3805 .90508 .35946 .88695 .33504 Metetra
.684 .763 .911 r
.26154 .50615 .28699 .52773 .32566 .51667 .30082 .49092 Metetra
.773 .748 .83 r
.30082 .49092 .32566 .51667 .36568 .48992 .3415 .45999 Metetra
.744 .719 .828 r
.3415 .45999 .36568 .48992 .40607 .46003 .38215 .43321 Metetra
.419 .623 .936 r
.38215 .43321 .40607 .46003 .44617 .44916 .42207 .43829 Metetra
.731 .204 0 r
.42207 .43829 .44617 .44916 .4866 .46636 .46232 .48293 Metetra
.775 .345 .231 r
.46232 .48293 .4866 .46636 .52844 .49431 .50465 .53913 Metetra
.587 .194 .265 r
.50465 .53913 .52844 .49431 .57169 .50035 .54923 .55753 Metetra
.101 0 .099 r
.54923 .55753 .57169 .50035 .61507 .46718 .59407 .51174 Metetra
.59407 .51174 .61507 .46718 .6577 .41149 .63744 .42706 Metetra
.896 .961 .631 r
.63744 .42706 .6577 .41149 .70046 .3662 .68009 .35322 Metetra
.816 .905 .903 r
.68009 .35322 .70046 .3662 .74502 .34931 .72431 .31924 Metetra
.528 .66 .92 r
.72431 .31924 .74502 .34931 .79189 .35203 .77127 .3179 Metetra
.492 .613 .9 r
.77127 .3179 .79189 .35203 .83974 .3517 .81984 .32104 Metetra
.64 .716 .903 r
.81984 .32104 .83974 .3517 .88695 .33504 .86802 .30792 Metetra
.696 .755 .898 r
.23546 .48279 .26154 .50615 .30082 .49092 .27522 .46575 Metetra
.781 .757 .831 r
.27522 .46575 .30082 .49092 .3415 .45999 .31647 .43331 Metetra
.742 .745 .854 r
.31647 .43331 .3415 .45999 .38215 .43321 .35747 .40826 Metetra
.222 .541 .927 r
.35747 .40826 .38215 .43321 .42207 .43829 .39734 .42048 Metetra
.776 .278 0 r
.39734 .42048 .42207 .43829 .46232 .48293 .43731 .47721 Metetra
.834 .37 .096 r
.43731 .47721 .46232 .48293 .50465 .53913 .47964 .54597 Metetra
.58 .031 0 r
.47964 .54597 .50465 .53913 .54923 .55753 .52489 .5698 Metetra
.81 .991 .744 r
.52489 .5698 .54923 .55753 .59407 .51174 .57089 .518 Metetra
.978 .91 .666 r
.57089 .518 .59407 .51174 .63744 .42706 .61534 .41996 Metetra
.961 .877 .707 r
.61534 .41996 .63744 .42706 .68009 .35322 .65864 .33306 Metetra
.841 .845 .848 r
.65864 .33306 .68009 .35322 .72431 .31924 .70316 .29096 Metetra
.545 .691 .935 r
.70316 .29096 .72431 .31924 .77127 .3179 .7504 .28698 Metetra
.459 .628 .926 r
.7504 .28698 .77127 .3179 .81984 .32104 .79948 .2908 Metetra
.626 .721 .914 r
.79948 .2908 .81984 .32104 .86802 .30792 .84836 .27871 Metetra
.683 .746 .899 r
.20871 .45798 .23546 .48279 .27522 .46575 .24874 .44198 Metetra
.782 .771 .843 r
.24874 .44198 .27522 .46575 .31647 .43331 .29046 .41007 Metetra
.763 .777 .864 r
.29046 .41007 .31647 .43331 .35747 .40826 .3321 .38236 Metetra
.398 .634 .95 r
.3321 .38236 .35747 .40826 .39734 .42048 .37248 .38689 Metetra
0 .02 .567 r
.37248 .38689 .39734 .42048 .43731 .47721 .41262 .43149 Metetra
0 0 .574 r
.41262 .43149 .43731 .47721 .47964 .54597 .45474 .48785 Metetra
.394 .446 .796 r
.45474 .48785 .47964 .54597 .52489 .5698 .49979 .50588 Metetra
.742 .623 .726 r
.49979 .50588 .52489 .5698 .57089 .518 .54609 .45875 Metetra
.831 .671 .685 r
.54609 .45875 .57089 .518 .61534 .41996 .59144 .3722 Metetra
.842 .703 .709 r
.59144 .3722 .61534 .41996 .65864 .33306 .63588 .2967 Metetra
.766 .728 .817 r
.63588 .2967 .65864 .33306 .70316 .29096 .68135 .26157 Metetra
.518 .676 .936 r
.68135 .26157 .70316 .29096 .7504 .28698 .7292 .25945 Metetra
.447 .658 .951 r
.7292 .25945 .7504 .28698 .79948 .2908 .77868 .26183 Metetra
.638 .743 .925 r
.77868 .26183 .79948 .2908 .84836 .27871 .82799 .24774 Metetra
.647 .728 .908 r
.18133 .43129 .20871 .45798 .24874 .44198 .22135 .4188 Metetra
.767 .78 .863 r
.22135 .4188 .24874 .44198 .29046 .41007 .26334 .39018 Metetra
.791 .809 .867 r
.26334 .39018 .29046 .41007 .3321 .38236 .30581 .35832 Metetra
.64 .755 .932 r
.30581 .35832 .3321 .38236 .37248 .38689 .34739 .34594 Metetra
.298 .468 .86 r
.34739 .34594 .37248 .38689 .41262 .43149 .38845 .36231 Metetra
.326 .362 .745 r
.38845 .36231 .41262 .43149 .45474 .48785 .43071 .3897 Metetra
.525 .434 .695 r
.43071 .3897 .45474 .48785 .49979 .50588 .4752 .39459 Metetra
.653 .504 .668 r
.4752 .39459 .49979 .50588 .54609 .45875 .52106 .35915 Metetra
.717 .555 .668 r
.52106 .35915 .54609 .45875 .59144 .3722 .5668 .30061 Metetra
.733 .601 .711 r
.5668 .30061 .59144 .3722 .63588 .2967 .61235 .25276 Metetra
.666 .655 .829 r
.61235 .25276 .63588 .2967 .68135 .26157 .65899 .23396 Metetra
.454 .666 .954 r
.65899 .23396 .68135 .26157 .7292 .25945 .70756 .2352 Metetra
.475 .712 .974 r
.70756 .2352 .7292 .25945 .77868 .26183 .7573 .23326 Metetra
.674 .769 .922 r
.7573 .23326 .77868 .26183 .82799 .24774 .80686 .21457 Metetra
.597 .699 .914 r
.1534 .402 .18133 .43129 .22135 .4188 .19323 .39391 Metetra
.722 .768 .889 r
.19323 .39391 .22135 .4188 .26334 .39018 .2351 .37201 Metetra
.793 .828 .879 r
.2351 .37201 .26334 .39018 .30581 .35832 .27819 .34027 Metetra
.762 .834 .908 r
.27819 .34027 .30581 .35832 .34739 .34594 .32116 .31381 Metetra
.622 .695 .897 r
.32116 .31381 .34739 .34594 .38845 .36231 .36369 .30287 Metetra
.544 .525 .785 r
.36369 .30287 .38845 .36231 .43071 .3897 .40666 .30154 Metetra
.577 .481 .708 r
.40666 .30154 .43071 .3897 .4752 .39459 .45091 .29346 Metetra
.627 .496 .683 r
.45091 .29346 .4752 .39459 .52106 .35915 .49627 .26964 Metetra
.658 .53 .697 r
.49627 .26964 .52106 .35915 .5668 .30061 .54212 .23887 Metetra
.654 .585 .765 r
.54212 .23887 .5668 .30061 .61235 .25276 .58851 .21769 Metetra
.556 .663 .908 r
.58851 .21769 .61235 .25276 .65899 .23396 .63614 .21234 Metetra
.408 .708 .984 r
.63614 .21234 .65899 .23396 .70756 .2352 .68527 .21253 Metetra
.566 .78 .979 r
.68527 .21253 .70756 .2352 .7573 .23326 .73513 .20268 Metetra
.712 .775 .901 r
.73513 .20268 .7573 .23326 .80686 .21457 .7849 .17841 Metetra
.562 .673 .912 r
.12493 .37013 .1534 .402 .19323 .39391 .16466 .36466 Metetra
.648 .724 .904 r
.16466 .36466 .19323 .39391 .2351 .37201 .20608 .35106 Metetra
.745 .811 .904 r
.20608 .35106 .2351 .37201 .27819 .34027 .24917 .32614 Metetra
.782 .873 .914 r
.24917 .32614 .27819 .34027 .32116 .31381 .29303 .29667 Metetra
.748 .851 .927 r
.29303 .29667 .32116 .31381 .36369 .30287 .33694 .27151 Metetra
.682 .73 .887 r
.33694 .27151 .36369 .30287 .40666 .30154 .38098 .25287 Metetra
.644 .623 .814 r
.38098 .25287 .40666 .30154 .45091 .29346 .4256 .23662 Metetra
.637 .591 .786 r
.4256 .23662 .45091 .29346 .49627 .26964 .47098 .21985 Metetra
.629 .616 .819 r
.47098 .21985 .49627 .26964 .54212 .23887 .51711 .20549 Metetra
.573 .688 .918 r
.51711 .20549 .54212 .23887 .58851 .21769 .56421 .19778 Metetra
.443 .748 .993 r
.56421 .19778 .58851 .21769 .63614 .21234 .61256 .19457 Metetra
.497 .798 .999 r
.61256 .19457 .63614 .21234 .68527 .21253 .66202 .18679 Metetra
.673 .803 .944 r
.66202 .18679 .68527 .21253 .73513 .20268 .71198 .16733 Metetra
.728 .754 .874 r
.71198 .16733 .73513 .20268 .7849 .17841 .76212 .13929 Metetra
.575 .677 .909 r
.09572 .33737 .12493 .37013 .16466 .36466 .13578 .33044 Metetra
.587 .674 .9 r
.13578 .33044 .16466 .36466 .20608 .35106 .17682 .32239 Metetra
.658 .741 .911 r
.17682 .32239 .20608 .35106 .24917 .32614 .21943 .30708 Metetra
.723 .834 .933 r
.21943 .30708 .24917 .32614 .29303 .29667 .26336 .28449 Metetra
.739 .898 .95 r
.26336 .28449 .29303 .29667 .33694 .27151 .30798 .25947 Metetra
.712 .901 .963 r
.30798 .25947 .33694 .27151 .38098 .25287 .35296 .23659 Metetra
.674 .862 .971 r
.35296 .23659 .38098 .25287 .4256 .23662 .39835 .21758 Metetra
.627 .83 .978 r
.39835 .21758 .4256 .23662 .47098 .21985 .44433 .20261 Metetra
.555 .824 .996 r
.44433 .20261 .47098 .21985 .51711 .20549 .49112 .19158 Metetra
.478 .823 .998 r
.49112 .19158 .51711 .20549 .56421 .19778 .53895 .18278 Metetra
.526 .839 .999 r
.53895 .18278 .56421 .19778 .61256 .19457 .58787 .17155 Metetra
.66 .824 .962 r
.58787 .17155 .61256 .19457 .66202 .18679 .63762 .15286 Metetra
.718 .763 .888 r
.63762 .15286 .66202 .18679 .71198 .16733 .68785 .12657 Metetra
.714 .723 .857 r
.68785 .12657 .71198 .16733 .76212 .13929 .73866 .09895 Metetra
.628 .716 .91 r
.06532 .30658 .09572 .33737 .13578 .33044 .10628 .2943 Metetra
.588 .668 .894 r
.10628 .2943 .13578 .33044 .17682 .32239 .14754 .28576 Metetra
.598 .672 .892 r
.14754 .28576 .17682 .32239 .21943 .30708 .1898 .27601 Metetra
.639 .728 .912 r
.1898 .27601 .21943 .30708 .26336 .28449 .23335 .26184 Metetra
.675 .807 .946 r
.23335 .26184 .26336 .28449 .30798 .25947 .27802 .2437 Metetra
.675 .868 .972 r
.27802 .2437 .30798 .25947 .35296 .23659 .32348 .22423 Metetra
.641 .892 .985 r
.32348 .22423 .35296 .23659 .39835 .21758 .36959 .2058 Metetra
.601 .888 .99 r
.36959 .2058 .39835 .21758 .44433 .20261 .41639 .18928 Metetra
.587 .875 .994 r
.41639 .18928 .44433 .20261 .49112 .19158 .46403 .1738 Metetra
.625 .855 .986 r
.46403 .1738 .49112 .19158 .53895 .18278 .5126 .15697 Metetra
.682 .81 .944 r
.5126 .15697 .53895 .18278 .58787 .17155 .56205 .13606 Metetra
.709 .752 .886 r
.56205 .13606 .58787 .17155 .63762 .15286 .61219 .11052 Metetra
.706 .713 .855 r
.61219 .11052 .63762 .15286 .68785 .12657 .66297 .08357 Metetra
.68 .703 .864 r
.66297 .08357 .68785 .12657 .73866 .09895 .71468 .06035 Metetra
.684 .764 .912 r
.03329 .27959 .06532 .30658 .10628 .2943 .07544 .26118 Metetra
.637 .712 .901 r
.07544 .26118 .10628 .2943 .14754 .28576 .11761 .24721 Metetra
.608 .67 .883 r
.11761 .24721 .14754 .28576 .1898 .27601 .16022 .23588 Metetra
.609 .663 .878 r
.16022 .23588 .1898 .27601 .23335 .26184 .20373 .22427 Metetra
.626 .689 .889 r
.20373 .22427 .23335 .26184 .27802 .2437 .24832 .21055 Metetra
.646 .729 .909 r
.24832 .21055 .27802 .2437 .32348 .22423 .29394 .19462 Metetra
.658 .762 .927 r
.29394 .19462 .32348 .22423 .36959 .2058 .34049 .17716 Metetra
.666 .776 .932 r
.34049 .17716 .36959 .2058 .41639 .18928 .38793 .15853 Metetra
.677 .768 .92 r
.38793 .15853 .41639 .18928 .46403 .1738 .43625 .13833 Metetra
.689 .744 .893 r
.43625 .13833 .46403 .1738 .5126 .15697 .48542 .11584 Metetra
.694 .715 .865 r
.48542 .11584 .5126 .15697 .56205 .13606 .53535 .09111 Metetra
.69 .696 .851 r
.53535 .09111 .56205 .13606 .61219 .11052 .58601 .06597 Metetra
.672 .694 .862 r
.58601 .06597 .61219 .11052 .66297 .08357 .63753 .04342 Metetra
.642 .711 .897 r
.63753 .04342 .66297 .08357 .71468 .06035 .69021 .02536 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.20751 .18843 m
.21203 .19319 L
s
[(5)] .19846 .17893 .95159 1 Mshowa
.43745 .0984 m
.44155 .10351 L
s
[(10)] .42923 .08816 .80266 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(15)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.25192 .17104 m
.25459 .17394 L
s
.2971 .15335 m
.29972 .15629 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.4859 .07942 m
.48831 .08254 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.16384 .20553 m
.1666 .20834 L
s
.12091 .22234 m
.12371 .22511 L
s
.07869 .23888 m
.08153 .2416 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002mOol50002Ool00`00Oomo
o`1IOol00;moo`07001oogooOol007oo0000FWoo002oOol00`00Oomoo`03Ool00`00Oomoo`1HOol0
0;moo`04001oogooOol2001KOol00;moo`05001oogooOol0001LOol00;ioo`8000=oo`<005Yoo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00<Ioo`8005Qoo`00a7oo0P0000=o
o`000000Egoo0031Ool30003Ool2001GOol00;ioo`<000Ioo`03001oo`0005Ioo`00_7oo0P002Goo
00@007ooOol005Eoo`00^Goo0`002goo00@007ooOol005Eoo`00]goo0P0000=oo`00Ool02Woo0P00
0goo00<007ooOol0DWoo002dOol3000=Ool200000e;L00000003Ool00`00Oomoo`1AOol00;9oo`80
00eoo`<000ABg080009oo`03001oogoo055oo`00[goo0`0037oo0`001e;L0P000goo00<007ooOol0
D7oo002/Ool3000=Ool2000:D]`01`00D]`007oo001oo`00055oo`00ZWoo0P0000=oo`00Ool02Woo
0`0035;L00@005;LD]`0009oo`03001oogoo04moo`00Ygoo0`003Goo0P000UKK00<005;LD]`02U;L
00D005;LD]aBg000009oo`03001oogoo04ioo`00YGoo0P003Woo0P0015KK00<005;LD]`02U;L00D0
05;LD]aBg00000=oo`03001oogoo04eoo`00Ngoo1@000Woo00<007ooOol07Goo0`003Goo0`001eKK
00<005;LD]`02E;L00<005;LD]`00U;L00@007ooOol004moo`00OGoo00L007ooOomoo`00Ool0000K
Ool3000>Ool2000:E]/00`00D]aBg009D]`00`00D]aBg002D]`20002Ool00`00Oomoo`1<Ool007eo
o`07001oogooOol007oo00006Goo0P0000=oo`00Ool037oo0P003EKK00<005;LD]`025;L00<005;L
D]`00P000UKK00<007oo0000CWoo001mOol01`00Oomoogoo001oo`0001Ioo`<000ioo`<0011Ff`03
001Bg5;L00MBg0<000AFf`04001oogoo001=Ool007eoo`07001oogooOol007oo000057oo0P003goo
0P000U[K00<005KKE]/03UKK00<005;LD]`01E;L0`001eKK00@007ooOol004aoo`00O7oo0P0017oo
00<007ooOol047oo0`003goo0P0015[K00<005KKE]/03eKK00<005;LD]`00U;L0P000UKK00<005KK
E]/01EKK00@007oo000004aoo`00Tgoo0P0047oo0P001e[K00<005KKE]/03UKK00<005;LD]`00P00
15KK00<005KKE]/01UKK00@007ooOol004]oo`00T7oo10003goo0P002U[K00<005KKE]/03UKK0P00
1UKK00<005KKE]/01eKK00@007ooOol004Yoo`00SGoo0`004Goo0P0035[K00<005KKE]/035KK0P00
00=Jf`00E]/01EKK00<005KKE]/01eKK00@007ooOol004Yoo`00Rgoo0P004Woo0P003e[K00<005KK
E]/02EKK0P000e[K00<005KKE]/015KK00<005KKE]/025KK00@007ooOol004Uoo`00R7oo0`004Woo
0P0000=Jf`00F]/03U[K00<005KKE]/01eKK0P001U[K00<005KKE]/015KK00<005KKE]/01eKK00D0
07ooOomoo`0004Qoo`00QWoo0P004goo0P000e[K00<005[KF]/03U[K00<005KKE]/015KK0P002E[K
00<005KKE]/00eKK00<005KKE]/025KK00@007ooOol004Qoo`00Pgoo0`0000=oo`00Ool047oo0P00
1U[K00<005[KF]/03U[K00@005KKE]]Ff`8000]Jf`03001FfeKK00=Ff`03001FfeKK00IFf`800005
F_/007ooOol00017Ool0081oo`<001Aoo`8000QJf`03001Jfe[K00iJf`04001Ff`00000>F]/00`00
E]]Ff`02E]/00`00E]]Ff`04E]/20003F_/01@00Oomoogoo0000AWoo001nOol2000EOol2000;F]/0
0`00F]]Jf`0>F]/00`00F]]Jf`0>F]/00`00E]]Ff`02E]/00`00E]]Ff`02E]/20006F_/01000Ool0
0000AWoo001kOol3000DOol3000=F]/00`00F]]Jf`0<F]/200000e/L001Jf`0?F]/01@00E]]FfeKK
00000UKK0P0025[k00D007ooOomoo`0004Eoo`00NGoo0P005Goo0P000U[l00<005[KF]/035[K00<0
05[KF]/02E[K0P000e/L00<005[KF]/03e[K00<005KKE]/00`002e[k00D007ooOomoo`0004Aoo`00
MWoo0`000Woo00<007ooOol047oo0P0015[l00<005[KF]/03E[K00<005[KF]/01U[K0P001U/L00<0
05[KF]/03U[K00@005KK000000eJn`05001oogooOol00008Ool00`00Oomoo`0iOol007Aoo`8001Io
o`8000MJo003001Jfe[K00aJf`03001Jfe[K00AJf`8000UK7003001Jfe[K00iJf`03001Jn`0000iJ
n`05001oogooOol00006Ool00`00Ool0000jOol0075oo`<001Ioo`8000YJo003001Jfe[K00aJf`04
001Jfe[KF]/2000;Fa`00`00F]]Jf`0<F]/200000e/L0000000>F_/00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`0hOol006ioo`<001Moo`8000aJo003001Jfe[K00aJf`04001Jf`00000>Fa`0
0`00F]]Jf`09F]/20003Fa`2000?F_/01@00Oomoogoo00001Goo0P00>goo001/Ool200000goo001o
o`0DOol3000?F_`00`00F]]Jf`0;F]/2000@Fa`00`00F]]Jf`07F]/20006Fa`00`00F_]Jn`0=F_/0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0jOol006Uoo`<001Moo`80009G7@03001Jo5[l
00eJo003001Jfe[K00UJf`80009G?P03001K75/L00iK7003001Jfe[K00AJf`8000QK7003001Jne[k
00iJn`03001oogoo009oo`04001oogooOol3000jOol006Moo`8001Moo`<000EG7@03001Jo5[l00eJ
o003001Jfe[K00IJf`8000EG?P03001K75/L00iK7004001Jfe[KF]/2000:Fa`2000=F_/200000elK
001oo`030010Ool004Ioo`03001oogoo01]oo`<001Ioo`<000QG7@03001Jo5[l00iJo003001Jfe[K
009Jf`<000MG?P03001K75/L00iK7004001Jf`00000<Fa`2000;F_/20003Ga/00`00Oomoo`02Ool0
0`00Oomoo`0mOol004Eoo`03001oo`0001Uoo`<001Moo`8000aG7@03001Jo5[l00eJo003001Jfe[K
008000]G?P03001K75/L00eK708000iK7003001K700000QJn`8000IO6`03001oogoo009oo`03001o
ogoo03aoo`00Agoo00<007ooOol05Goo0P000Woo00<007ooOol04Woo0`003eLM00<005[lF_`035[l
0`003ULn00<005/LFa`02U/L0P000UMN00<005/LFa`035/L0P001U[k0P0025lK00<007ooOol00Woo
00<007ooOol0?7oo0015Ool2000EOol3000GOol20002Ead00`00EaeG7@0>Ead00`00F_aJo008F_`3
0002Cgl00`00EciG?P0=Ech00`00FaaK7006Fa`30004Eeh00`00FaaK700<Fa`00`00Fa`00003F_/2
000;Ga/00`00Oomoo`02Ool00`00Oomoo`0kOol004Eoo`03001oogoo019oo`8001Qoo`8000EG7@03
001G7ELM00eG7@03001Jo5[l00AJo0@000I?O`03001G?ULn00aG?P03001K75/L00=K70<000QGGP03
001K75/L00]K7004001K7000F_/2000>Ga/01@00Oomoogoo0000?Goo0015Ool3000?Ool3000GOol3
0008Ead00`00EaeG7@0=Ead00`00F_aJo003000;Cgl00`00EciG?P0<Ech00`00FaaK7002000<Eeh0
0`00FaaK700:Fa`01000Fa`0000045lK00<007ooOol00Woo00<007ooOol0>Woo001DOol4000GOol2
000<Ead00`00EaeG7@0<Ead3000>Cgl00`00EciG?P0;Ech4000>Eeh00`00FaaK700:Fa`20002Ech0
0`00Ga]O6`0>Ga/00`00Oomoo`02Ool00`00Oomoo`0iOol0059oo`8001Qoo`<000mG7@03001G7ELM
00QG7@<0009;O`8000i?O`03001G?ULn00IG?P@000=3G`03001GGUMN00eGGP03001K75/L00IK70@0
00=G?P03001O6elK00iO6`04001oogooOol2000kOol004moo`<001Qoo`80009G7@03001G7ELM00iG
7@03001G7ELM00AG7@<000M;O`03001?Odmo00a?O`04001G?ULnEch40008@el00`00EeiGGP0=Eeh0
0`00FaaK7002Fa`30003Ech00`00EciG?P02Ech00`00Ga]O6`0=Ga/20004Ool00`00Oomoo`0hOol0
04eoo`8001Uoo`8000EG7@03001G7ELM00iG7@03001G7ELM00<000];O`03001?Odmo00Y?O`D000e3
G`03001GGUMN00aGGP03001K75/L008000IG?P03001G?ULn00=G?P03001O6elK00YO6`80009K7003
001oogoo009oo`03001oogoo03Moo`00BWoo0`0067oo0`0025LM00<005LMEad03ELM0`003d]o0P00
14mo1P000cmO0P003T=O00<005MNEeh02EMN1@0025Ln00<005LnEch00eLn00<005lKGa/025lK0P00
15/L00<007ooOol00Woo00<007ooOol0=goo0018Ool20002Ool00`00Oomoo`0DOol2000<Ead00`00
EaeG7@0:Ead20002Cil2000?Bgl5000;?el2000=@el00`00EeiGGP02Eeh60004?cl00`00EciG?P06
Ech00`00EciG?P04Ech00`00Ga]O6`05Ga/20007Fa`00`00Oomoo`02Ool00`00Oomoo`0fOol004Eo
o`<001Qoo`<000mG7@03001G7ELM00MG7@8000I?W`8000U;O`@00097G`8000hoG`8000M3G`T000/o
?`03001G?ULn00EG?P03001G?ULn00EG?P03001O6elK009O6`8000UK7003001oogoo00=oo`03001o
ogoo03Eoo`00@Woo0`0067oo0`000U;m00<005LMEad03ULM00<005LMEad00eLM0`002TnO0P000d]o
100024MO0P0033mO2@001S[o0P003Clo00<005LnEch015Ln00<005LnEch01ELn00<005lKGa/00P00
35/L00<007ooOol00Woo00<007ooOol0=Goo0010Ool2000HOol30006D_d00`00EaeG7@0>Ead00`00
EaeG7@02000>Cil4000>Ael20004?el60003B]d00`00>_ljo`0;>_l00`00?clo?`0;?cl00`00EciG
?P03Ech00`00EciG?P03Ech5000>Fa`00`00Oomoo`03Ool00`00Oomoo`0dOol003eoo`@001Ioo`<0
00YBo@03001G7ELM00eG7@<000e?W`<0009CG`8000m7G`D000Y:g@03000joc[o00/jo`8000`o?`03
001G?ULn009G?PH000A;7`03001K75/L00eK7003001oogoo009oo`8003Eoo`00>goo0P005goo0`00
3U;m0P002ULM0`000e>O0P0024nO0`001e=O0P002DMO10000U9j00<004[MB]d02d[M0P002c[o5000
2D/O00<005/LFa`03E/L00<007ooOol00goo00<007ooOol0<goo000hOol3000EOol40002D]`00`00
D_eBo@0>D_d00`00EaeG7@04Ead30008Dil20003Cil3000<Del20003Ael40006DWX00`00B]e:g@0=
B]d00`00>_ljo`02>_l60003A[d00`00=]lfg`0:=]l01000Bam;7`002T/O00<005/LFa`035/L0P00
1Goo00<007ooOol0<Woo000eOol3000DOol40007D]`00`00D_eBo@0>D_d00`00EaeG7@03000=Dil3
000@Del4000;DWX00`00B]e:g@0<B]d5000:A[d00`00=]lfg`0:=]l01000Bam;7`002T/O00<005/L
Fa`02E/L0P000ULM00<007ooOol00goo00<007ooOol0<Goo000cOol3000COol3000<D]`00`00D_eB
o@0=D_d3000>Dil20002Egl2000=Del200000e9I001BNP0=DWX00`00B]e:g@09B]d20002DUP00`00
A[e6_@0;A[d00`00=]lfg`0:=]l00`00Bal0000;Bal00`00FaaK7006Fa`20004Ead00`00Oomoo`03
Ool00`00Oomoo`0aOol0031oo`<0009oo`03001oogoo00eoo`@0009>_003001Bg5;L00]Bg003001B
oE;m00YBo@80009GO`8000]CW`8000IGO`03001CGe=O00QCG`8000ABF@03001BNU9j00aBNP03001:
gD[M00I:g@8000ABF0030016_DJm00a6_@03000fgcKO00Xfg`8000];7`03001K75/L00=K70<000MG
7@03001oogoo00=oo`03001oogoo031oo`00;Woo0P004Goo10001djl00<005;LD]`02e;L00<005;m
D_d01e;m0P001UMo0P001U>O0`002EMo00<005=ODel015=O0`001U9I00<0059jDWX0359j00<004[M
B]d00d[M0`001e9H00<004JmA[d034Jm00<003KO=]l02SKO00<004/OBal02T/O00<005/LFa`00P00
2eLM00<007ooOol00goo00<007ooOol0;goo000[Ool3000@Ool3000;C[`00`00D]aBg00<D]`00`00
D_eBo@03D_d3000:Egl20002Dil2000=Egl20002Del2000:DUT00`00DWYBNP0<DWX00`00B]e:g@02
000;DUP00`00A[e6_@0;A[dM000>Ead00`00Oomoo`02Ool00`00Oomoo`0_Ool002Uoo`8000moo`@0
009>_003001>_4jl00Y>_003001Bg5;L00aBg003001BoE;m008000iGO`<0011GO`<000aBF@03001B
NU9j00eBNP8000eBF0030016_DJm00U6_@80009FVP03000j_SZn00Pj_P03000j_P0000`ng`03001G
7ELM00aG7@03001oogoo009oo`80031oo`009Woo0`0000=oo`00Ool02Woo10001Tjl00<004jlC[`0
2djl00<005;LD]`02e;L0`003UMo0P000U^N0P0035Mo0`0000=BNP00DUT03E9I00<0059jDWX02U9j
0`003e9H00<004JmA[d01TJm0P001EJJ00<003Zn>[h01cZn00@003Zn>[h000/ng`03001G7ELM00eG
7@03001oogoo00=oo`03001oogoo02eoo`008goo0`003Goo0`002djl00<004jlC[`02djl00<005;L
D]`025;L0P000ULn0P002eMo0P001U^N0P0025Mo0P001E9j00<0059IDUT02e9I00<0059jDWX02E9j
00D005HFEQIF5P0000mBF0030016_DJm0096_@<000QFVP03000j_SZn00Dj_P80008j_P03000ngckO
00Xng`03001G7ELM00aG7@8000Aoo`03001oogoo02eoo`008Goo0P003Goo0`000U;L00<004jlC[`0
2Tjl00<004jlC[`02djl00<005;LD]`01E;L0P001ULn0P001eMo0P002U^N0P000eMo0`001e9j00<0
059IDUT0359I00<0059jDWX01U9j0P0015HF00<0059HDUP03E9H00<004JmA[d00P002eJJ00<003Zn
>[h00SZn0`000SZn00@003Zn>[h000`ng`03001G7ELM00QG7@<0009Bo@03001oogoo009oo`03001o
ogoo02aoo`007goo0P003Goo0P001E;L00<004jlC[`02Tjl00<004jlC[`02djl00<005;LD]`00e;L
0P002ULn0P000eMo0P003U^N0`002e9j00<0059IDUT02e9I00<0059jDWX01E9j00<005HFEQH01EHF
00<0059HDUP03E9H0P003UJJ10001CZn00D003Zn>[hj_P0000`ng`03001G7ELM00=G7@@000EBo@03
001oogoo00=oo`03001oogoo02]oo`007goo0P002Woo0`0025;L00<004jlC[`02Tjl00<004jlC[`0
2djl00<005;LD]`00P003ULn0`003U^N0P0000=Fo000DWX02e9j00<0059IDUT0359I00<0059jDWX0
0U9j0P0025HF00<0059HDUP0359H00<005if000035JJ10001cZn30001CkO00<005LMEad00`002U;m
00<007ooOol00Woo00<007ooOol0:goo000OOol00`00Ool00006Ool3000<D]`00`00C[a>_009C[`0
0`00C[a>_00;C[`3000?Ech200000enN0000000;Fih20004E_`00`00DWYBNP0:DWX00`00DUUBF@0;
DUT01@00DWYBNU9j00002eHF00<0059HDUP02U9H00@005ifGWH000YFVP8000AFVPL00092_@050012
_D:m@[d00005>[h8000=D_d00`00Oomoo`03Ool00`00Oomoo`0ZOol001moo`04001oogoo0003Ool2
0002Ead00`00D]aBg00:D]`00`00C[a>_00:C[`00`00C[a>_007C[`30002D_d00`00EciG?P0;Ech2
0005Gih20006Fih30006E_`00`00DWYBNP0:DWX00`00DUUBF@0<DUT3000<EQH00`00DUQBF009DUP0
0`00GWINMP02GWH00`00EYYFVP04EYX30005EYX00`00H_X00008@[d01000@[e2_@0033Zn00<005;m
D_d035;m00<007ooOol00goo00<007ooOol0:Goo000NOol20003Ool30005Ead00`00D]aBg00:D]`0
0`00C[a>_00:C[`00`00C[a>_003C[`30006D_d00`00EciG?P09Ech00`00GiiOWP07Gih20002Fih2
000:E_`00`00DWYBNP0:DWX00`00DUUBF@0;DUT00`00EQIF5P0<EQH00`00DUQBF008DUP00`00GWIN
MP03GWH01000EYYFVUJJ0`001UJJ0P000V;j00<004:m@[d01T:m00D004:m@[e2_@0000/j_P03001B
oE;m00eBo@04001oogooOol2000[Ool001ioo`04001oogooOol20008Ead00`00D]aBg00:D]`00`00
C[a>_009C[`00`00C[a>_003000:D_d20007Ech2000<Gih2000<E_`00`00DWYBNP0:DWX00`00DUUB
F@09DUT3000?EQH00`00DUQBF006DUP00`00GWINMP05GWH30008EYX00`00H_YRnP03H_X00`00@[e2
_@06@[d01@00@[e2_D:m00002cZn00<005;mD_d035;m00<007ooOol00goo00<007ooOol0:7oo000N
Ool01000Ool000002eLM00<005;LD]`02U;L00<004jlC[`01djl10003e;m00<005LnEch00ULn0P00
35nN0P0000=OO@00E_`035Kl00<0059jDWX02U9j00<0059IDUT01U9I0P000e7e00<005HFEQH035HF
00<0059HDUP01E9H00<005ifGWH00eif10002EJJ00<006;jH_X01F;j00<004:m@[d01T:m00D004:m
@[e2_@0000Xj_P03001BoE;m00aBo@8000Aoo`03001oogoo00Aoo`D0009oo`03001oogoo01Yoo`00
7Woo0P003ULM00<005;LD]`02E;L00@004jlC[a>_0H000=>_003001BoE;m00iBo@04001G?P00000<
Gih20004Ggd00`00E_aFo00:E_`00`00DWYBNP0:DWX00`00DUUBF@04DUT20005DOD00`00EQIF5P0=
EQH00`00DUQBF004DUP00`00GWINMP030004GWH00`00EYYFVP04EYX20009H_X00`00@[e2_@06@[d0
1000@[e2_@002cZn00<005;mD_d025;m0`000U;m00<007ooOol00Woo00<007ooOol01Goo00L007oo
Oomoo`00Ool0000KOol001ioo`8000mG7@03001Bg5;L00MBg0D000Y>_003001BoE;m00iBo@8000]O
WP8000MOO@03001Fo5Kl00YFo003001BNU9j00YBNP04001BFE9IDUT20007DOD00`00EQIF5P0=EQH0
0`00DUQBF003DUP40007GWH00`00EYYFVP03EYX00`00H_YRnP09H_X00`00@[e2_@06@[d01@00@[e2
_D:m00002cZn00<005;mD_d00e;m10001E;m00<007ooOol00goo00<007ooOol017oo00L007ooOomo
o`00Ool0000KOol001ioo`03001oo`0000mG7@04001Bg5;LD]`50003B[`00`00C[a>_00:C[`00`00
D_eBo@0;D_d20002Ged20007Gih20009Ggd00`00E_aFo00:E_`00`00DWYBNP0:DWX01000DUT00000
2U7e00<005HFEQH03EHF00<0059HDUP00`002eif00D005JJEYYFVP0000eRnP030012_D:m00E2_@/0
00Dj_P03001BoE;m00<000YBo@03001oogoo009oo`03001oogoo00Aoo`07001oogooOol007oo0000
6goo000HOol00`00Oomoo`02Ool01@00Oomoogoo00003ULM10002DZl00<004jlC[`02Tjl00<005;m
D_d025;m0P001UmM0`000UnN0P0035mm00<005KlE_`02UKl00<0059jDWX0259j0`00357e00<005HF
EQH03EHF10003Eif00@005JJ000000mRnPL00096g@050016gDKMA]d00004>Yd8000=D_d00`00Oomo
o`03Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0001]oo`005goo00<007oo00000goo0P000goo
0P002ELM0`000U;M00<004ZlB[`024Zl00<004jlC[`02djl00<005;mD_d01E;m0P002emM0P003emm
00<005KlE_`02EKl00<0059jDWX00U9j1P000TWf00<0057eDOD02U7e00<005HFEQH02eHF0P0000=F
5P0000003eif00<006;jH_X03V;j00<006]k00001dKM00D004KMA]e6g@0000/jW@03001BoE;m00aB
o@03001oogoo00=oo`04001oogooOol20004Ool00`00Oomoo`0JOol001Moo`03001oo`0000=oo`03
001oogoo00Aoo`03001G7ELM00AG7@8000EBg@03001:_4Zl00U:_003001>_4jl00]>_003001BoE;m
009Bo@8000aOG@800003Igd0000000iOO@03001Fo5Kl00AFo0T000Q9mP03001AmE7e00YAm@03001F
5UHF00QF5P<000=F5P03001NMUif00eNMP03001ZeP0000iRnP04001[Nf]k0008A]d01@00A]e6gDKM
00002cZM00<005;mD_d035;m00<007ooOol00`009Woo000GOol00`00Ool00003Ool00`00Oomoo`05
Ool00`00EaeG7@030008D]d00`00B[a:_009B[`00`00C[a>_00;C[`01000D_d000003EmM00<006Mm
Igd00fMm0P002emm20001DHI00<004WfBOH02TWf00<0057eDOD02U7e00<005HFEQH015HF0`001EHF
0P003eif00<006[F000036;j0P0016]k00<004KMA]d01TKM00@004KMA]d000`jW@03001BoE;m00]B
o@03001oogoo00=oo`03001oogoo02=oo`005goo00<007oo00000goo00<007ooOol01Woo0P0035;M
00<004ZlB[`02DZl00<004jlC[`02Tjl0P003UmM00<006MmIgd01VMm0P000emm1P000TkL00<004HI
AQT02DHI00<004WfBOH02DWf00<0057eDOD02U7e00@005HFEQIF5P<000MF5P04001J=EXe000=GWH0
1@00J]IZeV[F00002V;j00<006]kJg/01F]k00<004KMA]d01TKM00@004KMA]d000/jW@03001BoE;m
00]Bo@8000Eoo`03001oogoo029oo`0067oo00<007ooOol00Woo0P0027oo00<005;MD]d02U;M00<0
04ZlB[`02TZl00<004jlC[`01Tjl0`000UKm0P002UmM0P002fMm0`002DkL00<004HIAQT024HI00<0
04WfBOH02DWf00<0057eDOD02U7e10002UHF00@005XeFSD000eNMP03001ZeV[F009ZeP03001RnV;j
00IRnP03001[Nf]k00M[N`030016gDKM00E6g@050016gDKMA]d0000;>Yd00`00D_eBo@06D_d40002
D]`00`00Oomoo`02Ool00`00Oomoo`0ROol001aoo`8000Yoo`03001BgE;M00YBg@03001:_4Zl00U:
_003001>_4jl00A>_08000MFo@03001OGEmM00IOG@03001WOFMm00UWO@800003Hed004kL00U>g003
00166DHI00Q66@030019mTWf00U9mP03001AmE7e00QAm@@000]F5P05001J=EXeFSD0000<GWH00`00
J]IZeP03J]H00`00H_YRnP05H_X00`00Jg][N`08Jg/00`00A]e6g@06A]d01000A]e6g@0033ZM00@0
05;mD_eBo@@000IBg003001oogoo00=oo`03001oogoo025oo`0077oo00<007ooOol02Woo00<005;M
D]d02U;M00<004ZlB[`02DZl00<004jlC[`00`002UKm0P001EmM00<006MmIgd02FMm00<006=MHed0
0V=M00<004kLC]`024kL00<004HIAQT01dHI00<004WfBOH02TWf00<0057eDOD0157e0`000e7e00<0
05HFEQH025HF00<005XeFSD00eXe00<005ifGWH02Eif00<006[FJ]H016[F00<006;jH_X00f;j00<0
06]kJg/02V]k70002e;L00<007ooOol00goo00<007ooOol087oo000LOol00`00Oomoo`0;Ool00`00
D]eBg@0:D]d00`00B[a:_007B[`4000?E_d200000emM0000000:Igd20005Hed00`00C]a>g008C]`0
0`00AQU66@08AQT00`00BOI9mP09BOH01000DOEAmE7e0`001U7e00<005HFEQH01eHF00<005XeFSD0
15Xe00<005ifGWH025if00<006[FJ]H01V[F00<006;jH_X00P0036]k00<006^L00001d:m00D004:m
@[e2_@0000`nO003001Bg5;L00]Bg003001oogoo009oo`80025oo`0077oo0P003Goo00<005;MD]d0
2E;M00@004ZlB[a:_0H000=:_003001FoEKm00mFo@8000UWO@8000QSG@03001>g4kL00Q>g0030016
6DHI00M66@030019mTWf00U9mP@000YAm@03001F5UHF00EF5P03001J=EXe00EJ=@03001NMUif00QN
MP03001ZeV[F00IZeP03001RnP0000a[N`80009[W0030012_D:m00I2_@040012_D:m000<?W`00`00
D]aBg00<D]`01000Oomoogoo0P008Goo000LOol00`00Oomoo`0=Ool00`00D]eBg@07D]d5000:B[`0
0`00E_eFo@0<E_d20002Gc`20006Igd00`00HeeSG@09Hed00`00C]a>g007C]`00`00AQU66@07AQT0
0`00BOI9mP08BOH2000=DOD00`00EQIF5P05EQH00`00FSEJ=@06FSD00`00GWINMP06GWH00`00J]IZ
eP08J]H00`00Jg][N`0:Jg/00`00Jia[W003Ji`00`00@[e2_@06@[d01000@[e2_@0033il00<005;L
D]`02e;L00<007ooOol00goo00<007ooOol07Woo000LOol00`00Oomoo`0>Ool01000D]eBgE;M1@00
0dZm00<004ZlB[`02TZl00<005KmE_d02EKm0P001Ull0P000VMm0P003F=M00<004kLC]`01dkL00<0
04HIAQT01THI00<004WfBOH01DWf0`000TWf00<0057eDOD02U7e00<005HFEQH015HF00<005XeFSD0
1eXe00<005ifGWH01Eif00<006[FJ]H02F[F0P002V]k00<006^LJi`016^L00<004:m@[d01d:m00@0
04:m@[d000/nO003001Bg5;L00]Bg08000Aoo`03001oogoo01ioo`006goo00<007ooOol047oo0`00
2DZm00<004ZlB[`02TZl0P001eKm0P002Ull0P003f=M00<004kLC]`01dkL00<004HIAQT01dHI00@0
04WfBOI9mP<000E9mP03001AmE7e00YAm@03001F5UHF00=F5P03001J=EXe00QJ=@03001NMUif00EN
MP03001ZeV[F00QZeP04001kUW^F0008Jg/00`00Jia[W006Ji`00`00@[e2_@06@[d01@00@[e2_D:m
00002cil00<005;LD]`01e;L0`000UKl00<007ooOol00Woo00<007ooOol07Goo000KOol2000BOol0
0`00B[e:_@09B[d00`00B[a:_00;B[`00`00E_eFo@02E_d2000;Gc`200000fML0000000>Hed00`00
C]a>g007C]`00`00AQU66@06AQT40008BOH00`00DOEAm@0;DOD01@00EQIF5UHF00002eXe00<005if
GWH015if00<006[FJ]H02F[F00D007^FNiIkUP0000I[N`03001[W6^L00Q[W0030012_D:m00I2_@04
0012_D:m000<?W`00`00D]aBg003D]`30006E_`00`00Oomoo`02Ool00`00Oomoo`0LOol001]oo`03
001oogoo019oo`03001:_DZm00U:_@03001:_4Zl00]:_004001Fo@00000<Gc`00`00IeaWG003Ie`0
0`00HeeSG@0;Hed30007C]`00`00AQU66@04AQT3000;BOH00`00DOEAm@0;DOD01000EQIF5P003EXe
00<005ifGWH00eif00<006[FJ]H026[F00<007^FNiH00g^F00@006]kJg][N`8000][W0030012_D:m
00M2_@040012_D:m000;?W`00`00D]aBg0030009E_`00`00Oomoo`02Ool00`00Oomoo`0LOol001]o
o`03001oogoo01=oo`03001:_DZm00Q:_@03001:_4Zl00]:_08000eO?003001WG6ML00EWG003001S
GF=M00ISG@@0009C7@@000E>g00300166DHI00<000966@030019mTWf00U9mP03001AmE7e00]Am@04
001F5UHF000=FSD00`00GWINMP02GWH00`00J]IZeP09J]H00`00NiIkUP04NiH00`00Jg/0000=Ji`L
000=E_`00`00Oomoo`02Ool00`00Oomoo`0KOol001]oo`03001oogoo01Aoo`03001:_DZm00Q:_@03
001:_4Zl00M:_0<0009Bo08000UO?08000UWG080009SG@@000IC7@04000UfbGK9M/20003C]`30006
AQT00`00BOI9mP09BOH00`00DOEAm@0;DOD2000>FSD00`00GWINMP02GWH00`00J]IZeP08J]H00`00
NiIkUP06NiH00`00Jia[W009Ji`30002Ecd00`00@Wa2O006@W`01000@Wa2O00034Il00<005KlE_`0
35Kl00H007ooOol007oo000LOol001]oo`8001Ioo`03001:_DZm00Q:_@03001:_4Zl00A:_08000MB
o003001O?5ll00EO?003001WG6ML00]WG08000]C7@03000UfbGK008Uf`<00003C]`004HI00I66@03
0019mTWf00U9mP03001AmE7e00]Am@03001J=EXe00iJ=@04001NMUif000;J]H00`00NiIkUP05NiH0
1000Lm@000001f^L0P001ELm00<0049l@W`01d9l00@0049l@W`000]6O003001Fo5Kl00eFo005001o
ogooOol0000LOol001Yoo`8001Qoo`03001:_DZm00Q:_@03001:_4Zl00<000YBo003001O?5ll00=O
?003001WG6ML00YWG0800003Ic/005<M00YC7@03000Uf`00008000<Uf`8000M66@030019mTWf00U9
mP03001AmE7e00YAm@80011J=@04001NMUif000:J]H00`00NiIkUP06NiH01000LmAce7?D0P000V^L
0`0025Lm00<0049l@W`01d9l00<0049l000034Il00<005KlE_`02UKl0P0000=K?@00Ool00Woo00<0
07ooOol06Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0HOol00`00B[e:_@04B[d6000>D_`200000ell0000000<Ie`00`00Ic]W>`02Ic/0
0`00DaeC7@08Dad200079M/30005AQT00`00BOI9mP09BOH00`00DOEAm@08DOD200000e8E001J=@0?
FSD00`00GWH0000;J]H00`00NiIkUP05NiH00`00LmAce004Lm@2000<Ecd00`00@Wa2O006@W`01000
@Wa2O0002dIl00<005KlE_`025Kl0P000e/m00<007ooOol00Woo00<007ooOol067oo0005Ool00`00
Ool00007Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0IOol60005A[d00`00D_aBo00>
D_`00`00IeaWG00;Ie`00`00Ic]W>`04Ic/20005Dad30002Dad00`009M/Uf`059M/00`00:GL00005
AQT00`00BOI9mP09BOH00`00DOEAm@06DOD00`00DQEB5@02DQD00`00FSEJ=@0>FSD2000:J]H00`00
NiIkUP06NiH00`00LmAce003Lm@00`00JoT0000<Ecd00`00@Wa2O007@W`00`00@W`0000<AW`00`00
E_aFo005E_`20006Fcd01@00Oomoogoo00006Woo0005Ool00`00Ool00007Ool00`00Ool00004Ool0
1000Oomoogoo0P006goo00<004JmA[d024Jm00<005;lD_`02e;l0P0000=O700000002FML0P002FLk
00<005<M00000P001E<M00<002GK9M/01BGK00@002Ug:GL000A66@030019mTWf00U9mP03001AmE7e
00EAm@03001B5E8E00=B5@03001J=EXe00iJ=@03001ZeV[F00UZeP03001kUW^F00EkUP03001ce7?D
00=ce005001[nF_iJoT0000<Ecd00`00@Wa2O007@W`00`00@W`0000<AW`00`00E_aFo002E_`20009
Fcd01@00Oomoogoo00006Goo0005Ool00`00Ool00007Ool00`00Ool00002Ool20004Ool00`00Oomo
o`0KOol00`00A[e6_@08A[d00`00D_aBo008D_`20005Ga`00`00IeaWG005Ie`00`00Ic]W>`08Ic/3
0009Dad00`009M/Uf`049M/01000:GLYMbUg0P000THI00<004WfBOH02DWf00<0057eDOD00e7e0P00
1U8E00<005XeFSD03EXe0P002V[F00<007^FNiH01W^F00<007?DLm@00W?D00<006_iJoT00V_i00<0
05LmEcd02eLm00<0049l@W`01d9l0P0034Il00<005KlE_`00P002e/m00@007ooOomoo`8001Qoo`00
1Goo00<007oo00001goo00<007oo00000Woo00<007ooOol00goo00<007ooOol077oo00<004JmA[d0
24Jm00<005;lD_`01E;l0P0025lL00<006MLIe`00fML00<006LkIc/01VLk0`000fLk1@0015<M00<0
02GK9M/01BGK00<002Ug:GL00RUg00<004HI00002dWf00<0057eDOD00U7e00<0058EDQD01U8E00<0
05XeFSD03EXe00<006Ze00002F[F00<007^FNiH01G^F00<007?DLm@00W?D00<006_iJoT016_i00<0
05LmEcd02ULm00<0049l@W`01d9l00<0049l00002TIl10003U/m00D007ooOomoo`0001Qoo`001Woo
00<007ooOol01goo00@007ooOomoo`<0009oo`03001oogoo01eoo`030016_DJm00U6_@03001Bo5;l
009Bo08000]O70800003Ie`0000000IW>`<000AW>`800003Ha/003:N008bWPH000HUf`03000YMbUg
00<YM`<000]9mP04001AmE7e000:DQD00`00FSEJ=@0;FSD01000J[EZ]@0026[F00<007^FNiH01G^F
00<007?DLm@00W?D00<006_iJoT01V_i00<005LmEcd01ELm2`00149l0P0014Il1P000djl00<005/m
Fcd02U/m0P0000=OG@00Ool00Woo00<007ooOol05Goo000IOol2000OOol00`00A[e6_@09A[d01000
D_`000003elL00<006LkIc/00fLk0`001VLk00<006<KHa/00V<K00<003:N<Yh01S:N00<002GK9M/0
0bGK00<002Ug:GL01BUg1P001TWf0`002e8E00<005XeFSD02eXe00D006ZeJ[EZ]@0000MZeP03001k
UW^F00EkUP05001ce7?DLm@00009JoT80005BW/00`00@U]2F`03@U/:000:C[`00`00FceK?@07Fcd2
0004Ged01000Oomoo`005goo000IOol00`00Oomoo`0OOol00`00A[e6_@07A[d3000?Ga`200000f<K
000000030007Ic/20006Ha/00`00<YhbWP06<Yh00`009M/Uf`039M/00`00:GLYM`04:GL00`00@KI1
]P03@KH7000=DQD00`00FSEJ=@0:FSD00`00J[EZ]@02J[D00`00J]IZeP04J]H00`00NiIkUP05NiH0
0`00LmAce002Lm@00`00JoU[n@04JoT30002Fad00`00BW]:N`09BW/00`00@U]2F`08@U/2000<C[`0
0`00FceK?@05Fcd20006Ged01@00Oomoogoo00005Woo000IOol00`00Oomoo`0POol01000A[e6_DJm
1@000dkM00<005lLGa`02elL00<006<KHa/010001fLk0P002F<K00<003:N<Yh01C:N0P0012GK00<0
02Ug:GL01BUg00<0046f@KH0246f00<0058EDQD02e8E00<005XeFSD02UXe00<006ZeJ[D00fZe00<0
06[FJ]H00f[F00<007^FNiH01G^F00D007?DLmAce00000E[n@8000EK7@03001:NdYk00U:N`030012
Fd9K00Q2F`8000e>_003001K?E/m009K?@8000UOG@05001oogooOol0000EOol001Uoo`03001oogoo
025oo`<000U>g@03001O75lL00UO7004001S6`000004Ha/00`00Ic]W>`03Ic/00`00Ha]S6`0:Ha/0
0`00<YhbWP05<Yh200039M/00`00:GLYM`05:GL00`00@KI1]P08@KH00`00DQEB5@0<DQD00`00FSEJ
=@08FSD00`00J[EZ]@04J[D00`00J]IZeP02J]H00`00NiIkUP05NiH01@00LmAce7?D00000f_i0`00
25/M00<004YkBW/02DYk00<0049K@U/0249K0P003Djl00@005/m000000aOG@04001oogoo000EOol0
01Uoo`03001oogoo029oo`03001>gDkM00U>g@03001O75lL00IO70@000MS6`800003Ic/0000000iS
6`03000bWS:N00DbWP8000<Uf`03000YMbUg00@YM`030011]T6f00U1]P03001B5E8E00]B5@03001J
=EXe00QJ=@03001Z]FZe00EZ]@05001ZeV[FJ]H00006NiH01P00LmAce7?D001[n@<000]K7@03001:
NdYk00U:N`030012Fd9K00U2F`03001>_4jl00]>_08000aOG@800003Ged007oo008001Aoo`0067oo
0`0097oo00<004kMC]d02DkM00<005lLGa`00elL0`0036<K00<006<KHa/03f<K0P001S:N00D002GK
9M/Uf`0000HYM`030011]T6f00U1]P03001B5E8E00]B5@03001J=EXe00MJ=@03001Z]FZe00IZ]@04
001ZeV[F0007NiH00`00LmAce00400000f?M001K7@0;Fad00`00BW]:N`09BW/00`00@U]2F`08@U/2
0009C[`30002Ead00`00GeeOG@07Ged20004Ged01000Oomoo`004goo000HOol00`00Oomoo`0UOol0
0`00C]e>g@09C]d00`00Ga`00003000=Ha/00`00IaX0000>Ha/200000ekk000000020003<Yh20002
9M/00`00:GLYM`05:GL00`00@KI1]P08@KH00`00DQEB5@0;DQD00`00FSEJ=@07FSD00`00J[EZ]@07
J[D00`00J]H00006NiH00`00LmAce0030004Hmd00`00FaeK7@09Fad00`00BW]:N`09BW/00`00@U]2
F`09@U/20005C[`30006Ead00`00GeeOG@04Ged20006Ged01000Oomoo`001Woo1@000Woo00<007oo
Ool00goo000HOol00`00Oomoo`0UOol00`00C]e>g@08C]d300000elL0000000=Ha/01@00IaYW6VLJ
00002f<K0P0015kk00<001hm7Sd01P000RGK00<002Ug:GL012Ug00<0046f@KH0246f00<0058EDQD0
2e8E00<005XeFSD01UXe00<006ZeJ[D026Ze0P001g^F00<007?D00000P001F?M00<005/MFad02U/M
00<004YkBW/02DYk00<0049K@U/02D9K00<004jlC[`00`002ELM00<005mMGed00UmM0P002EmM00@0
07ooOol000Moo`07001oogooOol007oo000017oo000HOol00`00Oomoo`0VOol00`00C]e>g@04C]d3
0002C]d2000>Ha/00`00IaYW6P03IaX20007Ha/20007G_/00`007SdN?@037Sd300000bGK000YM`05
:GL00`00@KI1]P08@KH00`00DQEB5@0<DQD00`00FSEJ=@04FSD00`00J[EZ]@0:J[D20005NiH40008
Hmd00`00FaeK7@09Fad00`00BW]:N`09BW/00`00@U]2F`05@U/7000=Ead01000Ged0000035mM00@0
07ooOol000Ioo`03001oogoo00=oo`03001oogoo009oo`0067oo0P00:7oo00<004kMC]d00`000TkM
0`000U;m00<006<KHa/02V<K00<006LJIaX01VLJ00<006<KHa/00V<K0P002Ukk00<001hm7Sd011hm
0`001bUg00<0046f@KH0246f00<0058EDQD02e8E00<005XeFSD015Xe00<006ZeJ[D02VZe00<007ne
00000P000W^F0`002V?M00<005/MFad015/M60001DZK0P003ELM0P003UmM0P0000=oo`00Ool01Goo
00@007ooOomoo`8000Eoo`0067oo00<007ooOol09goo0`0000=>g@0000000P001U;m0P0026<K0P00
2VLJ00@006<K000000eNn`03000N?Ahm00<N?@0400004P000006:GL00`00@KI1]P08@KH00`00DQEB
5@0;DQD00`00FSEJ=@03FSD00`00J[EZ]@0:J[D00`00OkEo]@03OkD4000;Hmd70006BWX00`00AUY6
FP09AUX00`00BY]:V`09BY/2000:Ead20002Ged00`00GeeOG@09Ged20002Fcd30005Ool01@00Oomo
ogoo00001Woo000GOol00`00Oomoo`0UOol30002Ool2000<D_d00`00Ha]S6`04Ha/00`00IaYW6P0;
IaX00`00G_]Nn`0>G_/300037Sd00`0001800006:GL00`00@KI1]P08@KH00`00DQEB5@0;DQD00`00
FSEJ=@03FSD00`00J[EZ]@0:J[D00`00OkEo]@03OkD30008Hmd40002DYX00`00BWY:NP08BWX00`00
AUY6FP09AUX00`00BY]:V`0:BY/00`00EaeG7@06Ead20005Ged00`00GeeOG@06Ged20004Fcd30004
Ool20003Ool30004Ool001Moo`03001oogoo02=oo`8000Ioo`03001BoE;m00]Bo@03001S6f<K009S
6`03001W6VLJ00]W6P03001S6P0000eNn`800003G_X003Im00L000DYM`030011]T6f00Q1]P03001B
5E8E00aB5@05001J=EXeFSD0000<J[D00`00OkEo]@04OkD40003Hmd40006DYX00`00BWY:NP09BWX0
0`00AUY6FP09AUX00`00BY]:V`09BY/20005Ead20007Ged00`00GeeOG@03Ged30007Fcd2000@Ool0
01Moo`<0021oo`<000Uoo`03001BoE;m00]Bo@800003Ha/006LJ00]W6P8000=S6P03001Nnekk00UN
n`03001NnUkj009NnP03000fOCIm008fO@0400004P000005:GL00`00@KI1]P07@KH00`00DQEB5@0<
DQD01@00FSEJ=EXe000036Ze00<007neOkD00gne0P000d_L0`002e:J00<004YjBWX024Yj00<004IJ
AUX02DIJ00<004ZKBY/02TZK0P000ULM0P002UmM00<005mMGed00P002U/m0P0047oo000GOol00`00
Oomoo`0MOol3000=Ool00`00D_eBo@0;D_d2000<IaX00`00HaYS6P04HaX00`00G_]Nn`06G_/20006
G_X00`00=WdfO@02=Wd30005:GL00`00@KI1]P08@KH00`00DQEB5@0;DQD01000FSEJ=@0036Ze00<0
07neOkD017ne1@000UJj00<005:JDYX02E:J00<004YjBWX02DYj00<004IJAUX02DIJ00<004ZKBY/0
2TZK0`0035mM0`003E/m0P003goo0007Ool00`00Oomoo`02Ool00`00Oomoo`050003Ool00`00Oomo
o`0JOol3000AOol00`00D_eBo@07D_d30002E_`00`00IaYW6P08IaX00`00HaYS6P05HaX00`00G_]N
n`04G_/20008G_X00`00=WdfO@03=Wd30004:GL00`00@KI1]P08@KH00`00DQEB5@0;DQD01000FSEJ
=@0036Ze00<007neOkD00gne0`001EJj00<005:JDYX02U:J00<004YjBWX024Yj00<004IJAUX02DIJ
00<004ZKBY/01dZK0`0000=G7@0000002UmM0P000Umn00<005/mFcd02e/m0P003goo0006Ool00`00
Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`0GOol3000EOol00`00D_eBo@04D_d20006E_`00`00
IaYW6P06IaX00`00HaYS6P07HaX00`00G_]Nn`02G_/00`00G_YNnP09G_X00`00=WdfO@02=Wd20000
0`0B000YM`02:GL00`00@KI1]P08@KH00`00DQEB5@0<DQD2000<J[D00`00OkEo]@04OkD00`00E[YF
^P06E[X00`00DYYBVP09DYX00`00BWY:NP09BWX00`00AUY6FP09AUX00`00BY]:V`03BY/30004Ead0
0`00Ead00007Ged20005Ggh00`00FceK?@0:Fcd2000?Ool000Ioo`03001oo`0000Qoo`03001oogoo
009oo`03001oo`0001Eoo`<001Uoo`03001BoE;m00<000UFo003001W6VLJ00AW6P03001S6V<J00US
6P04001Nn`00000=G_X00`00=WdfO@0400000`0B000YM`02:GL00`00@KI1]P07@KH00`00DQEB5@0<
DQD2000<J[D00`00OkEo]@03OkD00`00E[YF^P07E[X00`00DYYBVP0:DYX00`00BWY:NP08BWX00`00
AUY6FP09AUX00`00BY]:V`030008Ead20005Ged20008Ggh00`00FceK?@05Fcd400000goo001oo`0>
Ool000Ioo`03001oo`0000Qoo`03001oogoo009oo`8001=oo`<001eoo`8000eFo004001W6VLJIaX2
000=HaX00`00G_YNnP0>G_X20003D[/00`0001800003:GL00`00@KI1]P08@KH00`00DQEB5@0;DQD0
0`00J[EZ]@0;J[D00`00OkEo]@03OkD00`00E[YF^P08E[X00`00DYYBVP09DYX00`00BWY:NP09BWX0
0`00AUY6FP07AUX4000<Ead20002Ged2000;Ggh00`00FceK?@040005Ool00`00Oomoo`0=Ool000Io
o`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00moo`<0025oo`03001Fo5Kl00aFo003001W
6P0000iS6P03001RnP0000iNnP03001Rf@0000=B^`800005018002Ug:GL0000:@KH00`00DQEB5@0:
DQD2000<J[D00`00OkEo]@03OkD00`00E[YF^P0:E[X00`00DYYBVP09DYX00`00BWY:NP08BWX01000
AUY6FTIJ1P000djl00<005LMEad02eLM0`003Emn0`002Goo00<007ooOol03Goo0007Ool00`00Oomo
o`06Ool20004Ool00`00Oomoo`0<Ool3000UOol00`00E_aFo00;E_`2000=HaX20003H_X00`00G_YN
nP09G_X20002H]T00`00D[]B^`02D[/0100001804P000RUg00<0046f@KH01d6f00<0058EDQD02E8E
00@005igGWL000]Z]@03001o]Gne00=o]@03001F^UJj00YF^P03001BVU:J00UBVP03001:NTYj00A:
NPP000Y>_003001G7ELM00QG7@<00003Fgh005mn00UOOP<000aoo`03001oogoo00eoo`005Woo0P00
2goo0P00:Goo0P002EKl0P000U/L00<006<JHaX02F<J00<006;jH_X016;j00<005kjG_X01ekj00<0
06;IH]T00f;I00<005:kD[/00U:k00H0000B018002Ug0009@KH00`00DQEB5@08DQD01@00GWMNMeig
00002VZe00<007neOkD00gne00<005:J000035Jj00<005:JDYX01e:J20001Tij00<004jlC[`02Djl
00<005LMEad01ULM0P000e]n00<005]n00001Umn0`0047oo00<007ooOol037oo000FOol00`00Oomo
o`07Ool3000]Ool00`00E_aFo003E_`30005Fa`00`00HaYS6P07HaX00`00H_YRnP05H_X00`00G_YN
nP06G_X00`00H]URf@05H]T01@00D[]B^e:k00000`0B0P002D6f00<0058EDQD01e8E00<005igGWL0
0eig00<006ZeJ[D01fZe00<007neOkD00gne00<005:J000035Jj00@005:JDYYBVPH0009>NP03001>
NTij00U>NP03001>_4jl00Y>_003001G7ELM00=G7@8000IKOP03001KOP00009OOP<001=oo`03001o
ogoo00aoo`005Goo00<007ooOol01Goo0`00<Goo00<005KlE_`00P002E/L0P001V<J00<006;jH_X0
1f;j00<005kjG_X015kj00<006;IH]T01V;I00<005:kD[/00U:k00<0000B01800P002T6f00<0058E
DQD01E8E00<005igGWL015ig00<006ZeJ[D01VZe00<007neOkD00gne00D005:JDYYBVP0000]F^P@0
00U>NP03001>NTij00U>NP03001>_4jl00Y>_003001G7ELM008000QKOP03001KOP00008001Ioo`03
001oogoo00aoo`005Goo00<007ooOol00Woo0`00=Goo0P003E/L00@006<JHaYS6P8000]RnP04001N
nUkjG_X2000:H]T00`00D[]B^`02D[/00`0001804P020009@KH00`00DQEB5@04DQD00`00GWMNM`06
GWL00`00J[EZ]@05J[D00`00OkEo]@03OkD00`00DYYBVP02DYX00`00E[YF^P04E[X400000e9i001>
NP0:CWX00`00CWY>NP09CWX00`00C[a>_00:C[`3000:Fgh2000IOol00`00Oomoo`0<Ool001Eoo`03
001oo`00008003Uoo`03001K75/L00aK7003001S6P0000iRnP03001NnP0000eRf@05001B^e:kD[/0
000301820008@KH00`00DQEB5@03DQD00`00GWMNM`07GWL00`00J[EZ]@05J[D00`00OkEo]@02OkD0
0`00DYYBVP03DYX00`00E[YF^P040006DWT00`00CWY>NP09CWX00`00CWY>NP09CWX00`00C[a>_006
C[`30002Ech00`00FgiKOP06Fgh20002Ool00`00Oomoo`0FOol00`00Oomoo`0<Ool001Eoo`8003eo
o`03001K75/L00]K7080011RnP03001RfF;I00aRf@06001B^`00001J^@000P0B00@0037I000000I1
]P03001B5E8E009B5@03001NMeig00UNM`03001Z]FZe00=Z]@03001o]Gne00=o]@03001BVU:J00=B
VP<000YBN@03001>NTij00U>NP03001>NTij00Y>NP03001>_4jl00=>_08000IG?P03001KOU]n00=K
OP8000Eoo`03001oogoo01Eoo`03001oogoo00aoo`005Woo00<007ooOol0?7oo0P002E/L0P000ULM
00<006;jH_X02f;j0P0000=S6`00H]T03F;I00<005ZiF[T00UZi00@0000B0180008af@8000A1]P05
001B5E8EDQD0000<GWL00`00J[EZ]@03J[D00`00OkEo]@02OkD00`00DYYBVP0400000eJI001BN@0;
DWT00`00CWY>NP09CWX00`00CWY>NP09CWX00`00C[a>_0030009Ech00`00FgiKOP020007Ool00`00
Oomoo`0EOol00`00Oomoo`0<Ool001Moo`8003ioo`03001K75/L00=K70<000EG7@03001RnV;j00UR
nP05001S6f<KHa/0000<H]T200000f;j001J^@02F[T0100001804P00137I0P000d6f00<0058E0000
3Uig00D006ZeJ[EZ]@0000Eo]@<000IFV@03001BNE9i00UBN@03001>NTij00U>NP03001>NTij00U>
NP<000aG?P<000Yoo`03001oogoo01Aoo`03001oogoo00aoo`006Goo00<007ooOol0?7oo00<005/L
Fa`00P002ELM00<006;jH_X01V;j0P001F<K00<006;IH]T026;I00D006;jH_YRnP0000AJ^@040000
4P0B0005<MT200000d6f0000000?GWL01@00J[EZ]FZe000017ne00<005JIEYT01eJI00<0059iDWT0
2U9i00<004ijCWX02Dij00<004ijCWX014ij10000U<M00<005LnEch01eLn0`003Woo00<007ooOol0
57oo00<007ooOol02goo000JOol00`00Oomoo`0lOol2000;Ead00`00H_YRnP04H_X20008Ha/00`00
H]URf@06H]T00`00H_YRnP03H_X00`00F[UJ^@02F[T00`0001800007<MT2000AGWL00`00J[D00005
OkD00`00EYUFV@08EYT00`00DWUBN@09DWT00`00CWY>NP09CWX00`00CWY>NP040007Dad00`00EciG
?P04Ech2000AOol00`00Oomoo`0DOol00`00Oomoo`0;Ool001]oo`03001oogoo03aoo`03001G7ELM
00YG7@03001RnV;j009RnP03001S6f<K00US6`03001RfF;I00=Rf@8000MRnP07001J^EZiF[T0000B
0000237I00<005igGWL03eig00<006Ze00000gne0P002eJI00<0059iDWT02U9i00<004ijCWX01dij
100035<M00<005LnEch00`0057oo00<007ooOol04goo00<007ooOol02goo000LOol2000mOol00`00
EaeG7@0:Ead01000H_X0000036<K00<006;IH]T00V;I00<006;jH_X01f;j00<005ZiF[T00UZi00<0
000B0000237I00<005igGWL03eig00<007ne00000`0000=J^P00EYT02UJI00<0059iDWT02E9i00@0
04ijCWY>NPH000=Bg003001C7E<M00YC7@<001Qoo`03001oogoo019oo`03001oogoo00]oo`007Woo
00<007ooOol0>goo00<005LMEad02ELM0P003f<K00@006;I000000]RnP07001J^EZiF[T0000B0000
237I00<005igGWL03eig0P000VOg00@005ZjF[X000]FV@03001BNE9i00UBN@@000YBg003001C7E<M
00MC7@8001aoo`03001oogoo015oo`03001oogoo00]oo`007goo00<007ooOol0>goo00<005LMEad0
1ELM0`000U<N00<006<KHa/03F<K00<006;jH_X036;j00L005ZiF[UJ^@0001800008<MT00`00GWMN
M`0=GWL01@00IoMWmfOg000015Zj00<005JIEYT02EJI00<0059iDWT0159i10000U;L00<005;LD]`0
2U;L00<005<MDad00e<M0`007Woo00<007ooOol04Goo00<007ooOol02goo000POol00`00Oomoo`0k
Ool00`00EaeG7@040006Dah00`00Ha]S6`0:Ha/200000elL001RnP0<H_X01@00F[T00000G]X00P00
237I00<005igGWL035ig00D006OgIoMWm`0000EJ^P03001FVEJI00UFV@03001BNE9i00@000IBg003
001Bg5;L00]Bg003001C7E<M0080029oo`03001oogoo011oo`03001oogoo00]oo`008Goo0P00?7oo
0P002e<N0P0026<K0P0015lL00<006;jH_X02f;j00@005kJG]YNfP8000Taf@03001NMeig00YNM`05
001WmfOgIoL00007F[X00`00EYUFV@08EYT3000;D]`00`00D]aBg00:D]`3000UOol00`00Oomoo`0@
Ool00`00Oomoo`0:Ool002=oo`03001oogoo03Yoo`8000aC7P03001S6f<K00=S6`8000MO7003001R
nV;j00QRnP800003Ga`005kJ009NfP8000Paf@03001NMeig00UNM`05001WmfOgIoL00008F[X00`00
EYUFV@06EYT20002E_`00`00D]aBg00:D]`00`00D]aBg006D]`3000YOol00`00Oomoo`0?Ool00`00
Oomoo`0:Ool002Aoo`03001oogoo03]oo`03001C7U<N00YC7P03001S6f<K008000UO7003001RnV;j
00IRnP8000=O7003001NfUkJ009NfP03000afC7I00Haf@03001NMeig00QNM`05001WmfOgIoL0000:
F[X00`00EYUFV@02EYT30004E_`00`00D]aBg00;D]`00`00D]aBg003D]`2000/Ool00`00Oomoo`0?
Ool00`00Oomoo`0:Ool002Eoo`03001oogoo03]oo`03001C7U<N00QC7P@000aO7003001RnV;j00=R
nP8000IO7004001NfUkJG]X20008<MT00`00GWMNM`06GWL01@00IoMWmfOg00002eZj00<005JIEYT0
0P0025Kl00<005;LD]`02U;L00<005;LD]`00`00;goo00<007ooOol03Woo00<007ooOol02Woo000V
Ool00`00Oomoo`0kOol20003Dah50003Bal00`00GaaO700;Ga`00`00H_YRnP020009Ga`01@00G]YN
fUkJ0000237I00<005igGWL01Uig00<006OgIoL00P002eZj0`002eKl00<005;LD]`02E;L0`00<goo
00<007ooOol03Goo00<007ooOol02Woo000WOol2000mOol30009Bal00`00GaaO700:Ga`3000<Ga`0
1000G]YNfUkJ0P001c7I00<005igGWL015ig00@006OgIoL0009JfP03001J^UZj00AJ^P@0009G7@03
001Fo5Kl00YFo003001Bg5;L00ABg0@003Ioo`03001oogoo00eoo`03001oogoo00Yoo`00:Goo00<0
07ooOol0>goo0P002T/O0P001elL0`000U<n00<005lLGa`02UlL00<005kJG]X00ekJ0P001C7I00<0
05igGWL00eig00@006OgIoL000=JfP03001J^UZj00@000MG7@03001Fo5Kl00UFo003001Bg5;L00@0
03]oo`03001oogoo00aoo`03001oogoo00Yoo`00:Woo00<007ooOol0?7oo00<004/OBal02D/O00<0
05lLGa`010001U<n00<005lLGa`02UlL00<005kJG]X00P000U/L0P00137I00D005igGWMNM`00009W
m`03001JfU[J009JfP<000]G7@03001Fo5Kl00UFo0<0041oo`03001oogoo00aoo`03001oogoo00Uo
o`00:goo00<007ooOol0?7oo0P001T/O1P002e<n00<005lLGa`02ElL0`001U/L0P000S7I00D005ig
GWL006Og008000=JfP80009G?P03001G7ELM00YG7@03001Fo5Kl00EFo0<004Aoo`03001oogoo00]o
o`03001oogoo00Uoo`00;7oo0P00?Woo1P001D;o0P002e<n00<005lLGa`01ElL0`000U<n00<005/L
Fa`01U/L0P0000<af@0000000P000U[J0`001ELn00<005LMEad02ULM00<005KlE_`01000Agoo00<0
07ooOol02goo00<007ooOol02Goo000^Ool00`00Oomoo`0lOol2000:@_l00`00DciC?P09Dch00`00
GaaO70040006Dch00`00FaaK7007Fa`30002F]X20009Ech00`00EaeG7@09Ead3001<Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool002moo`03001oogoo03eoo`030012od;o00Q2o`8000IC?PH000]C?P03
001K75/L00MK70@000aG?P03001G7ELM00EG7@<0051oo`03001oogoo00Uoo`03001oogoo00Uoo`00
<7oo00<007ooOol0?Goo0P001T;o2P001DLO00<005<nDch02U<n00@005/LFaaK70D000=?G`8000aG
?P03001G7ELM00@005Aoo`03001oogoo00Qoo`03001oogoo00Uoo`00<Goo0P00?goo1P001DKn0P00
2DLO0P002E<n1@002TmO00<005LnEch025Ln1000F7oo00<007ooOol027oo00<007ooOol02Goo000c
Ool00`00Oomoo`0mOol00`00A_i6oP09A_h00`00Aam77`08Aal01000DciC?U<n1@000dLo0P002dmO
0P000eLn1@00GGoo00<007ooOol027oo00<007ooOol027oo000dOol00`00Oomoo`0mOol00`00A_i6
oP09A_h20005Aal7000:Acl20007Cel7001SOol00`00Oomoo`07Ool00`00Oomoo`08Ool003Eoo`03
001oogoo03eoo`8000U6oPL000E:oP8000]7?`P006Yoo`03001oogoo00Moo`03001oogoo00Qoo`00
=Woo0P00?goo00@004KnA_i6oPD000=Bg@03001:oT[n00Q:oP8000A7?`D007=oo`03001oogoo00Io
o`03001oogoo00Qoo`00>7oo00<007ooOol0?Goo0`002E;M0P002D[n1@00NGoo00<007ooOol01Goo
00<007ooOol027oo000iOol00`00Oomoo`0mOol00`00D]eBg@0:D]d01000B_i:oT[n1@00Ogoo00<0
07ooOol017oo00<007ooOol027oo000jOol00`00Oomoo`0mOol00`00D]eBg@09D]d40024Ool00`00
Oomoo`04Ool00`00Oomoo`08Ool003]oo`8003ioo`03001BgE;M00IBg@8008Uoo`03001oogoo00=o
o`03001oogoo00Qoo`00?Goo00<007ooOol0?7oo00<005;MD]d00e;M0P00S7oo00<007ooOol00goo
00<007ooOol01goo000nOol00`00Oomoo`0lOol00`00D]eBg@02002>Ool00`00Oomoo`03Ool00`00
Oomoo`07Ool003moo`03001oogoo03aoo`80095oo`03001oogoo009oo`03001oogoo00Moo`00@7oo
0P00?7oo00<007ooOol0TGoo00D007ooOomoo`0000Uoo`00@Woo00<007ooOol0>Goo00<007ooOol0
TWoo00@007ooOol000Uoo`00@goo00<007ooOol0>7oo00<007ooOol0TWoo00@007ooOol000Uoo`00
A7oo00<007ooOol0=goo00<007ooOol0Tgoo00<007oo00002Goo0015Ool2000gOol00`00Oomoo`2D
Ool00`00Ool00008Ool004Moo`03001oogoo03Aoo`03001oogoo09Eoo`8000Qoo`00B7oo00<007oo
Ool0<goo00<007ooOol0UGoo0P0027oo0019Ool00`00Oomoo`0aOol00`00Oomoo`2FOol20008Ool0
04Yoo`03001oogoo031oo`03001oogoo099oo`@000Yoo`00Bgoo0P00<7oo00<007ooOol0SWoo1000
3Woo001=Ool00`00Oomoo`0]Ool00`00Oomoo`2:Ool4000BOol004ioo`03001oogoo02aoo`03001o
ogoo08Ioo`@001Ioo`00Cgoo00<007ooOol0:goo00<007ooOol0Pgoo0`006Woo001@Ool2000[Ool0
0`00Oomoo`1oOol4000MOol0059oo`03001oogoo02Qoo`03001oogoo07]oo`@0025oo`00Dgoo00<0
07ooOol09goo00<007ooOol0Mgoo10009Goo001DOol00`00Oomoo`0VOol00`00Oomoo`1dOol3000Y
Ool005Eoo`8002Ioo`03001oogoo071oo`@002aoo`00Egoo00<007ooOol08goo00<007ooOol0K7oo
1000<7oo001HOol00`00Oomoo`0ROol00`00Oomoo`1XOol4000dOol005Uoo`03001oogoo025oo`03
001oogoo06Aoo`@003Qoo`00FWoo0P008Goo00<007ooOol0HGoo0`00?7oo001LOol00`00Oomoo`0N
Ool00`00Oomoo`1MOol4000oOol005eoo`03001oogoo01eoo`03001oogoo05Uoo`@004=oo`00GWoo
00<007ooOol077oo00<007ooOol0EGoo1000Agoo001OOol2000LOol00`00Oomoo`1BOol3001;Ool0
065oo`03001oogoo01Uoo`03001oogoo04ioo`@004ioo`00HWoo00<007ooOol067oo00<007ooOol0
BWoo1000DWoo001SOol00`00Oomoo`0GOol00`00Oomoo`16Ool4001FOol006Aoo`8001Moo`03001o
ogoo049oo`@005Yoo`00IWoo00<007ooOol057oo00<007ooOol0?goo0`00GWoo001WOol00`00Oomo
o`0COol00`00Oomoo`0kOol4001QOol006Qoo`03001oogoo019oo`03001oogoo03Moo`@006Eoo`00
JGoo0P004Woo00<007ooOol0<goo1000JGoo001[Ool00`00Oomoo`0?Ool00`00Oomoo`0`Ool3001]
Ool006aoo`03001oogoo00eoo`03001oogoo02eoo`@0071oo`00KGoo00<007ooOol037oo00<007oo
Ool0:Goo1000M7oo001^Ool00`00Oomoo`0;Ool00`00Oomoo`0UOol4001hOol006moo`8000]oo`03
001oogoo025oo`@007aoo`00LGoo00<007ooOol027oo00<007ooOol07Woo0`00P7oo001bOol00`00
Oomoo`07Ool00`00Oomoo`0JOol40023Ool007=oo`03001oogoo00Ioo`03001oogoo01Ioo`@008Mo
o`00M7oo0P001Woo00<007ooOol04Woo1000Rgoo001fOol00`00Oomoo`03Ool00`00Oomoo`0?Ool3
002?Ool007Moo`03001oogoo009oo`03001oogoo00]oo`@0099oo`00N7oo00D007ooOomoo`0000Uo
o`@009Ioo`00NGoo0P0000=oo`00Ool017oo1000VWoo001kOol200000goo00000002002NOol007ao
o`800:9oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0810092, -0.000546004, 
  0.00369589, 0.00369589}}]
}, Open  ]],

Cell[TextData[StyleBox[
"A circularly symmetric highpass filter has an impulse response given by     \
"]], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm
      \`h\_I[n\_1, n\_2]\  = \ 
        \[Delta](n\_1, n\_2)\  - \ 
          \(\[Omega]\_C\/\(2  \[Pi]\)\) 
            \(\(J\_1\)(\(\[Omega]\_C\) \@\(n\_1\^2 + n\_2\^2\))
                \)\/\@\(n\_1\^2 + n\_2\^2\)\)]]],
  StyleBox[","]
}], "NumberedEquation"],

Cell[TextData[{
  StyleBox["where "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(J\_1\)( . )\)]]],
  StyleBox[" is the Bessel function of the first kind of order 1 and "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_C\ \)\)]]],
  StyleBox["is the cutoff frequency. Also, "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm
      \`\(h\_I\)(0, 0)\  = \ 1 - \[Omega]\_C\^2\/\(4  \[Pi]\)\)]]],
  StyleBox[". "]
}], "Text"],

Cell[BoxData[
    \(\(highC = 
      Table[If[i == 8\  && \ j == 8, 1. , 0. ], {i, 15}, {j, 15}] - lowC; 
    \)\)], "Input",
  CellLabel->"In[58]:="],

Cell["\<\
Here are the amplitude spectra of the lowpass and highpass circularly \
symmetric and truncated FIR sequences.\
\>", "Text"],

Cell[BoxData[
    \(\(FlowC = Abs[DFT[ZeroPad[lowC, {0, 17}, {0, 17}]]]*32\^2; \)\)], 
  "Input"],

Cell[BoxData[
    \(\(FhighC = Abs[DFT[ZeroPad[highC, {0, 17}, {0, 17}]]]*32\^2; \)\)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \(ListPlot3D[#1, PlotRange -> All, \ DisplayFunction -> Identity]\ &
            \)\ /@\ {FlowC, \ FhighC}]]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38626 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00919655 0.47619 [
[ 0 0 0 0 ]
[ 1 .38626 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .38626 L
0 .38626 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00919655 0.477324 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.20131 .17781 -11.698 -9 ]
[.20131 .17781 .302 0 ]
[.40909 .09608 -10.8909 -9 ]
[.40909 .09608 1.10907 0 ]
[.63425 .0076 -10.0839 -9 ]
[.63425 .0076 1.91614 0 ]
[.79552 .14001 0 -6.12026 ]
[.79552 .14001 12 2.87974 ]
[.88711 .28027 0 -5.98728 ]
[.88711 .28027 12 3.01272 ]
[.96711 .40279 0 -5.87447 ]
[.96711 .40279 12 3.12553 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01678 .31108 -24 -2.78117 ]
[.01678 .31108 0 6.21883 ]
[.00922 .35844 -18 -2.82133 ]
[.00922 .35844 0 6.17867 ]
[.00143 .40726 -24 -2.86285 ]
[.00143 .40726 0 6.13715 ]
[-0.0066 .4576 -6 -2.9058 ]
[-0.0066 .4576 0 6.0942 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.21035 .18732 m
.21487 .19208 L
s
[(10)] .20131 .17781 .94967 1 Mshowa
.41738 .10625 m
.42153 .11134 L
s
[(20)] .40909 .09608 .81515 1 Mshowa
.64163 .01845 m
.64532 .02387 L
s
[(30)] .63425 .0076 .68064 1 Mshowa
.125 Mabswid
.25047 .17161 m
.25314 .1745 L
s
.29122 .15565 m
.29385 .15859 L
s
.33262 .13945 m
.3352 .14242 L
s
.37466 .12298 m
.3772 .12599 L
s
.46079 .08926 m
.46322 .09235 L
s
.5049 .07199 m
.50728 .07512 L
s
.54973 .05443 m
.55206 .0576 L
s
.5953 .03659 m
.59757 .0398 L
s
.17084 .20279 m
.17359 .20561 L
s
.13192 .21803 m
.13471 .22081 L
s
.09359 .23304 m
.09641 .23578 L
s
.05583 .24783 m
.05869 .25053 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78318 .14446 m
.777 .14668 L
s
[(10)] .79552 .14001 -1 .36006 Mshowa
.87465 .28439 m
.86842 .28645 L
s
[(20)] .88711 .28027 -1 .33051 Mshowa
.95456 .40662 m
.94829 .40854 L
s
[(30)] .96711 .40279 -1 .30544 Mshowa
.125 Mabswid
.80252 .17404 m
.7988 .17536 L
s
.82131 .20279 m
.81759 .20409 L
s
.83959 .23075 m
.83586 .23202 L
s
.85736 .25793 m
.85363 .25919 L
s
.89149 .31014 m
.88774 .31135 L
s
.90788 .33521 m
.90413 .33641 L
s
.92384 .35963 m
.92009 .36081 L
s
.9394 .38343 m
.93564 .38459 L
s
.76327 .11401 m
.75957 .11536 L
s
.74277 .08265 m
.73908 .08403 L
s
.72165 .05034 m
.71797 .05174 L
s
.69987 .01704 m
.6962 .01846 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02904 .30639 m
.03517 .30405 L
s
[(0.25)] .01678 .31108 1 -0.38196 Mshowa
.02152 .35385 m
.02766 .35156 L
s
[(0.5)] .00922 .35844 1 -0.37304 Mshowa
.01376 .40277 m
.01993 .40053 L
s
[(0.75)] .00143 .40726 1 -0.36381 Mshowa
.00577 .45322 m
.01195 .45103 L
s
[(1)] -0.0066 .4576 1 -0.35427 Mshowa
.125 Mabswid
.03489 .26944 m
.03856 .26801 L
s
.03344 .27859 m
.03711 .27717 L
s
.03198 .2878 m
.03566 .28639 L
s
.03051 .29707 m
.03419 .29566 L
s
.02755 .31577 m
.03123 .31437 L
s
.02606 .3252 m
.02974 .32381 L
s
.02455 .3347 m
.02824 .33331 L
s
.02304 .34424 m
.02673 .34286 L
s
.01999 .36351 m
.02368 .36214 L
s
.01844 .37324 m
.02214 .37187 L
s
.01689 .38302 m
.02059 .38166 L
s
.01533 .39287 m
.01903 .39151 L
s
.01219 .41273 m
.01589 .41139 L
s
.0106 .42276 m
.0143 .42143 L
s
.009 .43285 m
.0127 .43152 L
s
.00739 .443 m
.0111 .44168 L
s
.00414 .4635 m
.00785 .46219 L
s
.0025 .47384 m
.00622 .47254 L
s
.00085 .48425 m
.00457 .48296 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.716 .594 .718 r
.38874 .76625 .3985 .79327 .41634 .77537 .40655 .75003 Metetra
.709 .597 .729 r
.40655 .75003 .41634 .77537 .43425 .75404 .42429 .73594 Metetra
0 .197 .724 r
.42429 .73594 .43425 .75404 .45154 .76035 .4413 .75413 Metetra
.806 .316 0 r
.4413 .75413 .45154 .76035 .46887 .77866 .45855 .77799 Metetra
.932 .87 .755 r
.45855 .77799 .46887 .77866 .48696 .75835 .47694 .7471 Metetra
.922 .72 .612 r
.47694 .7471 .48696 .75835 .50531 .68364 .49568 .65624 Metetra
.874 .666 .618 r
.49568 .65624 .50531 .68364 .52308 .5996 .51366 .56994 Metetra
.591 .509 .731 r
.51366 .56994 .52308 .5996 .54041 .57201 .53107 .56898 Metetra
.881 .887 .833 r
.53107 .56898 .54041 .57201 .55783 .56579 .54851 .54944 Metetra
.512 .569 .849 r
.54851 .54944 .55783 .56579 .5753 .55615 .56618 .5519 Metetra
.824 .885 .887 r
.56618 .5519 .5753 .55615 .59293 .55115 .58375 .53775 Metetra
.521 .618 .889 r
.58375 .53775 .59293 .55115 .61061 .54366 .6017 .53894 Metetra
.794 .883 .91 r
.6017 .53894 .61061 .54366 .62846 .53859 .61945 .52676 Metetra
.528 .651 .913 r
.61945 .52676 .62846 .53859 .64638 .53214 .63767 .52718 Metetra
.778 .882 .921 r
.63767 .52718 .64638 .53214 .66444 .5265 .65562 .51584 Metetra
.524 .674 .932 r
.65562 .51584 .66444 .5265 .68262 .52105 .67413 .51593 Metetra
.773 .882 .925 r
.67413 .51593 .68262 .52105 .70092 .51556 .69225 .50477 Metetra
.518 .67 .932 r
.69225 .50477 .70092 .51556 .71935 .51026 .71108 .50507 Metetra
.778 .886 .923 r
.71108 .50507 .71935 .51026 .73795 .50578 .72937 .49354 Metetra
.509 .638 .912 r
.72937 .49354 .73795 .50578 .7566 .4999 .74857 .49473 Metetra
.79 .893 .917 r
.74857 .49473 .7566 .4999 .77555 .49649 .76698 .48237 Metetra
.476 .589 .887 r
.76698 .48237 .77555 .49649 .79445 .49055 .78668 .48561 Metetra
.81 .905 .907 r
.78668 .48561 .79445 .49055 .81389 .48934 .80518 .47192 Metetra
.381 .488 .843 r
.80518 .47192 .81389 .48934 .83319 .48464 .82576 .48074 Metetra
.73 .927 .956 r
.82576 .48074 .83319 .48464 .85482 .50197 .84481 .47052 Metetra
0 0 .332 r
.84481 .47052 .85482 .50197 .88303 .57791 .87304 .54854 Metetra
0 0 .277 r
.87304 .54854 .88303 .57791 .91139 .64494 .90307 .63215 Metetra
0 .212 .735 r
.90307 .63215 .91139 .64494 .93417 .65566 .92718 .65381 Metetra
.969 .923 .695 r
.92718 .65381 .93417 .65566 .95229 .62587 .9448 .61807 Metetra
.925 .859 .758 r
.9448 .61807 .95229 .62587 .97189 .60856 .96293 .58812 Metetra
.511 .543 .825 r
.96293 .58812 .97189 .60856 .99548 .62042 .98549 .59213 Metetra
.715 .83 .936 r
.37811 .76017 .38874 .76625 .40655 .75003 .39573 .75229 Metetra
.39573 .75229 .40655 .75003 .42429 .73594 .41325 .75007 Metetra
.66 .274 .303 r
.41325 .75007 .42429 .73594 .4413 .75413 .43056 .76151 Metetra
.182 0 0 r
.43056 .76151 .4413 .75413 .45855 .77799 .44847 .75751 Metetra
.862 .683 .658 r
.44847 .75751 .45855 .77799 .47694 .7471 .46736 .70176 Metetra
.835 .624 .617 r
.46736 .70176 .47694 .7471 .49568 .65624 .48624 .61106 Metetra
.79 .595 .637 r
.48624 .61106 .49568 .65624 .51366 .56994 .50415 .5546 Metetra
.459 .557 .868 r
.50415 .5546 .51366 .56994 .53107 .56898 .52159 .55858 Metetra
.801 .757 .812 r
.52159 .55858 .53107 .56898 .54851 .54944 .53916 .54253 Metetra
.432 .725 .987 r
.53916 .54253 .54851 .54944 .56618 .5519 .55687 .54285 Metetra
.779 .783 .855 r
.55687 .54285 .56618 .5519 .58375 .53775 .57458 .5302 Metetra
.46 .721 .981 r
.57458 .5302 .58375 .53775 .6017 .53894 .59257 .53034 Metetra
.777 .795 .868 r
.59257 .53034 .6017 .53894 .61945 .52676 .61043 .51812 Metetra
.468 .698 .968 r
.61043 .51812 .61945 .52676 .63767 .52718 .62873 .51869 Metetra
.782 .802 .869 r
.62873 .51869 .63767 .52718 .65562 .51584 .64673 .50608 Metetra
.463 .669 .952 r
.64673 .50608 .65562 .51584 .67413 .51593 .66536 .50739 Metetra
.781 .805 .872 r
.66536 .50739 .67413 .51593 .69225 .50477 .68353 .49487 Metetra
.461 .666 .951 r
.68353 .49487 .69225 .50477 .71108 .50507 .7025 .49633 Metetra
.77 .804 .88 r
.7025 .49633 .71108 .50507 .72937 .49354 .72088 .48451 Metetra
.455 .685 .964 r
.72088 .48451 .72937 .49354 .74857 .49473 .74016 .48561 Metetra
.762 .799 .883 r
.74016 .48561 .74857 .49473 .76698 .48237 .75876 .47419 Metetra
.412 .686 .975 r
.75876 .47419 .76698 .48237 .78668 .48561 .77842 .47578 Metetra
.761 .789 .876 r
.77842 .47578 .78668 .48561 .80518 .47192 .79721 .46413 Metetra
.234 .594 .949 r
.79721 .46413 .80518 .47192 .82576 .48074 .81754 .46925 Metetra
.795 .771 .832 r
.81754 .46925 .82576 .48074 .84481 .47052 .8362 .45382 Metetra
0 0 .351 r
.8362 .45382 .84481 .47052 .87304 .54854 .86118 .50076 Metetra
0 0 .487 r
.86118 .50076 .87304 .54854 .90307 .63215 .89084 .5838 Metetra
.184 .202 .645 r
.89084 .5838 .90307 .63215 .92718 .65381 .91771 .63117 Metetra
.65 .603 .788 r
.91771 .63117 .92718 .65381 .9448 .61807 .93892 .62456 Metetra
.57 .837 .483 r
.93892 .62456 .9448 .61807 .96293 .58812 .95822 .60163 Metetra
.283 0 .071 r
.95822 .60163 .96293 .58812 .98549 .59213 .97937 .59304 Metetra
.373 0 0 r
.36683 .76549 .37811 .76017 .39573 .75229 .38425 .76657 Metetra
.546 .139 .222 r
.38425 .76657 .39573 .75229 .41325 .75007 .40176 .76988 Metetra
.057 0 .017 r
.40176 .76988 .41325 .75007 .43056 .76151 .42005 .7534 Metetra
.91 .753 .674 r
.42005 .7534 .43056 .76151 .44847 .75751 .43918 .70214 Metetra
.797 .591 .623 r
.43918 .70214 .44847 .75751 .46736 .70176 .45843 .62741 Metetra
.753 .549 .619 r
.45843 .62741 .46736 .70176 .48624 .61106 .47695 .56138 Metetra
.646 .494 .663 r
.47695 .56138 .48624 .61106 .50415 .5546 .49448 .5494 Metetra
.746 .862 .933 r
.49448 .5494 .50415 .5546 .52159 .55858 .51204 .53996 Metetra
.664 .62 .795 r
.51204 .53996 .52159 .55858 .53916 .54253 .52967 .53344 Metetra
.669 .761 .919 r
.52967 .53344 .53916 .54253 .55687 .54285 .54741 .52772 Metetra
.684 .667 .827 r
.54741 .52772 .55687 .54285 .57458 .5302 .56525 .52041 Metetra
.63 .736 .924 r
.56525 .52041 .57458 .5302 .59257 .53034 .58324 .51636 Metetra
.701 .69 .836 r
.58324 .51636 .59257 .53034 .61043 .51812 .60126 .50802 Metetra
.601 .722 .93 r
.60126 .50802 .61043 .51812 .62873 .51869 .61953 .50511 Metetra
.715 .702 .837 r
.61953 .50511 .62873 .51869 .64673 .50608 .63772 .49576 Metetra
.574 .709 .934 r
.63772 .49576 .64673 .50608 .66536 .50739 .65629 .49382 Metetra
.715 .705 .84 r
.65629 .49382 .66536 .50739 .68353 .49487 .67469 .48442 Metetra
.575 .708 .933 r
.67469 .48442 .68353 .49487 .7025 .49633 .69355 .48245 Metetra
.701 .698 .845 r
.69355 .48245 .7025 .49633 .72088 .48451 .71221 .474 Metetra
.599 .719 .928 r
.71221 .474 .72088 .48451 .74016 .48561 .73131 .47104 Metetra
.682 .684 .845 r
.73131 .47104 .74016 .48561 .75876 .47419 .75027 .46372 Metetra
.622 .732 .925 r
.75027 .46372 .75876 .47419 .77842 .47578 .7696 .45972 Metetra
.653 .654 .839 r
.7696 .45972 .77842 .47578 .79721 .46413 .78895 .45411 Metetra
.637 .75 .93 r
.78895 .45411 .79721 .46413 .81754 .46925 .8085 .44931 Metetra
.595 .585 .812 r
.8085 .44931 .81754 .46925 .8362 .45382 .82849 .44752 Metetra
.371 .72 .988 r
.82849 .44752 .8362 .45382 .86118 .50076 .84893 .44837 Metetra
.111 .139 .61 r
.84893 .44837 .86118 .50076 .89084 .5838 .8755 .50533 Metetra
.242 .197 .606 r
.8755 .50533 .89084 .5838 .91771 .63117 .9041 .572 Metetra
.308 .266 .648 r
.9041 .572 .91771 .63117 .93892 .62456 .93096 .61473 Metetra
.269 .579 .942 r
.93096 .61473 .93892 .62456 .95822 .60163 .95408 .62115 Metetra
.266 0 .178 r
.95408 .62115 .95822 .60163 .97937 .59304 .97479 .60667 Metetra
.571 .539 .78 r
.35669 .7419 .36683 .76549 .38425 .76657 .37413 .74197 Metetra
.657 .578 .755 r
.37413 .74197 .38425 .76657 .40176 .76988 .392 .7347 Metetra
.784 .609 .663 r
.392 .7347 .40176 .76988 .42005 .7534 .41108 .69329 Metetra
.782 .578 .624 r
.41108 .69329 .42005 .7534 .43918 .70214 .43069 .62303 Metetra
.743 .539 .618 r
.43069 .62303 .43918 .70214 .45843 .62741 .44962 .55934 Metetra
.65 .478 .637 r
.44962 .55934 .45843 .62741 .47695 .56138 .46727 .54119 Metetra
.665 .607 .78 r
.46727 .54119 .47695 .56138 .49448 .5494 .48478 .53421 Metetra
.696 .669 .82 r
.48478 .53421 .49448 .5494 .51204 .53996 .50239 .52597 Metetra
.659 .672 .852 r
.50239 .52597 .51204 .53996 .52967 .53344 .52008 .52056 Metetra
.682 .698 .858 r
.52008 .52056 .52967 .53344 .54741 .52772 .53788 .51384 Metetra
.657 .675 .856 r
.53788 .51384 .54741 .52772 .56525 .52041 .55579 .50851 Metetra
.675 .714 .877 r
.55579 .50851 .56525 .52041 .58324 .51636 .57381 .50223 Metetra
.658 .674 .854 r
.57381 .50223 .58324 .51636 .60126 .50802 .59196 .49675 Metetra
.67 .726 .891 r
.59196 .49675 .60126 .50802 .61953 .50511 .61021 .49076 Metetra
.661 .674 .852 r
.61021 .49076 .61953 .50511 .63772 .49576 .62859 .485 Metetra
.663 .735 .903 r
.62859 .485 .63772 .49576 .65629 .49382 .6471 .47928 Metetra
.66 .673 .852 r
.6471 .47928 .65629 .49382 .67469 .48442 .66572 .47352 Metetra
.662 .735 .904 r
.66572 .47352 .67469 .48442 .69355 .48245 .68448 .46779 Metetra
.654 .671 .854 r
.68448 .46779 .69355 .48245 .71221 .474 .70337 .46231 Metetra
.666 .724 .893 r
.70337 .46231 .71221 .474 .73131 .47104 .72237 .45631 Metetra
.649 .67 .857 r
.72237 .45631 .73131 .47104 .75027 .46372 .74155 .4511 Metetra
.667 .711 .881 r
.74155 .4511 .75027 .46372 .7696 .45972 .76079 .44494 Metetra
.64 .667 .86 r
.76079 .44494 .7696 .45972 .78895 .45411 .78029 .4402 Metetra
.662 .691 .866 r
.78029 .4402 .78895 .45411 .8085 .44931 .79981 .43411 Metetra
.612 .651 .864 r
.79981 .43411 .8085 .44931 .82849 .44752 .81974 .43093 Metetra
.633 .643 .843 r
.81974 .43093 .82849 .44752 .84893 .44837 .83972 .42645 Metetra
.458 .493 .807 r
.83972 .42645 .84893 .44837 .8755 .50533 .86105 .43356 Metetra
.279 .227 .619 r
.86105 .43356 .8755 .50533 .9041 .572 .8879 .48815 Metetra
.293 .228 .611 r
.8879 .48815 .9041 .572 .93096 .61473 .91656 .55022 Metetra
.401 .322 .651 r
.91656 .55022 .93096 .61473 .95408 .62115 .94261 .58255 Metetra
.603 .502 .712 r
.94261 .58255 .95408 .62115 .97479 .60667 .96469 .57904 Metetra
.616 .452 .638 r
.34885 .67183 .35669 .7419 .37413 .74197 .36647 .66243 Metetra
.656 .475 .628 r
.36647 .66243 .37413 .74197 .392 .7347 .38473 .639 Metetra
.684 .489 .616 r
.38473 .639 .392 .7347 .41108 .69329 .40354 .59785 Metetra
.693 .495 .615 r
.40354 .59785 .41108 .69329 .43069 .62303 .42224 .55238 Metetra
.639 .467 .635 r
.42224 .55238 .43069 .62303 .44962 .55934 .43989 .53663 Metetra
.634 .574 .77 r
.43989 .53663 .44962 .55934 .46727 .54119 .45732 .53186 Metetra
.762 .774 .863 r
.45732 .53186 .46727 .54119 .48478 .53421 .47497 .52047 Metetra
.621 .662 .869 r
.47497 .52047 .48478 .53421 .50239 .52597 .49259 .51715 Metetra
.717 .781 .903 r
.49259 .51715 .50239 .52597 .52008 .52056 .51038 .50894 Metetra
.629 .703 .899 r
.51038 .50894 .52008 .52056 .53788 .51384 .52825 .50505 Metetra
.703 .782 .913 r
.52825 .50505 .53788 .51384 .55579 .50851 .54623 .49751 Metetra
.631 .717 .909 r
.54623 .49751 .55579 .50851 .57381 .50223 .56436 .49343 Metetra
.7 .784 .916 r
.56436 .49343 .57381 .50223 .59196 .49675 .58256 .48597 Metetra
.629 .723 .915 r
.58256 .48597 .59196 .49675 .61021 .49076 .60094 .48187 Metetra
.7 .786 .918 r
.60094 .48187 .61021 .49076 .62859 .485 .61936 .47431 Metetra
.625 .726 .919 r
.61936 .47431 .62859 .485 .6471 .47928 .63801 .47029 Metetra
.699 .786 .919 r
.63801 .47029 .6471 .47928 .66572 .47352 .65665 .46269 Metetra
.624 .725 .919 r
.65665 .46269 .66572 .47352 .68448 .46779 .67557 .45864 Metetra
.696 .786 .92 r
.67557 .45864 .68448 .46779 .70337 .46231 .69446 .4511 Metetra
.626 .721 .915 r
.69446 .4511 .70337 .46231 .72237 .45631 .71366 .44695 Metetra
.695 .785 .92 r
.71366 .44695 .72237 .45631 .74155 .4511 .73278 .43939 Metetra
.624 .713 .91 r
.73278 .43939 .74155 .4511 .76079 .44494 .75227 .43533 Metetra
.697 .783 .918 r
.75227 .43533 .76079 .44494 .78029 .4402 .77164 .42755 Metetra
.61 .692 .901 r
.77164 .42755 .78029 .4402 .79981 .43411 .79148 .42419 Metetra
.706 .783 .912 r
.79148 .42419 .79981 .43411 .81974 .43093 .81105 .4158 Metetra
.55 .624 .879 r
.81105 .4158 .81974 .43093 .83972 .42645 .83152 .41573 Metetra
.676 .76 .914 r
.83152 .41573 .83972 .42645 .86105 .43356 .85152 .40884 Metetra
.511 .504 .785 r
.85152 .40884 .86105 .43356 .8879 .48815 .87288 .41333 Metetra
.405 .309 .633 r
.87288 .41333 .8879 .48815 .91656 .55022 .89808 .44891 Metetra
.469 .337 .617 r
.89808 .44891 .91656 .55022 .94261 .58255 .92347 .48032 Metetra
.533 .38 .619 r
.92347 .48032 .94261 .58255 .96469 .57904 .94717 .49334 Metetra
.624 .448 .623 r
.34202 .58761 .34885 .67183 .36647 .66243 .35959 .57321 Metetra
.653 .467 .62 r
.35959 .57321 .36647 .66243 .38473 .639 .37767 .5476 Metetra
.609 .433 .618 r
.37767 .5476 .38473 .639 .40354 .59785 .3951 .53654 Metetra
.577 .431 .646 r
.3951 .53654 .40354 .59785 .42224 .55238 .41223 .53575 Metetra
.717 .662 .795 r
.41223 .53575 .42224 .55238 .43989 .53663 .4298 .52501 Metetra
.722 .728 .855 r
.4298 .52501 .43989 .53663 .45732 .53186 .4474 .51582 Metetra
.635 .638 .836 r
.4474 .51582 .45732 .53186 .47497 .52047 .46498 .51161 Metetra
.71 .779 .906 r
.46498 .51161 .47497 .52047 .49259 .51715 .48273 .50371 Metetra
.641 .678 .87 r
.48273 .50371 .49259 .51715 .51038 .50894 .50055 .49925 Metetra
.68 .758 .91 r
.50055 .49925 .51038 .50894 .52825 .50505 .5185 .49279 Metetra
.658 .705 .882 r
.5185 .49279 .52825 .50505 .54623 .49751 .53657 .48737 Metetra
.666 .748 .912 r
.53657 .48737 .54623 .49751 .56436 .49343 .55475 .48153 Metetra
.668 .717 .886 r
.55475 .48153 .56436 .49343 .58256 .48597 .57305 .47554 Metetra
.657 .742 .913 r
.57305 .47554 .58256 .48597 .60094 .48187 .59148 .47005 Metetra
.674 .723 .886 r
.59148 .47005 .60094 .48187 .61936 .47431 .61002 .46363 Metetra
.651 .738 .913 r
.61002 .46363 .61936 .47431 .63801 .47029 .62871 .45838 Metetra
.674 .724 .887 r
.62871 .45838 .63801 .47029 .65665 .46269 .64748 .45186 Metetra
.651 .738 .913 r
.64748 .45186 .65665 .46269 .67557 .45864 .66643 .44652 Metetra
.669 .721 .888 r
.66643 .44652 .67557 .45864 .69446 .4511 .68547 .44024 Metetra
.658 .742 .912 r
.68547 .44024 .69446 .4511 .71366 .44695 .70466 .43446 Metetra
.661 .715 .888 r
.70466 .43446 .71366 .44695 .73278 .43939 .72398 .42853 Metetra
.668 .749 .911 r
.72398 .42853 .73278 .43939 .75227 .43533 .74341 .42217 Metetra
.648 .701 .885 r
.74341 .42217 .75227 .43533 .77164 .42755 .76304 .41686 Metetra
.686 .762 .909 r
.76304 .41686 .77164 .42755 .79148 .42419 .78267 .40952 Metetra
.62 .667 .874 r
.78267 .40952 .79148 .42419 .81105 .4158 .80272 .40569 Metetra
.689 .778 .919 r
.80272 .40569 .81105 .4158 .83152 .41573 .82259 .39806 Metetra
.599 .618 .843 r
.82259 .39806 .83152 .41573 .85152 .40884 .8431 .39558 Metetra
.553 .661 .908 r
.8431 .39558 .85152 .40884 .87288 .41333 .86397 .39471 Metetra
.71 .664 .803 r
.86397 .39471 .87288 .41333 .89808 .44891 .8839 .38351 Metetra
.575 .431 .648 r
.8839 .38351 .89808 .44891 .92347 .48032 .90519 .38301 Metetra
.523 .374 .62 r
.90519 .38301 .92347 .48032 .94717 .49334 .92863 .39779 Metetra
.581 .456 .675 r
.33335 .54191 .34202 .58761 .35959 .57321 .35016 .54071 Metetra
.558 .479 .722 r
.35016 .54071 .35959 .57321 .37767 .5476 .367 .54197 Metetra
.665 .84 .967 r
.367 .54197 .37767 .5476 .3951 .53654 .38432 .53586 Metetra
.824 .951 .902 r
.38432 .53586 .3951 .53654 .41223 .53575 .40205 .52157 Metetra
.715 .691 .825 r
.40205 .52157 .41223 .53575 .4298 .52501 .41965 .51203 Metetra
.637 .683 .877 r
.41965 .51203 .4298 .52501 .4474 .51582 .43718 .50778 Metetra
.728 .8 .909 r
.43718 .50778 .4474 .51582 .46498 .51161 .45493 .49898 Metetra
.64 .692 .882 r
.45493 .49898 .46498 .51161 .48273 .50371 .4727 .4945 Metetra
.689 .771 .914 r
.4727 .4945 .48273 .50371 .50055 .49925 .49062 .48759 Metetra
.65 .714 .895 r
.49062 .48759 .50055 .49925 .5185 .49279 .50864 .48257 Metetra
.679 .751 .906 r
.50864 .48257 .5185 .49279 .53657 .48737 .52678 .47607 Metetra
.652 .724 .901 r
.52678 .47607 .53657 .48737 .55475 .48153 .54504 .47084 Metetra
.675 .744 .902 r
.54504 .47084 .55475 .48153 .57305 .47554 .56342 .46443 Metetra
.653 .73 .906 r
.56342 .46443 .57305 .47554 .59148 .47005 .58193 .45907 Metetra
.674 .741 .901 r
.58193 .45907 .59148 .47005 .61002 .46363 .60055 .45265 Metetra
.653 .735 .91 r
.60055 .45265 .61002 .46363 .62871 .45838 .61932 .44721 Metetra
.673 .74 .901 r
.61932 .44721 .62871 .45838 .64748 .45186 .63819 .44073 Metetra
.653 .735 .91 r
.63819 .44073 .64748 .45186 .66643 .44652 .65721 .43525 Metetra
.673 .741 .901 r
.65721 .43525 .66643 .44652 .68547 .44024 .67633 .42868 Metetra
.652 .729 .906 r
.67633 .42868 .68547 .44024 .70466 .43446 .69563 .42318 Metetra
.674 .744 .903 r
.69563 .42318 .70466 .43446 .72398 .42853 .715 .41648 Metetra
.649 .722 .902 r
.715 .41648 .72398 .42853 .74341 .42217 .73458 .41107 Metetra
.677 .752 .907 r
.73458 .41107 .74341 .42217 .76304 .41686 .7542 .40416 Metetra
.639 .709 .897 r
.7542 .40416 .76304 .41686 .78267 .40952 .77411 .39916 Metetra
.686 .773 .917 r
.77411 .39916 .78267 .40952 .80272 .40569 .79396 .39167 Metetra
.602 .672 .89 r
.79396 .39167 .80272 .40569 .82259 .39806 .81434 .38862 Metetra
.688 .797 .932 r
.81434 .38862 .82259 .39806 .8431 .39558 .83445 .38088 Metetra
.587 .657 .885 r
.83445 .38088 .8431 .39558 .86397 .39471 .85525 .37861 Metetra
.49 .586 .878 r
.85525 .37861 .86397 .39471 .8839 .38351 .87681 .3813 Metetra
.469 .877 .949 r
.87681 .3813 .8839 .38351 .90519 .38301 .89765 .3755 Metetra
.789 .879 .912 r
.89765 .3755 .90519 .38301 .92863 .39779 .9177 .36198 Metetra
.72 .889 .958 r
.32226 .53815 .33335 .54191 .35016 .54071 .33955 .52969 Metetra
.761 .743 .836 r
.33955 .52969 .35016 .54071 .367 .54197 .3571 .5175 Metetra
.602 .548 .766 r
.3571 .5175 .367 .54197 .38432 .53586 .37426 .51492 Metetra
.634 .59 .787 r
.37426 .51492 .38432 .53586 .40205 .52157 .39165 .51023 Metetra
.712 .733 .868 r
.39165 .51023 .40205 .52157 .41965 .51203 .40928 .50181 Metetra
.692 .75 .896 r
.40928 .50181 .41965 .51203 .43718 .50778 .42696 .49474 Metetra
.65 .69 .874 r
.42696 .49474 .43718 .50778 .45493 .49898 .4447 .48969 Metetra
.689 .77 .914 r
.4447 .48969 .45493 .49898 .4727 .4945 .46259 .48277 Metetra
.651 .715 .894 r
.46259 .48277 .4727 .4945 .49062 .48759 .48056 .47763 Metetra
.672 .755 .913 r
.48056 .47763 .49062 .48759 .50864 .48257 .49866 .47144 Metetra
.661 .731 .901 r
.49866 .47144 .50864 .48257 .52678 .47607 .51688 .46573 Metetra
.664 .749 .913 r
.51688 .46573 .52678 .47607 .54504 .47084 .53522 .45984 Metetra
.667 .738 .903 r
.53522 .45984 .54504 .47084 .56342 .46443 .55368 .45378 Metetra
.659 .744 .913 r
.55368 .45378 .56342 .46443 .58193 .45907 .57227 .44805 Metetra
.671 .742 .904 r
.57227 .44805 .58193 .45907 .60055 .45265 .59098 .44172 Metetra
.656 .74 .912 r
.59098 .44172 .60055 .45265 .61932 .44721 .60982 .43608 Metetra
.671 .742 .904 r
.60982 .43608 .61932 .44721 .63819 .44073 .62878 .42966 Metetra
.656 .74 .912 r
.62878 .42966 .63819 .44073 .65721 .43525 .64789 .42393 Metetra
.667 .741 .905 r
.64789 .42393 .65721 .43525 .67633 .42868 .66711 .41759 Metetra
.66 .744 .912 r
.66711 .41759 .67633 .42868 .69563 .42318 .68648 .41159 Metetra
.663 .737 .905 r
.68648 .41159 .69563 .42318 .715 .41648 .70597 .40541 Metetra
.665 .749 .913 r
.70597 .40541 .715 .41648 .73458 .41107 .72559 .39904 Metetra
.655 .729 .903 r
.72559 .39904 .73458 .41107 .7542 .40416 .74539 .39316 Metetra
.675 .757 .913 r
.74539 .39316 .7542 .40416 .77411 .39916 .76524 .3862 Metetra
.64 .709 .897 r
.76524 .3862 .77411 .39916 .79396 .39167 .78539 .38106 Metetra
.675 .769 .921 r
.78539 .38106 .79396 .39167 .81434 .38862 .80552 .374 Metetra
.636 .683 .877 r
.80552 .374 .81434 .38862 .83445 .38088 .82598 .36901 Metetra
.602 .716 .925 r
.82598 .36901 .83445 .38088 .85525 .37861 .84676 .36543 Metetra
.678 .727 .887 r
.84676 .36543 .85525 .37861 .87681 .3813 .86731 .35797 Metetra
.676 .612 .776 r
.86731 .35797 .87681 .3813 .89765 .3755 .88774 .34829 Metetra
.563 .524 .77 r
.88774 .34829 .89765 .3755 .9177 .36198 .90951 .34865 Metetra
.599 .574 .797 r
.31208 .5174 .32226 .53815 .33955 .52969 .32902 .51511 Metetra
.54 .62 .881 r
.32902 .51511 .33955 .52969 .3571 .5175 .34599 .51514 Metetra
.533 .88 .986 r
.34599 .51514 .3571 .5175 .37426 .51492 .36335 .5104 Metetra
.768 .879 .927 r
.36335 .5104 .37426 .51492 .39165 .51023 .38109 .4996 Metetra
.729 .751 .87 r
.38109 .4996 .39165 .51023 .40928 .50181 .39884 .49017 Metetra
.632 .709 .902 r
.39884 .49017 .40928 .50181 .42696 .49474 .4165 .48595 Metetra
.703 .784 .915 r
.4165 .48595 .42696 .49474 .4447 .48969 .43438 .47832 Metetra
.658 .724 .898 r
.43438 .47832 .4447 .48969 .46259 .48277 .45231 .47283 Metetra
.674 .758 .914 r
.45231 .47283 .46259 .48277 .48056 .47763 .47038 .46653 Metetra
.662 .733 .902 r
.47038 .46653 .48056 .47763 .49866 .47144 .48855 .46075 Metetra
.668 .744 .907 r
.48855 .46075 .49866 .47144 .51688 .46573 .50685 .45465 Metetra
.662 .736 .905 r
.50685 .45465 .51688 .46573 .53522 .45984 .52527 .44878 Metetra
.667 .739 .904 r
.52527 .44878 .53522 .45984 .55368 .45378 .54382 .44267 Metetra
.662 .738 .907 r
.54382 .44267 .55368 .45378 .57227 .44805 .56249 .43675 Metetra
.667 .737 .903 r
.56249 .43675 .57227 .44805 .59098 .44172 .58128 .43055 Metetra
.661 .74 .908 r
.58128 .43055 .59098 .44172 .60982 .43608 .60021 .42459 Metetra
.666 .737 .903 r
.60021 .42459 .60982 .43608 .62878 .42966 .61925 .41833 Metetra
.66 .739 .908 r
.61925 .41833 .62878 .42966 .64789 .42393 .63844 .41232 Metetra
.665 .737 .904 r
.63844 .41232 .64789 .42393 .66711 .41759 .65776 .40602 Metetra
.661 .738 .907 r
.65776 .40602 .66711 .41759 .68648 .41159 .67721 .39992 Metetra
.665 .739 .905 r
.67721 .39992 .68648 .41159 .70597 .40541 .69679 .39356 Metetra
.659 .735 .906 r
.69679 .39356 .70597 .40541 .72559 .39904 .71653 .38744 Metetra
.665 .743 .908 r
.71653 .38744 .72559 .39904 .74539 .39316 .73638 .38098 Metetra
.654 .73 .905 r
.73638 .38098 .74539 .39316 .76524 .3862 .75642 .37506 Metetra
.669 .757 .916 r
.75642 .37506 .76524 .3862 .78539 .38106 .77654 .3683 Metetra
.626 .71 .907 r
.77654 .3683 .78539 .38106 .80552 .374 .79699 .36373 Metetra
.692 .787 .923 r
.79699 .36373 .80552 .374 .82598 .36901 .81729 .35565 Metetra
.586 .684 .909 r
.81729 .35565 .82598 .36901 .84676 .36543 .83825 .35296 Metetra
.546 .683 .928 r
.83825 .35296 .84676 .36543 .86731 .35797 .85956 .3517 Metetra
.653 .873 .981 r
.85956 .3517 .86731 .35797 .88774 .34829 .8804 .34414 Metetra
.752 .951 .942 r
.8804 .34414 .88774 .34829 .90951 .34865 .90079 .33157 Metetra
.691 .859 .963 r
.30078 .51234 .31208 .5174 .32902 .51511 .31811 .50513 Metetra
.729 .76 .878 r
.31811 .50513 .32902 .51511 .34599 .51514 .33564 .49591 Metetra
.613 .598 .812 r
.33564 .49591 .34599 .51514 .36335 .5104 .35294 .49269 Metetra
.648 .63 .818 r
.35294 .49269 .36335 .5104 .38109 .4996 .37048 .48728 Metetra
.692 .717 .868 r
.37048 .48728 .38109 .4996 .39884 .49017 .38822 .47984 Metetra
.678 .749 .905 r
.38822 .47984 .39884 .49017 .4165 .48595 .40603 .47339 Metetra
.656 .705 .882 r
.40603 .47339 .4165 .48595 .43438 .47832 .42391 .46789 Metetra
.678 .75 .905 r
.42391 .46789 .43438 .47832 .45231 .47283 .44194 .46132 Metetra
.656 .725 .9 r
.44194 .46132 .45231 .47283 .47038 .46653 .46007 .45581 Metetra
.669 .745 .907 r
.46007 .45581 .47038 .46653 .48855 .46075 .47833 .44964 Metetra
.662 .737 .905 r
.47833 .44964 .48855 .46075 .50685 .45465 .4967 .44375 Metetra
.664 .743 .909 r
.4967 .44375 .50685 .45465 .52527 .44878 .5152 .43772 Metetra
.665 .742 .907 r
.5152 .43772 .52527 .44878 .54382 .44267 .53383 .43159 Metetra
.661 .741 .909 r
.53383 .43159 .54382 .44267 .56249 .43675 .55258 .42562 Metetra
.668 .744 .907 r
.55258 .42562 .56249 .43675 .58128 .43055 .57146 .41929 Metetra
.659 .74 .91 r
.57146 .41929 .58128 .43055 .60021 .42459 .59047 .41334 Metetra
.668 .745 .908 r
.59047 .41334 .60021 .42459 .61925 .41833 .60961 .40692 Metetra
.659 .74 .91 r
.60961 .40692 .61925 .41833 .63844 .41232 .62889 .40088 Metetra
.666 .743 .908 r
.62889 .40088 .63844 .41232 .65776 .40602 .64829 .39448 Metetra
.662 .741 .909 r
.64829 .39448 .65776 .40602 .67721 .39992 .66784 .38824 Metetra
.663 .741 .908 r
.66784 .38824 .67721 .39992 .69679 .39356 .68752 .38188 Metetra
.665 .743 .908 r
.68752 .38188 .69679 .39356 .71653 .38744 .70733 .37539 Metetra
.659 .735 .906 r
.70733 .37539 .71653 .38744 .73638 .38098 .7273 .36917 Metetra
.671 .746 .907 r
.7273 .36917 .73638 .38098 .75642 .37506 .74737 .36228 Metetra
.649 .721 .901 r
.74737 .36228 .75642 .37506 .77654 .3683 .76766 .35648 Metetra
.669 .748 .91 r
.76766 .35648 .77654 .3683 .79699 .36373 .78802 .34956 Metetra
.65 .701 .884 r
.78802 .34956 .79699 .36373 .81729 .35565 .80862 .34361 Metetra
.627 .73 .921 r
.80862 .34361 .81729 .35565 .83825 .35296 .82947 .3387 Metetra
.667 .71 .88 r
.82947 .3387 .83825 .35296 .85956 .3517 .85028 .33167 Metetra
.682 .646 .808 r
.85028 .33167 .85956 .3517 .8804 .34414 .87099 .32234 Metetra
.6 .588 .811 r
.87099 .32234 .8804 .34414 .90079 .33157 .89255 .31926 Metetra
.653 .671 .854 r
.28996 .49788 .30078 .51234 .31811 .50513 .30722 .49253 Metetra
.534 .656 .914 r
.30722 .49253 .31811 .50513 .33564 .49591 .32429 .49211 Metetra
.55 .859 .997 r
.32429 .49211 .33564 .49591 .35294 .49269 .34174 .48782 Metetra
.743 .874 .941 r
.34174 .48782 .35294 .49269 .37048 .48728 .35959 .47817 Metetra
.737 .784 .891 r
.35959 .47817 .37048 .48728 .38822 .47984 .37751 .46846 Metetra
.629 .718 .911 r
.37751 .46846 .38822 .47984 .40603 .47339 .3953 .46422 Metetra
.693 .779 .918 r
.3953 .46422 .40603 .47339 .42391 .46789 .41332 .45695 Metetra
.665 .739 .906 r
.41332 .45695 .42391 .46789 .44194 .46132 .43141 .45099 Metetra
.668 .753 .914 r
.43141 .45099 .44194 .46132 .46007 .45581 .44963 .44481 Metetra
.667 .742 .906 r
.44963 .44481 .46007 .45581 .47833 .44964 .46797 .43867 Metetra
.664 .743 .909 r
.46797 .43867 .47833 .44964 .4967 .44375 .48642 .43262 Metetra
.666 .742 .907 r
.48642 .43262 .4967 .44375 .5152 .43772 .50501 .42642 Metetra
.663 .739 .906 r
.50501 .42642 .5152 .43772 .53383 .43159 .52371 .42032 Metetra
.665 .741 .907 r
.52371 .42032 .53383 .43159 .55258 .42562 .54255 .41409 Metetra
.664 .738 .905 r
.54255 .41409 .55258 .42562 .57146 .41929 .56151 .40787 Metetra
.664 .741 .908 r
.56151 .40787 .57146 .41929 .59047 .41334 .58061 .40163 Metetra
.663 .737 .905 r
.58061 .40163 .59047 .41334 .60961 .40692 .59984 .39534 Metetra
.663 .741 .908 r
.59984 .39534 .60961 .40692 .62889 .40088 .6192 .38903 Metetra
.662 .737 .906 r
.6192 .38903 .62889 .40088 .64829 .39448 .6387 .38273 Metetra
.664 .741 .908 r
.6387 .38273 .64829 .39448 .66784 .38824 .65833 .3763 Metetra
.661 .738 .907 r
.65833 .3763 .66784 .38824 .68752 .38188 .67811 .36996 Metetra
.663 .741 .908 r
.67811 .36996 .68752 .38188 .70733 .37539 .69802 .36347 Metetra
.66 .741 .91 r
.69802 .36347 .70733 .37539 .7273 .36917 .71809 .35708 Metetra
.659 .739 .909 r
.71809 .35708 .7273 .36917 .74737 .36228 .7383 .3507 Metetra
.662 .752 .916 r
.7383 .3507 .74737 .36228 .76766 .35648 .75864 .34411 Metetra
.635 .727 .915 r
.75864 .34411 .76766 .35648 .78802 .34956 .77925 .33886 Metetra
.695 .784 .92 r
.77925 .33886 .78802 .34956 .80862 .34361 .79975 .33047 Metetra
.581 .692 .917 r
.79975 .33047 .80862 .34361 .82947 .3387 .82091 .32773 Metetra
.567 .73 .951 r
.82091 .32773 .82947 .3387 .85028 .33167 .84228 .32496 Metetra
.674 .874 .974 r
.84228 .32496 .85028 .33167 .87099 .32234 .86326 .3166 Metetra
.759 .922 .943 r
.86326 .3166 .87099 .32234 .89255 .31926 .88391 .30418 Metetra
.682 .774 .92 r
.27863 .48888 .28996 .49788 .30722 .49253 .29604 .48231 Metetra
.701 .755 .894 r
.29604 .48231 .30722 .49253 .32429 .49211 .31362 .47466 Metetra
.63 .628 .83 r
.31362 .47466 .32429 .49211 .34174 .48782 .3311 .47033 Metetra
.651 .637 .823 r
.3311 .47033 .34174 .48782 .35959 .47817 .34878 .46461 Metetra
.676 .698 .862 r
.34878 .46461 .35959 .47817 .37751 .46846 .36664 .45779 Metetra
.67 .746 .907 r
.36664 .45779 .37751 .46846 .3953 .46422 .38457 .45156 Metetra
.659 .709 .884 r
.38457 .45156 .3953 .46422 .41332 .45695 .40261 .44576 Metetra
.671 .739 .901 r
.40261 .44576 .41332 .45695 .43141 .45099 .42079 .43937 Metetra
.659 .729 .901 r
.42079 .43937 .43141 .45099 .44963 .44481 .43907 .43355 Metetra
.666 .739 .904 r
.43907 .43355 .44963 .44481 .46797 .43867 .45748 .42735 Metetra
.663 .738 .906 r
.45748 .42735 .46797 .43867 .48642 .43262 .47602 .42128 Metetra
.664 .74 .906 r
.47602 .42128 .48642 .43262 .50501 .42642 .49468 .41511 Metetra
.665 .742 .908 r
.49468 .41511 .50501 .42642 .52371 .42032 .51347 .40887 Metetra
.662 .74 .908 r
.51347 .40887 .52371 .42032 .54255 .41409 .53239 .40269 Metetra
.666 .744 .908 r
.53239 .40269 .54255 .41409 .56151 .40787 .55144 .3963 Metetra
.661 .74 .909 r
.55144 .3963 .56151 .40787 .58061 .40163 .57063 .39009 Metetra
.666 .744 .908 r
.57063 .39009 .58061 .40163 .59984 .39534 .58994 .38361 Metetra
.661 .74 .908 r
.58994 .38361 .59984 .39534 .6192 .38903 .6094 .37731 Metetra
.665 .743 .909 r
.6094 .37731 .6192 .38903 .6387 .38273 .62899 .3708 Metetra
.663 .74 .908 r
.62899 .3708 .6387 .38273 .65833 .3763 .64871 .36434 Metetra
.663 .741 .908 r
.64871 .36434 .65833 .3763 .67811 .36996 .66858 .35781 Metetra
.664 .74 .906 r
.66858 .35781 .67811 .36996 .69802 .36347 .68859 .35118 Metetra
.661 .738 .907 r
.68859 .35118 .69802 .36347 .71809 .35708 .70875 .34468 Metetra
.667 .74 .904 r
.70875 .34468 .71809 .35708 .7383 .3507 .72903 .33778 Metetra
.656 .727 .902 r
.72903 .33778 .7383 .3507 .75864 .34411 .74949 .33146 Metetra
.666 .738 .903 r
.74949 .33146 .75864 .34411 .77925 .33886 .77007 .32452 Metetra
.656 .707 .885 r
.77007 .32452 .77925 .33886 .79975 .33047 .79084 .31803 Metetra
.644 .736 .916 r
.79084 .31803 .79975 .33047 .82091 .32773 .81181 .31213 Metetra
.662 .693 .869 r
.81181 .31213 .82091 .32773 .84228 .32496 .83285 .30509 Metetra
.671 .647 .817 r
.83285 .30509 .84228 .32496 .86326 .3166 .85389 .29659 Metetra
.625 .624 .829 r
.85389 .29659 .86326 .3166 .88391 .30418 .87546 .29154 Metetra
.685 .733 .886 r
.26732 .47753 .27863 .48888 .29604 .48231 .28482 .47057 Metetra
.528 .675 .932 r
.28482 .47057 .29604 .48231 .31362 .47466 .30199 .4699 Metetra
.563 .845 .997 r
.30199 .4699 .31362 .47466 .3311 .47033 .31955 .46572 Metetra
.73 .882 .951 r
.31955 .46572 .3311 .47033 .34878 .46461 .33754 .45646 Metetra
.742 .808 .904 r
.33754 .45646 .34878 .46461 .36664 .45779 .35565 .44651 Metetra
.627 .724 .917 r
.35565 .44651 .36664 .45779 .38457 .45156 .37356 .44219 Metetra
.688 .779 .92 r
.37356 .44219 .38457 .45156 .40261 .44576 .39174 .43498 Metetra
.668 .748 .911 r
.39174 .43498 .40261 .44576 .42079 .43937 .40999 .42872 Metetra
.666 .751 .914 r
.40999 .42872 .42079 .43937 .43907 .43355 .42836 .42252 Metetra
.669 .747 .909 r
.42836 .42252 .43907 .43355 .45748 .42735 .44686 .41612 Metetra
.662 .742 .91 r
.44686 .41612 .45748 .42735 .47602 .42128 .46548 .41 Metetra
.668 .745 .908 r
.46548 .41 .47602 .42128 .49468 .41511 .48422 .40357 Metetra
.662 .739 .908 r
.48422 .40357 .49468 .41511 .51347 .40887 .5031 .39738 Metetra
.666 .743 .908 r
.5031 .39738 .51347 .40887 .53239 .40269 .5221 .39093 Metetra
.663 .739 .906 r
.5221 .39093 .53239 .40269 .55144 .3963 .54124 .38461 Metetra
.664 .742 .908 r
.54124 .38461 .55144 .3963 .57063 .39009 .56051 .37818 Metetra
.663 .739 .906 r
.56051 .37818 .57063 .39009 .58994 .38361 .57992 .37176 Metetra
.664 .742 .908 r
.57992 .37176 .58994 .38361 .6094 .37731 .59946 .36522 Metetra
.661 .738 .907 r
.59946 .36522 .6094 .37731 .62899 .3708 .61915 .35882 Metetra
.665 .743 .908 r
.61915 .35882 .62899 .3708 .64871 .36434 .63897 .35215 Metetra
.66 .739 .908 r
.63897 .35215 .64871 .36434 .66858 .35781 .65894 .34572 Metetra
.665 .744 .909 r
.65894 .34572 .66858 .35781 .68859 .35118 .67904 .33897 Metetra
.658 .741 .911 r
.67904 .33897 .68859 .35118 .70875 .34468 .6993 .3325 Metetra
.662 .744 .911 r
.6993 .3325 .70875 .34468 .72903 .33778 .71971 .32583 Metetra
.659 .749 .917 r
.71971 .32583 .72903 .33778 .74949 .33146 .74026 .31921 Metetra
.639 .737 .92 r
.74026 .31921 .74949 .33146 .77007 .32452 .76105 .31355 Metetra
.696 .785 .92 r
.76105 .31355 .77007 .32452 .79084 .31803 .78176 .30492 Metetra
.577 .697 .923 r
.78176 .30492 .79084 .31803 .81181 .31213 .80313 .3021 Metetra
.571 .759 .967 r
.80313 .3021 .81181 .31213 .83285 .30509 .82464 .29858 Metetra
.678 .885 .975 r
.82464 .29858 .83285 .30509 .85389 .29659 .84582 .28977 Metetra
.761 .903 .939 r
.84582 .28977 .85389 .29659 .87546 .29154 .86673 .27728 Metetra
.668 .722 .89 r
.2559 .4657 .26732 .47753 .28482 .47057 .2734 .45957 Metetra
.675 .74 .899 r
.2734 .45957 .28482 .47057 .30199 .4699 .29103 .4531 Metetra
.647 .646 .836 r
.29103 .4531 .30199 .4699 .31955 .46572 .30871 .44763 Metetra
.651 .634 .821 r
.30871 .44763 .31955 .46572 .33754 .45646 .32654 .44168 Metetra
.664 .681 .856 r
.32654 .44168 .33754 .45646 .35565 .44651 .34451 .43536 Metetra
.666 .741 .906 r
.34451 .43536 .35565 .44651 .37356 .44219 .36258 .42921 Metetra
.661 .709 .883 r
.36258 .42921 .37356 .44219 .39174 .43498 .38077 .42316 Metetra
.666 .731 .898 r
.38077 .42316 .39174 .43498 .40999 .42872 .3991 .41689 Metetra
.662 .731 .901 r
.3991 .41689 .40999 .42872 .42836 .42252 .41754 .41078 Metetra
.664 .735 .902 r
.41754 .41078 .42836 .42252 .44686 .41612 .43611 .40451 Metetra
.663 .738 .906 r
.43611 .40451 .44686 .41612 .46548 .41 .45481 .39826 Metetra
.664 .737 .905 r
.45481 .39826 .46548 .41 .48422 .40357 .47363 .39194 Metetra
.664 .741 .908 r
.47363 .39194 .48422 .40357 .5031 .39738 .49259 .38557 Metetra
.663 .739 .906 r
.49259 .38557 .5031 .39738 .5221 .39093 .51168 .37919 Metetra
.664 .742 .908 r
.51168 .37919 .5221 .39093 .54124 .38461 .53091 .37272 Metetra
.663 .74 .908 r
.53091 .37272 .54124 .38461 .56051 .37818 .55027 .36627 Metetra
.664 .742 .908 r
.55027 .36627 .56051 .37818 .57992 .37176 .56977 .3597 Metetra
.663 .74 .908 r
.56977 .3597 .57992 .37176 .59946 .36522 .5894 .35315 Metetra
.664 .742 .908 r
.5894 .35315 .59946 .36522 .61915 .35882 .60918 .34651 Metetra
.663 .739 .906 r
.60918 .34651 .61915 .35882 .63897 .35215 .62909 .33985 Metetra
.663 .741 .908 r
.62909 .33985 .63897 .35215 .65894 .34572 .64915 .33313 Metetra
.664 .738 .905 r
.64915 .33313 .65894 .34572 .67904 .33897 .66935 .32635 Metetra
.663 .738 .906 r
.66935 .32635 .67904 .33897 .6993 .3325 .6897 .31958 Metetra
.665 .735 .902 r
.6897 .31958 .6993 .3325 .71971 .32583 .71019 .31264 Metetra
.661 .731 .901 r
.71019 .31264 .71971 .32583 .74026 .31921 .73085 .30586 Metetra
.664 .731 .899 r
.73085 .30586 .74026 .31921 .76105 .31355 .75164 .29884 Metetra
.66 .708 .883 r
.75164 .29884 .76105 .31355 .78176 .30492 .77259 .29193 Metetra
.658 .738 .909 r
.77259 .29193 .78176 .30492 .80313 .3021 .79372 .28517 Metetra
.659 .679 .858 r
.79372 .28517 .80313 .3021 .82464 .29858 .81498 .27802 Metetra
.657 .638 .819 r
.81498 .27802 .82464 .29858 .84582 .28977 .83635 .27037 Metetra
.646 .645 .835 r
.83635 .27037 .84582 .28977 .86673 .27728 .85799 .26374 Metetra
.697 .773 .91 r
.24415 .45618 .2559 .4657 .2734 .45957 .26183 .44866 Metetra
.517 .693 .948 r
.26183 .44866 .2734 .45957 .29103 .4531 .2791 .44783 Metetra
.569 .839 .996 r
.2791 .44783 .29103 .4531 .30871 .44763 .29679 .44359 Metetra
.723 .897 .958 r
.29679 .44359 .30871 .44763 .32654 .44168 .31494 .43431 Metetra
.746 .829 .916 r
.31494 .43431 .32654 .44168 .34451 .43536 .33322 .42416 Metetra
.625 .73 .922 r
.33322 .42416 .34451 .43536 .36258 .42921 .35128 .41971 Metetra
.687 .781 .922 r
.35128 .41971 .36258 .42921 .38077 .42316 .36961 .41241 Metetra
.669 .754 .915 r
.36961 .41241 .38077 .42316 .3991 .41689 .38802 .40596 Metetra
.665 .751 .914 r
.38802 .40596 .3991 .41689 .41754 .41078 .40655 .39963 Metetra
.669 .75 .911 r
.40655 .39963 .41754 .41078 .43611 .40451 .42521 .39304 Metetra
.662 .743 .911 r
.42521 .39304 .43611 .40451 .45481 .39826 .44399 .38679 Metetra
.668 .747 .909 r
.44399 .38679 .45481 .39826 .47363 .39194 .46291 .38018 Metetra
.661 .741 .909 r
.46291 .38018 .47363 .39194 .49259 .38557 .48195 .37384 Metetra
.666 .744 .909 r
.48195 .37384 .49259 .38557 .51168 .37919 .50113 .36724 Metetra
.663 .741 .908 r
.50113 .36724 .51168 .37919 .53091 .37272 .52044 .36074 Metetra
.664 .742 .908 r
.52044 .36074 .53091 .37272 .55027 .36627 .53989 .35415 Metetra
.663 .741 .908 r
.53989 .35415 .55027 .36627 .56977 .3597 .55948 .34755 Metetra
.664 .742 .908 r
.55948 .34755 .56977 .3597 .5894 .35315 .57921 .34085 Metetra
.661 .74 .908 r
.57921 .34085 .5894 .35315 .60918 .34651 .59908 .33427 Metetra
.666 .744 .909 r
.59908 .33427 .60918 .34651 .62909 .33985 .61909 .3274 Metetra
.659 .74 .909 r
.61909 .3274 .62909 .33985 .64915 .33313 .63925 .32082 Metetra
.665 .746 .91 r
.63925 .32082 .64915 .33313 .66935 .32635 .65955 .31386 Metetra
.658 .742 .912 r
.65955 .31386 .66935 .32635 .6897 .31958 .68001 .30724 Metetra
.662 .748 .914 r
.68001 .30724 .6897 .31958 .71019 .31264 .70062 .30035 Metetra
.659 .749 .917 r
.70062 .30035 .71019 .31264 .73085 .30586 .72139 .29359 Metetra
.64 .744 .924 r
.72139 .29359 .73085 .30586 .75164 .29884 .74237 .28769 Metetra
.697 .788 .921 r
.74237 .28769 .75164 .29884 .77259 .29193 .76331 .27884 Metetra
.575 .702 .929 r
.76331 .27884 .77259 .29193 .79372 .28517 .78487 .27588 Metetra
.565 .779 .979 r
.78487 .27588 .79372 .28517 .81498 .27802 .80658 .27202 Metetra
.672 .899 .977 r
.80658 .27202 .81498 .27802 .83635 .27037 .82798 .26293 Metetra
.762 .895 .937 r
.82798 .26293 .83635 .27037 .85799 .26374 .84915 .25025 Metetra
.668 .719 .888 r
.23247 .44389 .24415 .45618 .26183 .44866 .25011 .43761 Metetra
.675 .744 .903 r
.25011 .43761 .26183 .44866 .2791 .44783 .26789 .43099 Metetra
.647 .65 .839 r
.26789 .43099 .2791 .44783 .29679 .44359 .2857 .42537 Metetra
.65 .637 .823 r
.2857 .42537 .29679 .44359 .31494 .43431 .30368 .41927 Metetra
.663 .681 .857 r
.30368 .41927 .31494 .43431 .33322 .42416 .3218 .4128 Metetra
.666 .742 .907 r
.3218 .4128 .33322 .42416 .35128 .41971 .34002 .40649 Metetra
.661 .71 .884 r
.34002 .40649 .35128 .41971 .36961 .41241 .35837 .40028 Metetra
.666 .731 .898 r
.35837 .40028 .36961 .41241 .38802 .40596 .37685 .39386 Metetra
.662 .732 .901 r
.37685 .39386 .38802 .40596 .40655 .39963 .39545 .38759 Metetra
.664 .735 .902 r
.39545 .38759 .40655 .39963 .42521 .39304 .41418 .38116 Metetra
.663 .739 .906 r
.41418 .38116 .42521 .39304 .44399 .38679 .43304 .37474 Metetra
.664 .737 .905 r
.43304 .37474 .44399 .38679 .46291 .38018 .45204 .36826 Metetra
.664 .741 .908 r
.45204 .36826 .46291 .38018 .48195 .37384 .47117 .36173 Metetra
.663 .739 .906 r
.47117 .36173 .48195 .37384 .50113 .36724 .49044 .35518 Metetra
.664 .742 .908 r
.49044 .35518 .50113 .36724 .52044 .36074 .50984 .34853 Metetra
.663 .74 .908 r
.50984 .34853 .52044 .36074 .53989 .35415 .52938 .34191 Metetra
.664 .742 .908 r
.52938 .34191 .53989 .35415 .55948 .34755 .54906 .33517 Metetra
.663 .74 .908 r
.54906 .33517 .55948 .34755 .57921 .34085 .56888 .32845 Metetra
.664 .742 .908 r
.56888 .32845 .57921 .34085 .59908 .33427 .58884 .32163 Metetra
.663 .739 .906 r
.58884 .32163 .59908 .33427 .61909 .3274 .60895 .31479 Metetra
.663 .741 .908 r
.60895 .31479 .61909 .3274 .63925 .32082 .6292 .30789 Metetra
.664 .737 .905 r
.6292 .30789 .63925 .32082 .65955 .31386 .6496 .30093 Metetra
.663 .739 .906 r
.6496 .30093 .65955 .31386 .68001 .30724 .67016 .29397 Metetra
.665 .735 .902 r
.67016 .29397 .68001 .30724 .70062 .30035 .69085 .28685 Metetra
.661 .731 .902 r
.69085 .28685 .70062 .30035 .72139 .29359 .71172 .27987 Metetra
.664 .731 .899 r
.71172 .27987 .72139 .29359 .74237 .28769 .73272 .27267 Metetra
.66 .71 .884 r
.73272 .27267 .74237 .28769 .76331 .27884 .75389 .26556 Metetra
.658 .739 .91 r
.75389 .26556 .76331 .27884 .78487 .27588 .77524 .25861 Metetra
.659 .68 .859 r
.77524 .25861 .78487 .27588 .80658 .27202 .79672 .25126 Metetra
.657 .64 .822 r
.79672 .25126 .80658 .27202 .82798 .26293 .81832 .24341 Metetra
.645 .649 .839 r
.81832 .24341 .82798 .26293 .84915 .25025 .84019 .23658 Metetra
.689 .768 .912 r
.22042 .43392 .23247 .44389 .25011 .43761 .23822 .42666 Metetra
.513 .697 .952 r
.23822 .42666 .25011 .43761 .26789 .43099 .2556 .42574 Metetra
.571 .843 .996 r
.2556 .42574 .26789 .43099 .2857 .42537 .27342 .42129 Metetra
.728 .899 .956 r
.27342 .42129 .2857 .42537 .30368 .41927 .29175 .41168 Metetra
.745 .829 .916 r
.29175 .41168 .30368 .41927 .3218 .4128 .31022 .40138 Metetra
.626 .732 .923 r
.31022 .40138 .3218 .4128 .34002 .40649 .32842 .39677 Metetra
.689 .782 .922 r
.32842 .39677 .34002 .40649 .35837 .40028 .34692 .38923 Metetra
.668 .754 .915 r
.34692 .38923 .35837 .40028 .37685 .39386 .36548 .38266 Metetra
.666 .752 .914 r
.36548 .38266 .37685 .39386 .39545 .38759 .38417 .37613 Metetra
.669 .75 .911 r
.38417 .37613 .39545 .38759 .41418 .38116 .403 .36941 Metetra
.662 .744 .911 r
.403 .36941 .41418 .38116 .43304 .37474 .42195 .36297 Metetra
.668 .746 .909 r
.42195 .36297 .43304 .37474 .45204 .36826 .44103 .35621 Metetra
.662 .741 .909 r
.44103 .35621 .45204 .36826 .47117 .36173 .46025 .34968 Metetra
.666 .744 .908 r
.46025 .34968 .47117 .36173 .49044 .35518 .4796 .34289 Metetra
.663 .74 .908 r
.4796 .34289 .49044 .35518 .50984 .34853 .49909 .33624 Metetra
.664 .742 .908 r
.49909 .33624 .50984 .34853 .52938 .34191 .51872 .32946 Metetra
.663 .741 .908 r
.51872 .32946 .52938 .34191 .54906 .33517 .5385 .3227 Metetra
.664 .742 .908 r
.5385 .3227 .54906 .33517 .56888 .32845 .55841 .31581 Metetra
.661 .74 .908 r
.55841 .31581 .56888 .32845 .58884 .32163 .57847 .30905 Metetra
.665 .744 .909 r
.57847 .30905 .58884 .32163 .60895 .31479 .59868 .30202 Metetra
.66 .74 .91 r
.59868 .30202 .60895 .31479 .6292 .30789 .61903 .29523 Metetra
.665 .746 .91 r
.61903 .29523 .6292 .30789 .6496 .30093 .63954 .28812 Metetra
.658 .742 .912 r
.63954 .28812 .6496 .30093 .67016 .29397 .6602 .28128 Metetra
.662 .747 .914 r
.6602 .28128 .67016 .29397 .69085 .28685 .68101 .27424 Metetra
.66 .75 .917 r
.68101 .27424 .69085 .28685 .71172 .27987 .70199 .26724 Metetra
.639 .743 .924 r
.70199 .26724 .71172 .27987 .73272 .27267 .72319 .26122 Metetra
.697 .788 .921 r
.72319 .26122 .73272 .27267 .75389 .26556 .74435 .25218 Metetra
.575 .704 .93 r
.74435 .25218 .75389 .26556 .77524 .25861 .76612 .24901 Metetra
.562 .777 .979 r
.76612 .24901 .77524 .25861 .79672 .25126 .78805 .24514 Metetra
.671 .9 .978 r
.78805 .24514 .79672 .25126 .81832 .24341 .8097 .23591 Metetra
.762 .898 .937 r
.8097 .23591 .81832 .24341 .84019 .23658 .83112 .22295 Metetra
.682 .76 .91 r
.20825 .42347 .22042 .43392 .23822 .42666 .2261 .41644 Metetra
.703 .77 .904 r
.2261 .41644 .23822 .42666 .2556 .42574 .24415 .40831 Metetra
.628 .64 .843 r
.24415 .40831 .2556 .42574 .27342 .42129 .26203 .40356 Metetra
.651 .647 .833 r
.26203 .40356 .27342 .42129 .29175 .41168 .28015 .39738 Metetra
.676 .701 .865 r
.28015 .39738 .29175 .41168 .31022 .40138 .29847 .39009 Metetra
.671 .75 .91 r
.29847 .39009 .31022 .40138 .32842 .39677 .31687 .38339 Metetra
.659 .712 .887 r
.31687 .38339 .32842 .39677 .34692 .38923 .33537 .37712 Metetra
.671 .738 .9 r
.33537 .37712 .34692 .38923 .36548 .38266 .35402 .37026 Metetra
.659 .731 .903 r
.35402 .37026 .36548 .38266 .38417 .37613 .37278 .36396 Metetra
.666 .739 .904 r
.37278 .36396 .38417 .37613 .403 .36941 .39168 .35727 Metetra
.663 .74 .907 r
.39168 .35727 .403 .36941 .42195 .36297 .41071 .35071 Metetra
.664 .739 .906 r
.41071 .35071 .42195 .36297 .44103 .35621 .42988 .34405 Metetra
.665 .743 .908 r
.42988 .34405 .44103 .35621 .46025 .34968 .44918 .33731 Metetra
.662 .74 .908 r
.44918 .33731 .46025 .34968 .4796 .34289 .46862 .33063 Metetra
.666 .744 .909 r
.46862 .33063 .4796 .34289 .49909 .33624 .48821 .32373 Metetra
.661 .74 .909 r
.48821 .32373 .49909 .33624 .51872 .32946 .50793 .31701 Metetra
.666 .744 .909 r
.50793 .31701 .51872 .32946 .5385 .3227 .52779 .31 Metetra
.661 .74 .908 r
.52779 .31 .5385 .3227 .55841 .31581 .5478 .30318 Metetra
.665 .744 .909 r
.5478 .30318 .55841 .31581 .57847 .30905 .56796 .29613 Metetra
.663 .74 .907 r
.56796 .29613 .57847 .30905 .59868 .30202 .58826 .28914 Metetra
.663 .742 .909 r
.58826 .28914 .59868 .30202 .61903 .29523 .60872 .28207 Metetra
.664 .74 .906 r
.60872 .28207 .61903 .29523 .63954 .28812 .62932 .27488 Metetra
.661 .739 .908 r
.62932 .27488 .63954 .28812 .6602 .28128 .65008 .26783 Metetra
.667 .739 .904 r
.65008 .26783 .6602 .28128 .68101 .27424 .67099 .26037 Metetra
.655 .729 .904 r
.67099 .26037 .68101 .27424 .70199 .26724 .69207 .25349 Metetra
.666 .737 .903 r
.69207 .25349 .70199 .26724 .72319 .26122 .71329 .24597 Metetra
.656 .71 .888 r
.71329 .24597 .72319 .26122 .74435 .25218 .7347 .23891 Metetra
.644 .74 .919 r
.7347 .23891 .74435 .25218 .76612 .24901 .75633 .23243 Metetra
.662 .697 .872 r
.75633 .23243 .76612 .24901 .78805 .24514 .77804 .22481 Metetra
.672 .657 .827 r
.77804 .22481 .78805 .24514 .8097 .23591 .79979 .21568 Metetra
.624 .636 .842 r
.79979 .21568 .8097 .23591 .83112 .22295 .82202 .21005 Metetra
.656 .714 .891 r
.19615 .41061 .20825 .42347 .2261 .41644 .21395 .40467 Metetra
.513 .686 .945 r
.21395 .40467 .2261 .41644 .24415 .40831 .23142 .40378 Metetra
.567 .86 .997 r
.23142 .40378 .24415 .40831 .26203 .40356 .2494 .39892 Metetra
.743 .891 .946 r
.2494 .39892 .26203 .40356 .28015 .39738 .26796 .38857 Metetra
.742 .809 .905 r
.26796 .38857 .28015 .39738 .29847 .39009 .28661 .37817 Metetra
.627 .728 .92 r
.28661 .37817 .29847 .39009 .31687 .38339 .30495 .37334 Metetra
.694 .782 .919 r
.30495 .37334 .31687 .38339 .33537 .37712 .32363 .36542 Metetra
.665 .746 .911 r
.32363 .36542 .33537 .37712 .35402 .37026 .34235 .35882 Metetra
.668 .754 .914 r
.34235 .35882 .35402 .37026 .37278 .36396 .36121 .352 Metetra
.667 .745 .909 r
.36121 .352 .37278 .36396 .39168 .35727 .3802 .3452 Metetra
.664 .744 .91 r
.3802 .3452 .39168 .35727 .41071 .35071 .39932 .3385 Metetra
.666 .744 .908 r
.39932 .3385 .41071 .35071 .42988 .34405 .41858 .33165 Metetra
.663 .741 .908 r
.41858 .33165 .42988 .34405 .44918 .33731 .43797 .32488 Metetra
.665 .743 .908 r
.43797 .32488 .44918 .33731 .46862 .33063 .4575 .31798 Metetra
.664 .74 .907 r
.4575 .31798 .46862 .33063 .48821 .32373 .47717 .31108 Metetra
.664 .742 .908 r
.47717 .31108 .48821 .32373 .50793 .31701 .49699 .30415 Metetra
.663 .739 .907 r
.49699 .30415 .50793 .31701 .52779 .31 .51695 .29717 Metetra
.663 .741 .908 r
.51695 .29717 .52779 .31 .5478 .30318 .53705 .29016 Metetra
.662 .739 .907 r
.53705 .29016 .5478 .30318 .56796 .29613 .55731 .28315 Metetra
.664 .742 .909 r
.55731 .28315 .56796 .29613 .58826 .28914 .57771 .276 Metetra
.661 .74 .909 r
.57771 .276 .58826 .28914 .60872 .28207 .59827 .26894 Metetra
.663 .743 .909 r
.59827 .26894 .60872 .28207 .62932 .27488 .61897 .26171 Metetra
.66 .743 .911 r
.61897 .26171 .62932 .27488 .65008 .26783 .63984 .25458 Metetra
.659 .743 .912 r
.63984 .25458 .65008 .26783 .67099 .26037 .66087 .24747 Metetra
.663 .752 .916 r
.66087 .24747 .67099 .26037 .69207 .25349 .68205 .24012 Metetra
.634 .734 .92 r
.68205 .24012 .69207 .25349 .71329 .24597 .70348 .23413 Metetra
.696 .787 .921 r
.70348 .23413 .71329 .24597 .7347 .23891 .72488 .22494 Metetra
.578 .701 .927 r
.72488 .22494 .7347 .23891 .75633 .23243 .74684 .2215 Metetra
.557 .753 .969 r
.74684 .2215 .75633 .23243 .77804 .22481 .76904 .21801 Metetra
.67 .89 .978 r
.76904 .21801 .77804 .22481 .79979 .21568 .79096 .20883 Metetra
.763 .917 .941 r
.79096 .20883 .79979 .21568 .82202 .21005 .81264 .19549 Metetra
.699 .83 .945 r
.1833 .40333 .19615 .41061 .21395 .40467 .2014 .39533 Metetra
.736 .795 .9 r
.2014 .39533 .21395 .40467 .23142 .40378 .21979 .38526 Metetra
.609 .624 .841 r
.21979 .38526 .23142 .40378 .2494 .39892 .23771 .38137 Metetra
.648 .652 .84 r
.23771 .38137 .2494 .39892 .26796 .38857 .25597 .37521 Metetra
.693 .725 .874 r
.25597 .37521 .26796 .38857 .28661 .37817 .27452 .36695 Metetra
.678 .758 .911 r
.27452 .36695 .28661 .37817 .30495 .37334 .29311 .3597 Metetra
.656 .712 .889 r
.29311 .3597 .30495 .37334 .32363 .36542 .31175 .35343 Metetra
.678 .748 .903 r
.31175 .35343 .32363 .36542 .34235 .35882 .3306 .34605 Metetra
.656 .729 .903 r
.3306 .34605 .34235 .35882 .36121 .352 .34951 .33975 Metetra
.669 .743 .906 r
.34951 .33975 .36121 .352 .3802 .3452 .36858 .33277 Metetra
.662 .74 .908 r
.36858 .33277 .3802 .3452 .39932 .3385 .38778 .32606 Metetra
.664 .742 .908 r
.38778 .32606 .39932 .3385 .41858 .33165 .40712 .31921 Metetra
.666 .744 .909 r
.40712 .31921 .41858 .33165 .43797 .32488 .4266 .31225 Metetra
.661 .741 .909 r
.4266 .31225 .43797 .32488 .4575 .31798 .44622 .30544 Metetra
.668 .746 .909 r
.44622 .30544 .4575 .31798 .47717 .31108 .46599 .29825 Metetra
.659 .74 .91 r
.46599 .29825 .47717 .31108 .49699 .30415 .4859 .29145 Metetra
.668 .747 .909 r
.4859 .29145 .49699 .30415 .51695 .29717 .50595 .28415 Metetra
.659 .74 .91 r
.50595 .28415 .51695 .29717 .53705 .29016 .52615 .27725 Metetra
.666 .746 .91 r
.52615 .27725 .53705 .29016 .55731 .28315 .54651 .26995 Metetra
.662 .741 .909 r
.54651 .26995 .55731 .28315 .57771 .276 .56701 .26282 Metetra
.663 .743 .91 r
.56701 .26282 .57771 .276 .59827 .26894 .58767 .25555 Metetra
.665 .742 .908 r
.58767 .25555 .59827 .26894 .61897 .26171 .60848 .24814 Metetra
.659 .738 .909 r
.60848 .24814 .61897 .26171 .63984 .25458 .62945 .24101 Metetra
.671 .745 .906 r
.62945 .24101 .63984 .25458 .66087 .24747 .65056 .23317 Metetra
.649 .726 .905 r
.65056 .23317 .66087 .24747 .68205 .24012 .67188 .22644 Metetra
.669 .746 .908 r
.67188 .22644 .68205 .24012 .70348 .23413 .69332 .21855 Metetra
.649 .709 .891 r
.69332 .21855 .70348 .23413 .72488 .22494 .71498 .21166 Metetra
.627 .739 .928 r
.71498 .21166 .72488 .22494 .74684 .2215 .73689 .20581 Metetra
.667 .718 .887 r
.73689 .20581 .74684 .2215 .76904 .21801 .75883 .19778 Metetra
.687 .67 .828 r
.75883 .19778 .76904 .21801 .79096 .20883 .78074 .18739 Metetra
.595 .613 .84 r
.78074 .18739 .79096 .20883 .81264 .19549 .80338 .1834 Metetra
.592 .636 .864 r
.17131 .38635 .1833 .40333 .2014 .39533 .18893 .38329 Metetra
.499 .681 .947 r
.18893 .38329 .2014 .39533 .21979 .38526 .20646 .38263 Metetra
.548 .888 .984 r
.20646 .38263 .21979 .38526 .23771 .38137 .22465 .37701 Metetra
.77 .898 .933 r
.22465 .37701 .23771 .38137 .25597 .37521 .24353 .36512 Metetra
.737 .79 .895 r
.24353 .36512 .25597 .37521 .27452 .36695 .26235 .35463 Metetra
.63 .728 .918 r
.26235 .35463 .27452 .36695 .29311 .3597 .28085 .34953 Metetra
.704 .787 .916 r
.28085 .34953 .29311 .3597 .31175 .35343 .29975 .3409 Metetra
.657 .735 .907 r
.29975 .3409 .31175 .35343 .3306 .34605 .3186 .33447 Metetra
.674 .758 .914 r
.3186 .33447 .3306 .34605 .34951 .33975 .33765 .32719 Metetra
.662 .739 .907 r
.33765 .32719 .34951 .33975 .36858 .33277 .35679 .32045 Metetra
.668 .747 .909 r
.35679 .32045 .36858 .33277 .38778 .32606 .37609 .31336 Metetra
.662 .74 .908 r
.37609 .31336 .38778 .32606 .40712 .31921 .39552 .30651 Metetra
.667 .743 .907 r
.39552 .30651 .40712 .31921 .4266 .31225 .41509 .29939 Metetra
.662 .74 .908 r
.41509 .29939 .4266 .31225 .44622 .30544 .4348 .29246 Metetra
.667 .741 .906 r
.4348 .29246 .44622 .30544 .46599 .29825 .45466 .28523 Metetra
.661 .74 .909 r
.45466 .28523 .46599 .29825 .4859 .29145 .47466 .27825 Metetra
.666 .741 .906 r
.47466 .27825 .4859 .29145 .50595 .28415 .49481 .27094 Metetra
.66 .74 .909 r
.49481 .27094 .50595 .28415 .52615 .27725 .51511 .26388 Metetra
.665 .741 .906 r
.51511 .26388 .52615 .27725 .54651 .26995 .53556 .25651 Metetra
.661 .74 .908 r
.53556 .25651 .54651 .26995 .56701 .26282 .55616 .24934 Metetra
.665 .742 .908 r
.55616 .24934 .56701 .26282 .58767 .25555 .57692 .24189 Metetra
.659 .739 .909 r
.57692 .24189 .58767 .25555 .60848 .24814 .59784 .23467 Metetra
.665 .746 .91 r
.59784 .23467 .60848 .24814 .62945 .24101 .61891 .2271 Metetra
.653 .736 .91 r
.61891 .2271 .62945 .24101 .65056 .23317 .64017 .22007 Metetra
.67 .757 .916 r
.64017 .22007 .65056 .23317 .67188 .22644 .66155 .21216 Metetra
.624 .721 .916 r
.66155 .21216 .67188 .22644 .69332 .21855 .68322 .20651 Metetra
.694 .789 .924 r
.68322 .20651 .69332 .21855 .71498 .21166 .70487 .19721 Metetra
.581 .701 .925 r
.70487 .19721 .71498 .21166 .73689 .20581 .72704 .19347 Metetra
.528 .717 .959 r
.72704 .19347 .73689 .20581 .75883 .19778 .74955 .19119 Metetra
.649 .892 .983 r
.74955 .19119 .75883 .19778 .78074 .18739 .77179 .1824 Metetra
.755 .953 .94 r
.77179 .1824 .78074 .18739 .80338 .1834 .79373 .16844 Metetra
.683 .949 .957 r
.15732 .38562 .17131 .38635 .18893 .38329 .17576 .376 Metetra
.789 .837 .888 r
.17576 .376 .18893 .38329 .20646 .38263 .19469 .36249 Metetra
.597 .605 .831 r
.19469 .36249 .20646 .38263 .22465 .37701 .21269 .35898 Metetra
.638 .647 .843 r
.21269 .35898 .22465 .37701 .24353 .36512 .23106 .35326 Metetra
.717 .759 .886 r
.23106 .35326 .24353 .36512 .26235 .35463 .2499 .34365 Metetra
.694 .771 .911 r
.2499 .34365 .26235 .35463 .28085 .34953 .26872 .33544 Metetra
.649 .709 .891 r
.26872 .33544 .28085 .34953 .29975 .3409 .28749 .32932 Metetra
.689 .763 .908 r
.28749 .32932 .29975 .3409 .3186 .33447 .30655 .32124 Metetra
.651 .726 .904 r
.30655 .32124 .3186 .33447 .33765 .32719 .3256 .315 Metetra
.672 .751 .91 r
.3256 .315 .33765 .32719 .35679 .32045 .34486 .30767 Metetra
.661 .739 .908 r
.34486 .30767 .35679 .32045 .37609 .31336 .36423 .30082 Metetra
.664 .746 .911 r
.36423 .30082 .37609 .31336 .39552 .30651 .38375 .29377 Metetra
.667 .745 .909 r
.38375 .29377 .39552 .30651 .41509 .29939 .40341 .28654 Metetra
.66 .742 .911 r
.40341 .28654 .41509 .29939 .4348 .29246 .42321 .27964 Metetra
.671 .748 .908 r
.42321 .27964 .4348 .29246 .45466 .28523 .44317 .2721 Metetra
.656 .74 .911 r
.44317 .2721 .45466 .28523 .47466 .27825 .46326 .26527 Metetra
.671 .749 .909 r
.46326 .26527 .47466 .27825 .49481 .27094 .48351 .25761 Metetra
.656 .74 .911 r
.48351 .25761 .49481 .27094 .51511 .26388 .5039 .25066 Metetra
.668 .747 .91 r
.5039 .25066 .51511 .26388 .53556 .25651 .52446 .24308 Metetra
.66 .743 .911 r
.52446 .24308 .53556 .25651 .55616 .24934 .54516 .23582 Metetra
.663 .744 .91 r
.54516 .23582 .55616 .24934 .57692 .24189 .56603 .22837 Metetra
.666 .747 .911 r
.56603 .22837 .57692 .24189 .59784 .23467 .58705 .22071 Metetra
.655 .737 .91 r
.58705 .22071 .59784 .23467 .61891 .2271 .60824 .21354 Metetra
.676 .753 .909 r
.60824 .21354 .61891 .2271 .64017 .22007 .62957 .20525 Metetra
.639 .72 .906 r
.62957 .20525 .64017 .22007 .66155 .21216 .65113 .19883 Metetra
.676 .761 .915 r
.65113 .19883 .66155 .21216 .68322 .20651 .67277 .1904 Metetra
.634 .701 .894 r
.67277 .1904 .68322 .20651 .70487 .19721 .69471 .18411 Metetra
.598 .737 .942 r
.69471 .18411 .70487 .19721 .72704 .19347 .71693 .17926 Metetra
.68 .754 .907 r
.71693 .17926 .72704 .19347 .74955 .19119 .73908 .17038 Metetra
.693 .672 .825 r
.73908 .17038 .74955 .19119 .77179 .1824 .76122 .15919 Metetra
.54 .57 .834 r
.76122 .15919 .77179 .1824 .79373 .16844 .78439 .15838 Metetra
.569 .613 .857 r
.14515 .3672 .15732 .38562 .17576 .376 .16279 .36501 Metetra
.429 .679 .968 r
.16279 .36501 .17576 .376 .19469 .36249 .18033 .36539 Metetra
.419 .866 .829 r
.18033 .36539 .19469 .36249 .21269 .35898 .19885 .35805 Metetra
.826 .949 .901 r
.19885 .35805 .21269 .35898 .23106 .35326 .21833 .34212 Metetra
.738 .777 .884 r
.21833 .34212 .23106 .35326 .2499 .34365 .23739 .33117 Metetra
.634 .732 .919 r
.23739 .33117 .2499 .34365 .26872 .33544 .25605 .32573 Metetra
.73 .805 .91 r
.25605 .32573 .26872 .33544 .28749 .32932 .27524 .31553 Metetra
.638 .714 .902 r
.27524 .31553 .28749 .32932 .30655 .32124 .29419 .30984 Metetra
.69 .771 .913 r
.29419 .30984 .30655 .32124 .3256 .315 .31346 .30159 Metetra
.649 .726 .906 r
.31346 .30159 .3256 .315 .34486 .30767 .33273 .29531 Metetra
.68 .755 .908 r
.33273 .29531 .34486 .30767 .36423 .30082 .35224 .28746 Metetra
.652 .731 .907 r
.35224 .28746 .36423 .30082 .38375 .29377 .37181 .28093 Metetra
.676 .749 .906 r
.37181 .28093 .38375 .29377 .40341 .28654 .39159 .27316 Metetra
.653 .734 .909 r
.39159 .27316 .40341 .28654 .42321 .27964 .41147 .26648 Metetra
.674 .746 .905 r
.41147 .26648 .42321 .27964 .44317 .2721 .43153 .25866 Metetra
.653 .737 .911 r
.43153 .25866 .44317 .2721 .46326 .26527 .4517 .25187 Metetra
.674 .746 .905 r
.4517 .25187 .46326 .26527 .48351 .25761 .47206 .24398 Metetra
.653 .736 .911 r
.47206 .24398 .48351 .25761 .5039 .25066 .49255 .2371 Metetra
.674 .747 .906 r
.49255 .2371 .5039 .25066 .52446 .24308 .5132 .22909 Metetra
.651 .733 .909 r
.5132 .22909 .52446 .24308 .54516 .23582 .53401 .22218 Metetra
.675 .749 .907 r
.53401 .22218 .54516 .23582 .56603 .22837 .55497 .214 Metetra
.648 .729 .908 r
.55497 .214 .56603 .22837 .58705 .22071 .57611 .20715 Metetra
.677 .755 .91 r
.57611 .20715 .58705 .22071 .60824 .21354 .59739 .19872 Metetra
.638 .721 .908 r
.59739 .19872 .60824 .21354 .62957 .20525 .61888 .19227 Metetra
.687 .773 .916 r
.61888 .19227 .62957 .20525 .65113 .19883 .64046 .18321 Metetra
.596 .693 .91 r
.64046 .18321 .65113 .19883 .67277 .1904 .66241 .17876 Metetra
.691 .802 .934 r
.66241 .17876 .67277 .1904 .69471 .18411 .68431 .16941 Metetra
.573 .701 .928 r
.68431 .16941 .69471 .18411 .71693 .17926 .70672 .16574 Metetra
.42 .644 .95 r
.70672 .16574 .71693 .17926 .73908 .17038 .72973 .16723 Metetra
.509 .894 .957 r
.72973 .16723 .73908 .17038 .76122 .15919 .75238 .15984 Metetra
.65 .968 .828 r
.75238 .15984 .76122 .15919 .78439 .15838 .77456 .14441 Metetra
.1274 .39288 .14515 .3672 .16279 .36501 .14695 .37664 Metetra
.879 .988 .725 r
.14695 .37664 .16279 .36501 .18033 .36539 .16785 .3486 Metetra
.733 .697 .817 r
.16785 .3486 .18033 .36539 .19885 .35805 .187 .33588 Metetra
.562 .573 .823 r
.187 .33588 .19885 .35805 .21833 .34212 .20512 .33396 Metetra
.768 .833 .902 r
.20512 .33396 .21833 .34212 .23739 .33117 .22442 .32156 Metetra
.739 .808 .906 r
.22442 .32156 .23739 .33117 .25605 .32573 .24364 .31077 Metetra
.634 .696 .89 r
.24364 .31077 .25605 .32573 .27524 .31553 .26252 .30521 Metetra
.714 .796 .915 r
.26252 .30521 .27524 .31553 .29419 .30984 .28184 .29577 Metetra
.639 .714 .902 r
.28184 .29577 .29419 .30984 .31346 .30159 .30102 .28991 Metetra
.682 .768 .917 r
.30102 .28991 .31346 .30159 .33273 .29531 .32049 .28196 Metetra
.658 .735 .906 r
.32049 .28196 .33273 .29531 .35224 .28746 .34002 .27507 Metetra
.667 .755 .916 r
.34002 .27507 .35224 .28746 .37181 .28093 .35973 .26774 Metetra
.669 .744 .907 r
.35973 .26774 .37181 .28093 .39159 .27316 .37958 .26023 Metetra
.658 .746 .916 r
.37958 .26023 .39159 .27316 .41147 .26648 .39955 .25324 Metetra
.676 .749 .906 r
.39955 .25324 .41147 .26648 .43153 .25866 .41972 .24525 Metetra
.651 .739 .914 r
.41972 .24525 .43153 .25866 .4517 .25187 .43998 .23847 Metetra
.676 .75 .906 r
.43998 .23847 .4517 .25187 .47206 .24398 .46044 .23036 Metetra
.651 .739 .914 r
.46044 .23036 .47206 .24398 .49255 .2371 .48103 .22345 Metetra
.67 .747 .908 r
.48103 .22345 .49255 .2371 .5132 .22909 .50179 .21555 Metetra
.659 .747 .915 r
.50179 .21555 .5132 .22909 .53401 .22218 .5227 .20817 Metetra
.661 .741 .91 r
.5227 .20817 .53401 .22218 .55497 .214 .54377 .2006 Metetra
.669 .756 .916 r
.54377 .2006 .55497 .214 .57611 .20715 .56501 .19257 Metetra
.647 .73 .91 r
.56501 .19257 .57611 .20715 .59739 .19872 .58643 .18563 Metetra
.687 .772 .916 r
.58643 .18563 .59739 .19872 .61888 .19227 .60797 .17653 Metetra
.615 .702 .906 r
.60797 .17653 .61888 .19227 .64046 .18321 .62978 .1711 Metetra
.692 .795 .929 r
.62978 .1711 .64046 .18321 .66241 .17876 .65164 .16168 Metetra
.586 .671 .898 r
.65164 .16168 .66241 .17876 .68431 .16941 .67393 .15762 Metetra
.514 .731 .972 r
.67393 .15762 .68431 .16941 .70672 .16574 .69654 .15524 Metetra
.756 .851 .922 r
.69654 .15524 .70672 .16574 .72973 .16723 .71872 .14203 Metetra
.556 .565 .818 r
.71872 .14203 .72973 .16723 .75238 .15984 .74182 .13999 Metetra
.157 .381 .831 r
.74182 .13999 .75238 .15984 .77456 .14441 .76651 .15394 Metetra
.405 .105 .34 r
.10378 .46014 .1274 .39288 .14695 .37664 .12325 .44896 Metetra
.267 0 .288 r
.12325 .44896 .14695 .37664 .16785 .3486 .14456 .42282 Metetra
.032 0 .182 r
.14456 .42282 .16785 .3486 .187 .33588 .16789 .37784 Metetra
.16789 .37784 .187 .33588 .20512 .33396 .19139 .32839 Metetra
.839 .871 .866 r
.19139 .32839 .20512 .33396 .22442 .32156 .21138 .31049 Metetra
.648 .767 .936 r
.21138 .31049 .22442 .32156 .24364 .31077 .23028 .3042 Metetra
.783 .869 .912 r
.23028 .3042 .24364 .31077 .26252 .30521 .24995 .29088 Metetra
.614 .703 .908 r
.24995 .29088 .26252 .30521 .28184 .29577 .26897 .28611 Metetra
.722 .814 .922 r
.26897 .28611 .28184 .29577 .30102 .28991 .28855 .27614 Metetra
.626 .719 .913 r
.28855 .27614 .30102 .28991 .32049 .28196 .30792 .27072 Metetra
.705 .786 .914 r
.30792 .27072 .32049 .28196 .34002 .27507 .3277 .26142 Metetra
.629 .725 .916 r
.3277 .26142 .34002 .27507 .35973 .26774 .34739 .25577 Metetra
.701 .776 .91 r
.34739 .25577 .35973 .26774 .37958 .26023 .36743 .24654 Metetra
.628 .727 .918 r
.36743 .24654 .37958 .26023 .39955 .25324 .38743 .24084 Metetra
.701 .773 .908 r
.38743 .24084 .39955 .25324 .41972 .24525 .40775 .23146 Metetra
.625 .727 .92 r
.40775 .23146 .41972 .24525 .43998 .23847 .42807 .22581 Metetra
.699 .772 .908 r
.42807 .22581 .43998 .23847 .46044 .23036 .44867 .21636 Metetra
.624 .726 .92 r
.44867 .21636 .46044 .23036 .48103 .22345 .46933 .21065 Metetra
.697 .773 .91 r
.46933 .21065 .48103 .22345 .50179 .21555 .49021 .20124 Metetra
.625 .725 .918 r
.49021 .20124 .50179 .21555 .5227 .20817 .51122 .19538 Metetra
.696 .777 .914 r
.51122 .19538 .5227 .20817 .54377 .2006 .53241 .1859 Metetra
.622 .72 .917 r
.53241 .1859 .54377 .2006 .56501 .19257 .55377 .18011 Metetra
.699 .788 .92 r
.55377 .18011 .56501 .19257 .58643 .18563 .57526 .17037 Metetra
.606 .707 .916 r
.57526 .17037 .58643 .18563 .60797 .17653 .59701 .16527 Metetra
.71 .817 .932 r
.59701 .16527 .60797 .17653 .62978 .1711 .61881 .15485 Metetra
.528 .657 .918 r
.61881 .15485 .62978 .1711 .65164 .16168 .64109 .15318 Metetra
.665 .862 .975 r
.64109 .15318 .65164 .16168 .67393 .15762 .6633 .1443 Metetra
.35 .615 .95 r
.6633 .1443 .67393 .15762 .69654 .15524 .68634 .14739 Metetra
.721 .224 0 r
.68634 .14739 .69654 .15524 .71872 .14203 .71178 .18326 Metetra
.674 .298 .326 r
.71178 .18326 .71872 .14203 .74182 .13999 .7378 .21483 Metetra
.55 .235 .387 r
.7378 .21483 .74182 .13999 .76651 .15394 .76313 .22696 Metetra
.472 .147 .332 r
.08103 .51358 .10378 .46014 .12325 .44896 .09967 .51242 Metetra
.412 .102 .328 r
.09967 .51242 .12325 .44896 .14456 .42282 .1195 .50331 Metetra
.058 0 .197 r
.1195 .50331 .14456 .42282 .16789 .37784 .14371 .45735 Metetra
.14371 .45735 .16789 .37784 .19139 .32839 .17103 .38058 Metetra
.718 .781 .293 r
.17103 .38058 .19139 .32839 .21138 .31049 .19691 .3112 Metetra
.873 .959 .856 r
.19691 .3112 .21138 .31049 .23028 .3042 .21738 .29051 Metetra
.693 .739 .887 r
.21738 .29051 .23028 .3042 .24995 .29088 .23672 .28169 Metetra
.725 .823 .926 r
.23672 .28169 .24995 .29088 .26897 .28611 .2563 .27152 Metetra
.66 .719 .892 r
.2563 .27152 .26897 .28611 .28855 .27614 .27574 .26435 Metetra
.691 .774 .915 r
.27574 .26435 .28855 .27614 .30792 .27072 .29543 .25576 Metetra
.657 .715 .891 r
.29543 .25576 .30792 .27072 .3277 .26142 .31514 .24863 Metetra
.679 .758 .911 r
.31514 .24863 .3277 .26142 .34739 .25577 .33506 .24049 Metetra
.659 .714 .889 r
.33506 .24049 .34739 .25577 .36743 .24654 .35508 .23317 Metetra
.671 .749 .909 r
.35508 .23317 .36743 .24654 .38743 .24084 .37527 .22528 Metetra
.662 .714 .887 r
.37527 .22528 .38743 .24084 .40775 .23146 .3956 .21764 Metetra
.664 .743 .909 r
.3956 .21764 .40775 .23146 .42807 .22581 .41608 .21002 Metetra
.661 .713 .887 r
.41608 .21002 .42807 .22581 .44867 .21636 .43672 .20232 Metetra
.662 .743 .91 r
.43672 .20232 .44867 .21636 .46933 .21065 .45752 .19465 Metetra
.654 .711 .889 r
.45752 .19465 .46933 .21065 .49021 .20124 .47847 .18723 Metetra
.666 .748 .911 r
.47847 .18723 .49021 .20124 .51122 .19538 .49959 .17922 Metetra
.648 .709 .892 r
.49959 .17922 .51122 .19538 .53241 .1859 .52088 .17205 Metetra
.668 .755 .915 r
.52088 .17205 .53241 .1859 .55377 .18011 .54233 .16384 Metetra
.637 .707 .897 r
.54233 .16384 .55377 .18011 .57526 .17037 .56397 .15712 Metetra
.665 .768 .927 r
.56397 .15712 .57526 .17037 .59701 .16527 .58578 .14895 Metetra
.603 .695 .907 r
.58578 .14895 .59701 .16527 .61881 .15485 .60784 .14383 Metetra
.619 .796 .967 r
.60784 .14383 .61881 .15485 .64109 .15318 .63007 .13733 Metetra
.298 .541 .915 r
.63007 .13733 .64109 .15318 .6633 .1443 .65304 .14306 Metetra
.865 .416 .075 r
.65304 .14306 .6633 .1443 .68634 .14739 .67899 .19924 Metetra
.756 .393 .367 r
.67899 .19924 .68634 .14739 .71178 .18326 .70663 .26376 Metetra
.619 .294 .398 r
.70663 .26376 .71178 .18326 .7378 .21483 .73352 .29667 Metetra
.467 .17 .377 r
.73352 .29667 .7378 .21483 .76313 .22696 .7584 .29106 Metetra
.147 0 0 r
.06425 .51747 .08103 .51358 .09967 .51242 .0829 .5173 Metetra
.312 0 0 r
.0829 .5173 .09967 .51242 .1195 .50331 .10147 .51955 Metetra
.476 .817 .527 r
.10147 .51955 .1195 .50331 .14371 .45735 .12289 .5002 Metetra
.729 .823 .363 r
.12289 .5002 .14371 .45735 .17103 .38058 .14867 .44305 Metetra
.731 .775 .279 r
.14867 .44305 .17103 .38058 .19691 .3112 .17676 .36079 Metetra
.789 .822 .347 r
.17676 .36079 .19691 .3112 .21738 .29051 .20309 .28838 Metetra
.791 .947 .924 r
.20309 .28838 .21738 .29051 .23672 .28169 .22312 .27404 Metetra
.751 .856 .927 r
.22312 .27404 .23672 .28169 .2563 .27152 .24295 .2624 Metetra
.689 .823 .947 r
.24295 .2624 .2563 .27152 .27574 .26435 .26261 .25386 Metetra
.67 .796 .942 r
.26261 .25386 .27574 .26435 .29543 .25576 .28233 .24616 Metetra
.705 .822 .937 r
.28233 .24616 .29543 .25576 .31514 .24863 .30232 .23675 Metetra
.628 .762 .943 r
.30232 .23675 .31514 .24863 .33506 .24049 .32219 .23081 Metetra
.725 .828 .929 r
.32219 .23081 .33506 .24049 .35508 .23317 .34252 .22025 Metetra
.598 .736 .941 r
.34252 .22025 .35508 .23317 .37527 .22528 .36264 .21549 Metetra
.742 .833 .921 r
.36264 .21549 .37527 .22528 .3956 .21764 .38328 .20383 Metetra
.573 .713 .937 r
.38328 .20383 .3956 .21764 .41608 .21002 .4037 .20005 Metetra
.741 .834 .922 r
.4037 .20005 .41608 .21002 .43672 .20232 .4246 .1883 Metetra
.574 .713 .937 r
.4246 .1883 .43672 .20232 .45752 .19465 .44539 .18445 Metetra
.721 .831 .933 r
.44539 .18445 .45752 .19465 .47847 .18723 .46654 .17366 Metetra
.597 .733 .94 r
.46654 .17366 .47847 .18723 .49959 .17922 .48774 .16871 Metetra
.695 .824 .944 r
.48774 .16871 .49959 .17922 .52088 .17205 .50917 .1591 Metetra
.62 .757 .944 r
.50917 .1591 .52088 .17205 .54233 .16384 .53075 .153 Metetra
.654 .81 .958 r
.53075 .153 .54233 .16384 .56397 .15712 .55252 .14516 Metetra
.635 .784 .953 r
.55252 .14516 .56397 .15712 .58578 .14895 .57448 .13816 Metetra
.538 .769 .983 r
.57448 .13816 .58578 .14895 .60784 .14383 .59672 .13434 Metetra
.415 .736 .992 r
.59672 .13434 .60784 .14383 .63007 .13733 .61929 .13331 Metetra
.872 .431 .068 r
.61929 .13331 .63007 .13733 .65304 .14306 .64453 .19219 Metetra
.774 .408 .363 r
.64453 .19219 .65304 .14306 .67899 .19924 .67153 .26194 Metetra
.678 .328 .374 r
.67153 .26194 .67899 .19924 .70663 .26376 .69857 .30624 Metetra
.503 .135 .274 r
.69857 .30624 .70663 .26376 .73352 .29667 .72417 .31124 Metetra
.72417 .31124 .73352 .29667 .7584 .29106 .74857 .29351 Metetra
.661 .594 .769 r
.0516 .48983 .06425 .51747 .0829 .5173 .07156 .47972 Metetra
.573 .493 .726 r
.07156 .47972 .0829 .5173 .10147 .51955 .09082 .47579 Metetra
.357 .328 .689 r
.09082 .47579 .10147 .51955 .12289 .5002 .10838 .48682 Metetra
.627 .741 .929 r
.10838 .48682 .12289 .5002 .14867 .44305 .12832 .4809 Metetra
.866 .892 .468 r
.12832 .4809 .14867 .44305 .17676 .36079 .1549 .41832 Metetra
.908 .857 .411 r
.1549 .41832 .17676 .36079 .20309 .28838 .18503 .31818 Metetra
.935 .912 .527 r
.18503 .31818 .20309 .28838 .22312 .27404 .21036 .25564 Metetra
.41 .558 .891 r
.21036 .25564 .22312 .27404 .24295 .2624 .22889 .25824 Metetra
.851 .908 .874 r
.22889 .25824 .24295 .2624 .26261 .25386 .24963 .23928 Metetra
.509 .669 .935 r
.24963 .23928 .26261 .25386 .28233 .24616 .26889 .23791 Metetra
.8 .855 .891 r
.26889 .23791 .28233 .24616 .30232 .23675 .28946 .22257 Metetra
.513 .68 .941 r
.28946 .22257 .30232 .23675 .32219 .23081 .30911 .22095 Metetra
.788 .833 .887 r
.30911 .22095 .32219 .23081 .34252 .22025 .32984 .20604 Metetra
.498 .675 .944 r
.32984 .20604 .34252 .22025 .36264 .21549 .34983 .20484 Metetra
.79 .826 .88 r
.34983 .20484 .36264 .21549 .38328 .20383 .37079 .18948 Metetra
.473 .662 .945 r
.37079 .18948 .38328 .20383 .4037 .20005 .39114 .18902 Metetra
.787 .825 .882 r
.39114 .18902 .4037 .20005 .4246 .1883 .41231 .17372 Metetra
.47 .659 .944 r
.41231 .17372 .4246 .1883 .44539 .18445 .43308 .17337 Metetra
.777 .828 .892 r
.43308 .17337 .44539 .18445 .46654 .17366 .45446 .15878 Metetra
.485 .663 .941 r
.45446 .15878 .46654 .17366 .48774 .16871 .47568 .15801 Metetra
.772 .84 .904 r
.47568 .15801 .48774 .16871 .50917 .1591 .49729 .1438 Metetra
.473 .652 .938 r
.49729 .1438 .50917 .1591 .53075 .153 .51897 .14349 Metetra
.777 .867 .915 r
.51897 .14349 .53075 .153 .55252 .14516 .54085 .12899 Metetra
.363 .58 .925 r
.54085 .12899 .55252 .14516 .57448 .13816 .56306 .13241 Metetra
.833 .94 .895 r
.56306 .13241 .57448 .13816 .59672 .13434 .58516 .11382 Metetra
.687 .288 0 r
.58516 .11382 .59672 .13434 .61929 .13331 .60918 .16204 Metetra
.855 .472 .321 r
.60918 .16204 .61929 .13331 .64453 .19219 .63569 .24967 Metetra
.703 .344 .365 r
.63569 .24967 .64453 .19219 .67153 .26194 .66225 .29919 Metetra
.344 0 .194 r
.66225 .29919 .67153 .26194 .69857 .30624 .68688 .28983 Metetra
.858 .808 .8 r
.68688 .28983 .69857 .30624 .72417 .31124 .71064 .26265 Metetra
.616 .497 .695 r
.71064 .26265 .72417 .31124 .74857 .29351 .7354 .2511 Metetra
.793 .741 .804 r
.03703 .4745 .0516 .48983 .07156 .47972 .0584 .45502 Metetra
.733 .647 .763 r
.0584 .45502 .07156 .47972 .09082 .47579 .07945 .43787 Metetra
.113 .193 .669 r
.07945 .43787 .09082 .47579 .10838 .48682 .09588 .45627 Metetra
0 0 .557 r
.09588 .45627 .10838 .48682 .12832 .4809 .11197 .48097 Metetra
.933 .886 .762 r
.11197 .48097 .12832 .4809 .1549 .41832 .13578 .44516 Metetra
.997 .85 .57 r
.13578 .44516 .1549 .41832 .18503 .31818 .16684 .34369 Metetra
.997 .854 .567 r
.16684 .34369 .18503 .31818 .21036 .25564 .19628 .24809 Metetra
.478 .792 .999 r
.19628 .24809 .21036 .25564 .22889 .25824 .21543 .24523 Metetra
.835 .777 .796 r
.21543 .24523 .22889 .25824 .24963 .23928 .23668 .22227 Metetra
.453 .606 .912 r
.23668 .22227 .24963 .23928 .26889 .23791 .25579 .22306 Metetra
.785 .757 .827 r
.25579 .22306 .26889 .23791 .28946 .22257 .27662 .20589 Metetra
.494 .633 .915 r
.27662 .20589 .28946 .22257 .30911 .22095 .29623 .20526 Metetra
.762 .746 .839 r
.29623 .20526 .30911 .22095 .32984 .20604 .31708 .19018 Metetra
.514 .658 .924 r
.31708 .19018 .32984 .20604 .34983 .20484 .33714 .18867 Metetra
.75 .741 .844 r
.33714 .18867 .34983 .20484 .37079 .18948 .35815 .17446 Metetra
.519 .676 .936 r
.35815 .17446 .37079 .18948 .39114 .18902 .37863 .17254 Metetra
.746 .74 .846 r
.37863 .17254 .39114 .18902 .41231 .17372 .39987 .15847 Metetra
.514 .672 .935 r
.39987 .15847 .41231 .17372 .43308 .17337 .42075 .15673 Metetra
.75 .743 .846 r
.42075 .15673 .43308 .17337 .45446 .15878 .44224 .14223 Metetra
.495 .644 .923 r
.44224 .14223 .45446 .15878 .47568 .15801 .46352 .14139 Metetra
.76 .751 .844 r
.46352 .14139 .47568 .15801 .49729 .1438 .48528 .12595 Metetra
.442 .598 .91 r
.48528 .12595 .49729 .1438 .51897 .14349 .507 .12726 Metetra
.778 .765 .841 r
.507 .12726 .51897 .14349 .54085 .12899 .52902 .11033 Metetra
.266 .485 .884 r
.52902 .11033 .54085 .12899 .56306 .13241 .5513 .11759 Metetra
.74 .78 .885 r
.5513 .11759 .56306 .13241 .58516 .11382 .57366 .10435 Metetra
.908 .505 .117 r
.57366 .10435 .58516 .11382 .60918 .16204 .59847 .18638 Metetra
.867 .478 .302 r
.59847 .18638 .60918 .16204 .63569 .24967 .62512 .27545 Metetra
.64 .207 .203 r
.62512 .27545 .63569 .24967 .66225 .29919 .65081 .297 Metetra
.963 .935 .702 r
.65081 .297 .66225 .29919 .68688 .28983 .67415 .25539 Metetra
.803 .653 .696 r
.67415 .25539 .68688 .28983 .71064 .26265 .69753 .22022 Metetra
.498 .447 .73 r
.69753 .22022 .71064 .26265 .7354 .2511 .72311 .22223 Metetra
.822 1 .82 r
.0187 .48236 .03703 .4745 .0584 .45502 .04064 .46072 Metetra
.89 .979 .819 r
.04064 .46072 .0584 .45502 .07945 .43787 .06309 .43529 Metetra
.269 0 0 r
.06309 .43529 .07945 .43787 .09588 .45627 .08131 .44052 Metetra
.535 .047 0 r
.08131 .44052 .09588 .45627 .11197 .48097 .09809 .45909 Metetra
.791 .692 .756 r
.09809 .45909 .11197 .48097 .13578 .44516 .12067 .43468 Metetra
.931 .745 .629 r
.12067 .43468 .13578 .44516 .16684 .34369 .15028 .35017 Metetra
.973 .798 .605 r
.15028 .35017 .16684 .34369 .19628 .24809 .18018 .25615 Metetra
.926 .973 .747 r
.18018 .25615 .19628 .24809 .21543 .24523 .2026 .22414 Metetra
.663 .65 .827 r
.2026 .22414 .21543 .24523 .23668 .22227 .22255 .2154 Metetra
.759 .882 .934 r
.22255 .2154 .23668 .22227 .25579 .22306 .24297 .20293 Metetra
.646 .655 .845 r
.24297 .20293 .25579 .22306 .27662 .20589 .26305 .19546 Metetra
.713 .818 .93 r
.26305 .19546 .27662 .20589 .29623 .20526 .28351 .18526 Metetra
.646 .659 .848 r
.28351 .18526 .29623 .20526 .31708 .19018 .30389 .17769 Metetra
.688 .781 .922 r
.30389 .17769 .31708 .19018 .33714 .18867 .32453 .16858 Metetra
.655 .665 .847 r
.32453 .16858 .33714 .18867 .35815 .17446 .34527 .16032 Metetra
.664 .751 .915 r
.34527 .16032 .35815 .17446 .37863 .17254 .36615 .15225 Metetra
.652 .664 .849 r
.36615 .15225 .37863 .17254 .39987 .15847 .38719 .14411 Metetra
.659 .75 .917 r
.38719 .14411 .39987 .15847 .42075 .15673 .40839 .13615 Metetra
.633 .655 .854 r
.40839 .13615 .42075 .15673 .44224 .14223 .42974 .12905 Metetra
.671 .777 .929 r
.42974 .12905 .44224 .14223 .46352 .14139 .4513 .12041 Metetra
.613 .644 .857 r
.4513 .12041 .46352 .14139 .48528 .12595 .47299 .1144 Metetra
.67 .81 .95 r
.47299 .1144 .48528 .12595 .507 .12726 .49492 .10564 Metetra
.569 .618 .862 r
.49492 .10564 .507 .12726 .52902 .11033 .517 .10197 Metetra
.614 .855 .989 r
.517 .10197 .52902 .11033 .5513 .11759 .53932 .09449 Metetra
.052 .289 .779 r
.53932 .09449 .5513 .11759 .57366 .10435 .56215 .11081 Metetra
.897 .491 .225 r
.56215 .11081 .57366 .10435 .59847 .18638 .58686 .19109 Metetra
.884 .461 .179 r
.58686 .19109 .59847 .18638 .62512 .27545 .61294 .26243 Metetra
.05 .46 .881 r
.61294 .26243 .62512 .27545 .65081 .297 .63824 .27184 Metetra
.85 .726 .726 r
.63824 .27184 .65081 .297 .67415 .25539 .66206 .2364 Metetra
.803 .772 .824 r
.66206 .2364 .67415 .25539 .69753 .22022 .68639 .21477 Metetra
0 .343 .696 r
.68639 .21477 .69753 .22022 .72311 .22223 .71271 .22529 Metetra
.86 .957 .87 r
.00095 .48363 .0187 .48236 .04064 .46072 .02301 .46267 Metetra
.908 .933 .816 r
.02301 .46267 .04064 .46072 .06309 .43529 .04604 .43505 Metetra
.316 .802 .882 r
.04604 .43505 .06309 .43529 .08131 .44052 .06567 .43088 Metetra
0 .32 .725 r
.06567 .43088 .08131 .44052 .09809 .45909 .08376 .43944 Metetra
.798 .713 .771 r
.08376 .43944 .09809 .45909 .12067 .43468 .10635 .41591 Metetra
.904 .718 .64 r
.10635 .41591 .12067 .43468 .15028 .35017 .13519 .3413 Metetra
.939 .749 .619 r
.13519 .3413 .15028 .35017 .18018 .25615 .16507 .2521 Metetra
.939 .823 .703 r
.16507 .2521 .18018 .25615 .2026 .22414 .18936 .20549 Metetra
.51 .615 .892 r
.18936 .20549 .2026 .22414 .22255 .2154 .20856 .20441 Metetra
.824 .813 .84 r
.20856 .20441 .22255 .2154 .24297 .20293 .22979 .18508 Metetra
.54 .642 .899 r
.22979 .18508 .24297 .20293 .26305 .19546 .24945 .18273 Metetra
.742 .788 .89 r
.24945 .18273 .26305 .19546 .28351 .18526 .2702 .17034 Metetra
.632 .726 .916 r
.2702 .17034 .28351 .18526 .30389 .17769 .29058 .16389 Metetra
.681 .761 .912 r
.29058 .16389 .30389 .17769 .32453 .16858 .31131 .15499 Metetra
.688 .769 .913 r
.31131 .15499 .32453 .16858 .34527 .16032 .33221 .14566 Metetra
.635 .736 .921 r
.33221 .14566 .34527 .16032 .36615 .15225 .35311 .13888 Metetra
.692 .777 .917 r
.35311 .13888 .36615 .15225 .38719 .14411 .37434 .12921 Metetra
.64 .738 .92 r
.37434 .12921 .38719 .14411 .40839 .13615 .39561 .1221 Metetra
.647 .756 .929 r
.39561 .1221 .40839 .13615 .42974 .12905 .41708 .11455 Metetra
.693 .766 .908 r
.41708 .11455 .42974 .12905 .4513 .12041 .4388 .10454 Metetra
.567 .697 .929 r
.4388 .10454 .4513 .12041 .47299 .1144 .46054 .10051 Metetra
.757 .797 .886 r
.46054 .10051 .47299 .1144 .49492 .10564 .48267 .08632 Metetra
.393 .558 .898 r
.48267 .08632 .49492 .10564 .517 .10197 .50478 .08936 Metetra
.778 .827 .891 r
.50478 .08936 .517 .10197 .53932 .09449 .52723 .07384 Metetra
0 0 .505 r
.52723 .07384 .53932 .09449 .56215 .11081 .55016 .10483 Metetra
.9 .485 .123 r
.55016 .10483 .56215 .11081 .58686 .19109 .57465 .17993 Metetra
.85 .412 0 r
.57465 .17993 .58686 .19109 .61294 .26243 .60033 .24074 Metetra
.273 .475 .874 r
.60033 .24074 .61294 .26243 .63824 .27184 .62563 .24896 Metetra
.808 .735 .783 r
.62563 .24896 .63824 .27184 .66206 .2364 .65006 .22371 Metetra
.704 .838 .946 r
.65006 .22371 .66206 .2364 .68639 .21477 .67511 .2117 Metetra
.366 0 0 r
.67511 .2117 .68639 .21477 .71271 .22529 .70176 .22433 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.21035 .18732 m
.21487 .19208 L
s
[(10)] .20131 .17781 .94967 1 Mshowa
.41738 .10625 m
.42153 .11134 L
s
[(20)] .40909 .09608 .81515 1 Mshowa
.64163 .01845 m
.64532 .02387 L
s
[(30)] .63425 .0076 .68064 1 Mshowa
.125 Mabswid
.25047 .17161 m
.25314 .1745 L
s
.29122 .15565 m
.29385 .15859 L
s
.33262 .13945 m
.3352 .14242 L
s
.37466 .12298 m
.3772 .12599 L
s
.46079 .08926 m
.46322 .09235 L
s
.5049 .07199 m
.50728 .07512 L
s
.54973 .05443 m
.55206 .0576 L
s
.5953 .03659 m
.59757 .0398 L
s
.17084 .20279 m
.17359 .20561 L
s
.13192 .21803 m
.13471 .22081 L
s
.09359 .23304 m
.09641 .23578 L
s
.05583 .24783 m
.05869 .25053 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00919655 0.97619 0.377059 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.20131 .17781 -11.698 -9 ]
[.20131 .17781 .302 0 ]
[.40909 .09608 -10.8909 -9 ]
[.40909 .09608 1.10907 0 ]
[.63425 .0076 -10.0839 -9 ]
[.63425 .0076 1.91614 0 ]
[.79552 .14001 0 -6.12026 ]
[.79552 .14001 12 2.87974 ]
[.88711 .28027 0 -5.98728 ]
[.88711 .28027 12 3.01272 ]
[.96711 .40279 0 -5.87447 ]
[.96711 .40279 12 3.12553 ]
[.02428 .26408 -6 -2.74145 ]
[.02428 .26408 0 6.25855 ]
[.01653 .31264 -24 -2.7825 ]
[.01653 .31264 0 6.2175 ]
[.00853 .36276 -18 -2.825 ]
[.00853 .36276 0 6.175 ]
[.00027 .41452 -24 -2.86903 ]
[.00027 .41452 0 6.13097 ]
[-0.00826 .46799 -6 -2.91468 ]
[-0.00826 .46799 0 6.08532 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.21035 .18732 m
.21487 .19208 L
s
[(10)] .20131 .17781 .94967 1 Mshowa
.41738 .10625 m
.42153 .11134 L
s
[(20)] .40909 .09608 .81515 1 Mshowa
.64163 .01845 m
.64532 .02387 L
s
[(30)] .63425 .0076 .68064 1 Mshowa
.125 Mabswid
.25047 .17161 m
.25314 .1745 L
s
.29122 .15565 m
.29385 .15859 L
s
.33262 .13945 m
.3352 .14242 L
s
.37466 .12298 m
.3772 .12599 L
s
.46079 .08926 m
.46322 .09235 L
s
.5049 .07199 m
.50728 .07512 L
s
.54973 .05443 m
.55206 .0576 L
s
.5953 .03659 m
.59757 .0398 L
s
.17084 .20279 m
.17359 .20561 L
s
.13192 .21803 m
.13471 .22081 L
s
.09359 .23304 m
.09641 .23578 L
s
.05583 .24783 m
.05869 .25053 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78318 .14446 m
.777 .14668 L
s
[(10)] .79552 .14001 -1 .36006 Mshowa
.87465 .28439 m
.86842 .28645 L
s
[(20)] .88711 .28027 -1 .33051 Mshowa
.95456 .40662 m
.94829 .40854 L
s
[(30)] .96711 .40279 -1 .30544 Mshowa
.125 Mabswid
.80252 .17404 m
.7988 .17536 L
s
.82131 .20279 m
.81759 .20409 L
s
.83959 .23075 m
.83586 .23202 L
s
.85736 .25793 m
.85363 .25919 L
s
.89149 .31014 m
.88774 .31135 L
s
.90788 .33521 m
.90413 .33641 L
s
.92384 .35963 m
.92009 .36081 L
s
.9394 .38343 m
.93564 .38459 L
s
.76327 .11401 m
.75957 .11536 L
s
.74277 .08265 m
.73908 .08403 L
s
.72165 .05034 m
.71797 .05174 L
s
.69987 .01704 m
.6962 .01846 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.0365 .2593 m
.04261 .25691 L
s
[(0)] .02428 .26408 1 -0.39079 Mshowa
.02879 .30796 m
.03492 .30562 L
s
[(0.25)] .01653 .31264 1 -0.38167 Mshowa
.02083 .35819 m
.02698 .3559 L
s
[(0.5)] .00853 .36276 1 -0.37222 Mshowa
.01261 .41005 m
.01878 .40781 L
s
[(0.75)] .00027 .41452 1 -0.36244 Mshowa
.00412 .46363 m
.01031 .46145 L
s
[(1)] -0.00826 .46799 1 -0.35229 Mshowa
.125 Mabswid
.03498 .26891 m
.03865 .26749 L
s
.03344 .27858 m
.03712 .27716 L
s
.0319 .28832 m
.03558 .2869 L
s
.03035 .29811 m
.03403 .2967 L
s
.02722 .31788 m
.0309 .31648 L
s
.02564 .32786 m
.02932 .32647 L
s
.02404 .33791 m
.02773 .33652 L
s
.02244 .34801 m
.02613 .34663 L
s
.01921 .36843 m
.0229 .36706 L
s
.01757 .37873 m
.02127 .37737 L
s
.01593 .3891 m
.01963 .38775 L
s
.01428 .39954 m
.01798 .39819 L
s
.01094 .42062 m
.01464 .41929 L
s
.00925 .43127 m
.01295 .42994 L
s
.00755 .44198 m
.01126 .44066 L
s
.00584 .45277 m
.00955 .45145 L
s
.00239 .47456 m
.0061 .47326 L
s
.00064 .48556 m
.00436 .48427 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.446 .49 .811 r
.39516 .59712 .40466 .61683 .42165 .5992 .41141 .6032 Metetra
.489 0 0 r
.41141 .6032 .42165 .5992 .43796 .60743 .42793 .60727 Metetra
.927 .88 .769 r
.42793 .60727 .43796 .60743 .45499 .59176 .44537 .57995 Metetra
0 0 .494 r
.44537 .57995 .45499 .59176 .47164 .60076 .46184 .59912 Metetra
.927 .853 .75 r
.46184 .59912 .47164 .60076 .48884 .58083 .47933 .56912 Metetra
.952 .612 .328 r
.47933 .56912 .48884 .58083 .50556 .63846 .49575 .64806 Metetra
.893 .574 .438 r
.49575 .64806 .50556 .63846 .52301 .71873 .51312 .73273 Metetra
.765 .399 .362 r
.51312 .73273 .52301 .71873 .54127 .76039 .53142 .75916 Metetra
.898 .92 .827 r
.53142 .75916 .54127 .76039 .55966 .75433 .54983 .73742 Metetra
.765 .681 .77 r
.54983 .73742 .55966 .75433 .57799 .73607 .56824 .72045 Metetra
.426 .546 .874 r
.56824 .72045 .57799 .73607 .59656 .7308 .58705 .72575 Metetra
.152 .623 .927 r
.58705 .72575 .59656 .7308 .61541 .73209 .60604 .72892 Metetra
.796 .925 .922 r
.60604 .72892 .61541 .73209 .63428 .72741 .62479 .71587 Metetra
.754 .748 .847 r
.62479 .71587 .63428 .72741 .65316 .71923 .64362 .70386 Metetra
.519 .6 .874 r
.64362 .70386 .65316 .71923 .67227 .7144 .66305 .70562 Metetra
.43 .686 .971 r
.66305 .70562 .67227 .7144 .69156 .71064 .68267 .70706 Metetra
.768 .925 .939 r
.68267 .70706 .69156 .71064 .71086 .70413 .70183 .69522 Metetra
.769 .806 .882 r
.70183 .69522 .71086 .70413 .73034 .69867 .72103 .683 Metetra
.524 .6 .872 r
.72103 .683 .73034 .69867 .75017 .69662 .74115 .68466 Metetra
.452 .628 .929 r
.74115 .68466 .75017 .69662 .76993 .69103 .76156 .68744 Metetra
.797 .936 .922 r
.76156 .68744 .76993 .69103 .78936 .67934 .781 .67373 Metetra
.83 .892 .886 r
.781 .67373 .78936 .67934 .80941 .67432 .80031 .65777 Metetra
.413 .53 .866 r
.80031 .65777 .80941 .67432 .83076 .68265 .82157 .66461 Metetra
.312 .451 .84 r
.82157 .66461 .83076 .68265 .85126 .67849 .84359 .67647 Metetra
.971 .899 .693 r
.84359 .67647 .85126 .67849 .86702 .62494 .86113 .63856 Metetra
.976 .801 .385 r
.86113 .63856 .86702 .62494 .8781 .5311 .87217 .54006 Metetra
.989 .805 .419 r
.87217 .54006 .8781 .5311 .89082 .4604 .88282 .44716 Metetra
0 .252 .764 r
.88282 .44716 .89082 .4604 .91232 .46993 .90557 .46701 Metetra
.959 .919 .725 r
.90557 .46701 .91232 .46993 .93042 .4494 .92255 .43577 Metetra
.058 .336 .814 r
.92255 .43577 .93042 .4494 .95183 .45456 .94557 .45297 Metetra
.794 .992 .879 r
.94557 .45297 .95183 .45456 .9701 .43471 .96462 .43738 Metetra
.599 .673 .892 r
.38528 .5853 .39516 .59712 .41141 .6032 .40184 .5832 Metetra
.674 .607 .772 r
.40184 .5832 .41141 .6032 .42793 .60727 .41871 .57563 Metetra
.491 .438 .725 r
.41871 .57563 .42793 .60727 .44537 .57995 .43526 .58294 Metetra
.43526 .58294 .44537 .57995 .46184 .59912 .45229 .57858 Metetra
.201 .339 .78 r
.45229 .57858 .46184 .59912 .47933 .56912 .46913 .59293 Metetra
.851 .548 .476 r
.46913 .59293 .47933 .56912 .49575 .64806 .4855 .67716 Metetra
.815 .509 .473 r
.4855 .67716 .49575 .64806 .51312 .73273 .503 .74331 Metetra
.578 .138 .167 r
.503 .74331 .51312 .73273 .53142 .75916 .52141 .74928 Metetra
.864 .77 .756 r
.52141 .74928 .53142 .75916 .54983 .73742 .53992 .72188 Metetra
.73 .685 .807 r
.53992 .72188 .54983 .73742 .56824 .72045 .55847 .71018 Metetra
.053 .432 .871 r
.55847 .71018 .56824 .72045 .58705 .72575 .57738 .71972 Metetra
.318 .7 .98 r
.57738 .71972 .58705 .72575 .60604 .72892 .59643 .7212 Metetra
.822 .822 .849 r
.59643 .7212 .60604 .72892 .62479 .71587 .61521 .7047 Metetra
.759 .757 .851 r
.61521 .7047 .62479 .71587 .64362 .70386 .63413 .69238 Metetra
.385 .603 .934 r
.63413 .69238 .64362 .70386 .66305 .70562 .6537 .69656 Metetra
.37 .651 .965 r
.6537 .69656 .66305 .70562 .68267 .70706 .67347 .69946 Metetra
.79 .835 .886 r
.67347 .69946 .68267 .70706 .70183 .69522 .69268 .68602 Metetra
.797 .806 .859 r
.69268 .68602 .70183 .69522 .72103 .683 .71186 .67124 Metetra
.474 .645 .932 r
.71186 .67124 .72103 .683 .74115 .68466 .73206 .67307 Metetra
.319 .566 .927 r
.73206 .67307 .74115 .68466 .76156 .68744 .75276 .67921 Metetra
.768 .83 .9 r
.75276 .67921 .76156 .68744 .781 .67373 .77244 .66709 Metetra
.867 .867 .836 r
.77244 .66709 .781 .67373 .80031 .65777 .79156 .64668 Metetra
.48 .664 .943 r
.79156 .64668 .80031 .65777 .82157 .66461 .81244 .64796 Metetra
.099 .336 .807 r
.81244 .64796 .82157 .66461 .84359 .67647 .83499 .6655 Metetra
.808 .793 .839 r
.83499 .6655 .84359 .67647 .86113 .63856 .85471 .64864 Metetra
.981 .831 .433 r
.85471 .64864 .86113 .63856 .87217 .54006 .86811 .56922 Metetra
.786 .692 .148 r
.86811 .56922 .87217 .54006 .88282 .44716 .87869 .4707 Metetra
.102 0 .196 r
.87869 .4707 .88282 .44716 .90557 .46701 .89647 .44443 Metetra
.654 .596 .777 r
.89647 .44443 .90557 .46701 .92255 .43577 .91646 .43753 Metetra
.762 .984 .743 r
.91646 .43753 .92255 .43577 .94557 .45297 .93504 .41843 Metetra
.608 .511 .718 r
.93504 .41843 .94557 .45297 .96462 .43738 .95566 .41484 Metetra
.199 0 0 r
.37468 .58736 .38528 .5853 .40184 .5832 .39125 .58785 Metetra
.435 0 0 r
.39125 .58785 .40184 .5832 .41871 .57563 .40791 .59046 Metetra
.40791 .59046 .41871 .57563 .43526 .58294 .4253 .5742 Metetra
0 .328 .785 r
.4253 .5742 .43526 .58294 .45229 .57858 .44206 .58399 Metetra
.892 .56 .414 r
.44206 .58399 .45229 .57858 .46913 .59293 .45798 .65042 Metetra
.748 .467 .507 r
.45798 .65042 .46913 .59293 .4855 .67716 .47481 .7129 Metetra
.699 .391 .452 r
.47481 .7129 .4855 .67716 .503 .74331 .49276 .73955 Metetra
.737 .902 .952 r
.49276 .73955 .503 .74331 .52141 .74928 .51131 .72972 Metetra
.759 .66 .753 r
.51131 .72972 .52141 .74928 .53992 .72188 .52993 .71154 Metetra
.643 .738 .918 r
.52993 .71154 .53992 .72188 .55847 .71018 .54862 .70677 Metetra
0 .525 .807 r
.54862 .70677 .55847 .71018 .57738 .71972 .56754 .71059 Metetra
.602 .753 .95 r
.56754 .71059 .57738 .71972 .59643 .7212 .58657 .70715 Metetra
.742 .712 .824 r
.58657 .70715 .59643 .7212 .61521 .7047 .60555 .69499 Metetra
.71 .775 .903 r
.60555 .69499 .61521 .7047 .63413 .69238 .62469 .6866 Metetra
.371 .738 .99 r
.62469 .6866 .63413 .69238 .6537 .69656 .64422 .68687 Metetra
.528 .716 .958 r
.64422 .68687 .6537 .69656 .67347 .69946 .6639 .68593 Metetra
.716 .717 .85 r
.6639 .68593 .67347 .69946 .69268 .68602 .68338 .6762 Metetra
.747 .789 .886 r
.68338 .6762 .69268 .68602 .71186 .67124 .70288 .66522 Metetra
.498 .796 .998 r
.70288 .66522 .71186 .67124 .73206 .67307 .72295 .66295 Metetra
.447 .671 .958 r
.72295 .66295 .73206 .67307 .75276 .67921 .74344 .66455 Metetra
.677 .692 .857 r
.74344 .66455 .75276 .67921 .77244 .66709 .76355 .6573 Metetra
.793 .806 .863 r
.76355 .6573 .77244 .66709 .79156 .64668 .78323 .64259 Metetra
.58 .882 .992 r
.78323 .64259 .79156 .64668 .81244 .64796 .80366 .63665 Metetra
.247 .531 .918 r
.80366 .63665 .81244 .64796 .83499 .6655 .82543 .64453 Metetra
.578 .578 .816 r
.82543 .64453 .83499 .6655 .85471 .64864 .84672 .64386 Metetra
.962 .87 .701 r
.84672 .64386 .85471 .64864 .86811 .56922 .86447 .6053 Metetra
0 0 .07 r
.86447 .6053 .86811 .56922 .87869 .4707 .87802 .52925 Metetra
0 0 .315 r
.87802 .52925 .87869 .4707 .89647 .44443 .89034 .44879 Metetra
.703 .932 .616 r
.89034 .44879 .89647 .44443 .91646 .43753 .90879 .42705 Metetra
.336 .591 .939 r
.90879 .42705 .91646 .43753 .93504 .41843 .93057 .43245 Metetra
.144 0 .049 r
.93057 .43245 .93504 .41843 .95566 .41484 .95005 .41813 Metetra
.623 .581 .786 r
.36495 .56689 .37468 .58736 .39125 .58785 .38168 .56339 Metetra
.66 .573 .747 r
.38168 .56339 .39125 .58785 .40791 .59046 .39868 .55591 Metetra
.07 .146 .636 r
.39868 .55591 .40791 .59046 .4253 .5742 .41461 .58414 Metetra
.87 .543 .43 r
.41461 .58414 .4253 .5742 .44206 .58399 .43006 .64608 Metetra
.736 .458 .509 r
.43006 .64608 .44206 .58399 .45798 .65042 .44636 .70582 Metetra
.661 .379 .482 r
.44636 .70582 .45798 .65042 .47481 .7129 .46402 .73097 Metetra
.344 0 .151 r
.46402 .73097 .47481 .7129 .49276 .73955 .48251 .72405 Metetra
.746 .692 .8 r
.48251 .72405 .49276 .73955 .51131 .72972 .50115 .7106 Metetra
.644 .617 .808 r
.50115 .7106 .51131 .72972 .52993 .71154 .51981 .70539 Metetra
.474 .777 .997 r
.51981 .70539 .52993 .71154 .54862 .70677 .53862 .70397 Metetra
.531 .878 .987 r
.53862 .70397 .54862 .70677 .56754 .71059 .55756 .69901 Metetra
.687 .734 .886 r
.55756 .69901 .56754 .71059 .58657 .70715 .5766 .69181 Metetra
.652 .666 .851 r
.5766 .69181 .58657 .70715 .60555 .69499 .59579 .68638 Metetra
.616 .774 .956 r
.59579 .68638 .60555 .69499 .62469 .6866 .61514 .6821 Metetra
.592 .868 .994 r
.61514 .6821 .62469 .6866 .64422 .68687 .6346 .67667 Metetra
.658 .757 .923 r
.6346 .67667 .64422 .68687 .6639 .68593 .65419 .67083 Metetra
.643 .669 .861 r
.65419 .67083 .6639 .68593 .68338 .6762 .67394 .66586 Metetra
.647 .753 .927 r
.67394 .66586 .68338 .6762 .70288 .66522 .69382 .66049 Metetra
.626 .879 .988 r
.69382 .66049 .70288 .66522 .72295 .66295 .71378 .65394 Metetra
.64 .782 .949 r
.71378 .65394 .72295 .66295 .74344 .66455 .73395 .64856 Metetra
.618 .651 .86 r
.73395 .64856 .74344 .66455 .76355 .6573 .75438 .64498 Metetra
.656 .724 .9 r
.75438 .64498 .76355 .6573 .78323 .64259 .77481 .63912 Metetra
.683 .93 .969 r
.77481 .63912 .78323 .64259 .80366 .63665 .79511 .62962 Metetra
.623 .829 .98 r
.79511 .62962 .80366 .63665 .82543 .64453 .81584 .62398 Metetra
.519 .551 .828 r
.81584 .62398 .82543 .64453 .84672 .64386 .8375 .62689 Metetra
.62 .644 .853 r
.8375 .62689 .84672 .64386 .86447 .6053 .85877 .62307 Metetra
.85877 .62307 .86447 .6053 .87802 .52925 .87677 .58579 Metetra
0 0 .314 r
.87677 .58579 .87802 .52925 .89034 .44879 .89054 .51219 Metetra
.056 0 .356 r
.89054 .51219 .89034 .44879 .90879 .42705 .90329 .43602 Metetra
.815 .857 .404 r
.90329 .43602 .90879 .42705 .93057 .43245 .91958 .39482 Metetra
.607 .501 .707 r
.91958 .39482 .93057 .43245 .95005 .41813 .94036 .39085 Metetra
.542 .263 .441 r
.35158 .6176 .36495 .56689 .38168 .56339 .36854 .6169 Metetra
.621 .341 .472 r
.36854 .6169 .38168 .56339 .39868 .55591 .38506 .63078 Metetra
.664 .397 .507 r
.38506 .63078 .39868 .55591 .41461 .58414 .40119 .66425 Metetra
.674 .408 .511 r
.40119 .66425 .41461 .58414 .43006 .64608 .41762 .70435 Metetra
.648 .368 .481 r
.41762 .70435 .43006 .64608 .44636 .70582 .43508 .7267 Metetra
.428 .057 .23 r
.43508 .7267 .44636 .70582 .46402 .73097 .45348 .72238 Metetra
.801 .798 .849 r
.45348 .72238 .46402 .73097 .48251 .72405 .47218 .70729 Metetra
.681 .658 .82 r
.47218 .70729 .48251 .72405 .50115 .7106 .49083 .69956 Metetra
.522 .683 .94 r
.49083 .69956 .50115 .7106 .51981 .70539 .50955 .69932 Metetra
.55 .81 .994 r
.50955 .69932 .51981 .70539 .53862 .70397 .52844 .69607 Metetra
.718 .814 .925 r
.52844 .69607 .53862 .70397 .55756 .69901 .54745 .68732 Metetra
.684 .734 .888 r
.54745 .68732 .55756 .69901 .5766 .69181 .56658 .68018 Metetra
.59 .703 .921 r
.56658 .68018 .5766 .69181 .59579 .68638 .5859 .67761 Metetra
.592 .765 .962 r
.5859 .67761 .59579 .68638 .61514 .6821 .60536 .67414 Metetra
.695 .815 .94 r
.60536 .67414 .61514 .6821 .6346 .67667 .62486 .66636 Metetra
.69 .767 .91 r
.62486 .66636 .6346 .67667 .65419 .67083 .64448 .65881 Metetra
.608 .707 .915 r
.64448 .65881 .65419 .67083 .67394 .66586 .66438 .65541 Metetra
.592 .733 .942 r
.66438 .65541 .67394 .66586 .69382 .66049 .68447 .65226 Metetra
.684 .814 .945 r
.68447 .65226 .69382 .66049 .71378 .65394 .70449 .64476 Metetra
.703 .8 .925 r
.70449 .64476 .71378 .65394 .73395 .64856 .72459 .63633 Metetra
.613 .71 .914 r
.72459 .63633 .73395 .64856 .75438 .64498 .7451 .63255 Metetra
.577 .692 .92 r
.7451 .63255 .75438 .64498 .77481 .63912 .76589 .63042 Metetra
.686 .811 .942 r
.76589 .63042 .77481 .63912 .79511 .62962 .78645 .62266 Metetra
.743 .868 .938 r
.78645 .62266 .79511 .62962 .81584 .62398 .80688 .61178 Metetra
.597 .708 .922 r
.80688 .61178 .81584 .62398 .8375 .62689 .82809 .60861 Metetra
.472 .553 .857 r
.82809 .60861 .8375 .62689 .85877 .62307 .85021 .6131 Metetra
.661 .783 .939 r
.85021 .6131 .85877 .62307 .87677 .58579 .8715 .60642 Metetra
0 0 .014 r
.8715 .60642 .87677 .58579 .89054 .51219 .88993 .57181 Metetra
.205 .013 .384 r
.88993 .57181 .89054 .51219 .90329 .43602 .906 .51838 Metetra
.362 .153 .455 r
.906 .51838 .90329 .43602 .91958 .39482 .92243 .47168 Metetra
.448 .213 .464 r
.92243 .47168 .91958 .39482 .94036 .39085 .94107 .44538 Metetra
.574 .309 .477 r
.33663 .68818 .35158 .6176 .36854 .6169 .35374 .69342 Metetra
.62 .355 .494 r
.35374 .69342 .36854 .6169 .38506 .63078 .37051 .71162 Metetra
.606 .344 .494 r
.37051 .71162 .38506 .63078 .40119 .66425 .38776 .72639 Metetra
.55 .278 .456 r
.38776 .72639 .40119 .66425 .41762 .70435 .40582 .72677 Metetra
.275 0 .16 r
.40582 .72677 .41762 .70435 .43508 .7267 .4244 .71542 Metetra
.759 .75 .845 r
.4244 .71542 .43508 .7267 .45348 .72238 .44306 .70293 Metetra
.661 .624 .801 r
.44306 .70293 .45348 .72238 .47218 .70729 .46166 .69618 Metetra
.586 .709 .928 r
.46166 .69618 .47218 .70729 .49083 .69956 .48032 .6937 Metetra
.547 .816 .996 r
.48032 .6937 .49083 .69956 .50955 .69932 .49915 .69035 Metetra
.668 .781 .934 r
.49915 .69035 .50955 .69932 .52844 .69607 .51813 .68409 Metetra
.68 .728 .887 r
.51813 .68409 .52844 .69607 .54745 .68732 .53724 .67714 Metetra
.645 .752 .927 r
.53724 .67714 .54745 .68732 .56658 .68018 .55647 .67192 Metetra
.604 .782 .966 r
.55647 .67192 .56658 .68018 .5859 .67761 .57586 .66782 Metetra
.639 .761 .937 r
.57586 .66782 .5859 .67761 .60536 .67414 .59538 .66273 Metetra
.67 .741 .903 r
.59538 .66273 .60536 .67414 .62486 .66636 .615 .65621 Metetra
.663 .764 .925 r
.615 .65621 .62486 .66636 .64448 .65881 .63477 .64996 Metetra
.624 .781 .956 r
.63477 .64996 .64448 .65881 .66438 .65541 .65472 .64512 Metetra
.624 .751 .938 r
.65472 .64512 .66438 .65541 .68447 .65226 .67483 .64055 Metetra
.657 .737 .908 r
.67483 .64055 .68447 .65226 .70449 .64476 .69503 .63455 Metetra
.675 .773 .924 r
.69503 .63455 .70449 .64476 .72459 .63633 .71532 .62753 Metetra
.644 .795 .955 r
.71532 .62753 .72459 .63633 .7451 .63255 .73581 .62165 Metetra
.612 .74 .936 r
.73581 .62165 .7451 .63255 .76589 .63042 .75656 .61752 Metetra
.632 .712 .904 r
.75656 .61752 .76589 .63042 .78645 .62266 .77744 .61271 Metetra
.686 .789 .928 r
.77744 .61271 .78645 .62266 .80688 .61178 .79825 .60489 Metetra
.695 .862 .962 r
.79825 .60489 .80688 .61178 .82809 .60861 .81911 .59614 Metetra
.619 .718 .916 r
.81911 .59614 .82809 .60861 .85021 .6131 .8405 .59181 Metetra
.537 .559 .825 r
.8405 .59181 .85021 .6131 .8715 .60642 .86267 .59348 Metetra
.509 .659 .928 r
.86267 .59348 .8715 .60642 .88993 .57181 .88497 .594 Metetra
.329 0 .211 r
.88497 .594 .88993 .57181 .906 .51838 .90616 .58223 Metetra
.41 .167 .432 r
.90616 .58223 .906 .51838 .92243 .47168 .92562 .55521 Metetra
.436 .205 .463 r
.92562 .55521 .92243 .47168 .94107 .44538 .9445 .52443 Metetra
.536 .238 .409 r
.32258 .73122 .33663 .68818 .35374 .69342 .34027 .73111 Metetra
.557 .247 .398 r
.34027 .73111 .35374 .69342 .37051 .71162 .35799 .7339 Metetra
.396 .028 .217 r
.35799 .7339 .37051 .71162 .38776 .72639 .37628 .72802 Metetra
.81 .986 .887 r
.37628 .72802 .38776 .72639 .40582 .72677 .39503 .71248 Metetra
.765 .712 .802 r
.39503 .71248 .40582 .72677 .4244 .71542 .41379 .69749 Metetra
.665 .641 .816 r
.41379 .69749 .4244 .71542 .44306 .70293 .43236 .69074 Metetra
.564 .682 .919 r
.43236 .69074 .44306 .70293 .46166 .69618 .45093 .68925 Metetra
.567 .798 .986 r
.45093 .68925 .46166 .69618 .48032 .6937 .46969 .6859 Metetra
.676 .809 .946 r
.46969 .6859 .48032 .6937 .49915 .69035 .48864 .6791 Metetra
.673 .74 .901 r
.48864 .6791 .49915 .69035 .51813 .68409 .50771 .67256 Metetra
.632 .723 .914 r
.50771 .67256 .51813 .68409 .53724 .67714 .52689 .66805 Metetra
.624 .771 .951 r
.52689 .66805 .53724 .67714 .55647 .67192 .54622 .66344 Metetra
.659 .796 .948 r
.54622 .66344 .55647 .67192 .57586 .66782 .56568 .65726 Metetra
.663 .756 .919 r
.56568 .65726 .57586 .66782 .59538 .66273 .58527 .65106 Metetra
.638 .728 .914 r
.58527 .65106 .59538 .66273 .615 .65621 .60502 .64613 Metetra
.633 .759 .938 r
.60502 .64613 .615 .65621 .63477 .64996 .62492 .64115 Metetra
.657 .795 .949 r
.62492 .64115 .63477 .64996 .65472 .64512 .64493 .63489 Metetra
.661 .768 .929 r
.64493 .63489 .65472 .64512 .67483 .64055 .66507 .62858 Metetra
.637 .727 .914 r
.66507 .62858 .67483 .64055 .69503 .63455 .68541 .62354 Metetra
.634 .746 .929 r
.68541 .62354 .69503 .63455 .71532 .62753 .7059 .61849 Metetra
.661 .798 .948 r
.7059 .61849 .71532 .62753 .73581 .62165 .72647 .61184 Metetra
.665 .785 .938 r
.72647 .61184 .73581 .62165 .75656 .61752 .74716 .60507 Metetra
.627 .72 .914 r
.74716 .60507 .75656 .61752 .77744 .61271 .76815 .60039 Metetra
.62 .721 .918 r
.76815 .60039 .77744 .61271 .79825 .60489 .78933 .59597 Metetra
.684 .816 .946 r
.78933 .59597 .79825 .60489 .81911 .59614 .81039 .58799 Metetra
.721 .845 .941 r
.81039 .58799 .81911 .59614 .8405 .59181 .83141 .57805 Metetra
.622 .701 .901 r
.83141 .57805 .8405 .59181 .86267 .59348 .85307 .57356 Metetra
.485 .547 .845 r
.85307 .57356 .86267 .59348 .88497 .594 .8758 .57772 Metetra
.439 .569 .888 r
.8758 .57772 .88497 .594 .90616 .58223 .89891 .58252 Metetra
.264 .772 .798 r
.89891 .58252 .90616 .58223 .92562 .55521 .92116 .57721 Metetra
.279 0 .191 r
.92116 .57721 .92562 .55521 .9445 .52443 .94245 .56268 Metetra
.69 .926 .969 r
.31075 .72919 .32258 .73122 .34027 .73111 .329 .72053 Metetra
.768 .76 .845 r
.329 .72053 .34027 .73111 .35799 .7339 .34756 .70747 Metetra
.687 .589 .74 r
.34756 .70747 .35799 .7339 .37628 .72802 .36609 .6959 Metetra
.631 .533 .725 r
.36609 .6959 .37628 .72802 .39503 .71248 .38447 .68967 Metetra
.593 .564 .792 r
.38447 .68967 .39503 .71248 .41379 .69749 .40282 .68775 Metetra
.549 .727 .957 r
.40282 .68775 .41379 .69749 .43236 .69074 .42132 .68597 Metetra
.573 .851 .996 r
.42132 .68597 .43236 .69074 .45093 .68925 .44005 .68137 Metetra
.676 .808 .946 r
.44005 .68137 .45093 .68925 .46969 .6859 .45897 .67456 Metetra
.671 .739 .901 r
.45897 .67456 .46969 .6859 .48864 .6791 .478 .66809 Metetra
.639 .737 .919 r
.478 .66809 .48864 .6791 .50771 .67256 .49713 .66314 Metetra
.623 .765 .948 r
.49713 .66314 .50771 .67256 .52689 .66805 .51641 .65859 Metetra
.647 .773 .94 r
.51641 .65859 .52689 .66805 .54622 .66344 .53583 .65303 Metetra
.665 .76 .922 r
.53583 .65303 .54622 .66344 .56568 .65726 .55538 .64671 Metetra
.654 .756 .925 r
.55538 .64671 .56568 .65726 .58527 .65106 .57506 .64088 Metetra
.633 .758 .938 r
.57506 .64088 .58527 .65106 .60502 .64613 .59491 .63586 Metetra
.637 .759 .936 r
.59491 .63586 .60502 .64613 .62492 .64115 .6149 .63063 Metetra
.657 .762 .927 r
.6149 .63063 .62492 .64115 .64493 .63489 .635 .62447 Metetra
.661 .767 .928 r
.635 .62447 .64493 .63489 .66507 .62858 .65525 .6181 Metetra
.642 .761 .935 r
.65525 .6181 .66507 .62858 .68541 .62354 .67567 .61254 Metetra
.632 .748 .932 r
.67567 .61254 .68541 .62354 .7059 .61849 .69626 .60748 Metetra
.647 .755 .928 r
.69626 .60748 .7059 .61849 .72647 .61184 .71698 .60164 Metetra
.666 .78 .934 r
.71698 .60164 .72647 .61184 .74716 .60507 .73779 .59477 Metetra
.657 .776 .937 r
.73779 .59477 .74716 .60507 .76815 .60039 .75877 .5883 Metetra
.628 .731 .922 r
.75877 .5883 .76815 .60039 .78933 .59597 .78002 .58339 Metetra
.621 .721 .918 r
.78002 .58339 .78933 .59597 .81039 .58799 .80147 .57883 Metetra
.657 .806 .955 r
.80147 .57883 .81039 .58799 .83141 .57805 .8229 .57198 Metetra
.704 .893 .966 r
.8229 .57198 .83141 .57805 .85307 .57356 .84421 .56217 Metetra
.712 .782 .907 r
.84421 .56217 .85307 .57356 .8758 .57772 .86565 .55248 Metetra
.625 .58 .784 r
.86565 .55248 .8758 .57772 .89891 .58252 .88769 .54728 Metetra
.566 .494 .734 r
.88769 .54728 .89891 .58252 .92116 .57721 .91056 .54772 Metetra
.545 .51 .768 r
.91056 .54772 .92116 .57721 .94245 .56268 .9339 .54978 Metetra
.676 .605 .768 r
.30004 .70644 .31075 .72919 .329 .72053 .31832 .69747 Metetra
.699 .614 .758 r
.31832 .69747 .329 .72053 .34756 .70747 .33684 .68572 Metetra
.649 .6 .786 r
.33684 .68572 .34756 .70747 .36609 .6959 .35515 .67949 Metetra
.526 .6 .871 r
.35515 .67949 .36609 .6959 .38447 .68967 .37327 .68027 Metetra
.407 .677 .971 r
.37327 .68027 .38447 .68967 .40282 .68775 .39155 .68172 Metetra
.557 .818 .994 r
.39155 .68172 .40282 .68775 .42132 .68597 .4102 .67811 Metetra
.694 .813 .938 r
.4102 .67811 .42132 .68597 .44005 .68137 .42911 .67047 Metetra
.682 .751 .903 r
.42911 .67047 .44005 .68137 .45897 .67456 .44811 .66339 Metetra
.637 .734 .919 r
.44811 .66339 .45897 .67456 .478 .66809 .4672 .65851 Metetra
.624 .763 .946 r
.4672 .65851 .478 .66809 .49713 .66314 .48642 .65389 Metetra
.651 .78 .942 r
.48642 .65389 .49713 .66314 .51641 .65859 .50579 .64808 Metetra
.66 .758 .923 r
.50579 .64808 .51641 .65859 .53583 .65303 .52529 .64197 Metetra
.645 .745 .921 r
.52529 .64197 .53583 .65303 .55538 .64671 .54494 .63652 Metetra
.639 .761 .936 r
.54494 .63652 .55538 .64671 .57506 .64088 .56473 .63119 Metetra
.65 .776 .941 r
.56473 .63119 .57506 .64088 .59491 .63586 .58465 .6253 Metetra
.653 .761 .929 r
.58465 .6253 .59491 .63586 .6149 .63063 .60472 .61932 Metetra
.644 .745 .923 r
.60472 .61932 .6149 .63063 .635 .62447 .62495 .61376 Metetra
.644 .758 .932 r
.62495 .61376 .635 .62447 .65525 .6181 .64532 .60811 Metetra
.653 .777 .94 r
.64532 .60811 .65525 .6181 .67567 .61254 .66582 .60189 Metetra
.651 .765 .932 r
.66582 .60189 .67567 .61254 .69626 .60748 .68647 .59579 Metetra
.638 .742 .923 r
.68647 .59579 .69626 .60748 .71698 .60164 .70731 .59037 Metetra
.643 .753 .929 r
.70731 .59037 .71698 .60164 .73779 .59477 .7283 .58462 Metetra
.665 .785 .938 r
.7283 .58462 .73779 .59477 .75877 .5883 .74937 .57766 Metetra
.659 .775 .934 r
.74937 .57766 .75877 .5883 .78002 .58339 .7706 .57096 Metetra
.615 .724 .924 r
.7706 .57096 .78002 .58339 .80147 .57883 .79217 .56652 Metetra
.601 .722 .929 r
.79217 .56652 .80147 .57883 .8229 .57198 .81398 .56267 Metetra
.679 .815 .948 r
.81398 .56267 .8229 .57198 .84421 .56217 .83559 .55463 Metetra
.775 .881 .923 r
.83559 .55463 .84421 .56217 .86565 .55248 .85683 .54126 Metetra
.756 .804 .891 r
.85683 .54126 .86565 .55248 .88769 .54728 .87821 .52854 Metetra
.633 .645 .845 r
.87821 .52854 .88769 .54728 .91056 .54772 .9005 .52316 Metetra
.555 .55 .803 r
.9005 .52316 .91056 .54772 .9339 .54978 .92367 .52361 Metetra
.613 .649 .861 r
.28878 .69081 .30004 .70644 .31832 .69747 .30677 .68749 Metetra
.522 .713 .959 r
.30677 .68749 .31832 .69747 .33684 .68572 .32478 .68646 Metetra
.116 .668 .751 r
.32478 .68646 .33684 .68572 .35515 .67949 .34299 .68449 Metetra
.34299 .68449 .35515 .67949 .37327 .68027 .36152 .67947 Metetra
.584 .925 .959 r
.36152 .67947 .37327 .68027 .39155 .68172 .38027 .67205 Metetra
.69 .776 .917 r
.38027 .67205 .39155 .68172 .4102 .67811 .39913 .66462 Metetra
.656 .701 .88 r
.39913 .66462 .4102 .67811 .42911 .67047 .41805 .6588 Metetra
.632 .725 .915 r
.41805 .6588 .42911 .67047 .44811 .66339 .43707 .65416 Metetra
.629 .774 .95 r
.43707 .65416 .44811 .66339 .4672 .65851 .45624 .64923 Metetra
.652 .781 .942 r
.45624 .64923 .4672 .65851 .48642 .65389 .47557 .64336 Metetra
.66 .759 .923 r
.47557 .64336 .48642 .65389 .50579 .64808 .49503 .6372 Metetra
.648 .75 .924 r
.49503 .6372 .50579 .64808 .52529 .64197 .51463 .63157 Metetra
.637 .758 .935 r
.51463 .63157 .52529 .64197 .54494 .63652 .53436 .62631 Metetra
.644 .765 .937 r
.53436 .62631 .54494 .63652 .56473 .63119 .55424 .6207 Metetra
.655 .765 .93 r
.55424 .6207 .56473 .63119 .58465 .6253 .57426 .61456 Metetra
.653 .761 .928 r
.57426 .61456 .58465 .6253 .60472 .61932 .59443 .60848 Metetra
.642 .756 .932 r
.59443 .60848 .60472 .61932 .62495 .61376 .61475 .60287 Metetra
.64 .756 .933 r
.61475 .60287 .62495 .61376 .64532 .60811 .63523 .59731 Metetra
.65 .763 .932 r
.63523 .59731 .64532 .60811 .66582 .60189 .65584 .59122 Metetra
.657 .769 .932 r
.65584 .59122 .66582 .60189 .68647 .59579 .67659 .58477 Metetra
.648 .761 .931 r
.67659 .58477 .68647 .59579 .70731 .59037 .6975 .5787 Metetra
.637 .746 .927 r
.6975 .5787 .70731 .59037 .7283 .58462 .71861 .57316 Metetra
.642 .753 .93 r
.71861 .57316 .7283 .58462 .74937 .57766 .73986 .56733 Metetra
.659 .784 .941 r
.73986 .56733 .74937 .57766 .7706 .57096 .76122 .56051 Metetra
.664 .785 .938 r
.76122 .56051 .7706 .57096 .79217 .56652 .7827 .55339 Metetra
.643 .728 .91 r
.7827 .55339 .79217 .56652 .81398 .56267 .80444 .54748 Metetra
.614 .683 .892 r
.80444 .54748 .81398 .56267 .83559 .55463 .82651 .54326 Metetra
.6 .746 .946 r
.82651 .54326 .83559 .55463 .85683 .54126 .84877 .53902 Metetra
.485 .887 .946 r
.84877 .53902 .85683 .54126 .87821 .52854 .87097 .53227 Metetra
.87097 .53227 .87821 .52854 .9005 .52316 .89299 .52228 Metetra
.581 .943 .895 r
.89299 .52228 .9005 .52316 .92367 .52361 .91502 .51126 Metetra
.438 .797 .996 r
.27666 .68596 .28878 .69081 .30677 .68749 .29464 .6841 Metetra
.156 .668 .897 r
.29464 .6841 .30677 .68749 .32478 .68646 .31262 .68497 Metetra
.398 .836 .945 r
.31262 .68497 .32478 .68646 .34299 .68449 .33104 .68128 Metetra
.729 .914 .957 r
.33104 .68128 .34299 .68449 .36152 .67947 .34992 .67126 Metetra
.756 .813 .898 r
.34992 .67126 .36152 .67947 .38027 .67205 .36894 .66002 Metetra
.685 .734 .888 r
.36894 .66002 .38027 .67205 .39913 .66462 .38787 .65264 Metetra
.614 .715 .917 r
.38787 .65264 .39913 .66462 .41805 .6588 .4068 .64876 Metetra
.608 .752 .946 r
.4068 .64876 .41805 .6588 .43707 .65416 .42588 .64474 Metetra
.651 .778 .941 r
.42588 .64474 .43707 .65416 .45624 .64923 .44516 .63886 Metetra
.665 .765 .924 r
.44516 .63886 .45624 .64923 .47557 .64336 .46458 .63242 Metetra
.648 .75 .924 r
.46458 .63242 .47557 .64336 .49503 .6372 .48413 .62674 Metetra
.638 .758 .935 r
.48413 .62674 .49503 .6372 .51463 .63157 .50381 .62142 Metetra
.646 .768 .937 r
.50381 .62142 .51463 .63157 .53436 .62631 .52364 .61566 Metetra
.652 .762 .929 r
.52364 .61566 .53436 .62631 .55424 .6207 .54362 .60962 Metetra
.648 .753 .926 r
.54362 .60962 .55424 .6207 .57426 .61456 .56374 .60378 Metetra
.646 .76 .932 r
.56374 .60378 .57426 .61456 .59443 .60848 .584 .59797 Metetra
.649 .768 .936 r
.584 .59797 .59443 .60848 .61475 .60287 .60442 .59192 Metetra
.648 .761 .931 r
.60442 .59192 .61475 .60287 .63523 .59731 .62498 .58591 Metetra
.644 .752 .928 r
.62498 .58591 .63523 .59731 .65584 .59122 .64571 .5801 Metetra
.648 .76 .931 r
.64571 .5801 .65584 .59122 .67659 .58477 .66658 .574 Metetra
.656 .772 .934 r
.66658 .574 .67659 .58477 .6975 .5787 .68759 .56745 Metetra
.648 .761 .932 r
.68759 .56745 .6975 .5787 .71861 .57316 .70877 .56125 Metetra
.632 .744 .929 r
.70877 .56125 .71861 .57316 .73986 .56733 .73016 .55584 Metetra
.642 .758 .933 r
.73016 .55584 .73986 .56733 .76122 .56051 .75169 .54985 Metetra
.679 .789 .933 r
.75169 .54985 .76122 .56051 .7827 .55339 .77324 .54192 Metetra
.681 .776 .922 r
.77324 .54192 .7827 .55339 .80444 .54748 .79493 .53384 Metetra
.613 .711 .914 r
.79493 .53384 .80444 .54748 .82651 .54326 .81709 .52939 Metetra
.523 .665 .926 r
.81709 .52939 .82651 .54326 .84877 .53902 .83982 .52898 Metetra
.512 .738 .976 r
.83982 .52898 .84877 .53902 .87097 .53227 .86268 .52733 Metetra
.624 .905 .984 r
.86268 .52733 .87097 .53227 .89299 .52228 .88508 .51903 Metetra
.721 .966 .937 r
.88508 .51903 .89299 .52228 .91502 .51126 .90707 .50586 Metetra
.647 .863 .981 r
.26435 .68094 .27666 .68596 .29464 .6841 .28272 .67455 Metetra
.695 .777 .915 r
.28272 .67455 .29464 .6841 .31262 .68497 .3013 .6669 Metetra
.667 .647 .821 r
.3013 .6669 .31262 .68497 .33104 .68128 .31995 .65971 Metetra
.639 .603 .797 r
.31995 .65971 .33104 .68128 .34992 .67126 .33863 .6541 Metetra
.627 .643 .847 r
.33863 .6541 .34992 .67126 .36894 .66002 .35738 .64969 Metetra
.622 .75 .938 r
.35738 .64969 .36894 .66002 .38787 .65264 .37627 .64519 Metetra
.629 .814 .971 r
.37627 .64519 .38787 .65264 .4068 .64876 .39535 .63976 Metetra
.655 .789 .946 r
.39535 .63976 .4068 .64876 .42588 .64474 .41459 .63364 Metetra
.656 .749 .919 r
.41459 .63364 .42588 .64474 .44516 .63886 .43395 .62762 Metetra
.646 .745 .922 r
.43395 .62762 .44516 .63886 .46458 .63242 .45344 .62205 Metetra
.641 .762 .936 r
.45344 .62205 .46458 .63242 .48413 .62674 .47307 .61657 Metetra
.647 .769 .938 r
.47307 .61657 .48413 .62674 .50381 .62142 .49285 .61074 Metetra
.653 .762 .93 r
.49285 .61074 .50381 .62142 .52364 .61566 .51278 .60464 Metetra
.65 .756 .927 r
.51278 .60464 .52364 .61566 .54362 .60962 .53285 .59867 Metetra
.644 .757 .931 r
.53285 .59867 .54362 .60962 .56374 .60378 .55307 .59292 Metetra
.644 .761 .933 r
.55307 .59292 .56374 .60378 .584 .59797 .57343 .58707 Metetra
.65 .764 .932 r
.57343 .58707 .584 .59797 .60442 .59192 .59395 .5809 Metetra
.652 .763 .931 r
.59395 .5809 .60442 .59192 .62498 .58591 .61461 .57464 Metetra
.646 .758 .931 r
.61461 .57464 .62498 .58591 .64571 .5801 .63543 .56859 Metetra
.643 .754 .93 r
.63543 .56859 .64571 .5801 .66658 .574 .65642 .56267 Metetra
.647 .761 .932 r
.65642 .56267 .66658 .574 .68759 .56745 .67756 .55647 Metetra
.653 .771 .936 r
.67756 .55647 .68759 .56745 .70877 .56125 .69884 .54992 Metetra
.651 .765 .933 r
.69884 .54992 .70877 .56125 .73016 .55584 .72028 .54344 Metetra
.642 .744 .923 r
.72028 .54344 .73016 .55584 .75169 .54985 .74192 .53743 Metetra
.639 .744 .924 r
.74192 .53743 .75169 .54985 .77324 .54192 .76374 .53152 Metetra
.647 .788 .949 r
.76374 .53152 .77324 .54192 .79493 .53384 .78568 .52488 Metetra
.661 .825 .962 r
.78568 .52488 .79493 .53384 .81709 .52939 .80771 .51726 Metetra
.671 .766 .922 r
.80771 .51726 .81709 .52939 .83982 .52898 .82988 .50954 Metetra
.643 .65 .841 r
.82988 .50954 .83982 .52898 .86268 .52733 .85234 .50305 Metetra
.616 .591 .802 r
.85234 .50305 .86268 .52733 .88508 .51903 .87516 .49822 Metetra
.612 .621 .837 r
.87516 .49822 .88508 .51903 .90707 .50586 .89824 .49389 Metetra
.711 .757 .888 r
.25229 .67007 .26435 .68094 .28272 .67455 .27091 .66132 Metetra
.738 .727 .841 r
.27091 .66132 .28272 .67455 .3013 .6669 .28982 .64977 Metetra
.673 .661 .83 r
.28982 .64977 .3013 .6669 .31995 .65971 .30853 .64227 Metetra
.574 .618 .858 r
.30853 .64227 .31995 .65971 .33863 .6541 .32702 .64065 Metetra
.52 .656 .921 r
.32702 .64065 .33863 .6541 .35738 .64969 .34561 .64042 Metetra
.59 .765 .963 r
.34561 .64042 .35738 .64969 .37627 .64519 .36455 .63675 Metetra
.675 .806 .945 r
.36455 .63675 .37627 .64519 .39535 .63976 .38378 .62966 Metetra
.68 .776 .923 r
.38378 .62966 .39535 .63976 .41459 .63364 .40315 .62241 Metetra
.646 .747 .923 r
.40315 .62241 .41459 .63364 .43395 .62762 .42258 .61677 Metetra
.631 .751 .934 r
.42258 .61677 .43395 .62762 .45344 .62205 .44215 .61171 Metetra
.645 .766 .937 r
.44215 .61171 .45344 .62205 .47307 .61657 .46187 .60594 Metetra
.656 .765 .93 r
.46187 .60594 .47307 .61657 .49285 .61074 .48175 .59968 Metetra
.65 .757 .928 r
.48175 .59968 .49285 .61074 .51278 .60464 .50177 .59364 Metetra
.644 .758 .932 r
.50177 .59364 .51278 .60464 .53285 .59867 .52193 .58783 Metetra
.646 .763 .934 r
.52193 .58783 .53285 .59867 .55307 .59292 .54225 .58186 Metetra
.648 .761 .931 r
.54225 .58186 .55307 .59292 .57343 .58707 .56271 .57576 Metetra
.647 .758 .93 r
.56271 .57576 .57343 .58707 .59395 .5809 .58333 .56968 Metetra
.649 .761 .931 r
.58333 .56968 .59395 .5809 .61461 .57464 .6041 .56347 Metetra
.651 .765 .933 r
.6041 .56347 .61461 .57464 .63543 .56859 .62502 .55709 Metetra
.646 .758 .931 r
.62502 .55709 .63543 .56859 .65642 .56267 .64611 .55094 Metetra
.64 .754 .931 r
.64611 .55094 .65642 .56267 .67756 .55647 .66737 .54502 Metetra
.649 .764 .933 r
.66737 .54502 .67756 .55647 .69884 .54992 .68877 .53859 Metetra
.663 .773 .931 r
.68877 .53859 .69884 .54992 .72028 .54344 .7103 .53143 Metetra
.651 .757 .927 r
.7103 .53143 .72028 .54344 .74192 .53743 .73202 .52486 Metetra
.617 .735 .931 r
.73202 .52486 .74192 .53743 .76374 .53152 .75402 .51994 Metetra
.615 .755 .945 r
.75402 .51994 .76374 .53152 .78568 .52488 .77621 .51486 Metetra
.685 .814 .944 r
.77621 .51486 .78568 .52488 .80771 .51726 .7983 .50622 Metetra
.746 .815 .906 r
.7983 .50622 .80771 .51726 .82988 .50954 .82021 .49395 Metetra
.711 .73 .865 r
.82021 .49395 .82988 .50954 .85234 .50305 .84236 .48309 Metetra
.616 .634 .845 r
.84236 .48309 .85234 .50305 .87516 .49822 .86527 .47839 Metetra
.547 .6 .858 r
.86527 .47839 .87516 .49822 .89824 .49389 .88886 .47798 Metetra
.643 .701 .888 r
.24029 .65663 .25229 .67007 .27091 .66132 .2587 .65143 Metetra
.629 .761 .942 r
.2587 .65143 .27091 .66132 .28982 .64977 .27722 .64658 Metetra
.541 .875 .991 r
.27722 .64658 .28982 .64977 .30853 .64227 .29589 .64153 Metetra
.474 .882 .944 r
.29589 .64153 .30853 .64227 .32702 .64065 .31474 .63593 Metetra
.614 .87 .99 r
.31474 .63593 .32702 .64065 .34561 .64042 .33374 .62989 Metetra
.656 .761 .927 r
.33374 .62989 .34561 .64042 .36455 .63675 .35287 .62383 Metetra
.651 .719 .898 r
.35287 .62383 .36455 .63675 .38378 .62966 .37212 .61802 Metetra
.646 .741 .918 r
.37212 .61802 .38378 .62966 .40315 .62241 .3915 .61237 Metetra
.644 .772 .941 r
.3915 .61237 .40315 .62241 .42258 .61677 .41103 .60663 Metetra
.647 .772 .939 r
.41103 .60663 .42258 .61677 .44215 .61171 .43071 .60069 Metetra
.65 .758 .928 r
.43071 .60069 .44215 .61171 .46187 .60594 .45053 .59467 Metetra
.648 .754 .927 r
.45053 .59467 .46187 .60594 .48175 .59968 .4705 .5887 Metetra
.646 .76 .932 r
.4705 .5887 .48175 .59968 .50177 .59364 .49061 .58276 Metetra
.647 .764 .934 r
.49061 .58276 .50177 .59364 .52193 .58783 .51087 .57673 Metetra
.649 .762 .932 r
.51087 .57673 .52193 .58783 .54225 .58186 .53128 .57056 Metetra
.649 .76 .93 r
.53128 .57056 .54225 .58186 .56271 .57576 .55185 .56436 Metetra
.647 .759 .931 r
.55185 .56436 .56271 .57576 .58333 .56968 .57257 .55821 Metetra
.646 .759 .931 r
.57257 .55821 .58333 .56968 .6041 .56347 .59344 .55203 Metetra
.648 .762 .932 r
.59344 .55203 .6041 .56347 .62502 .55709 .61447 .54571 Metetra
.649 .765 .934 r
.61447 .54571 .62502 .55709 .64611 .55094 .63566 .53929 Metetra
.648 .761 .932 r
.63566 .53929 .64611 .55094 .66737 .54502 .65702 .5329 Metetra
.646 .753 .927 r
.65702 .5329 .66737 .54502 .68877 .53859 .67854 .52656 Metetra
.647 .757 .929 r
.67854 .52656 .68877 .53859 .7103 .53143 .70022 .52013 Metetra
.649 .773 .939 r
.70022 .52013 .7103 .53143 .73202 .52486 .72207 .51348 Metetra
.65 .774 .939 r
.72207 .51348 .73202 .52486 .75402 .51994 .74407 .50674 Metetra
.648 .741 .917 r
.74407 .50674 .75402 .51994 .77621 .51486 .76626 .50016 Metetra
.643 .716 .9 r
.76626 .50016 .77621 .51486 .7983 .50622 .78865 .49382 Metetra
.64 .756 .932 r
.78865 .49382 .7983 .50622 .82021 .49395 .81122 .48746 Metetra
.601 .867 .993 r
.81122 .48746 .82021 .49395 .84236 .48309 .83394 .48063 Metetra
.5 .895 .946 r
.83394 .48063 .84236 .48309 .86527 .47839 .85678 .47321 Metetra
.593 .894 .988 r
.85678 .47321 .86527 .47839 .88886 .47798 .87977 .46556 Metetra
.567 .706 .936 r
.22799 .64484 .24029 .65663 .2587 .65143 .24624 .64253 Metetra
.412 .705 .983 r
.24624 .64253 .2587 .65143 .27722 .64658 .26444 .64299 Metetra
.469 .841 .99 r
.26444 .64299 .27722 .64658 .29589 .64153 .28311 .63942 Metetra
.692 .933 .966 r
.28311 .63942 .29589 .64153 .31474 .63593 .30233 .62988 Metetra
.752 .864 .931 r
.30233 .62988 .31474 .63593 .33374 .62989 .32173 .61883 Metetra
.689 .762 .908 r
.32173 .61883 .33374 .62989 .35287 .62383 .34103 .61104 Metetra
.621 .714 .912 r
.34103 .61104 .35287 .62383 .37212 .61802 .36029 .60654 Metetra
.614 .736 .933 r
.36029 .60654 .37212 .61802 .3915 .61237 .3797 .60218 Metetra
.648 .773 .939 r
.3797 .60218 .3915 .61237 .41103 .60663 .39933 .59618 Metetra
.663 .773 .931 r
.39933 .59618 .41103 .60663 .43071 .60069 .41912 .58947 Metetra
.651 .757 .927 r
.41912 .58947 .43071 .60069 .45053 .59467 .43903 .58335 Metetra
.64 .753 .931 r
.43903 .58335 .45053 .59467 .4705 .5887 .45909 .57766 Metetra
.645 .761 .934 r
.45909 .57766 .4705 .5887 .49061 .58276 .47929 .57168 Metetra
.651 .764 .932 r
.47929 .57168 .49061 .58276 .51087 .57673 .49965 .56538 Metetra
.649 .76 .93 r
.49965 .56538 .51087 .57673 .53128 .57056 .52016 .55912 Metetra
.647 .76 .931 r
.52016 .55912 .53128 .57056 .55185 .56436 .54083 .5529 Metetra
.648 .761 .932 r
.54083 .5529 .55185 .56436 .57257 .55821 .56165 .5466 Metetra
.646 .759 .931 r
.56165 .5466 .57257 .55821 .59344 .55203 .58263 .54034 Metetra
.645 .759 .932 r
.58263 .54034 .59344 .55203 .61447 .54571 .60378 .53411 Metetra
.65 .764 .932 r
.60378 .53411 .61447 .54571 .63566 .53929 .62507 .52756 Metetra
.655 .765 .93 r
.62507 .52756 .63566 .53929 .65702 .5329 .64652 .52071 Metetra
.646 .755 .929 r
.64652 .52071 .65702 .5329 .67854 .52656 .66816 .5143 Metetra
.632 .75 .933 r
.66816 .5143 .67854 .52656 .70022 .52013 .68999 .50848 Metetra
.645 .768 .938 r
.68999 .50848 .70022 .52013 .72207 .51348 .71196 .50193 Metetra
.678 .783 .93 r
.71196 .50193 .72207 .51348 .74407 .50674 .734 .49368 Metetra
.675 .757 .913 r
.734 .49368 .74407 .50674 .76626 .50016 .75621 .48555 Metetra
.611 .706 .912 r
.75621 .48555 .76626 .50016 .78865 .49382 .77884 .48085 Metetra
.523 .695 .947 r
.77884 .48085 .78865 .49382 .81122 .48746 .80196 .47955 Metetra
.493 .789 .998 r
.80196 .47955 .81122 .48746 .83394 .48063 .82521 .4767 Metetra
.609 .923 .972 r
.82521 .4767 .83394 .48063 .85678 .47321 .84808 .46758 Metetra
.748 .937 .948 r
.84808 .46758 .85678 .47321 .87977 .46556 .87066 .45415 Metetra
.634 .788 .956 r
.21527 .63605 .22799 .64484 .24624 .64253 .23383 .63071 Metetra
.634 .731 .918 r
.23383 .63071 .24624 .64253 .26444 .64299 .25251 .62572 Metetra
.635 .652 .85 r
.25251 .62572 .26444 .64299 .28311 .63942 .27133 .62052 Metetra
.641 .637 .831 r
.27133 .62052 .28311 .63942 .30233 .62988 .29034 .61477 Metetra
.654 .689 .871 r
.29034 .61477 .30233 .62988 .32173 .61883 .30951 .60857 Metetra
.655 .771 .935 r
.30951 .60857 .32173 .61883 .34103 .61104 .32881 .60236 Metetra
.642 .801 .959 r
.32881 .60236 .34103 .61104 .36029 .60654 .34824 .59639 Metetra
.642 .773 .943 r
.34824 .59639 .36029 .60654 .3797 .60218 .36779 .59058 Metetra
.646 .749 .924 r
.36779 .59058 .3797 .60218 .39933 .59618 .3875 .58468 Metetra
.65 .753 .925 r
.3875 .58468 .39933 .59618 .41912 .58947 .40736 .57858 Metetra
.649 .765 .934 r
.40736 .57858 .41912 .58947 .43903 .58335 .42737 .5724 Metetra
.647 .765 .935 r
.42737 .5724 .43903 .58335 .45909 .57766 .44752 .56627 Metetra
.646 .758 .931 r
.44752 .56627 .45909 .57766 .47929 .57168 .46782 .56016 Metetra
.647 .758 .93 r
.46782 .56016 .47929 .57168 .49965 .56538 .48828 .55395 Metetra
.649 .762 .931 r
.48828 .55395 .49965 .56538 .52016 .55912 .50889 .54761 Metetra
.649 .762 .932 r
.50889 .54761 .52016 .55912 .54083 .5529 .52966 .54124 Metetra
.647 .76 .931 r
.52966 .54124 .54083 .5529 .56165 .5466 .55059 .53492 Metetra
.646 .761 .932 r
.55059 .53492 .56165 .5466 .58263 .54034 .57167 .52856 Metetra
.648 .761 .932 r
.57167 .52856 .58263 .54034 .60378 .53411 .59292 .52206 Metetra
.65 .759 .929 r
.59292 .52206 .60378 .53411 .62507 .52756 .61433 .51546 Metetra
.648 .759 .93 r
.61433 .51546 .62507 .52756 .64652 .52071 .6359 .50889 Metetra
.645 .764 .935 r
.6359 .50889 .64652 .52071 .66816 .5143 .65765 .50236 Metetra
.646 .764 .935 r
.65765 .50236 .66816 .5143 .68999 .50848 .67956 .49574 Metetra
.651 .753 .925 r
.67956 .49574 .68999 .50848 .71196 .50193 .70164 .48891 Metetra
.652 .75 .922 r
.70164 .48891 .71196 .50193 .734 .49368 .72389 .48197 Metetra
.645 .774 .942 r
.72389 .48197 .734 .49368 .75621 .48555 .74632 .47519 Metetra
.632 .797 .962 r
.74632 .47519 .75621 .48555 .77884 .48085 .76895 .46867 Metetra
.639 .766 .94 r
.76895 .46867 .77884 .48085 .80196 .47955 .79178 .46211 Metetra
.648 .688 .873 r
.79178 .46211 .80196 .47955 .82521 .4767 .81475 .45508 Metetra
.649 .641 .829 r
.81475 .45508 .82521 .4767 .84808 .46758 .83785 .44745 Metetra
.655 .661 .844 r
.83785 .44745 .84808 .46758 .87066 .45415 .86111 .43959 Metetra
.717 .838 .939 r
.20219 .62897 .21527 .63605 .23383 .63071 .22117 .61987 Metetra
.752 .773 .871 r
.22117 .61987 .23383 .63071 .25251 .62572 .24049 .60794 Metetra
.673 .662 .832 r
.24049 .60794 .25251 .62572 .27133 .62052 .25956 .60011 Metetra
.574 .593 .835 r
.25956 .60011 .27133 .62052 .29034 .61477 .27831 .59825 Metetra
.533 .624 .888 r
.27831 .59825 .29034 .61477 .30951 .60857 .29714 .59779 Metetra
.597 .747 .949 r
.29714 .59779 .30951 .60857 .32881 .60236 .31639 .59383 Metetra
.675 .814 .95 r
.31639 .59383 .32881 .60236 .34824 .59639 .33599 .58641 Metetra
.68 .788 .932 r
.33599 .58641 .34824 .59639 .36779 .59058 .35573 .57882 Metetra
.646 .748 .924 r
.35573 .57882 .36779 .59058 .3875 .58468 .37552 .57286 Metetra
.632 .744 .929 r
.37552 .57286 .3875 .58468 .40736 .57858 .39544 .56748 Metetra
.645 .763 .935 r
.39544 .56748 .40736 .57858 .42737 .5724 .41553 .56139 Metetra
.655 .769 .933 r
.41553 .56139 .42737 .5724 .44752 .56627 .43579 .55479 Metetra
.65 .761 .93 r
.43579 .55479 .44752 .56627 .46782 .56016 .4562 .54843 Metetra
.644 .756 .93 r
.4562 .54843 .46782 .56016 .48828 .55395 .47675 .54227 Metetra
.647 .759 .931 r
.47675 .54227 .48828 .55395 .50889 .54761 .49746 .53596 Metetra
.648 .762 .932 r
.49746 .53596 .50889 .54761 .52966 .54124 .51833 .52951 Metetra
.647 .762 .933 r
.51833 .52951 .52966 .54124 .55059 .53492 .53936 .52308 Metetra
.649 .762 .932 r
.53936 .52308 .55059 .53492 .57167 .52856 .56055 .51652 Metetra
.651 .761 .93 r
.56055 .51652 .57167 .52856 .59292 .52206 .58191 .50979 Metetra
.646 .756 .929 r
.58191 .50979 .59292 .52206 .61433 .51546 .60343 .50327 Metetra
.64 .757 .934 r
.60343 .50327 .61433 .51546 .6359 .50889 .62513 .49699 Metetra
.649 .768 .936 r
.62513 .49699 .6359 .50889 .65765 .50236 .64698 .49019 Metetra
.663 .769 .929 r
.64698 .49019 .65765 .50236 .67956 .49574 .66898 .48264 Metetra
.651 .75 .922 r
.66898 .48264 .67956 .49574 .70164 .48891 .69117 .47569 Metetra
.616 .736 .932 r
.69117 .47569 .70164 .48891 .72389 .48197 .71364 .47041 Metetra
.612 .767 .954 r
.71364 .47041 .72389 .48197 .74632 .47519 .73629 .46496 Metetra
.685 .822 .949 r
.73629 .46496 .74632 .47519 .76895 .46867 .7589 .4559 Metetra
.743 .795 .895 r
.7589 .4559 .76895 .46867 .79178 .46211 .78137 .44316 Metetra
.702 .695 .84 r
.78137 .44316 .79178 .46211 .81475 .45508 .80406 .43184 Metetra
.612 .609 .824 r
.80406 .43184 .81475 .45508 .83785 .44745 .82747 .42676 Metetra
.544 .6 .86 r
.82747 .42676 .83785 .44745 .86111 .43959 .85154 .42603 Metetra
.67 .783 .934 r
.18915 .61929 .20219 .62897 .22117 .61987 .20802 .61243 Metetra
.694 .832 .949 r
.20802 .61243 .22117 .61987 .24049 .60794 .22712 .60428 Metetra
.649 .901 .983 r
.22712 .60428 .24049 .60794 .25956 .60011 .2463 .59661 Metetra
.579 .887 .991 r
.2463 .59661 .25956 .60011 .27831 .59825 .26547 .59054 Metetra
.599 .811 .981 r
.26547 .59054 .27831 .59825 .29714 .59779 .28469 .58569 Metetra
.624 .734 .926 r
.28469 .58569 .29714 .59779 .31639 .59383 .30407 .58076 Metetra
.645 .726 .907 r
.30407 .58076 .31639 .59383 .33599 .58641 .32366 .57486 Metetra
.659 .757 .923 r
.32366 .57486 .33599 .58641 .35573 .57882 .34343 .56825 Metetra
.654 .775 .938 r
.34343 .56825 .35573 .57882 .37552 .57286 .36334 .56175 Metetra
.644 .764 .936 r
.36334 .56175 .37552 .57286 .39544 .56748 .38337 .5557 Metetra
.642 .752 .929 r
.38337 .5557 .39544 .56748 .41553 .56139 .40355 .54973 Metetra
.648 .758 .929 r
.40355 .54973 .41553 .56139 .43579 .55479 .4239 .5434 Metetra
.653 .766 .932 r
.4239 .5434 .43579 .55479 .4562 .54843 .4444 .5368 Metetra
.649 .762 .932 r
.4444 .5368 .4562 .54843 .47675 .54227 .46506 .53032 Metetra
.644 .756 .931 r
.46506 .53032 .47675 .54227 .49746 .53596 .48587 .52406 Metetra
.645 .759 .932 r
.48587 .52406 .49746 .53596 .51833 .52951 .50684 .51769 Metetra
.65 .764 .932 r
.50684 .51769 .51833 .52951 .53936 .52308 .52798 .511 Metetra
.652 .761 .93 r
.52798 .511 .53936 .52308 .56055 .51652 .54928 .50419 Metetra
.646 .757 .93 r
.54928 .50419 .56055 .51652 .58191 .50979 .57074 .49761 Metetra
.642 .76 .934 r
.57074 .49761 .58191 .50979 .60343 .50327 .59238 .49115 Metetra
.647 .764 .934 r
.59238 .49115 .60343 .50327 .62513 .49699 .61418 .48441 Metetra
.654 .76 .928 r
.61418 .48441 .62513 .49699 .64698 .49019 .63614 .47729 Metetra
.652 .756 .926 r
.63614 .47729 .64698 .49019 .66898 .48264 .65828 .47025 Metetra
.64 .762 .937 r
.65828 .47025 .66898 .48264 .69117 .47569 .68062 .46367 Metetra
.636 .769 .944 r
.68062 .46367 .69117 .47569 .71364 .47041 .70315 .4572 Metetra
.652 .756 .926 r
.70315 .4572 .71364 .47041 .73629 .46496 .72582 .44998 Metetra
.669 .735 .899 r
.72582 .44998 .73629 .46496 .7589 .4559 .7486 .44174 Metetra
.67 .75 .911 r
.7486 .44174 .7589 .4559 .78137 .44316 .77155 .4334 Metetra
.632 .82 .973 r
.77155 .4334 .78137 .44316 .80406 .43184 .79478 .42632 Metetra
.508 .855 .994 r
.79478 .42632 .80406 .43184 .82747 .42676 .81835 .42091 Metetra
.494 .844 .995 r
.81835 .42091 .82747 .42676 .85154 .42603 .8422 .41601 Metetra
.573 .655 .892 r
.17653 .60359 .18915 .61929 .20802 .61243 .19502 .60124 Metetra
.44 .681 .966 r
.19502 .60124 .20802 .61243 .22712 .60428 .21342 .6017 Metetra
.455 .853 .973 r
.21342 .6017 .22712 .60428 .2463 .59661 .23242 .59746 Metetra
.661 .962 .93 r
.23242 .59746 .2463 .59661 .26547 .59054 .25211 .58669 Metetra
.759 .913 .942 r
.25211 .58669 .26547 .59054 .28469 .58569 .27198 .57467 Metetra
.688 .773 .916 r
.27198 .57467 .28469 .58569 .30407 .58076 .29165 .56662 Metetra
.614 .701 .906 r
.29165 .56662 .30407 .58076 .32366 .57486 .31121 .56216 Metetra
.614 .726 .926 r
.31121 .56216 .32366 .57486 .34343 .56825 .33095 .55755 Metetra
.652 .775 .939 r
.33095 .55755 .34343 .56825 .36334 .56175 .35095 .55103 Metetra
.664 .779 .935 r
.35095 .55103 .36334 .56175 .38337 .5557 .37113 .54391 Metetra
.648 .757 .929 r
.37113 .54391 .38337 .5557 .40355 .54973 .39141 .53758 Metetra
.639 .75 .929 r
.39141 .53758 .40355 .54973 .4239 .5434 .41184 .53161 Metetra
.647 .76 .931 r
.41184 .53161 .4239 .5434 .4444 .5368 .43244 .52518 Metetra
.652 .766 .933 r
.43244 .52518 .4444 .5368 .46506 .53032 .4532 .51846 Metetra
.647 .762 .933 r
.4532 .51846 .46506 .53032 .48587 .52406 .47411 .51193 Metetra
.646 .758 .931 r
.47411 .51193 .48587 .52406 .50684 .51769 .49519 .50543 Metetra
.65 .759 .929 r
.49519 .50543 .50684 .51769 .52798 .511 .51643 .49868 Metetra
.648 .759 .93 r
.51643 .49868 .52798 .511 .54928 .50419 .53784 .49196 Metetra
.643 .761 .934 r
.53784 .49196 .54928 .50419 .57074 .49761 .55942 .48543 Metetra
.648 .765 .935 r
.55942 .48543 .57074 .49761 .59238 .49115 .58116 .47861 Metetra
.657 .763 .928 r
.58116 .47861 .59238 .49115 .61418 .48441 .60307 .47132 Metetra
.649 .753 .925 r
.60307 .47132 .61418 .48441 .63614 .47729 .62516 .46438 Metetra
.631 .751 .934 r
.62516 .46438 .63614 .47729 .65828 .47025 .64745 .45824 Metetra
.64 .772 .943 r
.64745 .45824 .65828 .47025 .68062 .46367 .66991 .45149 Metetra
.679 .785 .93 r
.66991 .45149 .68062 .46367 .70315 .4572 .69245 .44276 Metetra
.68 .749 .903 r
.69245 .44276 .70315 .4572 .72582 .44998 .71515 .43385 Metetra
.613 .697 .903 r
.71515 .43385 .72582 .44998 .7486 .44174 .73825 .42866 Metetra
.5 .696 .956 r
.73825 .42866 .7486 .44174 .77155 .4334 .76187 .42763 Metetra
.388 .788 .985 r
.76187 .42763 .77155 .4334 .79478 .42632 .78568 .42531 Metetra
.487 .9 .895 r
.78568 .42531 .79478 .42632 .81835 .42091 .80916 .41614 Metetra
.74 .956 .943 r
.80916 .41614 .81835 .42091 .8422 .41601 .83233 .40197 Metetra
.608 .667 .881 r
.16379 .58763 .17653 .60359 .19502 .60124 .18247 .58364 Metetra
.557 .625 .875 r
.18247 .58364 .19502 .60124 .21342 .6017 .20107 .58202 Metetra
.581 .611 .848 r
.20107 .58202 .21342 .6017 .23242 .59746 .21995 .57943 Metetra
.637 .655 .851 r
.21995 .57943 .23242 .59746 .25211 .58669 .23928 .57366 Metetra
.687 .741 .892 r
.23928 .57366 .25211 .58669 .27198 .57467 .25895 .5654 Metetra
.691 .808 .938 r
.25895 .5654 .27198 .57467 .29165 .56662 .27873 .55712 Metetra
.652 .797 .952 r
.27873 .55712 .29165 .56662 .31121 .56216 .29853 .5505 Metetra
.627 .752 .936 r
.29853 .5505 .31121 .56216 .33095 .55755 .31839 .5451 Metetra
.635 .741 .925 r
.31839 .5451 .33095 .55755 .35095 .55103 .33843 .5394 Metetra
.654 .763 .93 r
.33843 .5394 .35095 .55103 .37113 .54391 .35868 .5327 Metetra
.659 .774 .934 r
.35868 .5327 .37113 .54391 .39141 .53758 .37909 .5257 Metetra
.647 .76 .931 r
.37909 .5257 .39141 .53758 .41184 .53161 .39962 .51924 Metetra
.638 .75 .929 r
.39962 .51924 .41184 .53161 .43244 .52518 .42031 .51316 Metetra
.645 .76 .933 r
.42031 .51316 .43244 .52518 .4532 .51846 .44116 .50671 Metetra
.655 .77 .933 r
.44116 .50671 .4532 .51846 .47411 .51193 .46219 .4997 Metetra
.653 .762 .929 r
.46219 .4997 .47411 .51193 .49519 .50543 .48338 .49274 Metetra
.643 .752 .929 r
.48338 .49274 .49519 .50543 .51643 .49868 .50472 .48626 Metetra
.64 .758 .934 r
.50472 .48626 .51643 .49868 .53784 .49196 .52624 .47984 Metetra
.65 .768 .935 r
.52624 .47984 .53784 .49196 .55942 .48543 .54792 .47285 Metetra
.657 .764 .928 r
.54792 .47285 .55942 .48543 .58116 .47861 .56978 .46547 Metetra
.649 .753 .926 r
.56978 .46547 .58116 .47861 .60307 .47132 .59181 .45848 Metetra
.636 .756 .935 r
.59181 .45848 .60307 .47132 .62516 .46438 .61403 .45203 Metetra
.64 .768 .94 r
.61403 .45203 .62516 .46438 .64745 .45824 .63642 .44527 Metetra
.661 .766 .928 r
.63642 .44527 .64745 .45824 .66991 .45149 .65897 .43749 Metetra
.666 .752 .915 r
.65897 .43749 .66991 .45149 .69245 .44276 .68167 .42937 Metetra
.64 .755 .931 r
.68167 .42937 .69245 .44276 .71515 .43385 .70461 .42251 Metetra
.591 .774 .967 r
.70461 .42251 .71515 .43385 .73825 .42866 .72786 .41737 Metetra
.589 .776 .969 r
.72786 .41737 .73825 .42866 .76187 .42763 .75134 .41221 Metetra
.655 .733 .907 r
.75134 .41221 .76187 .42763 .78568 .42531 .77484 .40444 Metetra
.69 .679 .835 r
.77484 .40444 .78568 .42531 .80916 .41614 .79824 .39331 Metetra
.695 .663 .815 r
.79824 .39331 .80916 .41614 .83233 .40197 .8217 .38111 Metetra
.724 .889 .956 r
.14966 .58283 .16379 .58763 .18247 .58364 .16907 .57281 Metetra
.761 .783 .871 r
.16907 .57281 .18247 .58364 .20107 .58202 .18885 .55989 Metetra
.649 .618 .806 r
.18885 .55989 .20107 .58202 .21995 .57943 .20816 .55271 Metetra
.535 .525 .791 r
.20816 .55271 .21995 .57943 .23928 .57366 .22696 .55284 Metetra
.506 .567 .851 r
.22696 .55284 .23928 .57366 .25895 .5654 .24591 .55367 Metetra
.604 .743 .943 r
.24591 .55367 .25895 .5654 .27873 .55712 .26549 .5492 Metetra
.693 .839 .953 r
.26549 .5492 .27873 .55712 .29853 .5505 .28554 .54052 Metetra
.683 .8 .937 r
.28554 .54052 .29853 .5505 .31839 .5451 .30567 .53241 Metetra
.635 .74 .924 r
.30567 .53241 .31839 .5451 .33843 .5394 .3258 .52659 Metetra
.629 .738 .926 r
.3258 .52659 .33843 .5394 .35868 .5327 .34607 .52104 Metetra
.653 .767 .933 r
.34607 .52104 .35868 .5327 .37909 .5257 .36656 .51424 Metetra
.659 .774 .934 r
.36656 .51424 .37909 .5257 .39962 .51924 .38722 .50711 Metetra
.644 .759 .932 r
.38722 .50711 .39962 .51924 .42031 .51316 .40801 .50066 Metetra
.64 .753 .93 r
.40801 .50066 .42031 .51316 .44116 .50671 .42896 .49433 Metetra
.652 .76 .929 r
.42896 .49433 .44116 .50671 .46219 .4997 .45009 .4874 Metetra
.653 .764 .931 r
.45009 .4874 .46219 .4997 .48338 .49274 .47138 .48037 Metetra
.642 .761 .935 r
.47138 .48037 .48338 .49274 .50472 .48626 .49284 .47377 Metetra
.644 .761 .934 r
.49284 .47377 .50472 .48626 .52624 .47984 .51446 .46706 Metetra
.655 .762 .928 r
.51446 .46706 .52624 .47984 .54792 .47285 .53626 .45975 Metetra
.652 .757 .926 r
.53626 .45975 .54792 .47285 .56978 .46547 .55823 .45255 Metetra
.636 .756 .935 r
.55823 .45255 .56978 .46547 .59181 .45848 .58039 .44605 Metetra
.641 .768 .94 r
.58039 .44605 .59181 .45848 .61403 .45203 .60272 .4392 Metetra
.666 .772 .929 r
.60272 .4392 .61403 .45203 .63642 .44527 .6252 .43107 Metetra
.66 .749 .915 r
.6252 .43107 .63642 .44527 .65897 .43749 .64786 .4232 Metetra
.613 .73 .929 r
.64786 .4232 .65897 .43749 .68167 .42937 .67081 .41768 Metetra
.586 .767 .965 r
.67081 .41768 .68167 .42937 .70461 .42251 .694 .41276 Metetra
.677 .841 .962 r
.694 .41276 .70461 .42251 .72786 .41737 .71716 .40346 Metetra
.763 .795 .879 r
.71716 .40346 .72786 .41737 .75134 .41221 .74012 .3886 Metetra
.712 .664 .8 r
.74012 .3886 .75134 .41221 .77484 .40444 .76321 .37441 Metetra
.615 .567 .777 r
.76321 .37441 .77484 .40444 .79824 .39331 .78703 .36784 Metetra
.539 .56 .825 r
.78703 .36784 .79824 .39331 .8217 .38111 .81161 .36734 Metetra
.57 .939 .887 r
.13441 .58559 .14966 .58283 .16907 .57281 .15396 .57571 Metetra
.744 .988 .894 r
.15396 .57571 .16907 .57281 .18885 .55989 .1741 .5612 Metetra
.725 .977 .92 r
.1741 .5612 .18885 .55989 .20816 .55271 .19412 .54824 Metetra
.634 .889 .986 r
.19412 .54824 .20816 .55271 .22696 .55284 .2137 .5409 Metetra
.556 .724 .952 r
.2137 .5409 .22696 .55284 .24591 .55367 .23301 .53807 Metetra
.569 .669 .906 r
.23301 .53807 .24591 .55367 .26549 .5492 .2525 .53538 Metetra
.633 .721 .911 r
.2525 .53538 .26549 .5492 .28554 .54052 .2724 .52972 Metetra
.679 .787 .931 r
.2724 .52972 .28554 .54052 .30567 .53241 .29262 .52173 Metetra
.671 .788 .937 r
.29262 .52173 .30567 .53241 .3258 .52659 .31296 .51408 Metetra
.637 .748 .929 r
.31296 .51408 .3258 .52659 .34607 .52104 .33334 .50801 Metetra
.628 .738 .927 r
.33334 .50801 .34607 .52104 .36656 .51424 .35386 .50236 Metetra
.648 .766 .935 r
.35386 .50236 .36656 .51424 .38722 .50711 .37461 .49564 Metetra
.664 .78 .935 r
.37461 .49564 .38722 .50711 .40801 .50066 .39554 .4881 Metetra
.653 .759 .927 r
.39554 .4881 .40801 .50066 .42896 .49433 .41661 .48107 Metetra
.635 .743 .926 r
.41661 .48107 .42896 .49433 .45009 .4874 .43781 .47488 Metetra
.638 .758 .935 r
.43781 .47488 .45009 .4874 .47138 .48037 .4592 .46845 Metetra
.656 .777 .937 r
.4592 .46845 .47138 .48037 .49284 .47377 .48078 .46105 Metetra
.661 .766 .928 r
.48078 .46105 .49284 .47377 .51446 .46706 .50252 .4534 Metetra
.643 .746 .923 r
.50252 .4534 .51446 .46706 .53626 .45975 .52443 .44659 Metetra
.631 .751 .934 r
.52443 .44659 .53626 .45975 .55823 .45255 .54652 .4403 Metetra
.645 .774 .942 r
.54652 .4403 .55823 .45255 .58039 .44605 .56879 .43317 Metetra
.667 .773 .929 r
.56879 .43317 .58039 .44605 .60272 .4392 .59122 .42495 Metetra
.658 .748 .917 r
.59122 .42495 .60272 .4392 .6252 .43107 .61383 .41714 Metetra
.625 .743 .932 r
.61383 .41714 .6252 .43107 .64786 .4232 .63668 .41095 Metetra
.61 .768 .956 r
.63668 .41095 .64786 .4232 .67081 .41768 .65974 .40512 Metetra
.662 .784 .939 r
.65974 .40512 .67081 .41768 .694 .41276 .68291 .39687 Metetra
.709 .75 .884 r
.68291 .39687 .694 .41276 .71716 .40346 .70608 .3855 Metetra
.7 .72 .864 r
.70608 .3855 .71716 .40346 .74012 .3886 .7294 .37424 Metetra
.627 .745 .932 r
.7294 .37424 .74012 .3886 .76321 .37441 .7532 .36767 Metetra
.332 .743 .979 r
.7532 .36767 .76321 .37441 .78703 .36784 .77769 .36701 Metetra
0 .57 .733 r
.77769 .36701 .78703 .36784 .81161 .36734 .80264 .36803 Metetra
.538 .606 .869 r
.12142 .56656 .13441 .58559 .15396 .57571 .14001 .56556 Metetra
.305 .65 .969 r
.14001 .56556 .15396 .57571 .1741 .5612 .15847 .56763 Metetra
.15847 .56763 .1741 .5612 .19412 .54824 .1781 .5605 Metetra
.511 .858 .6 r
.1781 .5605 .19412 .54824 .2137 .5409 .19886 .54312 Metetra
.797 .988 .887 r
.19886 .54312 .2137 .5409 .23301 .53807 .2196 .52632 Metetra
.681 .77 .918 r
.2196 .52632 .23301 .53807 .2525 .53538 .23961 .51823 Metetra
.566 .649 .891 r
.23961 .51823 .2525 .53538 .2724 .52972 .25931 .51571 Metetra
.604 .713 .921 r
.25931 .51571 .2724 .52972 .29262 .52173 .27936 .51119 Metetra
.679 .796 .937 r
.27936 .51119 .29262 .52173 .31296 .51408 .29983 .50303 Metetra
.673 .787 .935 r
.29983 .50303 .31296 .51408 .33334 .50801 .32042 .49511 Metetra
.628 .743 .931 r
.32042 .49511 .33334 .50801 .35386 .50236 .34103 .48934 Metetra
.629 .744 .93 r
.34103 .48934 .35386 .50236 .37461 .49564 .36183 .48345 Metetra
.663 .77 .929 r
.36183 .48345 .37461 .49564 .39554 .4881 .38286 .47588 Metetra
.662 .771 .93 r
.38286 .47588 .39554 .4881 .41661 .48107 .40406 .46828 Metetra
.634 .754 .934 r
.40406 .46828 .41661 .48107 .43781 .47488 .42536 .46201 Metetra
.634 .754 .935 r
.42536 .46201 .43781 .47488 .4592 .46845 .44685 .45567 Metetra
.661 .766 .928 r
.44685 .45567 .4592 .46845 .48078 .46105 .46854 .44797 Metetra
.661 .763 .925 r
.46854 .44797 .48078 .46105 .50252 .4534 .4904 .4402 Metetra
.633 .753 .935 r
.4904 .4402 .50252 .4534 .52443 .44659 .51242 .43377 Metetra
.631 .761 .94 r
.51242 .43377 .52443 .44659 .54652 .4403 .53463 .4273 Metetra
.665 .771 .929 r
.53463 .4273 .54652 .4403 .56879 .43317 .55701 .41913 Metetra
.667 .756 .917 r
.55701 .41913 .56879 .43317 .59122 .42495 .57956 .41082 Metetra
.623 .74 .931 r
.57956 .41082 .59122 .42495 .61383 .41714 .60233 .40469 Metetra
.61 .766 .955 r
.60233 .40469 .61383 .41714 .63668 .41095 .62532 .39883 Metetra
.687 .802 .936 r
.62532 .39883 .63668 .41095 .65974 .40512 .64838 .3892 Metetra
.714 .752 .882 r
.64838 .3892 .65974 .40512 .68291 .39687 .67151 .37747 Metetra
.619 .668 .875 r
.67151 .37747 .68291 .39687 .70608 .3855 .69508 .37149 Metetra
.365 .62 .949 r
.69508 .37149 .70608 .3855 .7294 .37424 .71943 .37463 Metetra
.186 0 0 r
.71943 .37463 .7294 .37424 .7532 .36767 .7442 .37844 Metetra
.123 0 0 r
.7442 .37844 .7532 .36767 .77769 .36701 .76853 .37153 Metetra
.493 .873 .67 r
.76853 .37153 .77769 .36701 .80264 .36803 .79227 .35487 Metetra
.499 .365 .63 r
.11424 .49941 .12142 .56656 .14001 .56556 .13191 .50397 Metetra
.346 .265 .621 r
.13191 .50397 .14001 .56556 .15847 .56763 .14829 .52232 Metetra
.327 .298 .674 r
.14829 .52232 .15847 .56763 .1781 .5605 .16548 .53705 Metetra
.535 .561 .828 r
.16548 .53705 .1781 .5605 .19886 .54312 .18461 .53642 Metetra
.772 .868 .919 r
.18461 .53642 .19886 .54312 .2196 .52632 .20514 .52327 Metetra
.788 .931 .927 r
.20514 .52327 .2196 .52632 .23961 .51823 .22586 .50888 Metetra
.681 .817 .948 r
.22586 .50888 .23961 .51823 .25931 .51571 .24613 .50061 Metetra
.585 .691 .915 r
.24613 .50061 .25931 .51571 .27936 .51119 .26617 .49688 Metetra
.605 .713 .921 r
.26617 .49688 .27936 .51119 .29983 .50303 .28647 .49221 Metetra
.668 .793 .941 r
.28647 .49221 .29983 .50303 .32042 .49511 .30716 .48441 Metetra
.682 .8 .938 r
.30716 .48441 .32042 .49511 .34103 .48934 .32804 .47588 Metetra
.645 .744 .921 r
.32804 .47588 .34103 .48934 .36183 .48345 .34896 .46917 Metetra
.62 .724 .921 r
.34896 .46917 .36183 .48345 .38286 .47588 .36999 .46364 Metetra
.639 .766 .94 r
.36999 .46364 .38286 .47588 .40406 .46828 .39125 .45703 Metetra
.669 .795 .942 r
.39125 .45703 .40406 .46828 .42536 .46201 .41273 .4489 Metetra
.663 .763 .924 r
.41273 .4489 .42536 .46201 .44685 .45567 .43437 .44103 Metetra
.633 .729 .917 r
.43437 .44103 .44685 .45567 .46854 .44797 .45613 .43465 Metetra
.624 .75 .937 r
.45613 .43465 .46854 .44797 .4904 .4402 .47808 .42855 Metetra
.653 .79 .948 r
.47808 .42855 .4904 .4402 .51242 .43377 .50023 .4209 Metetra
.675 .778 .928 r
.50023 .4209 .51242 .43377 .53463 .4273 .52255 .41215 Metetra
.651 .735 .911 r
.52255 .41215 .53463 .4273 .55701 .41913 .54505 .4046 Metetra
.613 .732 .93 r
.54505 .4046 .55701 .41913 .57956 .41082 .56775 .3989 Metetra
.62 .782 .959 r
.56775 .3989 .57956 .41082 .60233 .40469 .59066 .39245 Metetra
.687 .801 .936 r
.59066 .39245 .60233 .40469 .62532 .39883 .61368 .38278 Metetra
.697 .746 .889 r
.61368 .38278 .62532 .39883 .64838 .3892 .63683 .37212 Metetra
.617 .7 .904 r
.63683 .37212 .64838 .3892 .67151 .37747 .66033 .36613 Metetra
.403 .696 .98 r
.66033 .36613 .67151 .37747 .69508 .37149 .68437 .3665 Metetra
.267 .735 .945 r
.68437 .3665 .69508 .37149 .71943 .37463 .70867 .36564 Metetra
.753 .891 .941 r
.70867 .36564 .71943 .37463 .7442 .37844 .73243 .35168 Metetra
.812 .691 .731 r
.73243 .35168 .7442 .37844 .76853 .37153 .75512 .32151 Metetra
.738 .564 .657 r
.75512 .32151 .76853 .37153 .79227 .35487 .77734 .28737 Metetra
.538 .364 .593 r
.11119 .40235 .11424 .49941 .13191 .50397 .12921 .40045 Metetra
.455 .296 .576 r
.12921 .40045 .13191 .50397 .14829 .52232 .14559 .41405 Metetra
.319 .19 .543 r
.14559 .41405 .14829 .52232 .16548 .53705 .16 .44859 Metetra
.18 .104 .528 r
.16 .44859 .16548 .53705 .18461 .53642 .17425 .49034 Metetra
.165 .186 .637 r
.17425 .49034 .18461 .53642 .20514 .52327 .1911 .51315 Metetra
.621 .79 .963 r
.1911 .51315 .20514 .52327 .22586 .50888 .21114 .50733 Metetra
.826 .95 .9 r
.21114 .50733 .22586 .50888 .24613 .50061 .23237 .48992 Metetra
.703 .801 .926 r
.23237 .48992 .24613 .50061 .26617 .49688 .25297 .48041 Metetra
.529 .651 .913 r
.25297 .48041 .26617 .49688 .28647 .49221 .27308 .47891 Metetra
.6 .732 .937 r
.27308 .47891 .28647 .49221 .30716 .48441 .29365 .47418 Metetra
.72 .818 .926 r
.29365 .47418 .30716 .48441 .32804 .47588 .31478 .46352 Metetra
.687 .777 .92 r
.31478 .46352 .32804 .47588 .34896 .46917 .33593 .45457 Metetra
.583 .709 .929 r
.33593 .45457 .34896 .46917 .36999 .46364 .35696 .45052 Metetra
.601 .742 .943 r
.35696 .45052 .36999 .46364 .39125 .45703 .37825 .44549 Metetra
.697 .8 .929 r
.37825 .44549 .39125 .45703 .41273 .4489 .39991 .43581 Metetra
.691 .774 .915 r
.39991 .43581 .41273 .4489 .43437 .44103 .4217 .42636 Metetra
.602 .72 .928 r
.4217 .42636 .43437 .44103 .45613 .43465 .44353 .42135 Metetra
.59 .74 .948 r
.44353 .42135 .45613 .43465 .47808 .42855 .46555 .41659 Metetra
.688 .799 .934 r
.46555 .41659 .47808 .42855 .50023 .4209 .48785 .40714 Metetra
.702 .775 .908 r
.48785 .40714 .50023 .4209 .52255 .41215 .51031 .39668 Metetra
.609 .717 .921 r
.51031 .39668 .52255 .41215 .54505 .4046 .53292 .39118 Metetra
.558 .731 .956 r
.53292 .39118 .54505 .4046 .56775 .3989 .55576 .38743 Metetra
.688 .816 .944 r
.55576 .38743 .56775 .3989 .59066 .39245 .57875 .37764 Metetra
.736 .777 .886 r
.57875 .37764 .59066 .39245 .61368 .38278 .60182 .36448 Metetra
.597 .676 .896 r
.60182 .36448 .61368 .38278 .63683 .37212 .62527 .35956 Metetra
.315 .625 .96 r
.62527 .35956 .63683 .37212 .66033 .36613 .64927 .36283 Metetra
.546 .91 .96 r
.64927 .36283 .66033 .36613 .68437 .3665 .67309 .35412 Metetra
.928 .834 .732 r
.67309 .35412 .68437 .3665 .70867 .36564 .69548 .31549 Metetra
.817 .608 .621 r
.69548 .31549 .70867 .36564 .73243 .35168 .71635 .25691 Metetra
.702 .486 .591 r
.71635 .25691 .73243 .35168 .75512 .32151 .73715 .20568 Metetra
.621 .417 .585 r
.73715 .20568 .75512 .32151 .77734 .28737 .75917 .17616 Metetra
.558 .393 .614 r
.106 .32586 .11119 .40235 .12921 .40045 .1241 .32085 Metetra
.579 .407 .612 r
.1241 .32085 .12921 .40045 .14559 .41405 .14287 .31157 Metetra
.343 .209 .55 r
.14287 .31157 .14559 .41405 .16 .44859 .15731 .34033 Metetra
.02 0 .442 r
.15731 .34033 .16 .44859 .17425 .49034 .1683 .40529 Metetra
0 0 .407 r
.1683 .40529 .17425 .49034 .1911 .51315 .18047 .46826 Metetra
.071 .127 .616 r
.18047 .46826 .1911 .51315 .21114 .50733 .19726 .49412 Metetra
.686 .758 .906 r
.19726 .49412 .21114 .50733 .23237 .48992 .21782 .48531 Metetra
.807 .911 .911 r
.21782 .48531 .23237 .48992 .25297 .48041 .23912 .46942 Metetra
.647 .788 .95 r
.23912 .46942 .25297 .48041 .27308 .47891 .25975 .46243 Metetra
.562 .67 .911 r
.25975 .46243 .27308 .47891 .29365 .47418 .28024 .45951 Metetra
.643 .729 .911 r
.28024 .45951 .29365 .47418 .31478 .46352 .3012 .45275 Metetra
.69 .808 .938 r
.3012 .45275 .31478 .46352 .33593 .45457 .32248 .44355 Metetra
.648 .795 .953 r
.32248 .44355 .33593 .45457 .35696 .45052 .34379 .43625 Metetra
.625 .734 .925 r
.34379 .43625 .35696 .45052 .37825 .44549 .36521 .43017 Metetra
.65 .728 .906 r
.36521 .43017 .37825 .44549 .39991 .43581 .38688 .42283 Metetra
.658 .77 .932 r
.38688 .42283 .39991 .43581 .4217 .42636 .40873 .41503 Metetra
.632 .792 .959 r
.40873 .41503 .4217 .42636 .44353 .42135 .43072 .40816 Metetra
.645 .766 .936 r
.43072 .40816 .44353 .42135 .46555 .41659 .45291 .40082 Metetra
.668 .735 .9 r
.45291 .40082 .46555 .41659 .48785 .40714 .47531 .3922 Metetra
.645 .741 .919 r
.47531 .3922 .48785 .40714 .51031 .39668 .49786 .38481 Metetra
.591 .775 .967 r
.49786 .38481 .51031 .39668 .53292 .39118 .5206 .37936 Metetra
.649 .799 .954 r
.5206 .37936 .53292 .39118 .55576 .38743 .54354 .37142 Metetra
.714 .755 .884 r
.54354 .37142 .55576 .38743 .57875 .37764 .56663 .35953 Metetra
.645 .702 .888 r
.56663 .35953 .57875 .37764 .60182 .36448 .58993 .35179 Metetra
.378 .662 .969 r
.58993 .35179 .60182 .36448 .62527 .35956 .61369 .35324 Metetra
.516 .854 .995 r
.61369 .35324 .62527 .35956 .64927 .36283 .63754 .3474 Metetra
.919 .799 .712 r
.63754 .3474 .64927 .36283 .67309 .35412 .66006 .30551 Metetra
.865 .638 .592 r
.66006 .30551 .67309 .35412 .69548 .31549 .68029 .22487 Metetra
.777 .538 .574 r
.68029 .22487 .69548 .31549 .71635 .25691 .69946 .14201 Metetra
.663 .445 .579 r
.69946 .14201 .71635 .25691 .73715 .20568 .72013 .09657 Metetra
.548 .368 .589 r
.72013 .09657 .73715 .20568 .75917 .17616 .74335 .09048 Metetra
.12 .668 .807 r
.0908 .32497 .106 .32586 .1241 .32085 .10847 .32408 Metetra
.231 0 0 r
.10847 .32408 .1241 .32085 .14287 .31157 .12606 .32544 Metetra
.565 .88 .599 r
.12606 .32544 .14287 .31157 .15731 .34033 .14631 .30657 Metetra
.352 .365 .734 r
.14631 .30657 .15731 .34033 .1683 .40529 .16335 .3156 Metetra
0 0 .36 r
.16335 .3156 .1683 .40529 .18047 .46826 .17404 .38562 Metetra
0 0 .372 r
.17404 .38562 .18047 .46826 .19726 .49412 .18618 .45184 Metetra
0 .077 .599 r
.18618 .45184 .19726 .49412 .21782 .48531 .2031 .47939 Metetra
.746 .894 .946 r
.2031 .47939 .21782 .48531 .23912 .46942 .22423 .46721 Metetra
.865 .934 .866 r
.22423 .46721 .23912 .46942 .25975 .46243 .24624 .44592 Metetra
.64 .702 .892 r
.24624 .44592 .25975 .46243 .28024 .45951 .26707 .43921 Metetra
.428 .556 .882 r
.26707 .43921 .28024 .45951 .3012 .45275 .2874 .44184 Metetra
.594 .782 .97 r
.2874 .44184 .3012 .45275 .32248 .44355 .30854 .43654 Metetra
.784 .889 .92 r
.30854 .43654 .32248 .44355 .34379 .43625 .33044 .42172 Metetra
.707 .759 .892 r
.33044 .42172 .34379 .43625 .36521 .43017 .3522 .411 Metetra
.525 .624 .892 r
.3522 .411 .36521 .43017 .38688 .42283 .37364 .40968 Metetra
.525 .721 .962 r
.37364 .40968 .38688 .42283 .40873 .41503 .3954 .40703 Metetra
.736 .879 .947 r
.3954 .40703 .40873 .41503 .43072 .40816 .41772 .39478 Metetra
.748 .794 .89 r
.41772 .39478 .43072 .40816 .45291 .40082 .44019 .38116 Metetra
.583 .65 .882 r
.44019 .38116 .45291 .40082 .47531 .3922 .46258 .37699 Metetra
.459 .658 .947 r
.46258 .37699 .47531 .3922 .49786 .38481 .48515 .377 Metetra
.668 .878 .977 r
.48515 .377 .49786 .38481 .5206 .37936 .50807 .36737 Metetra
.801 .834 .877 r
.50807 .36737 .5206 .37936 .54354 .37142 .53114 .34962 Metetra
.646 .659 .849 r
.53114 .34962 .54354 .37142 .56663 .35953 .55435 .34136 Metetra
.285 .516 .901 r
.55435 .34136 .56663 .35953 .58993 .35179 .578 .3481 Metetra
.289 .768 .927 r
.578 .3481 .58993 .35179 .61369 .35324 .60185 .34553 Metetra
.957 .867 .707 r
.60185 .34553 .61369 .35324 .63754 .3474 .62467 .30181 Metetra
.878 .65 .59 r
.62467 .30181 .63754 .3474 .66006 .30551 .64555 .21785 Metetra
.791 .55 .572 r
.64555 .21785 .66006 .30551 .68029 .22487 .66525 .1298 Metetra
.623 .428 .597 r
.66525 .1298 .68029 .22487 .69946 .14201 .68738 .10465 Metetra
.481 .446 .742 r
.68738 .10465 .69946 .14201 .72013 .09657 .71127 .10835 Metetra
.71127 .10835 .72013 .09657 .74335 .09048 .73404 .09105 Metetra
.587 .564 .796 r
.07874 .29989 .0908 .32497 .10847 .32408 .09677 .29608 Metetra
.657 .58 .757 r
.09677 .29608 .10847 .32408 .12606 .32544 .11575 .28637 Metetra
.426 .384 .708 r
.11575 .28637 .12606 .32544 .14631 .30657 .13281 .29265 Metetra
.644 .724 .906 r
.13281 .29265 .14631 .30657 .16335 .3156 .15168 .28637 Metetra
.148 .271 .735 r
.15168 .28637 .16335 .3156 .17404 .38562 .16838 .30022 Metetra
0 0 .178 r
.16838 .30022 .17404 .38562 .18618 .45184 .17727 .38991 Metetra
0 0 .185 r
.17727 .38991 .18618 .45184 .2031 .47939 .18941 .46062 Metetra
.321 .522 .896 r
.18941 .46062 .2031 .47939 .22423 .46721 .20897 .46557 Metetra
.923 .899 .786 r
.20897 .46557 .22423 .46721 .24624 .44592 .23213 .43389 Metetra
.767 .8 .88 r
.23213 .43389 .24624 .44592 .26707 .43921 .25371 .41942 Metetra
.191 .43 .861 r
.25371 .41942 .26707 .43921 .2874 .44184 .27357 .42819 Metetra
.442 .674 .961 r
.27357 .42819 .2874 .44184 .30854 .43654 .29442 .42813 Metetra
.835 .863 .866 r
.29442 .42813 .30854 .43654 .33044 .42172 .31681 .40832 Metetra
.769 .79 .871 r
.31681 .40832 .33044 .42172 .3522 .411 .33895 .39309 Metetra
.394 .579 .914 r
.33895 .39309 .3522 .411 .37364 .40968 .36023 .3959 Metetra
.387 .647 .96 r
.36023 .3959 .37364 .40968 .3954 .40703 .38189 .3973 Metetra
.796 .858 .896 r
.38189 .3973 .3954 .40703 .41772 .39478 .40453 .38077 Metetra
.794 .795 .853 r
.40453 .38077 .41772 .39478 .44019 .38116 .42728 .36276 Metetra
.477 .619 .912 r
.42728 .36276 .44019 .38116 .46258 .37699 .44963 .3629 Metetra
.256 .57 .939 r
.44963 .3629 .46258 .37699 .48515 .377 .47221 .36774 Metetra
.776 .876 .921 r
.47221 .36774 .48515 .377 .50807 .36737 .49535 .35257 Metetra
.841 .8 .812 r
.49535 .35257 .50807 .36737 .53114 .34962 .5186 .32832 Metetra
.507 .6 .881 r
.5186 .32832 .53114 .34962 .55435 .34136 .54193 .32776 Metetra
0 .208 .705 r
.54193 .32776 .55435 .34136 .578 .3481 .5658 .34496 Metetra
.828 .977 .885 r
.5658 .34496 .578 .3481 .60185 .34553 .58949 .3245 Metetra
.953 .741 .579 r
.58949 .3245 .60185 .34553 .62467 .30181 .61127 .23595 Metetra
.862 .614 .562 r
.61127 .23595 .62467 .30181 .64555 .21785 .63129 .12764 Metetra
.645 .446 .599 r
.63129 .12764 .64555 .21785 .66525 .1298 .65337 .09736 Metetra
.634 .564 .758 r
.65337 .09736 .66525 .1298 .68738 .10465 .67636 .08779 Metetra
.828 .784 .81 r
.67636 .08779 .68738 .10465 .71127 .10835 .69876 .06518 Metetra
.581 .484 .709 r
.69876 .06518 .71127 .10835 .73404 .09105 .72225 .05909 Metetra
.067 .511 .897 r
.06439 .28964 .07874 .29989 .09677 .29608 .08124 .29456 Metetra
.148 0 0 r
.08124 .29456 .09677 .29608 .11575 .28637 .09866 .29729 Metetra
.917 .979 .74 r
.09866 .29729 .11575 .28637 .13281 .29265 .12078 .26598 Metetra
0 .087 .643 r
.12078 .26598 .13281 .29265 .15168 .28637 .13646 .28501 Metetra
.929 .869 .758 r
.13646 .28501 .15168 .28637 .16838 .30022 .15893 .25077 Metetra
.895 .616 .108 r
.15893 .25077 .16838 .30022 .17727 .38991 .16785 .33476 Metetra
.876 .609 .085 r
.16785 .33476 .17727 .38991 .18941 .46062 .17725 .42588 Metetra
0 0 .569 r
.17725 .42588 .18941 .46062 .20897 .46557 .19444 .45333 Metetra
.85 .795 .796 r
.19444 .45333 .20897 .46557 .23213 .43389 .21725 .42754 Metetra
.848 .884 .866 r
.21725 .42754 .23213 .43389 .25371 .41942 .23953 .40703 Metetra
.224 .582 .944 r
.23953 .40703 .25371 .41942 .27357 .42819 .2598 .41106 Metetra
.416 .605 .925 r
.2598 .41106 .27357 .42819 .29442 .42813 .28056 .41273 Metetra
.77 .764 .848 r
.28056 .41273 .29442 .42813 .31681 .40832 .30285 .39646 Metetra
.773 .817 .887 r
.30285 .39646 .31681 .40832 .33895 .39309 .32513 .38134 Metetra
.402 .694 .98 r
.32513 .38134 .33895 .39309 .36023 .3959 .34664 .38136 Metetra
.455 .671 .956 r
.34664 .38136 .36023 .3959 .38189 .3973 .36845 .38101 Metetra
.752 .758 .858 r
.36845 .38101 .38189 .3973 .40453 .38077 .39116 .366 Metetra
.763 .783 .869 r
.39116 .366 .40453 .38077 .42728 .36276 .41397 .35055 Metetra
.415 .696 .979 r
.41397 .35055 .42728 .36276 .44963 .3629 .43644 .35036 Metetra
.372 .669 .973 r
.43644 .35036 .44963 .3629 .47221 .36774 .45917 .35138 Metetra
.774 .772 .851 r
.45917 .35138 .47221 .36774 .49535 .35257 .48248 .33421 Metetra
.787 .752 .822 r
.48248 .33421 .49535 .35257 .5186 .32832 .50587 .31455 Metetra
.223 .559 .935 r
.50587 .31455 .5186 .32832 .54193 .32776 .52931 .31995 Metetra
0 .327 .721 r
.52931 .31995 .54193 .32776 .5658 .34496 .55322 .33087 Metetra
.928 .81 .709 r
.55322 .33087 .5658 .34496 .58949 .3245 .57671 .28695 Metetra
.925 .686 .559 r
.57671 .28695 .58949 .3245 .61127 .23595 .59824 .17718 Metetra
.871 .625 .565 r
.59824 .17718 .61127 .23595 .63129 .12764 .61862 .07465 Metetra
.329 .289 .661 r
.61862 .07465 .63129 .12764 .65337 .09736 .6426 .09363 Metetra
.955 .932 .732 r
.6426 .09363 .65337 .09736 .67636 .08779 .66456 .0577 Metetra
.22 .33 .764 r
.66456 .0577 .67636 .08779 .69876 .06518 .68922 .07375 Metetra
.68922 .07375 .69876 .06518 .72225 .05909 .71219 .05457 Metetra
.872 .911 .853 r
.04848 .28796 .06439 .28964 .08124 .29456 .06922 .26696 Metetra
.327 .401 .786 r
.06922 .26696 .08124 .29456 .09866 .29729 .08594 .2741 Metetra
.753 .659 .757 r
.08594 .2741 .09866 .29729 .12078 .26598 .10651 .2552 Metetra
0 .364 .794 r
.10651 .2552 .12078 .26598 .13646 .28501 .12358 .26312 Metetra
.788 .682 .747 r
.12358 .26312 .13646 .28501 .15893 .25077 .14488 .23955 Metetra
.932 .564 .288 r
.14488 .23955 .15893 .25077 .16785 .33476 .15615 .30053 Metetra
.958 .634 .232 r
.15615 .30053 .16785 .33476 .17725 .42588 .16553 .38704 Metetra
0 0 .28 r
.16553 .38704 .17725 .42588 .19444 .45333 .18068 .43139 Metetra
.655 .652 .835 r
.18068 .43139 .19444 .45333 .21725 .42754 .20191 .42275 Metetra
.864 .903 .858 r
.20191 .42275 .21725 .42754 .23953 .40703 .22456 .40052 Metetra
.625 .875 .989 r
.22456 .40052 .23953 .40703 .2598 .41106 .24594 .39271 Metetra
.49 .626 .911 r
.24594 .39271 .2598 .41106 .28056 .41273 .2669 .39216 Metetra
.634 .663 .861 r
.2669 .39216 .28056 .41273 .30285 .39646 .28862 .38496 Metetra
.715 .817 .929 r
.28862 .38496 .30285 .39646 .32513 .38134 .31079 .37383 Metetra
.61 .861 .991 r
.31079 .37383 .32513 .38134 .34664 .38136 .33286 .36642 Metetra
.616 .737 .932 r
.33286 .36642 .34664 .38136 .36845 .38101 .35505 .36016 Metetra
.663 .678 .854 r
.35505 .36016 .36845 .38101 .39116 .366 .3776 .35081 Metetra
.654 .75 .921 r
.3776 .35081 .39116 .366 .41397 .35055 .40026 .34262 Metetra
.5 .818 1 r
.40026 .34262 .41397 .35055 .43644 .35036 .423 .33817 Metetra
.652 .803 .955 r
.423 .33817 .43644 .35036 .45917 .35138 .44607 .32976 Metetra
.729 .701 .824 r
.44607 .32976 .45917 .35138 .48248 .33421 .46946 .31457 Metetra
.639 .69 .881 r
.46946 .31457 .48248 .33421 .50587 .31455 .49286 .30675 Metetra
0 .472 .828 r
.49286 .30675 .50587 .31455 .52931 .31995 .51643 .3137 Metetra
.541 .871 .993 r
.51643 .3137 .52931 .31995 .55322 .33087 .54038 .30676 Metetra
.916 .734 .641 r
.54038 .30676 .55322 .33087 .57671 .28695 .56385 .24518 Metetra
.912 .673 .564 r
.56385 .24518 .57671 .28695 .59824 .17718 .58581 .13999 Metetra
.899 .676 .593 r
.58581 .13999 .59824 .17718 .61862 .07465 .60719 .06093 Metetra
.141 .494 .905 r
.60719 .06093 .61862 .07465 .6426 .09363 .6308 .06867 Metetra
.795 .697 .757 r
.6308 .06867 .6426 .09363 .66456 .0577 .65343 .04397 Metetra
.328 .615 .954 r
.65343 .04397 .66456 .0577 .68922 .07375 .67746 .04693 Metetra
.781 .68 .753 r
.67746 .04693 .68922 .07375 .71219 .05457 .70024 .02292 Metetra
.867 .935 .864 r
.03199 .28773 .04848 .28796 .06922 .26696 .05284 .26737 Metetra
.852 .954 .879 r
.05284 .26737 .06922 .26696 .08594 .2741 .07346 .2485 Metetra
.667 .607 .779 r
.07346 .2485 .08594 .2741 .10651 .2552 .09284 .23833 Metetra
.256 .506 .901 r
.09284 .23833 .10651 .2552 .12358 .26312 .11028 .24332 Metetra
.774 .696 .777 r
.11028 .24332 .12358 .26312 .14488 .23955 .13117 .22387 Metetra
.937 .565 .245 r
.13117 .22387 .14488 .23955 .15615 .30053 .1425 .28191 Metetra
.953 .608 .302 r
.1425 .28191 .15615 .30053 .16553 .38704 .15219 .36211 Metetra
.886 .503 .041 r
.15219 .36211 .16553 .38704 .18068 .43139 .16644 .41241 Metetra
.455 .602 .907 r
.16644 .41241 .18068 .43139 .20191 .42275 .18676 .41304 Metetra
.844 .838 .84 r
.18676 .41304 .20191 .42275 .22456 .40052 .2096 .39086 Metetra
.767 .848 .912 r
.2096 .39086 .22456 .40052 .24594 .39271 .23168 .37665 Metetra
.522 .679 .937 r
.23168 .37665 .24594 .39271 .2669 .39216 .25284 .37436 Metetra
.532 .659 .917 r
.25284 .37436 .2669 .39216 .28862 .38496 .27426 .37193 Metetra
.668 .785 .936 r
.27426 .37193 .28862 .38496 .31079 .37383 .29637 .36317 Metetra
.718 .837 .938 r
.29637 .36317 .31079 .37383 .33286 .36642 .31884 .35167 Metetra
.68 .765 .915 r
.31884 .35167 .33286 .36642 .35505 .36016 .34133 .34208 Metetra
.614 .696 .902 r
.34133 .34208 .35505 .36016 .3776 .35081 .36381 .33582 Metetra
.564 .723 .948 r
.36381 .33582 .3776 .35081 .40026 .34262 .38642 .33149 Metetra
.614 .81 .975 r
.38642 .33149 .40026 .34262 .423 .33817 .40937 .32442 Metetra
.739 .805 .904 r
.40937 .32442 .423 .33817 .44607 .32976 .43273 .31093 Metetra
.723 .733 .859 r
.43273 .31093 .44607 .32976 .46946 .31457 .45621 .29726 Metetra
.498 .662 .934 r
.45621 .29726 .46946 .31457 .49286 .30675 .47963 .29571 Metetra
.07 .514 .898 r
.47963 .29571 .49286 .30675 .51643 .3137 .50331 .30236 Metetra
.785 .862 .907 r
.50331 .30236 .51643 .3137 .54038 .30676 .5274 .28567 Metetra
.936 .75 .626 r
.5274 .28567 .54038 .30676 .56385 .24518 .55114 .21772 Metetra
.944 .717 .565 r
.55114 .21772 .56385 .24518 .58581 .13999 .57363 .11882 Metetra
.949 .745 .594 r
.57363 .11882 .58581 .13999 .60719 .06093 .59545 .04257 Metetra
.379 .568 .911 r
.59545 .04257 .60719 .06093 .6308 .06867 .61897 .04582 Metetra
.787 .714 .783 r
.61897 .04582 .6308 .06867 .65343 .04397 .64185 .02389 Metetra
.609 .67 .883 r
.64185 .02389 .65343 .04397 .67746 .04693 .6655 .01756 Metetra
.461 .493 .806 r
.6655 .01756 .67746 .04693 .70024 .02292 .68991 .02024 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.21035 .18732 m
.21487 .19208 L
s
[(10)] .20131 .17781 .94967 1 Mshowa
.41738 .10625 m
.42153 .11134 L
s
[(20)] .40909 .09608 .81515 1 Mshowa
.64163 .01845 m
.64532 .02387 L
s
[(30)] .63425 .0076 .68064 1 Mshowa
.125 Mabswid
.25047 .17161 m
.25314 .1745 L
s
.29122 .15565 m
.29385 .15859 L
s
.33262 .13945 m
.3352 .14242 L
s
.37466 .12298 m
.3772 .12599 L
s
.46079 .08926 m
.46322 .09235 L
s
.5049 .07199 m
.50728 .07512 L
s
.54973 .05443 m
.55206 .0576 L
s
.5953 .03659 m
.59757 .0398 L
s
.17084 .20279 m
.17359 .20561 L
s
.13192 .21803 m
.13471 .22081 L
s
.09359 .23304 m
.09641 .23578 L
s
.05583 .24783 m
.05869 .25053 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{417.25, 161.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006Q0000XA000`40O003h00OogooXWoo003oOonR
Ool00?mooj9oo`00ogooXWoo003oOonROol00?mooj9oo`00ogooXWoo003oOonROol00?mooj9oo`00
ogooXWoo003oOonROol00?mooj9oo`00ogooXWoo003oOonROol007ioo`8000Aoo`03001oogoo0<Io
o`8000Aoo`03001oogoo04]oo`00P7oo00H007ooOol007oo0039Ool01P00Oomoo`00Ool004aoo`00
Ogoo00L007ooOomoo`00Ool00038Ool01`00Oomoogoo001oo`0004aoo`00P7oo00H007ooOol007oo
0039Ool01P00Oomoo`00Ool004aoo`00OWoo00<007oo00000Woo00<007oo0000agoo00<007oo0000
0Woo00<007oo0000C7oo001oOol00`00Oomoo`02Ool00`00Oomoo`37Ool00`00Oomoo`02Ool00`00
Oomoo`1;Ool00?mooj9oo`00SGoo0P00cGoo0P00@goo002;Ool200000goo0000003:Ool200000goo
00000012Ool008Moo`@000=oo`<00<Eoo`H00004Ool000000011Ool008Ioo`<000Eoo`03001oo`00
0<Aoo`@00003B[/003Wi00@0045oo`00Pgoo0`0027oo00@007ooOol00<1oo`@00005H]P004ZkB[/0
0002>OT40010Ool0081oo`<000]oo`04001oogoo002mOol30002Ool01000H]QRf0000dZk00<003Wi
00000V:g00<007ooOol0?Woo001nOol3000=Ool01@00Oomoogoo0000^Woo10000Woo00<006;HH]P0
0V;H0P0000A:^`000000009R]`8003moo`00FWoo0`000goo00<007ooOol067oo0`004Goo00@007oo
Oomoo`8009Aoo`<000=oo`03001oogoo01Qoo`<0009oo`04000^?0000004H]P200001BIn000006:g
00000f:g0P00?Woo001JOol00`00Oomoo`02Ool00`00Ool0000FOol3000DOol01@00Oomoogoo0000
UGoo00<007ooOol00Woo00<007oo00005Woo0`0017oo00<007Kb00000Rhl00@006;HH]P0009Re`03
000VORIn008000=R]`8003ioo`00Fgoo00L007ooOomoo`00Ool0000DOol4000EOol00`00Oomoo`02
Ool00`00Oomoo`2COol01`00Oomoogoo001oo`0001Aoo`@000Eoo`08001flP00000^?000H]P000=R
e`03000VORIn0080009R]`@003eoo`00Fgoo00L007ooOomoo`00Ool0000BOol2000IOol00`00Oomo
o`03Ool00`00Oomoo`2BOol01`00Oomoogoo001oo`00019oo`8000Uoo`03001flP0000@000=Re`05
001k]P00000VOP0500000dWf0000000lOol005Yoo`03001oo`00009oo`03001oo`0000moo`<00003
Ool007oo01Qoo`03001oogoo00=oo`03001oogoo095oo`03001oo`00009oo`03001oo`0000moo`<0
00Yoo`06001flWKb001b/P000Q7l00L006;GH]L007^f000IE`040003BOH2000lOol005]oo`03001o
ogoo009oo`03001oogoo00aoo`8000=oo`03001SG00001Qoo`03001oogoo00Aoo`03001oogoo095o
o`03001oogoo009oo`03001oogoo00aoo`8000eoo`03001flP00009b/P8000044O`006;G0003NkH4
00000fLI0019mP02BOH2000kOol006aoo`@0009oo`80009SG08001Moo`03001oogoo00Aoo`800:=o
o`<000moo`03001flP00009b/P03000Y500000<000=k]P06001W6FLI001W6@000dWf0`00>Woo001Z
Ool4000015lk000000001F=L00<007ooOol05Goo00<007ooOol01Goo00<007ooOol0Wgoo0P004Goo
00P007KbM_8007:b001^L@000RTD00<007^fNkH00P0000I>=`00IaT006LI0003BOH3000jOol006Mo
o`D000=O>`04000b?38l0002He`200000dmo001oo`0EOol00`00Oomoo`06Ool00`00Oomoo`2KOol3
000COol02000M_9flP00L[8006ia0003:A@20003CSL01@00IaT006LI00000TWf0P0000=5LP000000
>Goo001TOol50002A]d00`00Gc]O>`02Gc/50003Cgl20002Ool00`00Oomoo`0@Ool00`00Oomoo`07
Ool00`00Oomoo`2GOol3000FOol00`00M_800002L[800`00KW400003:A@20004CSL20002IaT20003
AG800`00Ool0000hOol0069oo`D00005Ea`004KMA]d00002Gc/2000015<m0016NdIk0`000Tmo1P00
47oo00<007ooOol01goo0P0017oo1@000Woo00<007ooOol0R7oo0`005goo00@007KbM_80009b/P03
001^L@00008Y5004001AdU7B0002CSL70003AG800`00Ool00005Ool50002Ool00`00Oomoo`0YOol0
05moo`<00003Ool0000000AG70D000=C?@050016NdIk001S6P050002LNH00`00LN<0000?Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0008Ioo`<001Yoo`04001flWKb0002L[80
1P00KW5^L@00:A@0009AdP03001>=`00009=/P06000iecWG001A/P000dEb0`001Woo00L007ooOomo
o`00Ool0000ZOol003Qoo`D0009oo`03001oogoo01]oo`H0009Bo@06001G7000001C7@000TjJ0`00
0U<m0P000V<J00@0027k8O/Qn`800004LNH0077S000@Ool00`00Oomoo`08Ool00`00Oomoo`03Ool0
1`00Oomoogoo001oo`0008Aoo`8001eoo`800004M_8007:b0003KW420004DM820002CK800`00>ML0
0002DK801`00AG95LTEb001oo`0000Ioo`07001oogooOol007oo0000:Woo000jOol01`00Oomoogoo
001oo`0001Uoo`D0009>o004001BoE;mD_d20003Dad01@00CYY>VP00G_X0100016<J1@0000IaiP00
LN=ah`00Ool2000<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0005moo`D0
009oo`03001oogoo01Qoo`<001moo`<0009b/P05001^LFiaKW400005DM801`00CK9=/Tfb000ie`00
009A/P050015LTEbAG800002Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0002Yoo`00>Woo00L0
07ooOomoo`00Ool0000EOol00`00Ool000030002Ea`00`00C_a>o0040002CYX01000DaeC7E<M0P00
0Ukj00H003IL=U`fG000HaX200000f=l000^G@020002LNH01@00LN<00000E@0010002Goo00<007oo
Ool02Goo00<007ooOol00Woo00L007ooOomoo`00Ool0001QOol01`00Oomoogoo001oo`0001Moo`80
025oo`04001fdGKA0002L[801@00KW5^LFia00001E7B00@004fbCK9=/P8000=A/P050015LTEbAG80
0003Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0002Yoo`00>Woo00L007ooOomoo`00Ool0000D
Ool40002C_`00`00EaaG70030002D_`00`00CYY>VP02CYX40004G_X50004Hg`400001W7V001ahg7S
001E0080009]X@D000Aoo`03001oogoo00D000Aoo`80009oo`8000Aoo`03001oogoo061oo`07001o
ogooOol007oo000057oo0`008goo00@007KAM]40009b/P05001^LFiaKW400004DM820003CK820003
DK801@00AG95LTEb00000goo0P000Woo0P0017oo00<007ooOol0:Goo000jOol01`00Oomoogoo001o
o`00019oo`<00003Ea`004kl00=>o080009BVP04001Bo5;l0002CYX200001Ukj000nWCjM001NnP80
0003He`003ZM008jW@05001SO000001C?P030000177V001ahg7S0P0000=Yb@00KJ400ffQ00<006fQ
KJ400`0000=oo`0000000P000eDY0`0000Aoo`00DmT006]oo`07001oogooOol007oo00004Woo0P00
9Woo00@007KAM]40009b/P03001^LFia008000AAdP8000==/P8000=A/P050015LTEbAG800003Ool2
000dOol003Uoo`8000Aoo`03001oogoo00ioo`@000=G7003001>o4kl00800003D_`005:J009BVPD0
00=NnPD000=SG004000jWCZM>Yd20003Dch300000g7V001ah`02LN<01000JLUYb@000VfQ00<0066;
00000ffQ0`000US000D005DYEBUE:@000094j`D006Yoo`07001oogooOol007oo00003goo0`00:7oo
00<007KAM]400P0000Mb/P00KW5^L@00KW400003DM800`00HS400002CK820004DK801@00AG95LTEb
000017oo00<007ooOol0<Goo001=Ool50002Ea`00`00EaaG70030003D_`01P00DYYBVP00G_X0008n
_@06001NnUkj001SG0000cjM00<006=LHe`010000Tkm0`0000=>g00000000W7V00@0077SLN<0009Y
b@06001]XFfQ001QR`000ffQ00D005f;001H`00000AE:@050014jdC[A>/00002@SX2001XOol20004
Ool00`00Oomoo`0;Ool4000ZOol01000M]4007:a0P000fia00<006ia00000e7B00<0068a00000Tfb
00<0068A00000e6b00D004EbAG95LP0000Aoo`03001oogoo035oo`00Bgoo10000TkL00<005LLEa`0
0`000U:j00<005;lD_`00U;l0P000Ukj00H003jm?[d005kj0002He`01000?YdnWCjM0`000UMM00H0
04km000005;l0003C]`200000g7V001ah`020002JLT01000KJ5]X@000V6;00P006fQKJ4005f;001H
`00015DY00D004C[A>]4j`0000=2>P03001oogoo07Qoo`8002eoo`04001fdGKA0002L[401`00KW5^
LFia001^L@00009AdP04001R<F8a0002CK800`00HQ400003DK801@00AG95LTEb00001Goo00<007oo
Ool0<7oo0018Ool400000elK001>g003C]`20002Ead01000D[YB^U:j1@0015kj100016=L0`000T[m
00<005MMEed00P000e;l00<004kLC]`00`0000IaiP00LN<006gY0002JLT00`00KJ400002HH/00`00
KJ400002GH/30004EBT01P00A>]4jdC[0012>P800003Gmd007oo07Eoo`<002moo`04001fdGKA0002
L[401`00KW5^LFia001^L@00009AdP04001R<F8a0002CK800`00HQ400003DK801@00AG95LTEb0000
1Woo00<007ooOol0;goo0016Ool40004Ga/01P00C]`00000DYX0009G7@06001B^P00001NnP000d:m
00H005kj000006=K0002>Yd01P00He`00000Fed000=:o@<0009Bg003001Bo5;l00<00003Ea`00000
009aiP04001]jFgY0002JLT20004HH/20002GH/00`00GH/00003EBT00`00A>]4j`02A>/20002Gmd3
001cOol2000bOol01000M]5fd@000W:a00L006iaKW5^L@00KW400002DM801000HS5R<@000Tfb00<0
068A00000e6b00<004EbAG800P001Woo00<007ooOol0;goo0013Ool50002@Y`01000Ga]O6elK0P00
15:J100015kj1@0016=K10000e]M10000U;l00<005;LD]`00`000TkL00<005LL00000P0000EaiP00
KNU]j@0000=Yb@03001QRf6;009QR`80009MR`04001MR`000002EBT00`00A>]4j`02A>/40002BWX0
0`00Oomoo`1^Ool3000dOol01000M]5fd@000W:a00@006iaKW40009^L@03001AdP0000=R<@04001=
/P00HQ420003DK800`00AG95LP020007Ool00`00Oomoo`0^Ool0045oo`800005Ool00000IcX00002
@Y`40002Fcd01P00DYYBVP00G_X0008nW@06001NnUkj001SF`000cZM00H006=K000005mM0002A]d3
0002D]/00`00D_aBo0040002Ea`00`00C]a>g0070002KNT01@00JLUYbFW900001F6;00X005f;GH/0
05f;001=;000EBT000=4j`@000A:NP03001oogoo06]oo`800003Ool007oo03Aoo`03001fd@00009b
/@05001f/@00KW400002KW400`00DM800003HS401000CK80068A0P00156b0P000Tfb00<007ooOol0
1Goo00<007ooOol0;Goo000mOol40003Ool01000IcYW>VLj0P000U:J0P000U/m00<005:J00000Ukj
00H003jM?Yd005kj0002He/01000>YdjWCZM0P0015mM0P000U;l00@005;KD]]Bf`80009>g004001G
75LLEa`30002D_`30002KLD01000KNU]j@000VW900<0066;HH/00f6;00X005f;GH/005f;001=;000
EBT000=4j`06001F^EJiE[T004Yj1000J7oo1000>Goo00<007KA00000W:a00D007Ja001^L@0000=^
L@8000=R<@07001=/P00HQ40068A00000e6b0P000Tfb00<007ooOol01Goo0P00;Woo000lOol20002
Ool40002IcX200000emm001BVP03DYX40004G_X40003He/40002A]d01P00Ged00000D]/0009Bo006
001Bf`00001G70000TkL10000U;l00<005;lD_`0100000E]a@00KNU]j@00009Yb@8000AQR`04001M
Ref;GH/20002CB`20003A>/01000E[UF^EJi0P000enm00<007ooOol0IGoo0P00>goo00@007KAM]40
009b/@05001f/@00KW400003KW420004HS420000168A001R4@000e6b00D004fbCK9=/P0000Moo`80
02ioo`00>Goo0`000goo00<007ME00000Sil0P000emm00L005:JDYYBVP00H_T00002?Y`01P00G_X0
0000He/0008n_@<0009OG0030016gDKM00<000=Bf`03001Bo5;l008000AG7080009Bo003001Bo5;l
00@0009Bo0800005KLD006gYKNT00002JLT20003HH/30002GH/20003CB`01P00A>]4jdC[001F^@80
0003Dih0000000@006=oo`<003eoo`04001fdGKA0002L[401@00M[4006ia00000fia00<0068aHS40
0f8a00H0068AHQ40068A0003DK801@00CK9=/Tfb00002Goo00<007ooOol0:goo000gOol20006Ool0
1000MeD003il0P0000EBV@00000005mm00<0009Rn@03000nW3jL008000ASF`80009:o@03001OG5mL
00<0009Bo004001Bfe;KD]/30002C]`01P00Ea`00000D_`000=Bo080009Fo003001Bo5;l00<00003
KLD006gY009]j@04001Yb@00ED/300000e]M0000000600001Dd/00000000A>/00P000U>N0`000djJ
0P00H7oo0P00@7oo00@007KAM]40009b/@05001f/@00KW400003KW400`00HS5R<@03HS401P00HQ5R
4@00HQ40009A/P8000==/P03001oogoo00Moo`03001oogoo02]oo`00=7oo0`001goo00D007MEMeEg
E@0000=BV@03001[6000008000ERn@80008n_@06001SF`00001KG@000T[m0`000U;K00<005;lD_`0
10000ULL00<004kLC]`00P000e;l00H005;l000005;l0003E_`20002D_`2000016g5001]jFgY0P00
00=EB`0000000U]M00<006LIIaT01P0000A=;000>:/hZ`D000=FV@04001>VTjJCYX2001LOol40011
Ool200001GKA001b/G:a00000WJa00<006iaKW400Via00<0068aHS400f8a00H0068AHQ40068A0002
DK800`00EO800002CK800`00Oomoo`08Ool00`00Oomoo`0ZOol0035oo`<000Yoo`08001gEGME001g
e`00DYT0009[6004000fO3Il0002H_T2000016Ml000n_Cjm0P000e]M0`000U;l00<005;KD]/00`00
0Tkl00<005LLEa`010000U;l00<005;lD_`00P000e;l00H005Kl000005;l0003D_`00`00KLD00002
KNT3000016Kh001KG@000fLI00<006JE00000cgF0P000cR[00@005;KD]/000=FV@06001>VP00001O
W@00FGoo0`000Woo0`00?goo00@007Kc0000009b/@05001f/GJaM[400004KW400`00HS5R<@03HS40
2000HQ5R4@00HQ40056b0002EO801@00CK9=/Tfb00002Goo0P00:goo000_Ool3000;Ool01000MeEg
E@000WOG00<005:I00000f/H1@000fMl0`000TlM0`000U;K00<005;lD_`00`000ULL00<004klC_`0
0`000UKl00<005;lD_`010000UKl00<005;lD_`00P000e;l00<005;l000010000VgY0P000fKh00D0
06LIIaUW6@00009VU@04000meSgF?MH20003>:/01000D]]Bf`000UJI0`000UnM0`00EWoo0`000Woo
0P0000ARf000MRL003ioo`04001flgKc0002L[401@00M[5f/GJa00000fia00<006jB0000168a00@0
068AHQ40009R4@80009ElP05001=/TfbCK80000:Ool00`00Oomoo`0YOol002aoo`<000ioo`04001g
EGME0002MmL20003JaP00`00Ji/00002?[d40002Fed01P00Cad00000Ea`000=Bf`80009>o003001G
75LL00<0009Bo003001Fo5Kl00<0009Bo004001Fo5KlE_`30002D_`00`00D_aBo0020003D_`30000
0fgY001Vn002I_P01@00J]H006LI00000VJE0P0013gF00D003R[>:/hZ`00009Bf`<0009CWP<0009B
VP80059oo`D00003DWP0000000=Rf004001f9`00000lOol01@00M_=flgKc00000W:a00D007JaM[5f
/@0000=^L@03001^TP0000=R<@800003HQ400000009R4@80009ElP05001=/TfbCK80000;Ool00`00
Oomoo`0XOol002Yoo`80011oo`03001gEGME00@0008k?`03001[600000=[V`80009C?@04001KGE]M
Fed20003Ea`01P00D]/00000Ea`0009>o0<0009Fo003001Bo5;l00<0009Fo003001Bo5;l00@0009B
o003001Bo5;l00<0009Bo005001Bo5;l000Qf`020003I_P01@00J]IZeP00IaT00`0000=VU@000000
0cgF00@003R[>:/hZ`<00003Aah0000000800003DYT005:J00=BVP03001oogoo04ioo`80009oo`07
001BN59hDWP001gl00000V;H00D007HW001f:00003]oo`05001flgKcM_<00002L[401@00M[5f/GJa
00000fia00<006jB00000f8a0`000V8A00<0068A00000eGb00D004fbCK9=/P0000aoo`03001oogoo
02Moo`00:7oo0P004Woo100000=k<P00000010000V^K0P0000AGG@00DceC?@@0009Bg003001G75LL
008000AG7080009Bo003001Fo5Kl00<0009Bo003001Fo5Kl00<0009Bo003001Bo5;l00@0009Bo003
001Bo00000<00005D_`0027K8M/00002I_P00`00J]H000020005IYD00`00?MH000020002>:/00`00
A]d000020002D[X01P00DYUBVE:I001BVP800003Gid007oo00Aoo`<000=oo`03001oogoo03moo`80
00=oo`8000ABN0800005H]P006:g001f9`02000kOol02000M_=fl`00L_@007:a0002M[400`00M_80
0002KW400`00KY80000400001fjB001R4F8A001R4@0000=ElP05001=/TfbCK80000<Ool20004Ool3
0003Ool00`00Oomoo`0KOol002Qoo`80015oo`06001flgKc001k<P000Wma0P000S8l0P000eMM0`00
0ULL00@005;LD]aBg0<0009>g006001G7000001Bo0000U;l0`000UKl00<005;lD_`00`000U;l00<0
05;lD_`00`000U;l00<005;lD_`00`000U;l00<005;lD_`00P0000<Qf`00I_P00`0000=ZeP000000
1FJE0P000dge00@003R[0000009Bo004001B^U:j0002DYT30002Gid30004Ool00`00Oomoo`02Ool0
0`00Ool0000kOol00`00Oomoo`02Ool200000goo00000002Jm/01@00DWQBN000GYL00P000V:g00@0
07HW000003Yoo`09001flgKcM_<007;d001b/@00009f/@06001flP00KW4006jB0`000V8a00<006jB
00000f8A0P0015Gb00@004fbCK8000eoo`03001oogoo009oo`03001oogoo009oo`03001oo`0001ao
o`008goo00@007ooOomoo`800003Ool007oo00moo`03001fl`00009k<P06001oL@00Mi00038l0P00
00AOO@000000009Bg003001G75LL00@0009K7003001>g4kL008000ABo080009Bo004001Fo5KlE_`2
0002D_`00`00D_aBo0030002D_`00`00D_aBo0030002D_`00`00D_aBo00300000e;l000000030003
J]H00`00NkD00003IYD200001Tge001=mDge000hZ`80009Bo003001B^U:j00<0009GWP<0009BVP03
001oogoo00=oo`07001oogooOol007oo0000>Woo00<007oo00000Woo0P0000=oo`0000000P0000A[
f`000000009NU`<00003H[L007HW008003Yoo`04001flgKc0002L_@20003M[400`00M_8000030002
KY800`00HS400002KY801000HQ5R4F8A0P0015Gb00D004fbCK9=/P0000eoo`03001oogoo009oo`07
001oogooOol007oo000077oo000ROol00`00Ool00002Ool20002Ool00`00Oomoo`0=Ool00`00M_<0
0002Nc800`00Og400002Mi000`00GgeOO@0200000e]M001Bg002D]`20002C]`00`00FaaK70040002
D_`00`00D_`000020003D_`01P00E_`00000D_`0009Bo0<0009Bo003001Bo5;l00<0009Bo003001B
o5;l00<0009Bo0@00085f`04001ZeV[F0002NkD01000IYEVU@000V/i00H004ge001=m@00>:/70000
0dLN0000000200000e:I001BVP02DYX20004Ool01`00Oomoogoo001oo`0003Yoo`03001oo`00009o
o`<0009_^`04001_VP000003GYL01`00LoMcm`00H[L007HW00<003Qoo`05001flgKcM_<00002L_@2
0003M[4300000fia001^TP02KY800`00HS400002KY801000HQ5R4F8A0`000eGb00D004fbCK9=/P00
00eoo`03001oogoo009oo`07001oogooOol007oo000077oo000ROol00`00Ool00002Ool00`00Oomo
o`02Ool00`00Oomoo`0;Ool02@00M_=fl`00Nc8007ma001gT00200000f?M00000003Fed01P00D]`0
0000Fcd0009>g0<0009Bo003001Bo5;l00<000=Fo003001Bo5;l008000ABo080009Bo003001Bo5;l
00<0009Bo003001Bo5;l00<0009Bo0H00006D_`000GK001ZeP0017^e0P000f/i00T004ge001=m@00
>:/005LL00000TKM0`000U:j00@005:IDYUBV@<00003Gid00000009oo`03001oo`00009oo`03001o
o`0003Yoo`03001oo`00009oo`80009_^`06001_VVnJ000UV0000UjG00<007?gLoL00`0000Af9`00
000003Qoo`05001flgKcM_<00003L_@40002M_800`00KW400003KY800`00HS400002KY801000HQ5R
4@000VIc00D005GbEO9ElP0000==/P03001oogoo00aoo`06001oogoo001oo`000Woo00<007oo0000
77oo000ROol00`00Ool00002Ool20004Ool00`00Oomoo`0:Ool01`00M_=fl`00Nc8007ma00D0009F
n`D000=K?@<0009G7003001Bo5;l00<0009Bo003001Fo5Kl00@0009Bo007001Bo000001Bo000D_`0
10000U;l00<005;l00000`000U;l1P000U;l00<005;lD_`0100017^e00<006/iJcT00V/i00D004ge
COD004ge0080009G70800003D_`005:j009B^P03001BVE:I008000=OW@8000=oo`03001oogoo009o
o`03001oogoo03Uoo`03001oo`00009oo`L00004KiX00000GYL400001G?g00000000MRL00P00=goo
00D006=l001fl`00009bm0<0009f/@05001flWKbM_800004KY800`00HS400002KY801000HQ5R4@00
0VIc0P000UGb00D004fbCK9=/P0000eoo`03001oo`00009oo`03001oogoo009oo`03001oogoo01]o
o`008Woo00<007oo00000Woo00<007ooOol017oo00<007ooOol027oo00@007KcM_<0009k<P03001o
L@0000800003KmX005Kk00800004Hg`004kLC]`30002C]`00`00EaaG70030002E_`00`00D_aBo003
0002D_`00`00D_aBo0030003D_`20002D_`00`00D_aBo0030002D_`00`00D_`000040002D_`00`00
D_`000030002D_`01000NkEk]G^e0P0000=Bo000JcT00V/i00@004geCOE=m@800005Ea`00000D]/0
0002D_`00`00D[YB^P030002Eih30002CWX00`00Oomoo`12Ool01@00Oomoogoo00001Goo1P0000=B
E`00=IH00`0000AfJ@00000002eoo`D000=oo`80009SO003001fl`0000800003L_@00000009f/@05
001flWKbM_800005KY800`00KY9^TP02KY820003IW<01@00EO8005Gb00000Tfb0P003goo00<007oo
Ool08goo000SOol01000Oomoogoo0P001Woo0P0027oo00L007KcM_<007/b001oL@030002KmX20003
Hg`01P00C]`00000Fc`0009>g0<0009Bg003001Fo5Kl00<0009Bo003001Bo5;l00<0009Bo006001B
o000001Bo0000U;l0`000U;l00<005;l00000`000U;l00<005;lD_`00`000U;l00<005;lD_`01P00
0U;l00<006/iJcT00V/i00<004ge00000`000e;K1P000TLN0`0000=BV@00CWX00Tij0P00Agoo00<0
07ooOol017oo0P0000=:>000DUL00U9G00@003FF=IH0009fJ@8002]oo`800004F_X003jM?Yd40004
Hg`30003L_@01@00McH007Ja00000gKb00<006jBKY800fjB00<006jBKY800VjB0P000fIc00X005Gb
EO8005Gb001=/P00GS@000moo`03001oogoo029oo`009goo00<007ooOol01goo00<007ooOol01Goo
00L007KcM_<007/b001oL@050002Dad50003Fc`30002Ea`00`00D]aBg0030002D_`00`00D_aBo003
0002D_`00`00D_aBo0020004D_`20002D_`00`00D_aBo0030002D_`00`00D_aBo0030002D_`00`00
D_aBo0030002D_`00`00D_aBo00300000e;l00000005000015;l000005;K0`000dKM00<004LNAah0
0P000e:I00<004ij00000`00AWoo0P001goo00@004XhBSP0009BE`06000eUSFF=IH007IY0P00:Goo
0P000e[j00<003jM?Yd00`0000<67000000010000g;d00H007LfMcH007Ja0003M_800`00KY9^TP03
KY800`00KY9^TP02KY800`00IW=VL`02IW<01@00EO9ElP00EO800P000Uhd00<007ooOol03Woo00<0
07ooOol08Goo000COol00`00Oomoo`02Ool01000Oomoogoo0`000goo00@007ooOomoo`8000Yoo`03
001oogoo00=oo`06001flgKcM_<007/b1@0000=[N`00Dad00P0000AO?000C]]>f`<0009>g003001G
75LL00<0009Fo003001Bo5;l00<0009Bo003001Bo5;l00<0009Bo006001Bo000001Bo0000U;l0`00
0U;l00<005;lD_`00`000U;l00<005;lD_`00`000U;l00<005;lD_`00`000U;l00<005;lD_`00`00
0U;l00<005;lD_`00P000eLL00<004KMA]d00`000U:k00D005:IDYUBV@0000=O_@80039oo`03001o
ogoo009oo`04001oogooOol30003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01000BSQ:>0000U9G
00<003FF=IH00P0000=fJ@000000:7oo00<005ll000015[j0P000Tjk1P000T=o00@007;dL_@0009g
=P8000=flP03001kMP0000=^TP8000A^TP03001VLfIc009VL`04001ElUGbEO830002GS@00`00Oomo
o`0>Ool00`00Oomoo`0QOol0019oo`03001oo`0000Moo`03001oogoo009oo`03001oo`00009oo`80
00]oo`03001oogoo009oo`07001flgKc001k<P00Og400`000f]k00H005llGcaO?000C]/2000015/l
001>g4kL0`000U;L00<005KlE_`00`000U;l00<005;lD_`00`000U;l00<005;lD_`00P000e;l0`00
0U;l00<005;lD_`00`000U;l00<005;lD_`00`000U;l00<005;lD_`00`000U;l00<005;lD_`00`00
0U;l00<005;l00000`0000A>o000001G70@0009Bo005001B^e:k001BV@0200000eMn000000020000
0goo001oo`0_Ool00`00Ool00007Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`07Ool0
1000BSQ:>0000U9G100000=fJ@0000009Woo0P000Ull00<005[jF_X00P0000=Jf@0000000P0000=R
n@0000000P000T=o00<007;d000017Lf00L007KbM_9flP00NgH00003KY800`00LcH00002KY820004
IW<00`00EO9ElP02EO800`00GSAN=002GS@00`00Oomoo`0>Ool00`00Oomoo`0POol0019oo`03001o
o`0000Qoo`03001oogoo00=oo`04001oogoo000=Ool01@00Oomoogoo00000WKc00<007/b00000`00
0V]k0P0000ASG000GcaO?08000=K?0<0009G7003001Bg5;L00<0009Bo003001Bo5;l00<0009Bo003
001Bo5;l00<0009Bo0@00004D_`005;lD_`30002D_`00`00D_aBo0030002D_`00`00D_`000030002
D_`00`00D_`000030002D_`00`00D_`000020002D_`00`00C_a>o0030002D]/00`00D_aBo0060000
1EMn000005JI00000TYI0P00<7oo00<007oo000027oo00<007ooOol00goo00<007ooOol00P0027oo
1`0000A9T`00001fJ@<002=oo`8000EO?0H00003C[/006;i009Rn@D00003@gl0000000Ag=P04001f
lWKb0002NgH01000KY9^TP000W<f00H006jBKY8007MF0003IW<01000EO9ElUGb0`000ehd00<007oo
Ool03Woo00<007ooOol087oo000BOol00`00Ool00008Ool01000Oomoogoo0P000goo00<007ooOol0
37oo00<007oo00000gKc00<007/b00001@000f=L0`000Tkl0`000U;L00<005LLEa`00`000ULL00<0
05;lD_`00`000U;l00<005;lD_`00`000U;l1@000e;l0`000U;l00<005;l00000`000U;l00<005;l
00000P000U;l00<005;lD_`00`000U;l00<005;lD_`00`000U;l00<005;lD_`00`0000=Bo0000000
0U;K0`000TZl00<004KmA_d00P000eJI00@004YIBUU:F@8002moo`03001oo`0000Qoo`04001oogoo
Ool20003Ool00`00Oomoo`0:Ool00`00AI<00002BI<2000017IY0000000077oo1`000Tln00<005ll
Gc`0100015[I00L006;iH_URn@00JcT00003?U/20004McH01@00Io/007Kb00000W]f00<006jB0000
0g<f00<006jB00000WMF00<006IcIW<00VIc00<005Gb00000VJf00D005hdGSAN=000015oo`80021o
o`004Woo00<007oo00001goo00<007oo00000Woo00<007ooOol00Woo00<007ooOol03Goo0P000gKc
1P000TII0`000UlK00H004kl000005LL0003D]`20002D_`00`00EaaG70030002D_`00`00D_aBo003
0002D_`60002D_`30002D_`00`00D_`000020002D_`00`00D_aBo0030002D_`00`00D_aBo0030002
D_`00`00D_aBo0030002D_`00`00D_aBo0030002D_`00`00D_aBo0030002Ea`00`00B[a:_0030000
0e;K001FV@03EYT300000eoM0000000^Ool00`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00AI<00002BI<2000017IY000000006Woo0P000TkL00@004KMA]e6g@P0
0003Dch005[I009Jf@05001S6P00H_T00002JcT00`00?U/nF`02?U/200000gLf00000002Io/20004
NgH20003LcH00`00KY800002MeH00`00IW=VL`02IW<00`00EO800002I[H20002GS@00`00Oomoo`0@
Ool00`00Oomoo`0NOol001=oo`03001oogoo00Moo`04001oogooOol30002Ool00`00Oomoo`0>Ool4
00000g/b001oD@030002AUT00`00Im`00002Ga/20003Ea`01P00D]`00000Fa`0009Bo0<0009Bo003
001Bo5;l00<0009Bo0H0009Bo0<00004D_`005;lD_`30002D_`00`00D_aBo0030002D_`00`00D_aB
o0030002D_`00`00D_aBo0030002D_`00`00D_aBo0030002D_`00`00D_`00003000014kl000005LL
10000Tkl00@005;KD]/0009FV@L002moo`03001oogoo00Moo`04001oogooOol300000goo0000000<
Ool00`00AI<00002BI<01000:=4007IY0P0067oo0P0000EG7000C]a>g0000096g@800003D_`00000
00<000=C?P<0009S6P03001Rn@0000=[>@05000nF`00001BVP080003NgH20005LcH01@00MeIgEWMF
000016Ic0P000fJf00<005hd00000Uhd00<007ooOol03goo00<007ooOol07Woo000UOol2000?Ool0
1000L]=bdg;C1@000U[I0P000VOL0`000U/K1@000e/L0`000UKl00<005;lD_`00`000U;l1P000U;l
00@005;l000000=Bo0<0009Bo003001Bo5;l00<0009Bo003001Bo5;l00<0009Bo003001Bo5;l00<0
009Bo003001Bo00000<0009Bo003001Bo0000080009Bo003001>o4kl00<0009Bf`d000=66080045o
o`03001oogoo00Yoo`030015T`000099T`04000Xd@00MVT2000FOol20003Ea`00`00C]a>g0060000
0e;l000000060005HaX00`00JcU[>@02JcT20003DYX010008Q`R728L1`000T=o00<007<fLcH00W<f
00<007MFMeH00WMF00D006IcIW=VL`0000AV]P03001N=000009N=003001oogoo011oo`03001oogoo
01eoo`005Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol03Woo00@0
07;CL]=bd`800004Oe400000F]T50002CYX01P00Fa/00000Gc`0009>o0<0009Bf`03001Fo5Kl00<0
009Bo0H0009Bo003001Bo0000080009Bo0<0009Bo003001Bo5;l00<0009Bo003001Bo5;l00<0009B
o003001Bo00000<0009Bo003001Bo0000080009Bo003001Bo5;l00<0009Bo003001Bo5;l00<00004
D_`00000D]/30003B[`00`00@[d000020002EWP01000AQQ664HH0`00?goo0P0037oo00<004FC0000
0TVC00@002SA001fJ@8001Aoo`800003Fed005LL009G70H0009Bo0800003Ga/003;N008bgP04000^
_Rjn0002HaX200000f=l001[>@0200000fMK001BVP03DYX30002D]/00`00;Yh^WP03000014=o001c
=W<f0P0000=3WP00MeH00WMF00H006Ic000005nM0004I[H01P00GS@00000?g@0019oo`03001oogoo
01aoo`005Goo00<007oo00001goo00<007oo00000goo0P003goo00L007;CL]<007Kc001oD@060000
0dYj001>VP02CYX00`00GcaO?002Gc`20002Ea`00`00D]]Bf`030002D_`60002D_`00`00D_`00002
0002D_`30002D_`00`00D_aBo0030002D_`00`00D_aBo0030002D_`00`00D_`000020002D_`00`00
D_aBo0030002D_`00`00D_aBo0030002D_`00`00D_aBo0030002D]`50003Ead00`00B[`000020002
E_/01P00EWQFN5Ih001660800003Ool007oo02moo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`8000aoo`040015TdFC0002BI<200000gIY0000000BOol20003Fed400000dkm00000003
D[X20004Ga/90004Hg`01@00Ie]WFfMK00000U:J0P0000=Jn`00D]/00e;K0P000TZl3P000enM00<0
06JfI[H00VJf200047oo00<007ooOol077oo000EOol00`00Ool00009Ool01@00Oomoogoo00003goo
00H007;CL]=bd`00M_<3000013Jn000000000TYj00L004jJ000006>M001O?002000015KK001G75LL
0`000ULL1P000U;l00<005;l00000P000U;l0`000U;l00<005;lD_`00`000U;l00<005;lD_`00`00
0U;l00<005;l00000P000U;l00<005;lD_`00`000U;l00<005;lD_`00`000U;l00<005;l00000`00
0U;l0`0000=Bo000C]`01`000T[M00@005KkE_/000=FN080009SO003001oo`0002ioo`03001oo`00
00Moo`03001oo`0000=oo`03001oogoo00]oo`040015TdFC0002BI<6000:Ool70002Dad30002Cgl3
00000dkm001B^P02000015lJ000005lK0P0000=S>P00>W`00SYl00@001hm7Sd0009SO0800004Dgh0
06MKIe/30003F_/00`00D]]Bf`030004B[`30002C]`00`00<]hbgP070002Gid00`00I[IV]P030000
0dhh00000003@ST00`00Oomoo`0>Ool00`00Oomoo`0KOol001Eoo`03001oo`0000Moo`8000Aoo`03
001oogoo00eoo`07001bdg;C001fl`00Oe400`000f=K00@004Yj000000=SW@8000AFf`80009>o0H0
009Bo003001Bo0000080009Bo0<0009Bo003001Bo5;l00<0009Bo003001Bo5;l00<0009Bo003001B
o0000080009Bo003001Bo5;l00<0009Bo003001Bo5;l00<0009Bo003001Bo0000080009Bo0D000=B
o0D000=>^`H00003E_/005Ih008000=SO004001oogoo0004Ool20004Ool00`00Oomoo`0POol00`00
Ool00009Ool01@00Oomoogoo00003Goo00@004FCAI<00099T`03000Xd@0000<000Moo`<00092_@04
0012W4:L0002Dad200000e/m000000020003C_d20005GaX01@00HcYS>V<j00000cYl1P000e=n0`00
0U<n00@005[kF_]Jn`<000=O6`06001:_000001Fn`0014kL0P000Tjk00<002im;Wd0200014hh00D0
048i@SU2>@00015oo`03001oogoo00=oo`8000Aoo`03001oogoo00ioo`005Goo00<007oo00001goo
00<007ooOol00goo00<007ooOol03Goo00L007;CL]<007Kc001oD@0=0002DYX01@00E]/00000Gc`0
1P000U;K00<005;lD_`00P000U;l00H005;l000005;l0002D_`30002D_`00`00D_aBo0030002D_`0
0`00D_`000020002D_`00`00D_aBo0030002D_`00`00D_`000030002D_`00`00D_`000020002D_`3
0002D_`00`00D_`000030002C]`00`00Ea`0000300001ULm001:VdZK000nF`H0009SO004001oo`00
0006Ool01P00Oomoo`00Ool0025oo`03001oo`0000Moo`8000Aoo`03001oogoo00]oo`040015TdFC
0002BI<00`00:=4000030005Ool200000f=L00000002@[d00`00@Ya2W00600000e/m000000040002
>[h01`00GaYO6UlJ001SO00000=S>P<0009:V`03000jWCZM00@0009;7P03001C?U<n00@0009G?@03
001O6elK00<000=Fn`03001>g4kL00<000A>^`8000=Ff`<0009JV@04001>>4hhCSP400000eJI001o
o`0?Ool20006Ool01P00Oomoo`00Ool000moo`005Woo00<007ooOol01Woo0`000Woo0P003Woo00H0
07;CL]=bd`00M_<300001Woo001:VdZK000n_@<0009:NP03001BVU:J0080009O?0@0009Bo003001B
fe;K00<00003D_`0000000<000=Bo0<0009Bo003001Bo5;l00<00004D_`005;lD_`30002D_`00`00
D_aBo0030002D_`00`00D_`000020002D_`00`00D_aBo0030002D_`30002D_`00`00D_`000020002
E_`00`00C]a>g0050003Ecd01000BY]:VdZK10000TFd0`0000ESO000Oomoo`0000Aoo`07001oogoo
Ool007oo00008Goo00<007oo00001goo00<007ooOol00Woo0P003Goo00@004FCAI<00099T`03000X
d@0000@000=oo`03001SG6=L00=SG0T00004Fcd00000Hc/50002>[h01000GaX000000V=l00H006<j
000005lk0004BY/20002D_`01000Bai;7T/N0`000TKn00@005LmEceG?@<0009G?@04001FneKkE_/3
0003F_/01P00C[/00000F_/000=Ff`03001JVEZI009JV@04001>>4hhCSP30002EYT00`00Oomoo`0>
Ool20005Ool01`00Oomoogoo001oo`0000moo`0097oo00<007ooOol03Goo00L007;CL]<007Kc001o
D@02000017oo001:VdZK0P000ell00<004Yj00000P0000=OW@0000000P000UKK00<005;lD_`00`00
0ULM0`0000ABo000D_aBo0<0009Bo003001Bo5;l00<0009Bo003001Bo0000080009Bo003001Bo5;l
00<0009Bo003001Bo0000080009Bo003001Bo5;l00<0009Bo0<0009Bo003001Bo0000080009Bo003
001Fo5Kl00<0009G7003001:^`0000P0009JV@040015]4Fd0002@G<20003Ool00`00Oomoo`02Ool0
1P00Oomoo`00Ool0029oo`03001oogoo00Ioo`<0009oo`8000eoo`040015TdFC0002BI<01000:=40
06gP0P0000Ioo`00Ool006]J0002He`200000dmo000000020004CY/01P00Hc]S>f<k001S>`L000ES
O005001O>elkGc/00002BY/200000e;l001Bo002D_`30002B]`00`00A_i6oP040002Cah00`00EceG
?@040002Ecd00`00F_]Jn`030003F_/01P00E]/00000Gc/000AJV@<00004E[X005JI0002EYT00`00
Oomoo`0;Ool200000cC>00000005Ool01P00Oomoo`00Ool000moo`0097oo0P003Woo00L007;CL]<0
07Kc001oD@020002Ool20002Eed500000dMo000000020002DYX00`00E]]Ff`030002C_d40003D_`3
0002D_`00`00D_aBo0030002D_`00`00D_`000020002D_`00`00D_aBo0030002D_`00`00D_`00002
0002D_`00`00D_aBo00300000e;l000000020002D_`00`00D_`000020002D_`00`00D_aBo0030002
C]`00`00Ea`0000200000eLL00000003BWX00`00AY`00003FYT01000AKA5]0000T5c00D007ooOomo
o`00009oo`03001oo`00009oo`03001oo`00031oo`03001oogoo00aoo`@00099T`03000Xd@0000<0
009oo`04001[FV]JJeX20002Cgl20002?W`00`00CY]>V`02000016<J001S>`000V<k00D0039L<U`b
G000008^WP03001SO6=l00800004Ggd005lkGc/30003D_`01P00D_`00000Ea`000=:g0<0009>o@04
001?7TlNCah30002Cah01000EceG?ELm0`000U<M00@005[kF_]Jn`8000=O>`04001JVEZIFYT20003
E[X00`00EYT00002EYT00`00Oomoo`0:Ool20002=<h20003Ool00`00Ool00002Ool00`00Ool0000?
Ool0011oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00aoo`06001bdg;CL]<007Kc0`0017oo0`000U;L1@000TjJ00@005:JDYYBVP80009OG0<00004
D_`005;KD]/30002D_`00`00D_aBo0030002D_`00`00D_`000020002D_`00`00D_aBo0030002D_`0
0`00D_`000020002D_`00`00D_aBo003000015;l000000000U;l00<005;lD_`00`000U;l00<005;l
D_`00`000UKl00<004kL00000P000Tjk00@005LLEa`0009:NP<00005AY`005ZIFYT00002AK@01000
@G=1L`000Woo0`000Woo00<007ooOol00Woo00<007ooOol0;goo0P003Goo00<0045b@G80100000<X
d@00000010000f]J00<006nJ00002@0016<J00<006<kHc/00V<k2@000emm0`000U<M00@005;lD_aB
o08000AG70<0009Bo003001>oDkm00@0009>o@03001?7TlN00@0009?7P03001C7E<M00@0009GGP03
001O>elk00@00003D_`005Jj00=F^P06001FV@00001Og@002goo0P000SC>0`000goo00<007ooOol0
0Woo00<007ooOol03Woo000?Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000=oo`03001oogoo
00aoo`04001bdg;C0002M_<30006Ool600001ULL001>VTjJ001BVP800004Fih000000002D[X01000
D_`005;K0P0000AG7@00D_aBo0<0009Bo003001Bo0000080009Bo003001Bo5;l00<0009Bo003001B
o0000080009Bo0H00004D_`000000002D_`00`00D_aBo0030002D_`00`00D_aBo0030002D]`00`00
E_`000020002Ea`00`00C[]>^`0600000eLL000mn0020002FYT01000AKA5]0000d5c00<007ooOol0
0Woo00<007ooOol08Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol037oo00@0045b@G80008i<@03000Xd@0000D0009[FP<00004KiX006^K00026Ud0
1000<WdbO@000f<J00@006]k001S>`800003Fa`0049l0092O0030012gT;N00@0009??P03001C7E<M
00@0009G?@06001G7000001G7@0015;l0P000U;l00<004kmC_d010000Tkm00<004lNCah010000T/N
00<005MNEeh010000T/N00D005;lD_aBo000009F^P<00004Gmd00000000:Ool00`00;8h00002=<h4
000HOol000moo`03001oo`0000Qoo`03001oogoo00=oo`05001oogooOol0000=Ool01P00I]P007;C
001fl`@000Aoo`D0009G7003001G7000009>VPD0009BV@03001B^U:j00@000=G7@<0009Bo003001B
o0000080009Bo003001Bo5;l00<0009Bo003001Bo0000080009Bo0<0009Bo003001Bo0000080009B
o003001Bo5;l00<0009Bo003001Bo00000<0009Fo003001Bg0000080009Bf`03001G75LL00<0009K
70040016N`000002Ea`01P00?OP00000FYT00095]0050011Ld5c@G<00004Ool00`00Oomoo`0QOol0
0`00Ool00008Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00aoo`040011LT5b0002>C400`00
:=4000020002>W`30002KiX20003Ji/30002<Wd01000HaX000000f]k00D005/LFaaK700000=2O0<0
009C7@04001??TlnCch30002B_d01000EceG?ELm0P000eLM00<005;lD_`00`0015;l0P000U;l00@0
04kmC_e>o@<0009>o@04001;7T/NBah30002Bah01@00Bai;7T/N00000U;l10000SnL100000<oG`00
Ool027oo00<002b>00000SC>00@004XFBQH001Qoo`003goo00<007oo00002Goo00<007ooOol00P00
17oo00<007ooOol017oo0P0017oo00<006KHI]P00P000WKc0`000goo0P0017oo00<005LLEa`01`00
0U:J00P005:IDYT005:j001OG0000Tkm0`000U;K00<005;lD_`00P000U;l00<005;lD_`00`000U;l
00<005;lD_`00P000U;l0`000U;l00<005;lD_`00P000U;l00<005;lD_`00`000U;l00<005;l0000
0P000U;l00<005KlE_`00`000U;l00<005;K00000`000Tjl00<005/L00001@0000AG7000?OPmn0<0
0095]0050011Ld5c@G<00004Ool2000ROol00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02
000>Ool01000@G91LP000STa20000U:J0P000f^K0P0000=S>`00000010000f]k0P0000ASW000FaaK
70@0009Bo003001C7E<M00@0009:g@03001:oD[m00@0009C?@03001G7ELM00<000=C7@06001Bo000
001C7@000e;l0`000U;l00<004kmC_d010000Tkm00<004/NBah01`000RlO2`001goo00@002b>;8h0
008dcP03001:5TXF008001Moo`003goo00<007oo00001goo00<007oo00000Woo00<007ooOol00Woo
00<007ooOol00goo1P0000=oo`00I]P00fKH00<007KcM_<01P001goo0P0000AG70000000009Fo004
001BVU:J0002DYT20002Ge`30002D_`00`00D]]Bf`03000015;l001Bo5;l0`000U;l00<005;lD_`0
0`0000ABo0000000009Bo003001Bo5;l00<00004D_`005;lD_`30002D_`00`00D_`000020002E_`0
0`00D_aBo0030002D]/00`00D_`000020002Ea`00`00C[a>_00300000djK001>VP02CYX30002?OP2
00001EZI0015]4Fd00000T5c00<007oo00000P0000=oo`00Ool08Goo00<007oo00002Goo00<007oo
Ool00P000goo00<007ooOol03Goo00@0045b@G80008i<@L000=BVP03001[>000008000=S>`04000E
^aFk0002=[h30003Hi`30002C_d00`00D_aBo002D_`20002Ea`01000B]e:gD[M0`000Tkm00@005<m
DceC?@<0009?7@03001C7E<M00<000=C7@06001Bo000001C7@0015;l0P000U;l00<004kmC_d01000
0TkL00<003kN?]h01P0000=F^P00CWT00Tii0P000T9K00<007ooOol017oo00@002b>;8h0008dcP05
001:5TXFBQH0000GOol0011oo`03001oogoo00Ioo`<0009oo`<0009oo`8000=oo`05001c^G>i001_
n@030004I]P00`00H[L00004000;Ool300001E;K001Fo5Kl00000U:J0`000U^N0P000U:j00<005;l
D_`00`000ULL00<005;l00000P000U;l00<005;lD_`00`0000ABo0000000009Bo003001Bo5;l00<0
009Bo003001Bo0000080009Bo003001Bo0000080009Bo003001Fo5Kl00<0009Bo003001Bf`000080
009>g003001G75LL00<0009B^`04001>VdjK0002CYX01`00>OT00000?OP0034c00800095]0030011
Ld5c008000Aoo`03001oogoo021oo`03001oo`0000Moo`03001oo`00009oo`03001oogoo009oo`80
00ioo`050011LT5b000i<@0200000bB`0000000400001U:J001[>6/h001gV080009S>`H000=;7P<0
009C?@04001>oDkm0002D_`2000015Lm001G75LL10000Tkl00<004kmC_d010000Tkm00<004lMCad0
0`000U<M00@005<MDaeC7@8000=C7@03001Bo5;l00<000ABo080009Fo004001>g4kLC]`30002D_`2
0003E[X01P00CWU>NDii0012F`<000Eoo`80008/SP04000dcSC>0002BQH2000GOol002=oo`80009o
o`06001c^G>i001_n@000UZG0P000VKH00<006:g000010003Woo00<005;K00001@000TMO0`0000AB
V@00D[YB^P<0009>g003001G70000080009Bo0H00004D_`000000002D_`00`00D_aBo0030002D_`0
0`00D_`000020002D_`00`00D_`000020002E_`00`00D_aBo0030002D]/00`00D_`000020002Ea`0
0`00C]a>g0030002C[/00`00D[/00008000013Wi000mn0000S4c00@004FdAK@000=1L`03001oogoo
009oo`03001oogoo025oo`03001oogoo00Ioo`<0009oo`<0009oo`03001oogoo00eoo`030011LP00
00800005>C4002B`00003@0400001E:J001[>6/h00000gNH0P000TkL00@003Hk=S/0009;7P800004
Ecd005<mDcd60003Ecd30002Dad01000C_a>o4kl0`000U<M00<004kmC_d010000Tkm00<005<MDad0
10000U<M00<005<MDad00`000e<M00H005;l000005LM0002E_`40002D_`00`00D_`000020004E[X0
0`00CWU>N@04000015:J001oogoo0P0000D42P00;8h/SP00008dcPD001Moo`008goo00H007ooOomo
o`00LkT30003FYL200001fKH00000000H[L007NG008000ioo`80009G70030012_D:m00<00003DYX0
05:I009BV@80009O?003001>g4kL0080009Bf`<0009Bo003001Bo5;l0080009Bo003001Bo5;l00<0
009Bo003001Bo0000080009Bo003001Bo5;l0080009Bo003001Fo5Kl00<0009Bo003001Bf`000080
009>g0H0009Bf`03001>^`000080009>o@03001:FDYI00800003;]l0000000800003?OP0034c0080
0003AK@0045c0091L`03001oogoo009oo`03001oogoo03Aoo`03001oogoo00aoo`<00091LP06000i
<@009;00000=1@000V/h00L007NHMiQgV000Kk/00002C]`00`00=S/f>`030003Ecd30002B]d00`00
B_e:o@040002Dcd00`00DaeC7@040002Dad00`00DaeC7@030002D_d01000C_e>oDkm0`000Tkm00<0
05<MDad010000TlM00<005<MDad00`000eLM0`000U;m00@005;lD_aBo08000=O?003001F^UJj00@0
0004DYX005:J0002DYX60002;8h00`00=<h000030002Ool00`00Oomoo`0DOol001aoo`D0009oo`03
001oogoo00D00004H_T005ZGFYL30004H[L3000@Ool00`00EaaG70030002E_`00`00DYYBVP030000
15]m001O?5ll0`0000=Bo000D]/00P0000AG7000D_aBo0<00004D]`005;lD_`30002D_`00`00D_`0
00020002D_`00`00D_aBo00300000eKl000000040002E]/50002Ea`300000e;L001B^P02D[X50002
DYX01@00C_e>o@00BUT0100000@^g`00000Pl`800003<C<003UC008000=1L`03001oogoo00=oo`03
001oogoo03=oo`8000Yoo`<0009oo`070011LT5b000i<@009;00200000=[>000MiP00P000Vnk1P00
0U;l10000ULL00<004[MB]d00`000TlM00@005<mDceC?@<0009>o@04001C7E<MDad30002Dad00`00
D_eBo@040002D_d00`00C_e>o@030002C_d01000Cae?7DlM0`000TlM100000=?7@00D_d00U;m00H0
05;l000005MM0002Gc`40002D[/01P00DYYBVU:J001BVP800003Gkd0000000<0008/SP800003=<h0
07oo00=oo`03001oogoo01Aoo`007Woo00<007ooOol00Woo00L007oo001_f`00IoT00002H_T30000
15ZG000<]0000V:g00@007NG0000015oo`80009Bf`03001Fo5Kl00@000=KO@<0009Ff`@000=G70<0
009Fo003001Bg0000080009Bo003001Bo0000080009Bo003001Bo5;l00<00004D_`000000002E]/0
0`00D_aBo003000015LL001>g4kL0`000U:j00<005;LD]`00`0000IF^P00C_e>o@00DYX60003HaX0
1@00;]l000008?<00P000S4c0P0000E5]000@G=1L`0000Eoo`03001oogoo02aoo`D0009oo`03001o
ogoo00Ioo`<000Eoo`070011LT5b000i<@009;00100000<02`00000020000U<M00D004JlA[`005;l
00800003Fcd00000009G70<0009>g003001?7DlM00@0009>o@03001>oDkm00@0009C7@03001C7E<M
00<0009C7@04001BoE;mD_d30002D_d00`00C_e>o@040002C_d01P00Cad00000Cad000=?7@03001B
oE;m008000=GG@<0009?7@05001B^e:kD[/00003DYX200000enm000000050002;8h200000cC>001o
o`03Ool00`00Oomoo`0DOol001ioo`04001oogooOol300001FoK00000000H_T00P0000=Rn@00FYL0
0P0000@<]000001R]`<001=oo`03001Bfe;K00<00003@[d0000000@0009BV@05001Ff`00Ga`00002
C]`30002D]/00`00E_`000020002Ea`00`00D_aBo0020002D_`6000015Kl000000000U;l00<005KK
E]/010000eLL0`000U;l00<005:j000010000eJj1@000UlK0`0000<JG@00HaX01P0000HPl`00<C<a
<`00>E<20002@G<00`00Oomoo`03Ool00`00Oomoo`0^Ool01000Oomoogoo0P001Woo0P0027oo00L0
045b@G8003Ta000T/00700000bHL00000002Gid00`00Ii`00002Dad00`00A[a6_0020005Fcd20002
D_`01000C]a>g4kL0P000U<M00@004kmC_e>o@<0009?7@03001C7E<M00@0009C7@03001C7E<M00@0
009C7@03001BoE;m00<0009Bo@03001>oDkm00<000=?7@L00003Cah000000080009??P04001?7DlM
0004D[/3000014^n000000000T^O10000Rb>00@003C>=<h000Aoo`03001oogoo01Aoo`007Woo00@0
07ooOomoo`P000=Rn@800003AOH0000000H001Aoo`80009Fn`<00005E_`004ijCWX00002DYT20002
Ga`30002E_`00`00D]]Bf`020002D]`6000015Kl000000000UKl00<005;L00000P000U;K00<005;l
D_`00`0000AG7000C]a>g0<0009B^P03001Bo0000080009FfP03001:gD[M00<00003Gc/000000080
0005Ga/00000000]nP0300000e^n0000000600001C4c000iDcUC00000d5c00<007ooOol00Woo00<0
07ooOol0;Woo00D007ooOomoo`0000Aoo`<000Yoo`070011LT5b000i<@009;000`0000D030000000
DP00009OW@8000=WW0D0009:o@03001K?E/m00800006Ecd005;lD_`004kL0P0000AC7@00DaeC7@@0
009>o@03001?7DlM00<0009C7@04001C7E<MDad30002Dad00`00DaeC7@040002Dad00`00D_eBo@03
0002D_d40002D_d00`00C_e>o@030002Dad00`00Cci??P0=00000cnM000000060002;8h01000=<hd
cP0017oo00<007ooOol057oo000NOol01000Oomoogoo1@000Woo00<006;i00000P000dGf00H002UE
000004km000FOol30002Ea`00`00E_`00002CWX30002Ggd20002E]/00`00E_aFo00300000eLL001B
g00200000eLL001Bg0030002D]`00`00E_aFo0020002D_`00`00D]]Bf`030002C]`00`00Ea`00002
0002D_`00`00D[X000020002A]d00`00E]YFfP040002Gc/300000cYK00000003Ii`01000;OX00000
0U^n1@0000@Pl`00<C<0008iD`<00003@G<007oo00=oo`03001oogoo02ioo`04001oogooOol5000=
Ool02`00@G91LP00>C4002B`000DL00000`00`0000<0DP0000000fNL0P0000EG?@00@Ya2W000009:
o@<000=G?@03001Bo5;l008000=C7@<0009C7@04001>oDkmC_d30002Dad00`00DaeC7@040002Cad0
0`00DaeC7@030002Dad01000DaeC7E<M0`000U<M00H005;m000005<M0003D_d30002D_d00`00DaeC
7@030002C]`00`00@[e2_@0400000d]o000000020002CYX20002AUX200000bb>00000002=<h00`00
Oomoo`02Ool00`00Oomoo`0DOol001eoo`8000=oo`8000Ioo`05001BF59HDUP00002AOH00`00:EDY
E@03000HOol00`00EaaG70050002Agl30000159i001FfeKK0`0000=>g00000000`000eLL0P000ULL
00<005;LD]`00`0000ABf`00D_aBo0<0009G7003001>g0000080009B^P03001Bo0000080009JfP@0
0003E]X006<k00D000=SW003000jF`0000D0009oo`03001K_P0000<000058?<00000<C<00002>E<0
0`00@G=1L`020004Ool00`00Oomoo`0^Ool01000Oomoogoo0P0047oo00H0045b@G8003Ta00029;02
00000`0<0004L`020002Ea`30003Ecd00`00@Ya2W0030002Dcd70002C_d30002Dad00`00DaeC7@04
0002Dad00`00DaeC7@030002D_d01000Cae?7DlM0`000U<M00<005<MDad010000U<M00<005<MDad0
0P000e<M00H005;m000005;m0002D_d40002E_`00`00C]a>g0030002C_d30002F_/01P00CYY>VTjJ
0016FP@00003;8h00000008dcP03001oogoo009oo`03001oogoo01Aoo`008goo00<007ooOol01Goo
00@0059HDUP00095mP05000YEBUE:ED0000JOol2000015:j0012W4:L0`0000=>F@00DWT00U9i0P00
0U[k0P000UKl00<005:kD[/00`0000A>^`00EaaG70<0009G7003001Bf`000080009>g003001G7000
0080009Bg003001B^P0000800096g@05001JfP00001S>`0300001V<k000006>M000nW0H000Uoo`80
000500X000bC000Pl`0200001C4c000iDcUC00000T5c00<007ooOol00Woo00<007ooOol0;Goo0P00
17oo00<007ooOol03Woo0P0000A1LP00>C40008T/0@00084L`04001G70000002Im`60002B]`01P00
Dcd00000Ead000=>o@06001>o@00001C7@000U<M0`000Tkm00@005<MDaeC7@<0009C7@03001BoE;m
00@0009C7@03001C7E<M00<0009C7@03001C7E<M00@0009C7@03001C7E<M008000ABo@80009G7@03
001Fo5Kl00@0009Bg003001>o@00008000=Jn`04001>VTjJCYX30002CWX200001C2]000dcSC>0000
1Goo00<007ooOol04goo000TOol20005Ool01000DUQBF0000TGf00<002UE:ED00P006goo00<005:j
00000P0000=K6`00CUT00TiI0`0000ISO@00F_/005[k0002E_`30002Fc`00`00C[/000020002D[/0
0`00Ea`000020002Ea`00`00C]`000020002D[X50002F]X50003Hc/40002Hid3000AOol200000`bC
000Pl`0200001C4c000iDcUC00000T5c00<007ooOol00Woo00<007ooOol0=7oo0P003Woo00H003ec
000003Ta00029;000`005700000200000`Ac00000003Im`200001ELm001:_4Zl00000T[L0P000eLM
1P000e<M0`000U<M00<004kmC_d010000U<M00<005<MDad00`000U<M00<005<MDad010000U;m00<0
05<MDad00`000Tkm00<005<MDad010000U<M00H005;m000005<M0002Ead30002D_`01000D]aBg5;L
0P000ell00<005[kF_/0100000A>F@00CWX0009>NP03000`[@00008dcP03001oogoo00=oo`03001o
ogoo01=oo`009Woo00<007ooOol00goo00@0059HDUP00095mP<001aoo`80009GOP05001K6e/K001>
F@020003Hgd20003F_/20002C[/00`00Fc`000020002Fa`00`00D[/000020002C]`50002E]/02@00
D[X00000E[X004[M001JfP02000016<k000j_CZm0`0000=SO@00@[d00`0057oo10000R3c0`000SUC
00D0045c@G=1L`0000=oo`03001oogoo03Ioo`03001oogoo00]oo`03000mLcec00<0008T/004000D
L0004;<20002Cch30003Ecd00`00B[a:_0030002Ecd30002C_d01000C_e>oDkm0`000U<M00<005<M
Dad00`000U<M00<005<MDad010000U<M00<005<MDad00`000U<M00<005;mD_d010000U;m00<004km
C_d00`000U<M1P000U<M10000U<M00D005;lD_`005;L00800004Ecd005llGc`40002DYX01P00CUU>
FDiI001>NP800003Fmd00000008dcP03001oogoo00=oo`03001oogoo01=oo`009goo00<007ooOol0
0Woo1`007goo3@000TiH0`0000AJ^@00C[]>^`80009>VPD0009K70<00004E]X005:jD[X50003E[X4
0002Hc/50002Hgd3000GOol50000123c000000000SUC00D0045c@G=1L`0000Aoo`03001oogoo03Io
o`03001oogoo00Yoo`03000mLcec00<0008T/003000DL000008@/`04001??P000002Hkd60002B]`0
1P00Ecd00000Dad0009>o@@0009C7@03001C7E<M00<0009>o@03001C7E<M00<0009C7@04001C7E<M
Dad30002Dad00`00DaeC7@030002Dad01000D_eBoE;m0`000U<M0`000U;m00<004kmC_d00`000U<M
00@005<MDaeC7@D000=G?@<0009C7@05001BVU:JDYX00002CUT300001E_M000004^l00000SC>00<0
07ooOol00goo00<007ooOol04goo000XOol00`00Oomoo`0YOol00`00BUU:F@03000015kj001:>000
0diH00<005ZiF[T00UZi0P0000=JnP00CYX00`000TjK0`000U:j00<005KJE]X00`0000AF^@00C_e>
o@<00003Hc/0000000<0009SO0D001]oo`80000339<0023c00<0008iD`050011Ld5c@G<00004Ool0
0`00Oomoo`0gOol00`00Oomoo`09Ool01P00?G<mL`00:A<0008T/003000DL00000<@/`D0009G7004
0016W4JL0002B]`20003Dad30002C_d01000DaeC7E<M0`000U<M00<004kmC_d00`000U<M00<005<M
Dad010000U<M00<005<MDad00`000U<M00<005<MDad010000U<M00H005<M000005<M0002D_d30002
D_d00`00DaeC7@040002C_d00`00C_d000030002Deh01000DaeC7@000e:J0`0000=?WP0000001@00
0SC>00<007ooOol00goo00<007ooOol04goo000YOol2000YOol01000BUU:F@000ekj00<004XhBSP0
0`0000=Wg000F[T00P0000=JV000F_X00P000elK0`0000AF^@00D[YB^P@000=F^@@0009S>`03001S
W0000092W0<0021oo`@000048?<0023c0003>E<01000@G=1L`0017oo00<007ooOol0>7oo0P002Goo
00D003ec?G<002TC00@0008DL0<00003Hg`006Ok0080009G70030016W4JL00<0009G7@<0009>o@03
001>oDkm00@0009C7@03001C7E<M00<0009C7@03001C7E<M00<0009Bo@03001C7E<M00@0009C7@03
001C7E<M00<0009C7@03001C7E<M00<0009C7@@0009Bo@03001BoE;m00<0009Bo@03001>oDkm00<0
009C7@03001CGU=N00P00003?_h0000000<00003CYX000000096>@<000Eoo`03001oogoo01=oo`00
:goo00<007ooOol09goo0P0000=KWP00G_X00Ukj00<004Xh00001@000eZH0P000TiH00@005lKGa/0
00AF^@800008DWP005<LDa`005Ji001S6PD0009SW0<002=oo`H000038?<00000008iD`050011Ld5c
@G<00003Ool00`00Oomoo`0jOol00`00Oomoo`07Ool01`00?G<mL`00:A<002De00@0009SO004001W
nfOkIo/60002C]`01P00Ead00000Ecd0009>o@<0009C7@03001C7E<M00@0009>o@03001C7E<M00<0
009C7@03001BoE;m00<0009C7@04001C7E<MDad30002Dad00`00DaeC7@030002Dad30002Dad00`00
D_eBo@040002Dad00`00D_eBo@030002C_d00`00DaeC7@030002C]`00`00@[e2_@0600000ell001>
VP02CYX2000014Hi000000001Goo00<007ooOol04goo000/Ool00`00Oomoo`0WOol;0003AK@30000
0dgC001>F002CUP200000e9h001F^@030003DWP400001V<J000006NK0012N`<002Moo`D0008Pl`80
0003>E<0045c0091L`05001oogooOol0000mOol00`00Oomoo`06Ool01P00?G<mL`00:A<0008U=@03
0012>D8i00H00096g@040016_4Jl0002C]`20003Ecd30002C_d00`00DaeC7@030002D_d01000C_e>
oDkm0`000U<M00<005<MDad00`000U<M00<005<MDad010000U<M00<005<MDad00`000U<M0`000U<M
00<005<MDad00`000U<M00<005<MDad010000U;m00<004kmC_d00`000ULM00<004kLC]`00`000T[m
0P000ell00P004jJCYY>VP00AST004Hi0P001Woo00<007ooOol04Woo000]Ool00`00Oomoo`0VOol0
1000BME9e@000dGf00@004VcBK<000=5]005001=ddgCCM<00002CUP20003DWP01000GgeOOEmm0`00
00=Vn@0000000P000fNK0P00:Woo0`0000HLdP008?<Pl`00>E<20003@G<01@00Oomoogoo0000?Woo
00<007ooOol01Goo00H003ec?G<002TC00029CD00`00@SU2>@090002A[`30002Eed30002C_d00`00
C_e>o@030002Dad00`00D_eBo@040002Dad00`00DaeC7@030002D_d00`00DaeC7@030002Dad00`00
DaeC7@0400000e<M000000020002Dad00`00DaeC7@030002C_d00`00DaeC7@030002Dad00`00D_eB
o@040002Ead00`00Ead000030002C[`01@00B_d00000Hgd03@001Woo00<007ooOol04Woo000^Ool2
000WOol01@00BME9e@00AOH00P000TVc00D004FdAKA5]00000A=d`80009Al`<00003DO@000000080
009Vn@03001_VP00008n>P<002aoo`0400003`007=8200000b3c000000020003@G<01@00Oomoogoo
0000?goo0P001Goo00H003ec?G<002TC00039CD2000015_l000000000d8H10000T[m0`000U<m00<0
04kmC_d00`000U<M00<005<MDad00`000U;m00<005<MDad010000U<M00<005;mD_d00`000U<M1P00
0U<M0`000U<M00<005<MDad010000U<M00<004km00000`000U<M00<005<MDad00`000U<M00<005LM
Ead00`000U;l00<004jlC[`00`0000ESO@00001K7000009>F0090015mTGfAOH0048H0012600000Io
o`03001oogoo019oo`00<7oo00<007ooOol097oo00D004WEBMD004Gf00800099/`030015]4Fd0080
00A=d`05001Ale7cDO<00003DO@20002>S/01P00I_T006nJ000n>P8002moo`D000038?<0035D0080
00=1L`05001oogooOol00011Ool00`00Oomoo`02Ool00`00?G<0000200000bTC000U=@040003DWT0
1000@QQ260000Shj0`000ULm00<005<mDcd00`000TkM00<005<MDad00`000U<M00<005;mD_d00`00
0U<M00@005<MDaeC7@<0009C7@<0009C7@03001C7E<M00<0009C7@03001C7E<M00<0009C7@03001C
7E<M00<0009C7@03001C7E<M00@0009>o@03001C7E<M00<0009C7@03001Bo5;l00<0009G?@8000=K
7004001>F4iH0003AOH00`00@QQ260020006Ool00`00Oomoo`0BOol0035oo`03001oogoo02=oo`07
0019eDWEBMD0057C00000dVc00D004Fd001El`0000==d`05001Ale7cDO<00002DO@00`00HU=RD`04
0002KiX2000aOol3000011cB000Plb3c0P0000<iD`00@G<00T5c00D007ooOomoo`00045oo`04001o
ogooOol20002@W/400001Eol000005lK00000U9i00@0048H@QQ260<00004E_`005LmEcd30002C]`0
0`00C]e>g@030002Dad00`00DaeC7@030002Dad00`00DaeC7@0400000e<M000000020002Dad00`00
Dad000030002Dad00`00DaeC7@030002Dad00`00DaeC7@030002D_d00`00DaeC7@030002Dad00`00
C_e>o@0400000e<M000000050002B]d30002Fih01@00FaaK75/L00000TiH00@004GfAOI5mP<000Mo
o`03001oogoo019oo`00<Woo0P008goo00D004WEBME9e@00009Ad`030019/dVc0080009El`03001=
ddgC0080009Al`80009Am004001RDf9C0003BQH2000dOol200001QcB000Plb3c000aE08000=1L`05
001oogooOol00012Ool20002Ool01000@W]2Nd9k10000elK00H0059iDWUBN@00@QP20004E_`20002
Ea`00`00C]a>g0030002D_d00`00DaeC7@030002C_d00`00DaeC7@030002Dad30002Dad00`00DaeC
7@030002Dad00`00DaeC7@040002Dad00`00DaeC7@030002Dad00`00D_eBo@030002Dad00`00DaeC
7@030002D_d30002Dad01@00C]e>g@00B]d00P0000=C?P000000200000A>F000AOI5mP80009oo`03
001oogoo00Aoo`03001oogoo019oo`00=7oo00<007ooOol08Goo10000U7C00<004VcBK<00P000UGc
00<004gCCM<00P000U7c0P000U7d00@0069CHU<0009:5P03001oogoo03Aoo`8000057=8000008?<0
0002<E@50003Ool00`00Oomoo`12Ool01000Ool0049k10000U^N2@000TjJ00H005Kl000005nM0002
Ea`30002D]`00`00D_eBo@030002D_d60002Dad30002C_d00`00DaeC7@030002Dad00`00DaeC7@03
0002Dad00`00DaeC7@040002Dad00`00Dad000030002Dad00`00DaeC7@0300000dkm000000020002
Dad00`00DaeC7@050002Dch30003C]`01@00?SXn>P00=S/010001Goo00<007ooOol00goo00<007oo
Ool04Woo000eOol00`00Oomoo`0POol01000CM==d`000U7C00<004VcBK<00P000UGc00<004gCCM<0
0P000U7c00@005hc0000009RD`04001^/`00000gOol50000223c000aE35D0019mP00BOH20002Ool0
0`00Oomoo`13Ool01000Ool000000Woo0`000TZk00H004IkAW/004Yj0004CYX70002C_d00`00D]aB
g0030002Ead30002D_d00`00D_eBo@030002D_d00`00C_e>o@030002Dad00`00DaeC7@030002Dad0
0`00DaeC7@030002Dad00`00DaeC7@030002D_d00`00DaeC7@04000015<M000000000U;m00<005<M
Dad010000Tkm00<004kL00000P000e]M00@004kLC]`000<n>P<000Qoo`03001oogoo00=oo`03001o
ogoo015oo`00=Woo00<007ooOol07goo00@004gCCM<0009Ad`040019/dVc0003EO<00`00CM<00002
GQ<20002GS<20002HU<01000K[<00000>7oo0P0000@LdP00000000<aE0040019mP00BOH40016Ool0
0`00Oomoo`04Ool01000B[]:^`000TIk00D004YjBWX004jJ00<0009;W`04001;?T/n0002C_d30002
Ecd30002Dad00`00D_eBo@030002Dad00`00D_eBo@030002D_d00`00DaeC7@030002Dad00`00DaeC
7@030002Dad00`00DaeC7@030002Dad60002Dad30002C_d00`00D_eBo@030002Dad00`00C_e>o@03
0002Ecd<000:Ool00`00Oomoo`03Ool00`00Oomoo`0AOol003Moo`8001moo`04001=ddgC0002DM<0
1000BK=9/`000eGc00<004gC00000UhC0P000Uhc0P000V9C00<006jc0000>Goo100000<U50000000
0S5D00D004Wf0019mP00008n>@03001oogoo04Eoo`8000Eoo`/00003Dih0000000L0009:o@<0009C
?P03001C7E<M00<0009C7@03001C7E<M00<0009C7@03001BoE;m00<0009Bo@03001C7E<M00<0009B
o@H0009C7@<0009>o@03001C7E<M00<0009C7@03001>oDkm00<0009C7@03001C7E<M00<0009>g006
001G?@00001GOP000TkL00D0048i@SU2>@0000eoo`03001oogoo009oo`03001oogoo015oo`00>Goo
00<007ooOol077oo00@004gCCM<0009Ad`040019/dVc0004EO<20002GQ<20002GS<01`00HU=RDf9C
001^/`0003Uoo`@000039A@00000008aE0030019mTWf0080008n>@03001oogoo04Moo`03001oogoo
00=oo`040016W4JL0002=[h50002EYX01000AUY6FP000T9k0`000U<M00<005<nDch00`000Tkm00<0
05<MDad00`000U<M00<005<MDad00`000U<M00<005;mD_d00`0000=Bo@0000000P000U;m00<005<M
00000`000U;m00<004km00000`000U<M00<005<M00000`000U;m00<005<M00000`000TkL00<004kL
00000P000UMn0`0000A>g000@SU2>@8000ioo`05001oogooOol0000COol003Yoo`03001oogoo01]o
o`04001=ddgC0002DM<01000BK<0000015Gc0P000UhC0P000Uhc00@0069CHU<0009^/`03001oogoo
03Qoo`03000De000008U5080008aE0P004Uoo`03001oogoo009oo`030016W4JL00<00005Eed00000
Ga/00002EYX00`00AUY6FP030002D[/00`00DaeC7@030002C]`00`00C_e>o@030002Dad00`00Dad0
00030002Dad00`00Dad00003000015<M000000000U<M00<005;mD_d00`000U<M00<005;mD_d00`00
0U<M00<005<MDad00`000Tkm00<005;mD_d00`000U<M00<004kLC]`00`000ULM0`000T[M1P0047oo
00@007ooOol001=oo`00>goo00<007ooOol06Woo00D004gCCM==d`00009Ad`<000AEl`05001N4ehC
GQ<00003GS<01000HU=RD`000Vjc00<007ooOol0>7oo10000RDD1@0000Aoo`00Oomoo`8004Yoo`03
001oogoo009oo`80009C7@8000=O6`03001FVUJJ00<00003DYX005:k00=B^`80009G7003001>g000
00<0009Bo0D0009>o@H0009C7@<0009C7@03001C7E<M00<0009C7@03001C7E<M00<0009Bo@03001C
7E<M00<0009C7@03001>oDkm00<0009C?@H0009>g0<0009OO@04001:gD[M0003>SX2000@Ool01000
Oomoo`004goo000lOol2000JOol01@00CM==ddgC00000U7C0P0000=El`00EO<00UGc00D005hCGQ=N
4`0000=N<`800004HU<006jc000lOol00`005=@000029A@200000g^e001oo`02Ool01000Oomoo`00
Bgoo0P000goo0`000U]M00<005lKGa/00`0000=>VP00DYX00U:J00L005:k000005mm001G70030002
D]`01P00D_`00000Ead0009Bo@<0009Bo@03001C7E<M00<0009?7@03001C7E<M00<0009C7@03001C
7E<M00<0009C7@03001BoE;m00<0009C7@H00003C_d000000080009C?P05001>oDkm001>g0020000
0eLm001OO@0:000AOol00`00Ool0000COol003ioo`03001oogoo01Qoo`04001=ddgC0002DM<01000
EO=El`000eGc00D005hCGQ=N4`0000=N<`800004HU<006jc000lOol00`005=@0000200000e9h0000
0005Ool00`00Ool0001=Ool00`00Oomoo`02Ool00`00FeeKG@030002C_`01@00CYY>VP00DYX00`00
0Umm0`000U<M00<005;LD]`00P000eLM0`000U;l00<005;mD_d00`000U;m00<004lMCad00`000TlM
00<005<MDad00`000U<M00<005<MDad00`0000=C7@0000000P000U<M00<004kl00000P000ULM00<0
05<nDch01P000ULm0`000TmN00D0048i@ST004jJ00<0019oo`03001oo`00019oo`00?goo00<007oo
Ool05goo00@004gCCM<0009Ad`04001EleGc0002EO<20002GQ<20002GS<01`00JW<0069C001^/`00
03eoo`07000De000DWP007^e00001Woo0P00CWoo00<007ooOol00Woo0P000TlN00@004klC_`0009>
VPl0009G?@<0009C7@03001Bo5;l00<0009C7@03001BoE;m00<0009Bo@03001?7DlM00<00003Cad0
000000D00004Cad000000002Dcd00`00DaeC7@030002D_`00`00EaeG7@030002C]`00`00A[a6_003
00001UNn00000000Ceh000=2>@<001Aoo`80019oo`00@7oo00<007ooOol05Woo00D004gCCM<0057C
0080009El`03001EleGc0080009N4`06001VD`00GS<006Yc0P000Vjc00<007ooOol0>goo0`0000=B
N00000001goo0P00Cgoo00<007ooOol00Woo2`0000A3O`0000000096NP040012W4:L0002Bah30002
Cch00`00DaeC7@030002Dad00`00DaeC7@0300000e<M00000005000015;l000000000U;m00<004lM
Cad00`000TlM00<005<mDcd00`000Tkm00<005;lD_`00`000ULm00<004kLC]`00`000U;L3@0057oo
0P004Woo0011Ool2000FOol00`00CM==d`0200001E7C001EleGc00000UGc0P000UhC00D006IC001N
<`00009ZL`04001^/fjc000nOol300000g^e001oo`06Ool2001@Ool20004Ool00`00A]e6g@030002
Cad3000015JJ0016NTIj1P000Tkm1P000T[m1P0000AC7@000000009C7@03001C7E<M00<0009C7@03
001BoE;m00<0009>o003001?7DlM00<0009?7P03001>oDkm00<00003Ecd0000000D0009>V`@00004
KgX003ZM>Yd30003AUT2000DOol2000BOol004=oo`03001oogoo01=oo`03001=ddgC00800005DM<0
05GcEO<00002EO<20002GQ<01@00IU<005hc00000VYc00@006jcK[<0041oo`8000Aoo`@005Aoo`03
001oogoo009oo`80009Bf`07001?7@00001NnP00EYX00`000Tii00<004jJCYX00`000UKk00<004kL
C]`00`000TkL00<004lM00000P000TlM00<005<MDad00`000U<M00<005<MDad00`000U;l00<004kl
C_`00`0000=C7@0000001@0000A:o@000000009?O`04001?7DlM0002CY/200000f<k001_NP02KgX2
00000cZM00000005000@Ool4000DOol004Aoo`03001oogoo019oo`04001=d`000002DM<01P00EO=E
l`00EO<0009RD`80009VD`03001N<`00009ZL`<004=oo`@005Uoo`03001oogoo009oo`03001Bfe;K
008000=NnP80009BV@05001>NDii001>VP02000015ll001FneKk0`000U;K00<004kL00000P000Tkl
00<004lMCad00`000TlM00<005<MDad00`000U<m00<005;lD_`00`000U;l0P000ULL00<004[LB]`0
0`000U;m2@000UJj00<006mjKgX00`0000Db6`000009F@00009W>P03001oogoo00]oo`@001Qoo`00
AGoo00<007ooOol04Goo0P0000E=d`00DM=Ad`00009El`03001El`00009RD`80009VD`03001N<`00
009ZL`<003moo`@005ioo`03001oogoo009oo`80009Jn`<00005Ea`005:IDYT00003CWT01000GcaO
?5ll0`000ULL00<005;K00000P000UKl00<004klC_`00`000Tkl1P0000=?7@0000001@000TlM0`00
00AG?@00EaaG70<0009B^`<00003Ga/0000000@00005=[h00000001SG0020003Ji/00`00<Q/b6`05
0009Ool4000LOol004Ioo`80015oo`04001=ddgC0002DM<01000EO=EleGc0P000V9C0P000VIC00D0
05hc001ZL`00009fd`03001oogoo03Yoo`<006=oo`8000=oo`04001Jne[k0003Ea`01000DYUBVE:I
0`0000AKWP000000009;_P03001G75LL0080009G?@03001Fo5Kl00<0009Bo0<0009Fo003001>g000
0080009Bo@03001;7T/N00D000=G?@<0009Bo@04001B^`000002Ga/2000016Lj000jWCZM0`000f=L
00<006Nm0000100000<b6`009MX00`001Woo0`0087oo0018Ool00`00Oomoo`0>Ool01000CM==d`00
0U7C00@005GcEO=El`80009RD`8000=VD`04001ZLfYc0002M]<00`00Oomoo`0fOol4001XOol01000
Oomoogoo3P0000=BF00000001@0000=7?`00000010000ULm0`000ULm00<005Kl00000P000UKk00<0
05;mD_d00`000T[L1P000T]o00<005;m00000P000U[J0P000fLj1@0000<V?@00He`00`001Goo1000
17oo10008goo0019Ool00`00Oomoo`0=Ool01000CM==d`000e7C00@005GcEO<000=RD`03001VDfIC
009VD`04001ZLfYc0002M]<00`00Oomoo`0bOol4001]Ool00`00Oomoo`02Ool600001D;N000005Ig
00000U9H00<0049K@U/01@000TKn1P000TLo00<005Lm00000P000U<M00<005KkE_/00`000UKk0`00
0U:j00<004lN00001@000T;N00D005[JF]X006=K00<00004Hc/0049K@U/5000;Ool4000WOol004Yo
o`03001oogoo00aoo`04001=ddgC0003DM<01000EO=El`000f9C00<006ICIU<00VIC00H006YcJW<0
07KC000aOol4001bOol00`00Oomoo`03Ool00`00CY]>V`020003EWL01000DUQBF59H0P0000A>5P00
BSQ:>0<0009BV@030016_4Jl00D00097?`03001C7E<M00<0009K?@<00003E_/005:j009B^P800004
Fa`00000G_X500001E[J001SFf=K00000f<k1P002Goo1000:goo001;Ool2000<Ool01@00CM==ddgC
00000U7C00@005Gc000000=RD`03001VDfIC009VD`03001ZL`00009fd`03001oogoo02aoo`<007Mo
o`8000=oo`06001>V`00001FN0000eIg10000ThF00H004XhBSP005kI0003DYT20002DWT00`00B]d0
000:0002@gl00`00E_]Fn`0300000ekI00000003G_X200001Bim00000000He/00P0000AS_@000000
00aoo`<002moo`00CGoo00<007ooOol02Woo00@004gCCM<0009Ad`04001El`000003HU<00`00IU=V
D`02IU<00`00JW<00002M]<00`00Oomoo`0XOol4001lOol01@00Oomoogoo00000eIh00D005IgEWMF
M`00009FE`04001>5ThFCQH20002G]T00`00DYT000020003DWT20002EYT30002DWT:0003G]T00`00
IeX0000200000ekj00000007000;Ool4000bOol004ioo`03001oogoo00Uoo`04001=ddgC0002DM<2
0000169d001RDf9C0P000fIC0P0000EZL`00M]=fd`0002Ioo`@0085oo`05001oogooOol00003EWP4
0003EUL01000CQI>5P0015kI00@005kjG_YNnP<00003IcX005JI00<0009BN@04001NU`00D_`20000
0eZi00000002B_d00`00G]T00002IeX01@00G_YNnUkj00000T9K0`002Woo1000=Woo001?Ool00`00
Oomoo`08Ool01000CM==d`000U7C0P0000MRM000HU=RD`00L_D00002IU<2000016Yc001fd`008goo
1000QWoo00@007ooOol0009FN08000=S6P03001FEeIG00<00003Io/005kI00800003Ool005kj0080
00=W>P8000=N^@8000=NU`04001J^EZiF[T600001FMJ000006>m00000Ukj0`002Goo1000>Woo001@
Ool20008Ool01000CM==d`000U7C00@0069dHWARM080009bm@05001VDfIC001^]00200000gKC001o
o`0OOol3002;Ool200000goo00000002Ekh01@00HaYS6P00EUL01`000goo0P000Woo0`0000=oo`00
G[T00Uji00@005jGGYMNU`80009J^@03001N^00000D000=S_@<000Uoo`<003ioo`00DWoo00<007oo
Ool01Goo00D004gCCM<0057C008000=RM080009bm@03001VD`00009^]004001fdgKC000LOol4002@
Ool00`00Ool000070005Ool00`00Oomoo`0;Ool3000015nM001NU`000VlG0P000ejh0P000goo0`00
27oo1000@Goo001COol00`00Oomoo`04Ool500000e9G001RM002HW@20002L_D00`00IU<00002K[@0
1000M]=fd`0067oo1000UGoo00<007ooOol02goo00<007ooOol02goo1@0000ENU`00KaM_5`0000=N
^003001oogoo00Yoo`@004Eoo`00E7oo0P001Goo00<004HH00000U9G00D0069dHWARM00000Abm@80
009^]003001fd`0001Eoo`@009Yoo`8000]oo`03001oogoo00moo`80009_5`05001c^@00G[P00009
Ool40019Ool005Ioo`03001oogoo009oo`04001664HH0002DUL01000HWARM00017;e00D006jdK[@0
07Mg0080015oo`@00:1oo`03001oogoo00Qoo`03001oogoo015oo`04001_5`00LkT20006Ool4001=
Ool005Moo`03001oogoo009oo`0300166000009BE`04001RM000FUH50002K[@01000MgMgM`003Woo
0`00YGoo00<007ooOol01goo00<007ooOol04Woo0`001Goo0`00DGoo001HOol01000Oomoogoo1000
00=BE`0000000P0017oo00<006jd00000WMg00<007ooOol02Goo1000ZGoo00<007ooOol01Woo00<0
07ooOol05Woo1000E7oo001IOol20005Ool200000eYF00000004Ool300000gMg001oo`07Ool4002^
Ool20006Ool00`00Oomoo`0BOol4001HOol005]oo`03001oogoo009oo`04001JEUYF0006Ool30005
Ool4002dOol00`00Oomoo`03Ool00`00Oomoo`0>Ool4001LOol005aoo`03001oogoo009oo`8000ao
o`<00;Uoo`03001oogoo009oo`03001oogoo00]oo`<0061oo`00GGoo00D007ooOomoo`0000Uoo`@0
0;eoo`05001oogooOol00009Ool4001SOol005ioo`800003Ool007oo00Aoo`@00<9oo`800003Ool0
07oo00Aoo`@006Moo`00H7oo0P0000=oo`0000000P00b7oo0P0000=oo`0000000P00Jgoo001QOol2
003=Ool2001_Ool00?mooj9oo`00ogooXWoo003oOonROol00?mooj9oo`00ogooXWoo003oOonROol0
0?mooj9oo`00ogooXWoo003oOonROol00?mooj9oo`00ogooXWoo003oOonROol00001\
\>"],
  ImageRangeCache->{{{0, 416.25}, {160.125, 0}} -> {-0.0543104, -0.0193168, 
  0.00506576, 0.00506576}, {{10.6875, 198.688}, {156.313, 
  3.8125}} -> {-0.208572, -0.057075, 0.00605201, 0.00605201}, {{217.5, 
  405.5}, {156.313, 3.8125}} -> {-1.46306, -0.0576897, 0.00605928, 
  0.00605928}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2: Smoothing with circularly symmetric 2D windows", "Subsection"],

Cell["\<\
As in the case of rectangularly supported FIR filters, the ideal impulse \
response must be truncated and smoothed with an appropraite window sequence. \
Window sequences with nearly circular symmetry may be obtained by a method \
introduced by Huang (\"Two-Dimensional Windows,\" IEEE Trans. Audio and \
Electroacoustics, AU-20, No. 1, 1972, pp. 88-90). The 2D sequence is formed \
by sampling a circularly rotated 1D window sequence according to:\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm
      \`w\_C[n\_1, n\_2]\  = \ w[\@\(n\_1\^2 + n\_2\^2\)]\)]]
}], "NumberedEquation"],

Cell[TextData[{
  " ",
  StyleBox["DiscreteWindow2D", "Program"],
  " called with a dimensions list of length 1 will return a circularly \
symmetric sequence. The desired smooth FIR filter is a product of the ideal \
impulse response ",
  Cell[BoxData[
      \(TraditionalForm\`h\_I\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`w\_C\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(hC = \ lowC\ *\ DiscreteWindow2D[\ 15, "\<Hamming\>"]; \)\)], "Input",\

  CellLabel->"In[59]:="],

Cell[TextData[StyleBox[
"Here we verify the amplitude spectrum of the 2D FIR filter."]], "Text"],

Cell[BoxData[
    \(\(H = Abs[DFT[ZeroPad[hC, {0, 17}, {0, 17}]]]*32^2; \)\)], "Input",
  CellLabel->"In[60]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot3D[H, PlotRange -> All]; \)\)], "Input",
  CellLabel->"In[61]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.20131 .17781 -11.698 -9 ]
[.20131 .17781 .302 0 ]
[.40909 .09608 -10.8909 -9 ]
[.40909 .09608 1.10907 0 ]
[.63425 .0076 -10.0839 -9 ]
[.63425 .0076 1.91614 0 ]
[.79552 .14001 0 -6.12026 ]
[.79552 .14001 12 2.87974 ]
[.88711 .28027 0 -5.98728 ]
[.88711 .28027 12 3.01272 ]
[.96711 .40279 0 -5.87447 ]
[.96711 .40279 12 3.12553 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01575 .31752 -24 -2.78663 ]
[.01575 .31752 0 6.21337 ]
[.0071 .37175 -18 -2.83264 ]
[.0071 .37175 0 6.16736 ]
[-0.00186 .42789 -24 -2.88043 ]
[-0.00186 .42789 0 6.11957 ]
[-0.01114 .48604 -6 -2.93013 ]
[-0.01114 .48604 0 6.06987 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.21035 .18732 m
.21487 .19208 L
s
[(10)] .20131 .17781 .94967 1 Mshowa
.41738 .10625 m
.42153 .11134 L
s
[(20)] .40909 .09608 .81515 1 Mshowa
.64163 .01845 m
.64532 .02387 L
s
[(30)] .63425 .0076 .68064 1 Mshowa
.125 Mabswid
.25047 .17161 m
.25314 .1745 L
s
.29122 .15565 m
.29385 .15859 L
s
.33262 .13945 m
.3352 .14242 L
s
.37466 .12298 m
.3772 .12599 L
s
.46079 .08926 m
.46322 .09235 L
s
.5049 .07199 m
.50728 .07512 L
s
.54973 .05443 m
.55206 .0576 L
s
.5953 .03659 m
.59757 .0398 L
s
.17084 .20279 m
.17359 .20561 L
s
.13192 .21803 m
.13471 .22081 L
s
.09359 .23304 m
.09641 .23578 L
s
.05583 .24783 m
.05869 .25053 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.78318 .14446 m
.777 .14668 L
s
[(10)] .79552 .14001 -1 .36006 Mshowa
.87465 .28439 m
.86842 .28645 L
s
[(20)] .88711 .28027 -1 .33051 Mshowa
.95456 .40662 m
.94829 .40854 L
s
[(30)] .96711 .40279 -1 .30544 Mshowa
.125 Mabswid
.80252 .17404 m
.7988 .17536 L
s
.82131 .20279 m
.81759 .20409 L
s
.83959 .23075 m
.83586 .23202 L
s
.85736 .25793 m
.85363 .25919 L
s
.89149 .31014 m
.88774 .31135 L
s
.90788 .33521 m
.90413 .33641 L
s
.92384 .35963 m
.92009 .36081 L
s
.9394 .38343 m
.93564 .38459 L
s
.76327 .11401 m
.75957 .11536 L
s
.74277 .08265 m
.73908 .08403 L
s
.72165 .05034 m
.71797 .05174 L
s
.69987 .01704 m
.6962 .01846 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02801 .31285 m
.03415 .31052 L
s
[(0.25)] .01575 .31752 1 -0.38075 Mshowa
.0194 .36719 m
.02556 .36491 L
s
[(0.5)] .0071 .37175 1 -0.37053 Mshowa
.01049 .42345 m
.01666 .42122 L
s
[(0.75)] -0.00186 .42789 1 -0.3599 Mshowa
.00125 .48172 m
.00745 .47956 L
s
[(1)] -0.01114 .48604 1 -0.34886 Mshowa
.125 Mabswid
.03469 .2707 m
.03836 .26927 L
s
.03304 .28113 m
.03671 .27971 L
s
.03138 .29163 m
.03505 .29022 L
s
.0297 .30221 m
.03338 .3008 L
s
.02632 .32357 m
.03 .32218 L
s
.02461 .33436 m
.02829 .33298 L
s
.02288 .34523 m
.02657 .34385 L
s
.02115 .35617 m
.02484 .3548 L
s
.01764 .37828 m
.02134 .37692 L
s
.01587 .38946 m
.01957 .3881 L
s
.01409 .40071 m
.01779 .39936 L
s
.0123 .41204 m
.016 .4107 L
s
.00867 .43494 m
.01237 .43361 L
s
.00683 .44651 m
.01054 .44519 L
s
.00499 .45816 m
.0087 .45685 L
s
.00313 .4699 m
.00684 .46859 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.624 .812 .973 r
.38757 .79709 .39815 .80326 .4156 .79971 .40513 .79261 Metetra
.671 .801 .945 r
.40513 .79261 .4156 .79971 .43317 .79655 .42285 .78669 Metetra
.768 .76 .845 r
.42285 .78669 .43317 .79655 .45097 .78845 .44083 .77424 Metetra
.822 .711 .743 r
.44083 .77424 .45097 .78845 .46904 .76769 .45909 .74888 Metetra
.843 .684 .686 r
.45909 .74888 .46904 .76769 .48726 .72957 .47746 .70803 Metetra
.851 .675 .662 r
.47746 .70803 .48726 .72957 .50534 .67829 .49567 .65719 Metetra
.851 .676 .664 r
.49567 .65719 .50534 .67829 .52306 .62625 .51353 .60821 Metetra
.84 .687 .693 r
.51353 .60821 .52306 .62625 .54047 .58611 .53108 .5718 Metetra
.803 .707 .759 r
.53108 .5718 .54047 .58611 .5578 .56289 .54852 .55125 Metetra
.701 .717 .861 r
.54852 .55125 .5578 .56289 .57525 .55268 .56608 .54363 Metetra
.674 .76 .915 r
.56608 .54363 .57525 .55268 .59286 .54766 .58375 .53778 Metetra
.668 .742 .905 r
.58375 .53778 .59286 .54766 .61059 .54251 .60154 .53218 Metetra
.652 .729 .906 r
.60154 .53218 .61059 .54251 .62842 .53703 .61947 .52733 Metetra
.661 .746 .913 r
.61947 .52733 .62842 .53703 .64637 .53186 .6375 .52198 Metetra
.676 .749 .905 r
.6375 .52198 .64637 .53186 .66442 .52609 .65562 .51587 Metetra
.657 .736 .908 r
.65562 .51587 .66442 .52609 .68262 .52111 .67389 .51069 Metetra
.67 .738 .901 r
.67389 .51069 .68262 .52111 .70089 .51515 .69225 .5048 Metetra
.65 .734 .911 r
.69225 .5048 .70089 .51515 .71933 .50998 .71079 .49984 Metetra
.666 .745 .91 r
.71079 .49984 .71933 .50998 .73785 .5042 .7294 .49411 Metetra
.675 .751 .908 r
.7294 .49411 .73785 .5042 .75652 .49874 .74811 .48788 Metetra
.659 .731 .903 r
.74811 .48788 .75652 .49874 .77529 .49295 .76699 .4824 Metetra
.653 .736 .911 r
.76699 .4824 .77529 .49295 .79417 .48701 .78602 .47718 Metetra
.608 .736 .935 r
.78602 .47718 .79417 .48701 .81363 .48637 .80534 .47377 Metetra
.234 .476 .885 r
.80534 .47377 .81363 .48637 .83454 .49912 .82603 .48363 Metetra
0 .113 .665 r
.82603 .48363 .83454 .49912 .85754 .52943 .84863 .50994 Metetra
0 0 .538 r
.84863 .50994 .85754 .52943 .88245 .57236 .87314 .54952 Metetra
0 .003 .578 r
.87314 .54952 .88245 .57236 .90805 .61493 .89861 .59142 Metetra
0 .181 .698 r
.89861 .59142 .90805 .61493 .93282 .64416 .92366 .62331 Metetra
.288 .405 .807 r
.92366 .62331 .93282 .64416 .95596 .65543 .94738 .63923 Metetra
.511 .594 .874 r
.94738 .63923 .95596 .65543 .97774 .65345 .96981 .64169 Metetra
.624 .726 .92 r
.96981 .64169 .97774 .65345 .99901 .64624 .99158 .63727 Metetra
.676 .73 .891 r
.37703 .78651 .38757 .79709 .40513 .79261 .39471 .78048 Metetra
.732 .719 .839 r
.39471 .78048 .40513 .79261 .42285 .78669 .41263 .77021 Metetra
.776 .682 .76 r
.41263 .77021 .42285 .78669 .44083 .77424 .43082 .75157 Metetra
.799 .653 .701 r
.43082 .75157 .44083 .77424 .45909 .74888 .44926 .72057 Metetra
.81 .638 .668 r
.44926 .72057 .45909 .74888 .47746 .70803 .46775 .67752 Metetra
.815 .634 .658 r
.46775 .67752 .47746 .70803 .49567 .65719 .48604 .62925 Metetra
.813 .639 .666 r
.48604 .62925 .49567 .65719 .51353 .60821 .50396 .58617 Metetra
.802 .655 .7 r
.50396 .58617 .51353 .60821 .53108 .5718 .5216 .556 Metetra
.768 .685 .771 r
.5216 .556 .53108 .5718 .54852 .55125 .53914 .53965 Metetra
.671 .71 .877 r
.53914 .53965 .54852 .55125 .56608 .54363 .55679 .53383 Metetra
.678 .747 .903 r
.55679 .53383 .56608 .54363 .58375 .53778 .57454 .52771 Metetra
.665 .739 .906 r
.57454 .52771 .58375 .53778 .60154 .53218 .59241 .52222 Metetra
.657 .74 .911 r
.59241 .52222 .60154 .53218 .61947 .52733 .6104 .51705 Metetra
.662 .737 .905 r
.6104 .51705 .61947 .52733 .6375 .52198 .62851 .5116 Metetra
.672 .739 .901 r
.62851 .5116 .6375 .52198 .65562 .51587 .64672 .50563 Metetra
.657 .739 .91 r
.64672 .50563 .65562 .51587 .67389 .51069 .66507 .50034 Metetra
.67 .742 .905 r
.66507 .50034 .67389 .51069 .69225 .5048 .68351 .49442 Metetra
.655 .738 .911 r
.68351 .49442 .69225 .5048 .71079 .49984 .70212 .48919 Metetra
.665 .737 .904 r
.70212 .48919 .71079 .49984 .7294 .49411 .72082 .48343 Metetra
.67 .74 .903 r
.72082 .48343 .7294 .49411 .74811 .48788 .73963 .47738 Metetra
.662 .742 .909 r
.73963 .47738 .74811 .48788 .76699 .4824 .75858 .47166 Metetra
.649 .734 .911 r
.75858 .47166 .76699 .4824 .78602 .47718 .77771 .46658 Metetra
.654 .74 .912 r
.77771 .46658 .78602 .47718 .80534 .47377 .79696 .46119 Metetra
.384 .57 .91 r
.79696 .46119 .80534 .47377 .82603 .48363 .81731 .4666 Metetra
.054 .287 .777 r
.81731 .4666 .82603 .48363 .84863 .50994 .83928 .48631 Metetra
0 .131 .667 r
.83928 .48631 .84863 .50994 .87314 .54952 .86308 .51958 Metetra
.001 .14 .656 r
.86308 .51958 .87314 .54952 .89861 .59142 .88813 .55856 Metetra
.155 .232 .692 r
.88813 .55856 .89861 .59142 .92366 .62331 .91331 .59249 Metetra
.32 .353 .74 r
.91331 .59249 .92366 .62331 .94738 .63923 .93767 .61411 Metetra
.46 .477 .79 r
.93767 .61411 .94738 .63923 .96981 .64169 .96091 .6229 Metetra
.564 .594 .842 r
.96091 .6229 .96981 .64169 .99158 .63727 .98334 .62293 Metetra
.666 .59 .76 r
.36693 .76333 .37703 .78651 .39471 .78048 .38468 .75555 Metetra
.715 .605 .732 r
.38468 .75555 .39471 .78048 .41263 .77021 .40276 .74068 Metetra
.747 .603 .697 r
.40276 .74068 .41263 .77021 .43082 .75157 .42113 .7164 Metetra
.766 .598 .67 r
.42113 .7164 .43082 .75157 .44926 .72057 .43968 .68167 Metetra
.776 .596 .656 r
.43968 .68167 .44926 .72057 .46775 .67752 .45819 .63947 Metetra
.779 .599 .656 r
.45819 .63947 .46775 .67752 .48604 .62925 .47645 .5971 Metetra
.776 .609 .672 r
.47645 .5971 .48604 .62925 .50396 .58617 .49436 .56263 Metetra
.763 .632 .715 r
.49436 .56263 .50396 .58617 .5216 .556 .51204 .54033 Metetra
.73 .675 .797 r
.51204 .54033 .5216 .556 .53914 .53965 .52967 .52871 Metetra
.665 .723 .892 r
.52967 .52871 .53914 .53965 .55679 .53383 .54738 .52321 Metetra
.659 .728 .9 r
.54738 .52321 .55679 .53383 .57454 .52771 .56522 .51796 Metetra
.663 .748 .913 r
.56522 .51796 .57454 .52771 .59241 .52222 .58317 .51245 Metetra
.671 .751 .911 r
.58317 .51245 .59241 .52222 .6104 .51705 .60123 .50656 Metetra
.665 .736 .903 r
.60123 .50656 .6104 .51705 .62851 .5116 .61941 .50089 Metetra
.66 .731 .902 r
.61941 .50089 .62851 .5116 .64672 .50563 .63771 .49546 Metetra
.661 .744 .912 r
.63771 .49546 .64672 .50563 .66507 .50034 .65614 .48993 Metetra
.666 .742 .907 r
.65614 .48993 .66507 .50034 .68351 .49442 .67468 .48412 Metetra
.667 .746 .909 r
.67468 .48412 .68351 .49442 .70212 .48919 .69333 .4782 Metetra
.662 .732 .902 r
.69333 .4782 .70212 .48919 .72082 .48343 .71212 .47253 Metetra
.657 .733 .906 r
.71212 .47253 .72082 .48343 .73963 .47738 .73106 .46708 Metetra
.663 .749 .914 r
.73106 .46708 .73963 .47738 .75858 .47166 .7501 .46123 Metetra
.668 .749 .911 r
.7501 .46123 .75858 .47166 .77771 .46658 .76925 .45513 Metetra
.662 .729 .899 r
.76925 .45513 .77771 .46658 .79696 .46119 .78856 .44928 Metetra
.52 .658 .922 r
.78856 .44928 .79696 .46119 .81731 .4666 .80854 .44969 Metetra
.294 .447 .844 r
.80854 .44969 .81731 .4666 .83928 .48631 .82975 .46114 Metetra
.168 .282 .738 r
.82975 .46114 .83928 .48631 .86308 .51958 .85258 .48527 Metetra
.183 .242 .689 r
.85258 .48527 .86308 .51958 .88813 .55856 .87682 .51786 Metetra
.264 .274 .684 r
.87682 .51786 .88813 .55856 .91331 .59249 .90171 .5506 Metetra
.361 .336 .697 r
.90171 .5506 .91331 .59249 .93767 .61411 .92637 .57583 Metetra
.453 .408 .718 r
.92637 .57583 .93767 .61411 .96091 .6229 .95024 .59031 Metetra
.534 .481 .744 r
.95024 .59031 .96091 .6229 .98334 .62293 .97325 .59498 Metetra
.641 .508 .686 r
.35763 .72203 .36693 .76333 .38468 .75555 .37535 .71301 Metetra
.684 .533 .676 r
.37535 .71301 .38468 .75555 .40276 .74068 .39347 .69543 Metetra
.713 .548 .663 r
.39347 .69543 .40276 .74068 .42113 .7164 .41186 .66898 Metetra
.733 .557 .654 r
.41186 .66898 .42113 .7164 .43968 .68167 .43036 .63512 Metetra
.743 .564 .652 r
.43036 .63512 .43968 .68167 .45819 .63947 .44875 .5983 Metetra
.746 .573 .661 r
.44875 .5983 .45819 .63947 .47645 .5971 .46687 .56502 Metetra
.741 .59 .687 r
.46687 .56502 .47645 .5971 .49436 .56263 .4847 .54054 Metetra
.725 .623 .744 r
.4847 .54054 .49436 .56263 .51204 .54033 .50239 .52599 Metetra
.69 .679 .834 r
.50239 .52599 .51204 .54033 .52967 .52871 .52008 .51842 Metetra
.659 .735 .906 r
.52008 .51842 .52967 .52871 .54738 .52321 .53787 .51315 Metetra
.658 .741 .911 r
.53787 .51315 .54738 .52321 .56522 .51796 .55578 .50786 Metetra
.667 .745 .908 r
.55578 .50786 .56522 .51796 .58317 .51245 .57381 .5021 Metetra
.667 .741 .905 r
.57381 .5021 .58317 .51245 .60123 .50656 .59195 .49633 Metetra
.664 .744 .909 r
.59195 .49633 .60123 .50656 .61941 .50089 .61021 .49066 Metetra
.664 .745 .91 r
.61021 .49066 .61941 .50089 .63771 .49546 .62859 .48493 Metetra
.664 .74 .907 r
.62859 .48493 .63771 .49546 .65614 .48993 .64709 .47916 Metetra
.663 .736 .905 r
.64709 .47916 .65614 .48993 .67468 .48412 .66572 .47345 Metetra
.663 .74 .907 r
.66572 .47345 .67468 .48412 .69333 .4782 .68447 .4677 Metetra
.663 .744 .911 r
.68447 .4677 .69333 .4782 .71212 .47253 .70335 .46189 Metetra
.66 .742 .911 r
.70335 .46189 .71212 .47253 .73106 .46708 .72236 .45617 Metetra
.66 .738 .908 r
.72236 .45617 .73106 .46708 .7501 .46123 .7415 .45045 Metetra
.669 .745 .908 r
.7415 .45045 .7501 .46123 .76925 .45513 .76074 .44424 Metetra
.668 .744 .907 r
.76074 .44424 .76925 .45513 .78856 .44928 .78011 .43801 Metetra
.619 .719 .917 r
.78011 .43801 .78856 .44928 .80854 .44969 .79981 .43412 Metetra
.48 .578 .876 r
.79981 .43412 .80854 .44969 .82975 .46114 .82033 .43744 Metetra
.352 .413 .785 r
.82033 .43744 .82975 .46114 .85258 .48527 .8421 .45106 Metetra
.317 .33 .716 r
.8421 .45106 .85258 .48527 .87682 .51786 .86522 .47395 Metetra
.349 .321 .686 r
.86522 .47395 .87682 .51786 .90171 .5506 .88928 .50075 Metetra
.408 .347 .677 r
.88928 .50075 .90171 .5506 .92637 .57583 .9136 .52473 Metetra
.471 .387 .68 r
.9136 .52473 .92637 .57583 .95024 .59031 .93753 .54116 Metetra
.532 .431 .685 r
.93753 .54116 .95024 .59031 .97325 .59498 .96073 .54838 Metetra
.625 .473 .656 r
.34913 .66619 .35763 .72203 .37535 .71301 .36671 .65703 Metetra
.66 .497 .653 r
.36671 .65703 .37535 .71301 .39347 .69543 .38469 .63996 Metetra
.686 .515 .65 r
.38469 .63996 .39347 .69543 .41186 .66898 .4029 .61612 Metetra
.704 .53 .65 r
.4029 .61612 .41186 .66898 .43036 .63512 .42115 .5882 Metetra
.714 .544 .658 r
.42115 .5882 .43036 .63512 .44875 .5983 .43929 .5605 Metetra
.717 .562 .677 r
.43929 .5605 .44875 .5983 .46687 .56502 .4572 .53769 Metetra
.71 .589 .719 r
.4572 .53769 .46687 .56502 .4847 .54054 .47494 .52239 Metetra
.689 .637 .793 r
.47494 .52239 .4847 .54054 .50239 .52599 .49263 .51376 Metetra
.663 .703 .877 r
.49263 .51376 .50239 .52599 .52008 .51842 .51038 .50821 Metetra
.66 .74 .909 r
.51038 .50821 .52008 .51842 .53787 .51315 .52825 .50281 Metetra
.665 .74 .906 r
.52825 .50281 .53787 .51315 .55578 .50786 .54623 .49714 Metetra
.659 .732 .903 r
.54623 .49714 .55578 .50786 .57381 .5021 .56434 .4917 Metetra
.668 .743 .906 r
.56434 .4917 .57381 .5021 .59195 .49633 .58255 .48579 Metetra
.664 .74 .906 r
.58255 .48579 .59195 .49633 .61021 .49066 .6009 .48003 Metetra
.662 .739 .907 r
.6009 .48003 .61021 .49066 .62859 .48493 .61936 .47435 Metetra
.66 .74 .909 r
.61936 .47435 .62859 .48493 .64709 .47916 .63795 .46873 Metetra
.667 .747 .91 r
.63795 .46873 .64709 .47916 .66572 .47345 .65666 .46272 Metetra
.665 .742 .908 r
.65666 .46272 .66572 .47345 .68447 .4677 .67549 .45679 Metetra
.663 .739 .907 r
.67549 .45679 .68447 .4677 .70335 .46189 .69445 .45092 Metetra
.659 .738 .908 r
.69445 .45092 .70335 .46189 .72236 .45617 .71355 .44521 Metetra
.668 .743 .906 r
.71355 .44521 .72236 .45617 .7415 .45045 .73276 .43901 Metetra
.662 .733 .902 r
.73276 .43901 .7415 .45045 .76074 .44424 .75211 .43304 Metetra
.667 .741 .905 r
.75211 .43304 .76074 .44424 .78011 .43801 .77158 .42681 Metetra
.663 .741 .908 r
.77158 .42681 .78011 .43801 .79981 .43412 .7912 .42071 Metetra
.603 .676 .893 r
.7912 .42071 .79981 .43412 .82033 .43744 .81123 .41777 Metetra
.495 .538 .83 r
.81123 .41777 .82033 .43744 .8421 .45106 .83209 .42174 Metetra
.429 .426 .754 r
.83209 .42174 .8421 .45106 .86522 .47395 .85402 .43355 Metetra
.426 .38 .704 r
.85402 .43355 .86522 .47395 .88928 .50075 .87689 .45057 Metetra
.457 .377 .678 r
.87689 .45057 .88928 .50075 .9136 .52473 .90025 .468 Metetra
.499 .395 .667 r
.90025 .468 .9136 .52473 .93753 .54116 .92359 .48132 Metetra
.542 .419 .662 r
.92359 .48132 .93753 .54116 .96073 .54838 .94645 .48765 Metetra
.618 .465 .651 r
.3409 .60841 .34913 .66619 .36671 .65703 .35828 .60009 Metetra
.645 .484 .651 r
.35828 .60009 .36671 .65703 .38469 .63996 .37599 .58614 Metetra
.665 .502 .654 r
.37599 .58614 .38469 .63996 .4029 .61612 .39387 .56828 Metetra
.68 .52 .662 r
.39387 .56828 .4029 .61612 .42115 .5882 .41179 .54904 Metetra
.691 .542 .68 r
.41179 .54904 .42115 .5882 .43929 .5605 .42962 .53136 Metetra
.694 .573 .716 r
.42962 .53136 .43929 .5605 .4572 .53769 .44735 .51774 Metetra
.682 .62 .78 r
.44735 .51774 .4572 .53769 .47494 .52239 .46502 .50917 Metetra
.659 .687 .865 r
.46502 .50917 .47494 .52239 .49263 .51376 .48273 .50371 Metetra
.664 .745 .911 r
.48273 .50371 .49263 .51376 .51038 .50821 .50056 .49811 Metetra
.665 .746 .91 r
.50056 .49811 .51038 .50821 .52825 .50281 .5185 .49238 Metetra
.649 .736 .913 r
.5185 .49238 .52825 .50281 .54623 .49714 .53657 .48741 Metetra
.664 .756 .919 r
.53657 .48741 .54623 .49714 .56434 .4917 .55475 .48168 Metetra
.677 .755 .91 r
.55475 .48168 .56434 .4917 .58255 .48579 .57305 .47527 Metetra
.664 .742 .909 r
.57305 .47527 .58255 .48579 .6009 .48003 .59147 .46948 Metetra
.663 .743 .91 r
.59147 .46948 .6009 .48003 .61936 .47435 .61002 .46367 Metetra
.658 .74 .911 r
.61002 .46367 .61936 .47435 .63795 .46873 .6287 .4581 Metetra
.669 .746 .908 r
.6287 .4581 .63795 .46873 .65666 .46272 .64748 .45191 Metetra
.664 .742 .909 r
.64748 .45191 .65666 .46272 .67549 .45679 .6664 .44594 Metetra
.663 .743 .909 r
.6664 .44594 .67549 .45679 .69445 .45092 .68545 .43997 Metetra
.65 .738 .913 r
.68545 .43997 .69445 .45092 .71355 .44521 .70467 .43461 Metetra
.663 .751 .916 r
.70467 .43461 .71355 .44521 .73276 .43901 .72398 .42857 Metetra
.677 .761 .914 r
.72398 .42857 .73276 .43901 .75211 .43304 .74338 .42175 Metetra
.662 .74 .908 r
.74338 .42175 .75211 .43304 .77158 .42681 .76296 .4157 Metetra
.663 .745 .911 r
.76296 .4157 .77158 .42681 .7912 .42071 .78267 .40951 Metetra
.666 .746 .91 r
.78267 .40951 .7912 .42071 .81123 .41777 .8025 .40317 Metetra
.607 .663 .879 r
.8025 .40317 .81123 .41777 .83209 .42174 .82277 .40004 Metetra
.534 .542 .81 r
.82277 .40004 .83209 .42174 .85402 .43355 .84375 .40214 Metetra
.505 .463 .744 r
.84375 .40214 .85402 .43355 .87689 .45057 .86542 .40851 Metetra
.511 .43 .701 r
.86542 .40851 .87689 .45057 .90025 .468 .88761 .41659 Metetra
.532 .424 .676 r
.88761 .41659 .90025 .468 .92359 .48132 .90997 .42332 Metetra
.559 .431 .662 r
.90997 .42332 .92359 .48132 .94645 .48765 .93217 .42602 Metetra
.621 .482 .672 r
.3322 .56212 .3409 .60841 .35828 .60009 .34942 .55495 Metetra
.64 .497 .673 r
.34942 .55495 .35828 .60009 .37599 .58614 .36686 .54481 Metetra
.653 .514 .681 r
.36686 .54481 .37599 .58614 .39387 .56828 .38443 .53326 Metetra
.664 .536 .699 r
.38443 .53326 .39387 .56828 .41179 .54904 .40203 .52194 Metetra
.672 .571 .733 r
.40203 .52194 .41179 .54904 .42962 .53136 .41965 .51205 Metetra
.674 .622 .789 r
.41965 .51205 .42962 .53136 .44735 .51774 .43727 .50437 Metetra
.657 .685 .865 r
.43727 .50437 .44735 .51774 .46502 .50917 .45493 .49897 Metetra
.66 .742 .911 r
.45493 .49897 .46502 .50917 .48273 .50371 .47272 .49351 Metetra
.661 .744 .911 r
.47272 .49351 .48273 .50371 .50056 .49811 .49062 .48794 Metetra
.669 .748 .91 r
.49062 .48794 .50056 .49811 .5185 .49238 .50864 .48196 Metetra
.65 .739 .914 r
.50864 .48196 .5185 .49238 .53657 .48741 .52678 .47683 Metetra
.671 .743 .905 r
.52678 .47683 .53657 .48741 .55475 .48168 .54504 .4707 Metetra
.666 .736 .902 r
.54504 .4707 .55475 .48168 .57305 .47527 .56343 .46474 Metetra
.659 .743 .913 r
.56343 .46474 .57305 .47527 .59147 .46948 .58194 .45911 Metetra
.675 .753 .91 r
.58194 .45911 .59147 .46948 .61002 .46367 .60055 .45264 Metetra
.656 .735 .908 r
.60055 .45264 .61002 .46367 .6287 .4581 .61932 .4471 Metetra
.671 .742 .904 r
.61932 .4471 .6287 .4581 .64748 .45191 .63819 .44073 Metetra
.652 .734 .909 r
.63819 .44073 .64748 .45191 .6664 .44594 .65722 .43529 Metetra
.668 .751 .913 r
.65722 .43529 .6664 .44594 .68545 .43997 .67635 .429 Metetra
.661 .744 .912 r
.67635 .429 .68545 .43997 .70467 .43461 .69562 .42304 Metetra
.657 .732 .905 r
.69562 .42304 .70467 .43461 .72398 .42857 .71505 .41726 Metetra
.675 .745 .904 r
.71505 .41726 .72398 .42857 .74338 .42175 .73454 .41046 Metetra
.658 .741 .911 r
.73454 .41046 .74338 .42175 .76296 .4157 .75423 .40451 Metetra
.665 .747 .911 r
.75423 .40451 .76296 .4157 .78267 .40951 .77403 .39814 Metetra
.667 .746 .909 r
.77403 .39814 .78267 .40951 .8025 .40317 .79396 .39166 Metetra
.667 .745 .908 r
.79396 .39166 .8025 .40317 .82277 .40004 .81402 .3851 Metetra
.624 .67 .873 r
.81402 .3851 .82277 .40004 .84375 .40214 .83445 .38089 Metetra
.59 .58 .81 r
.83445 .38089 .84375 .40214 .86542 .40851 .85529 .37899 Metetra
.574 .515 .751 r
.85529 .37899 .86542 .40851 .88761 .41659 .87651 .3786 Metetra
.573 .481 .712 r
.87651 .3786 .88761 .41659 .90997 .42332 .89799 .37847 Metetra
.583 .469 .689 r
.89799 .37847 .90997 .42332 .93217 .42602 .91954 .37691 Metetra
.637 .541 .729 r
.32257 .53305 .3322 .56212 .34942 .55495 .33971 .52675 Metetra
.649 .552 .732 r
.33971 .52675 .34942 .55495 .36686 .54481 .35701 .51933 Metetra
.653 .569 .747 r
.35701 .51933 .36686 .54481 .38443 .53326 .37439 .51202 Metetra
.656 .598 .778 r
.37439 .51202 .38443 .53326 .40203 .52194 .39184 .50547 Metetra
.658 .644 .825 r
.39184 .50547 .40203 .52194 .41965 .51205 .40936 .49966 Metetra
.663 .703 .877 r
.40936 .49966 .41965 .51205 .43727 .50437 .42699 .49401 Metetra
.659 .74 .91 r
.42699 .49401 .43727 .50437 .45493 .49897 .44472 .48855 Metetra
.658 .74 .91 r
.44472 .48855 .45493 .49897 .47272 .49351 .46258 .48312 Metetra
.666 .744 .908 r
.46258 .48312 .47272 .49351 .49062 .48794 .48056 .47726 Metetra
.67 .741 .904 r
.48056 .47726 .49062 .48794 .50864 .48196 .49866 .47118 Metetra
.66 .737 .907 r
.49866 .47118 .50864 .48196 .52678 .47683 .51688 .46556 Metetra
.664 .731 .899 r
.51688 .46556 .52678 .47683 .54504 .4707 .53522 .45966 Metetra
.65 .732 .909 r
.53522 .45966 .54504 .4707 .56343 .46474 .55369 .45441 Metetra
.665 .752 .915 r
.55369 .45441 .56343 .46474 .58194 .45911 .57228 .4484 Metetra
.679 .75 .905 r
.57228 .4484 .58194 .45911 .60055 .45264 .59098 .44166 Metetra
.655 .739 .911 r
.59098 .44166 .60055 .45264 .61932 .4471 .60982 .43608 Metetra
.672 .745 .905 r
.60982 .43608 .61932 .4471 .63819 .44073 .62878 .4296 Metetra
.648 .736 .914 r
.62878 .4296 .63819 .44073 .65722 .43529 .6479 .42428 Metetra
.662 .745 .912 r
.6479 .42428 .65722 .43529 .67635 .429 .66714 .41823 Metetra
.676 .756 .911 r
.66714 .41823 .67635 .429 .69562 .42304 .68647 .4114 Metetra
.663 .736 .904 r
.68647 .4114 .69562 .42304 .71505 .41726 .70596 .40523 Metetra
.667 .732 .898 r
.70596 .40523 .71505 .41726 .73454 .41046 .72558 .39878 Metetra
.657 .736 .908 r
.72558 .39878 .73454 .41046 .75423 .40451 .74536 .39279 Metetra
.661 .738 .907 r
.74536 .39279 .75423 .40451 .77403 .39814 .76527 .38656 Metetra
.669 .745 .908 r
.76527 .38656 .77403 .39814 .79396 .39166 .78529 .37989 Metetra
.667 .743 .907 r
.78529 .37989 .79396 .39166 .81402 .3851 .80545 .37324 Metetra
.663 .741 .908 r
.80545 .37324 .81402 .3851 .83445 .38089 .82577 .36678 Metetra
.658 .701 .879 r
.82577 .36678 .83445 .38089 .85529 .37899 .84626 .36049 Metetra
.64 .636 .83 r
.84626 .36049 .85529 .37899 .87651 .3786 .86698 .35495 Metetra
.623 .581 .786 r
.86698 .35495 .87651 .3786 .89799 .37847 .88796 .35021 Metetra
.616 .548 .755 r
.88796 .35021 .89799 .37847 .91954 .37691 .90913 .34558 Metetra
.662 .656 .833 r
.31207 .51753 .32257 .53305 .33971 .52675 .32923 .5116 Metetra
.645 .655 .845 r
.32923 .5116 .33971 .52675 .35701 .51933 .34643 .50679 Metetra
.66 .699 .875 r
.34643 .50679 .35701 .51933 .37439 .51202 .36379 .50129 Metetra
.676 .736 .896 r
.36379 .50129 .37439 .51202 .39184 .50547 .38129 .49506 Metetra
.662 .74 .908 r
.38129 .49506 .39184 .50547 .40936 .49966 .39887 .48947 Metetra
.665 .746 .911 r
.39887 .48947 .40936 .49966 .42699 .49401 .41657 .48369 Metetra
.665 .745 .91 r
.41657 .48369 .42699 .49401 .44472 .48855 .43439 .47791 Metetra
.662 .739 .907 r
.43439 .47791 .44472 .48855 .46258 .48312 .45232 .47222 Metetra
.667 .737 .903 r
.45232 .47222 .46258 .48312 .48056 .47726 .47038 .46627 Metetra
.665 .736 .903 r
.47038 .46627 .48056 .47726 .49866 .47118 .48856 .46037 Metetra
.661 .74 .908 r
.48856 .46037 .49866 .47118 .51688 .46556 .50685 .45459 Metetra
.658 .737 .908 r
.50685 .45459 .51688 .46556 .53522 .45966 .52527 .44895 Metetra
.659 .744 .913 r
.52527 .44895 .53522 .45966 .55369 .45441 .54382 .44322 Metetra
.669 .739 .903 r
.54382 .44322 .55369 .45441 .57228 .4484 .56249 .43695 Metetra
.665 .734 .901 r
.56249 .43695 .57228 .4484 .59098 .44166 .58128 .4308 Metetra
.656 .744 .915 r
.58128 .4308 .59098 .44166 .60982 .43608 .60022 .42509 Metetra
.671 .748 .908 r
.60022 .42509 .60982 .43608 .62878 .4296 .61926 .41859 Metetra
.661 .746 .913 r
.61926 .41859 .62878 .4296 .6479 .42428 .63845 .41252 Metetra
.658 .732 .904 r
.63845 .41252 .6479 .42428 .66714 .41823 .65778 .40658 Metetra
.668 .739 .903 r
.65778 .40658 .66714 .41823 .68647 .4114 .67722 .40009 Metetra
.669 .747 .909 r
.67722 .40009 .68647 .4114 .70596 .40523 .69679 .3935 Metetra
.666 .74 .905 r
.69679 .3935 .70596 .40523 .72558 .39878 .7165 .38705 Metetra
.663 .74 .907 r
.7165 .38705 .72558 .39878 .74536 .39279 .73637 .38071 Metetra
.661 .734 .904 r
.73637 .38071 .74536 .39279 .76527 .38656 .75637 .37444 Metetra
.665 .737 .903 r
.75637 .37444 .76527 .38656 .78529 .37989 .7765 .36787 Metetra
.663 .739 .907 r
.7765 .36787 .78529 .37989 .80545 .37324 .79679 .3614 Metetra
.662 .744 .911 r
.79679 .3614 .80545 .37324 .82577 .36678 .81722 .35493 Metetra
.665 .746 .911 r
.81722 .35493 .82577 .36678 .84626 .36049 .83778 .34824 Metetra
.651 .735 .911 r
.83778 .34824 .84626 .36049 .86698 .35495 .85856 .34222 Metetra
.665 .733 .901 r
.85856 .34222 .86698 .35495 .88796 .35021 .87942 .33542 Metetra
.674 .705 .871 r
.87942 .33542 .88796 .35021 .90913 .34558 .90035 .32789 Metetra
.671 .747 .907 r
.3011 .50751 .31207 .51753 .32923 .5116 .31833 .5016 Metetra
.665 .747 .911 r
.31833 .5016 .32923 .5116 .34643 .50679 .33564 .49594 Metetra
.666 .732 .899 r
.33564 .49594 .34643 .50679 .36379 .50129 .35307 .49017 Metetra
.657 .726 .9 r
.35307 .49017 .36379 .50129 .38129 .49506 .3706 .48481 Metetra
.661 .745 .912 r
.3706 .48481 .38129 .49506 .39887 .48947 .38825 .47919 Metetra
.672 .748 .908 r
.38825 .47919 .39887 .48947 .41657 .48369 .40604 .47302 Metetra
.648 .736 .913 r
.40604 .47302 .41657 .48369 .43439 .47791 .42391 .46794 Metetra
.663 .755 .918 r
.42391 .46794 .43439 .47791 .45232 .47222 .44192 .46209 Metetra
.675 .756 .912 r
.44192 .46209 .45232 .47222 .47038 .46627 .46007 .45563 Metetra
.666 .746 .91 r
.46007 .45563 .47038 .46627 .48856 .46037 .47833 .44958 Metetra
.664 .744 .909 r
.47833 .44958 .48856 .46037 .50685 .45459 .4967 .44358 Metetra
.664 .74 .907 r
.4967 .44358 .50685 .45459 .52527 .44895 .5152 .43757 Metetra
.662 .735 .903 r
.5152 .43757 .52527 .44895 .54382 .44322 .53383 .43158 Metetra
.662 .731 .901 r
.53383 .43158 .54382 .44322 .56249 .43695 .55258 .42557 Metetra
.66 .737 .907 r
.55258 .42557 .56249 .43695 .58128 .4308 .57146 .41965 Metetra
.661 .743 .911 r
.57146 .41965 .58128 .4308 .60022 .42509 .59048 .41361 Metetra
.666 .74 .905 r
.59048 .41361 .60022 .42509 .61926 .41859 .60962 .40728 Metetra
.667 .745 .908 r
.60962 .40728 .61926 .41859 .63845 .41252 .62889 .40083 Metetra
.665 .738 .905 r
.62889 .40083 .63845 .41252 .65778 .40658 .64829 .39447 Metetra
.664 .732 .9 r
.64829 .39447 .65778 .40658 .67722 .40009 .66783 .38808 Metetra
.663 .735 .903 r
.66783 .38808 .67722 .40009 .69679 .3935 .68751 .38171 Metetra
.663 .74 .908 r
.68751 .38171 .69679 .3935 .7165 .38705 .70732 .37533 Metetra
.661 .742 .91 r
.70732 .37533 .7165 .38705 .73637 .38071 .72729 .369 Metetra
.652 .74 .915 r
.72729 .369 .73637 .38071 .75637 .37444 .74742 .36307 Metetra
.663 .753 .917 r
.74742 .36307 .75637 .37444 .7765 .36787 .76767 .35652 Metetra
.678 .76 .913 r
.76767 .35652 .7765 .36787 .79679 .3614 .78799 .34917 Metetra
.655 .737 .91 r
.78799 .34917 .79679 .3614 .81722 .35493 .80856 .34294 Metetra
.665 .747 .911 r
.80856 .34294 .81722 .35493 .83778 .34824 .82922 .33613 Metetra
.67 .748 .909 r
.82922 .33613 .83778 .34824 .85856 .34222 .85001 .32905 Metetra
.661 .727 .898 r
.85001 .32905 .85856 .34222 .87942 .33542 .87099 .32237 Metetra
.663 .731 .901 r
.87099 .32237 .87942 .33542 .90035 .32789 .89212 .31557 Metetra
.67 .745 .907 r
.29 .49731 .3011 .50751 .31833 .5016 .30729 .49136 Metetra
.673 .747 .906 r
.30729 .49136 .31833 .5016 .33564 .49594 .3247 .48525 Metetra
.662 .737 .905 r
.3247 .48525 .33564 .49594 .35307 .49017 .34219 .47959 Metetra
.655 .738 .911 r
.34219 .47959 .35307 .49017 .3706 .48481 .35979 .47421 Metetra
.665 .742 .907 r
.35979 .47421 .3706 .48481 .38825 .47919 .37752 .46833 Metetra
.664 .738 .905 r
.37752 .46833 .38825 .47919 .40604 .47302 .39537 .46248 Metetra
.653 .742 .915 r
.39537 .46248 .40604 .47302 .42391 .46794 .41332 .4571 Metetra
.67 .743 .905 r
.41332 .4571 .42391 .46794 .44192 .46209 .43142 .45085 Metetra
.669 .736 .901 r
.43142 .45085 .44192 .46209 .46007 .45563 .44963 .44463 Metetra
.659 .739 .909 r
.44963 .44463 .46007 .45563 .47833 .44958 .46796 .43883 Metetra
.67 .749 .909 r
.46796 .43883 .47833 .44958 .4967 .44358 .48642 .43246 Metetra
.652 .738 .912 r
.48642 .43246 .4967 .44358 .5152 .43757 .505 .42693 Metetra
.663 .752 .916 r
.505 .42693 .5152 .43757 .53383 .43158 .52371 .42084 Metetra
.671 .754 .912 r
.52371 .42084 .53383 .43158 .55258 .42557 .54255 .41432 Metetra
.668 .744 .907 r
.54255 .41432 .55258 .42557 .57146 .41965 .56151 .4079 Metetra
.661 .734 .904 r
.56151 .4079 .57146 .41965 .59048 .41361 .58061 .40177 Metetra
.666 .736 .902 r
.58061 .40177 .59048 .41361 .60962 .40728 .59984 .39537 Metetra
.659 .733 .905 r
.59984 .39537 .60962 .40728 .62889 .40083 .61921 .38926 Metetra
.656 .74 .912 r
.61921 .38926 .62889 .40083 .64829 .39447 .63872 .38326 Metetra
.664 .751 .915 r
.63872 .38326 .64829 .39447 .66783 .38808 .65836 .37682 Metetra
.674 .755 .912 r
.65836 .37682 .66783 .38808 .68751 .38171 .6781 .3698 Metetra
.657 .739 .91 r
.6781 .3698 .68751 .38171 .70732 .37533 .69803 .36364 Metetra
.667 .748 .911 r
.69803 .36364 .70732 .37533 .72729 .369 .71807 .35689 Metetra
.658 .738 .909 r
.71807 .35689 .72729 .369 .74742 .36307 .73829 .35056 Metetra
.657 .732 .905 r
.73829 .35056 .74742 .36307 .76767 .35652 .75865 .34426 Metetra
.673 .744 .904 r
.75865 .34426 .76767 .35652 .78799 .34917 .7791 .33706 Metetra
.663 .745 .911 r
.7791 .33706 .78799 .34917 .80856 .34294 .79973 .33033 Metetra
.662 .737 .906 r
.79973 .33033 .80856 .34294 .82922 .33613 .82052 .32363 Metetra
.671 .744 .906 r
.82052 .32363 .82922 .33613 .85001 .32905 .84141 .3164 Metetra
.665 .741 .907 r
.84141 .3164 .85001 .32905 .87099 .32237 .86249 .30945 Metetra
.655 .734 .907 r
.86249 .30945 .87099 .32237 .89212 .31557 .88377 .30296 Metetra
.659 .728 .9 r
.27883 .48621 .29 .49731 .30729 .49136 .29615 .48072 Metetra
.658 .737 .909 r
.29615 .48072 .30729 .49136 .3247 .48525 .31358 .47524 Metetra
.668 .753 .914 r
.31358 .47524 .3247 .48525 .34219 .47959 .33116 .46925 Metetra
.67 .749 .91 r
.33116 .46925 .34219 .47959 .35979 .47421 .34886 .46313 Metetra
.661 .734 .904 r
.34886 .46313 .35979 .47421 .37752 .46833 .36666 .45737 Metetra
.665 .739 .905 r
.36666 .45737 .37752 .46833 .39537 .46248 .38458 .45138 Metetra
.662 .737 .905 r
.38458 .45138 .39537 .46248 .41332 .4571 .40262 .44549 Metetra
.659 .728 .9 r
.40262 .44549 .41332 .4571 .43142 .45085 .42078 .43969 Metetra
.653 .736 .91 r
.42078 .43969 .43142 .45085 .44963 .44463 .43905 .43418 Metetra
.668 .755 .915 r
.43905 .43418 .44963 .44463 .46796 .43883 .45747 .4279 Metetra
.674 .749 .907 r
.45747 .4279 .46796 .43883 .48642 .43246 .47602 .42127 Metetra
.653 .739 .913 r
.47602 .42127 .48642 .43246 .505 .42693 .49467 .41564 Metetra
.668 .743 .907 r
.49467 .41564 .505 .42693 .52371 .42084 .51347 .40923 Metetra
.669 .739 .903 r
.51347 .40923 .52371 .42084 .54255 .41432 .53239 .40272 Metetra
.654 .736 .91 r
.53239 .40272 .54255 .41432 .56151 .4079 .55145 .3969 Metetra
.66 .751 .917 r
.55145 .3969 .56151 .4079 .58061 .40177 .57064 .39072 Metetra
.666 .753 .915 r
.57064 .39072 .58061 .40177 .59984 .39537 .58996 .38421 Metetra
.673 .755 .912 r
.58996 .38421 .59984 .39537 .61921 .38926 .6094 .37734 Metetra
.658 .737 .908 r
.6094 .37734 .61921 .38926 .63872 .38326 .629 .37116 Metetra
.659 .736 .906 r
.629 .37116 .63872 .38326 .65836 .37682 .64874 .36488 Metetra
.674 .745 .905 r
.64874 .36488 .65836 .37682 .6781 .3698 .66858 .35781 Metetra
.653 .738 .912 r
.66858 .35781 .6781 .3698 .69803 .36364 .68862 .35174 Metetra
.659 .744 .913 r
.68862 .35174 .69803 .36364 .71807 .35689 .70878 .34532 Metetra
.674 .757 .914 r
.70878 .34532 .71807 .35689 .73829 .35056 .72905 .33811 Metetra
.667 .74 .905 r
.72905 .33811 .73829 .35056 .75865 .34426 .74947 .33118 Metetra
.664 .73 .898 r
.74947 .33118 .75865 .34426 .7791 .33706 .77006 .32434 Metetra
.662 .736 .905 r
.77006 .32434 .7791 .33706 .79973 .33033 .7908 .31759 Metetra
.666 .739 .905 r
.7908 .31759 .79973 .33033 .82052 .32363 .81167 .3106 Metetra
.658 .732 .905 r
.81167 .3106 .82052 .32363 .84141 .3164 .83274 .30397 Metetra
.66 .746 .914 r
.83274 .30397 .84141 .3164 .86249 .30945 .85395 .29719 Metetra
.669 .754 .915 r
.85395 .29719 .86249 .30945 .88377 .30296 .87527 .28987 Metetra
.66 .746 .913 r
.26744 .47592 .27883 .48621 .29615 .48072 .28484 .47029 Metetra
.66 .745 .913 r
.28484 .47029 .29615 .48072 .31358 .47524 .30235 .46462 Metetra
.668 .745 .907 r
.30235 .46462 .31358 .47524 .33116 .46925 .32 .45853 Metetra
.673 .745 .905 r
.32 .45853 .33116 .46925 .34886 .46313 .33779 .45218 Metetra
.66 .739 .908 r
.33779 .45218 .34886 .46313 .36666 .45737 .35565 .44641 Metetra
.666 .741 .907 r
.35565 .44641 .36666 .45737 .38458 .45138 .37365 .44033 Metetra
.662 .74 .908 r
.37365 .44033 .38458 .45138 .40262 .44549 .39176 .4344 Metetra
.655 .739 .911 r
.39176 .4344 .40262 .44549 .42078 .43969 .40999 .42876 Metetra
.659 .744 .913 r
.40999 .42876 .42078 .43969 .43905 .43418 .42835 .42287 Metetra
.672 .742 .903 r
.42835 .42287 .43905 .43418 .45747 .4279 .44685 .41632 Metetra
.667 .737 .903 r
.44685 .41632 .45747 .4279 .47602 .42127 .46548 .40995 Metetra
.662 .742 .91 r
.46548 .40995 .47602 .42127 .49467 .41564 .48422 .4038 Metetra
.666 .735 .902 r
.48422 .4038 .49467 .41564 .51347 .40923 .5031 .39741 Metetra
.657 .734 .907 r
.5031 .39741 .51347 .40923 .53239 .40272 .5221 .39144 Metetra
.665 .748 .912 r
.5221 .39144 .53239 .40272 .55145 .3969 .54124 .385 Metetra
.666 .739 .904 r
.54124 .385 .55145 .3969 .57064 .39072 .56052 .37847 Metetra
.661 .732 .902 r
.56052 .37847 .57064 .39072 .58996 .38421 .57993 .37215 Metetra
.662 .737 .906 r
.57993 .37215 .58996 .38421 .6094 .37734 .59947 .36573 Metetra
.67 .75 .91 r
.59947 .36573 .6094 .37734 .629 .37116 .61915 .35884 Metetra
.661 .735 .905 r
.61915 .35884 .629 .37116 .64874 .36488 .63897 .35238 Metetra
.665 .735 .902 r
.63897 .35238 .64874 .36488 .66858 .35781 .65893 .34567 Metetra
.66 .741 .91 r
.65893 .34567 .66858 .35781 .68862 .35174 .67905 .33917 Metetra
.656 .733 .907 r
.67905 .33917 .68862 .35174 .70878 .34532 .69932 .33286 Metetra
.667 .741 .905 r
.69932 .33286 .70878 .34532 .72905 .33811 .71971 .32587 Metetra
.672 .749 .908 r
.71971 .32587 .72905 .33811 .74947 .33118 .74022 .31861 Metetra
.665 .742 .907 r
.74022 .31861 .74947 .33118 .77006 .32434 .76091 .31164 Metetra
.661 .74 .908 r
.76091 .31164 .77006 .32434 .7908 .31759 .78176 .30482 Metetra
.667 .742 .907 r
.78176 .30482 .7908 .31759 .81167 .3106 .80273 .29767 Metetra
.655 .736 .909 r
.80273 .29767 .81167 .3106 .83274 .30397 .82392 .29111 Metetra
.659 .741 .91 r
.82392 .29111 .83274 .30397 .85395 .29719 .84525 .28427 Metetra
.667 .745 .909 r
.84525 .28427 .85395 .29719 .87527 .28987 .8667 .27698 Metetra
.667 .741 .906 r
.25595 .46516 .26744 .47592 .28484 .47029 .27343 .45915 Metetra
.666 .735 .902 r
.27343 .45915 .28484 .47029 .30235 .46462 .29103 .45313 Metetra
.664 .73 .899 r
.29103 .45313 .30235 .46462 .32 .45853 .30874 .44717 Metetra
.66 .732 .903 r
.30874 .44717 .32 .45853 .33779 .45218 .32656 .44138 Metetra
.665 .745 .91 r
.32656 .44138 .33779 .45218 .35565 .44641 .34451 .43529 Metetra
.663 .74 .907 r
.34451 .43529 .35565 .44641 .37365 .44033 .36258 .42925 Metetra
.663 .742 .909 r
.36258 .42925 .37365 .44033 .39176 .4344 .38077 .4232 Metetra
.667 .743 .907 r
.38077 .4232 .39176 .4344 .40999 .42876 .3991 .41689 Metetra
.663 .731 .9 r
.3991 .41689 .40999 .42876 .42835 .42287 .41754 .41072 Metetra
.658 .726 .899 r
.41754 .41072 .42835 .42287 .44685 .41632 .4361 .40477 Metetra
.661 .739 .907 r
.4361 .40477 .44685 .41632 .46548 .40995 .4548 .39862 Metetra
.67 .747 .908 r
.4548 .39862 .46548 .40995 .48422 .4038 .47363 .39197 Metetra
.652 .734 .909 r
.47363 .39197 .48422 .4038 .5031 .39741 .49259 .38617 Metetra
.667 .751 .913 r
.49259 .38617 .5031 .39741 .5221 .39144 .51168 .37959 Metetra
.664 .74 .907 r
.51168 .37959 .5221 .39144 .54124 .385 .53091 .37313 Metetra
.653 .738 .911 r
.53091 .37313 .54124 .385 .56052 .37847 .55028 .36715 Metetra
.674 .756 .913 r
.55028 .36715 .56052 .37847 .57993 .37215 .56977 .36012 Metetra
.663 .741 .908 r
.56977 .36012 .57993 .37215 .59947 .36573 .58941 .35355 Metetra
.66 .739 .908 r
.58941 .35355 .59947 .36573 .61915 .35884 .60919 .34711 Metetra
.675 .754 .91 r
.60919 .34711 .61915 .35884 .63897 .35238 .62909 .33987 Metetra
.657 .735 .907 r
.62909 .33987 .63897 .35238 .65893 .34567 .64917 .3335 Metetra
.666 .746 .91 r
.64917 .3335 .65893 .34567 .67905 .33917 .66936 .32661 Metetra
.669 .741 .905 r
.66936 .32661 .67905 .33917 .69932 .33286 .6897 .31952 Metetra
.663 .727 .897 r
.6897 .31952 .69932 .33286 .71971 .32587 .71019 .31264 Metetra
.66 .73 .901 r
.71019 .31264 .71971 .32587 .74022 .31861 .73085 .3059 Metetra
.665 .742 .908 r
.73085 .3059 .74022 .31861 .76091 .31164 .75164 .29888 Metetra
.664 .743 .909 r
.75164 .29888 .76091 .31164 .78176 .30482 .77259 .29185 Metetra
.662 .74 .908 r
.77259 .29185 .78176 .30482 .80273 .29767 .7937 .28485 Metetra
.667 .746 .91 r
.7937 .28485 .80273 .29767 .82392 .29111 .81494 .27755 Metetra
.663 .733 .902 r
.81494 .27755 .82392 .29111 .84525 .28427 .83635 .2704 Metetra
.661 .729 .9 r
.83635 .2704 .84525 .28427 .8667 .27698 .85794 .2633 Metetra
.667 .752 .913 r
.24426 .45482 .25595 .46516 .27343 .45915 .26182 .44873 Metetra
.669 .752 .912 r
.26182 .44873 .27343 .45915 .29103 .45313 .2795 .44249 Metetra
.665 .748 .912 r
.2795 .44249 .29103 .45313 .30874 .44717 .29729 .43642 Metetra
.664 .747 .912 r
.29729 .43642 .30874 .44717 .32656 .44138 .31519 .43037 Metetra
.669 .745 .908 r
.31519 .43037 .32656 .44138 .34451 .43529 .33323 .42404 Metetra
.659 .739 .909 r
.33323 .42404 .34451 .43529 .36258 .42925 .35136 .41814 Metetra
.66 .744 .912 r
.35136 .41814 .36258 .42925 .38077 .4232 .36963 .41213 Metetra
.665 .747 .911 r
.36963 .41213 .38077 .4232 .3991 .41689 .38803 .40584 Metetra
.663 .748 .914 r
.38803 .40584 .3991 .41689 .41754 .41072 .40655 .39963 Metetra
.659 .748 .916 r
.40655 .39963 .41754 .41072 .4361 .40477 .4252 .39354 Metetra
.666 .749 .912 r
.4252 .39354 .4361 .40477 .4548 .39862 .44398 .38706 Metetra
.671 .746 .907 r
.44398 .38706 .4548 .39862 .47363 .39197 .4629 .38032 Metetra
.652 .74 .914 r
.4629 .38032 .47363 .39197 .49259 .38617 .48194 .37447 Metetra
.673 .747 .906 r
.48194 .37447 .49259 .38617 .51168 .37959 .50113 .36753 Metetra
.651 .735 .911 r
.50113 .36753 .51168 .37959 .53091 .37313 .52044 .36162 Metetra
.649 .746 .92 r
.52044 .36162 .53091 .37313 .55028 .36715 .5399 .35573 Metetra
.677 .758 .912 r
.5399 .35573 .55028 .36715 .56977 .36012 .55949 .34843 Metetra
.676 .755 .91 r
.55949 .34843 .56977 .36012 .58941 .35355 .57921 .34115 Metetra
.654 .736 .909 r
.57921 .34115 .58941 .35355 .60919 .34711 .59909 .3349 Metetra
.675 .748 .906 r
.59909 .3349 .60919 .34711 .62909 .33987 .61909 .32755 Metetra
.657 .741 .912 r
.61909 .32755 .62909 .33987 .64917 .3335 .63926 .32109 Metetra
.661 .743 .911 r
.63926 .32109 .64917 .3335 .66936 .32661 .65957 .31437 Metetra
.668 .75 .912 r
.65957 .31437 .66936 .32661 .6897 .31952 .68001 .30724 Metetra
.665 .75 .914 r
.68001 .30724 .6897 .31952 .71019 .31264 .70061 .30023 Metetra
.662 .748 .914 r
.70061 .30023 .71019 .31264 .73085 .3059 .72137 .2933 Metetra
.667 .748 .911 r
.72137 .2933 .73085 .3059 .75164 .29888 .74226 .28607 Metetra
.668 .746 .909 r
.74226 .28607 .75164 .29888 .77259 .29185 .7633 .27871 Metetra
.659 .739 .909 r
.7633 .27871 .77259 .29185 .7937 .28485 .78453 .27179 Metetra
.664 .744 .91 r
.78453 .27179 .7937 .28485 .81494 .27755 .8059 .26458 Metetra
.662 .746 .913 r
.8059 .26458 .81494 .27755 .83635 .2704 .82744 .25738 Metetra
.658 .746 .914 r
.82744 .25738 .83635 .2704 .85794 .2633 .84916 .25033 Metetra
.666 .733 .9 r
.23252 .44335 .24426 .45482 .26182 .44873 .25014 .43719 Metetra
.666 .733 .9 r
.25014 .43719 .26182 .44873 .2795 .44249 .26788 .43102 Metetra
.664 .735 .903 r
.26788 .43102 .2795 .44249 .29729 .43642 .28574 .42492 Metetra
.66 .735 .905 r
.28574 .42492 .29729 .43642 .31519 .43037 .3037 .41897 Metetra
.665 .739 .906 r
.3037 .41897 .31519 .43037 .33323 .42404 .3218 .41273 Metetra
.663 .742 .909 r
.3218 .41273 .33323 .42404 .35136 .41814 .34002 .40653 Metetra
.662 .738 .906 r
.34002 .40653 .35136 .41814 .36963 .41213 .35837 .40033 Metetra
.667 .737 .902 r
.35837 .40033 .36963 .41213 .38803 .40584 .37685 .39386 Metetra
.663 .734 .903 r
.37685 .39386 .38803 .40584 .40655 .39963 .39545 .38753 Metetra
.658 .732 .904 r
.39545 .38753 .40655 .39963 .4252 .39354 .41417 .38142 Metetra
.661 .734 .904 r
.41417 .38142 .4252 .39354 .44398 .38706 .43303 .37511 Metetra
.67 .741 .903 r
.43303 .37511 .44398 .38706 .4629 .38032 .45204 .36829 Metetra
.652 .735 .911 r
.45204 .36829 .4629 .38032 .48194 .37447 .47116 .36233 Metetra
.667 .74 .905 r
.47116 .36233 .48194 .37447 .50113 .36753 .49043 .35558 Metetra
.664 .744 .91 r
.49043 .35558 .50113 .36753 .52044 .36162 .50984 .34895 Metetra
.653 .729 .905 r
.50984 .34895 .52044 .36162 .5399 .35573 .52938 .3428 Metetra
.672 .733 .895 r
.52938 .3428 .5399 .35573 .55949 .34843 .54906 .33559 Metetra
.663 .732 .901 r
.54906 .33559 .55949 .34843 .57921 .34115 .56888 .32885 Metetra
.66 .742 .911 r
.56888 .32885 .57921 .34115 .59909 .3349 .58885 .32223 Metetra
.674 .743 .902 r
.58885 .32223 .59909 .3349 .61909 .32755 .60895 .31481 Metetra
.657 .737 .909 r
.60895 .31481 .61909 .32755 .63926 .32109 .62922 .30826 Metetra
.666 .74 .905 r
.62922 .30826 .63926 .32109 .65957 .31437 .64961 .30119 Metetra
.668 .737 .901 r
.64961 .30119 .65957 .31437 .68001 .30724 .67015 .29391 Metetra
.663 .734 .902 r
.67015 .29391 .68001 .30724 .70061 .30023 .69085 .28684 Metetra
.66 .733 .904 r
.69085 .28684 .70061 .30023 .72137 .2933 .71172 .27992 Metetra
.664 .736 .904 r
.71172 .27992 .72137 .2933 .74226 .28607 .73272 .27271 Metetra
.664 .738 .905 r
.73272 .27271 .74226 .28607 .7633 .27871 .75389 .26549 Metetra
.662 .742 .909 r
.75389 .26549 .7633 .27871 .78453 .27179 .77521 .25829 Metetra
.667 .74 .905 r
.77521 .25829 .78453 .27179 .8059 .26458 .79668 .25079 Metetra
.663 .736 .904 r
.79668 .25079 .8059 .26458 .82744 .25738 .81832 .24344 Metetra
.661 .734 .904 r
.81832 .24344 .82744 .25738 .84916 .25033 .84014 .23614 Metetra
.66 .741 .91 r
.22058 .43229 .23252 .44335 .25014 .43719 .23825 .42637 Metetra
.66 .747 .914 r
.23825 .42637 .25014 .43719 .26788 .43102 .25604 .42041 Metetra
.669 .755 .915 r
.25604 .42041 .26788 .43102 .28574 .42492 .27398 .41401 Metetra
.673 .752 .91 r
.27398 .41401 .28574 .42492 .3037 .41897 .29207 .40735 Metetra
.66 .737 .907 r
.29207 .40735 .3037 .41897 .3218 .41273 .31023 .40128 Metetra
.666 .743 .908 r
.31023 .40128 .3218 .41273 .34002 .40653 .32853 .39489 Metetra
.662 .74 .908 r
.32853 .39489 .34002 .40653 .35837 .40033 .34695 .38865 Metetra
.655 .738 .911 r
.34695 .38865 .35837 .40033 .37685 .39386 .36548 .3827 Metetra
.659 .751 .918 r
.36548 .3827 .37685 .39386 .39545 .38753 .38416 .37649 Metetra
.672 .758 .915 r
.38416 .37649 .39545 .38753 .41417 .38142 .40299 .36961 Metetra
.667 .744 .908 r
.40299 .36961 .41417 .38142 .43303 .37511 .42195 .36292 Metetra
.662 .737 .906 r
.42195 .36292 .43303 .37511 .45204 .36829 .44103 .35644 Metetra
.666 .746 .91 r
.44103 .35644 .45204 .36829 .47116 .36233 .46025 .34971 Metetra
.656 .731 .904 r
.46025 .34971 .47116 .36233 .49043 .35558 .47959 .34341 Metetra
.665 .743 .908 r
.47959 .34341 .49043 .35558 .50984 .34895 .49909 .33663 Metetra
.666 .742 .907 r
.49909 .33663 .50984 .34895 .52938 .3428 .51872 .32976 Metetra
.661 .73 .901 r
.51872 .32976 .52938 .3428 .54906 .33559 .5385 .32309 Metetra
.662 .741 .909 r
.5385 .32309 .54906 .33559 .56888 .32885 .55842 .31632 Metetra
.67 .745 .906 r
.55842 .31632 .56888 .32885 .58885 .32223 .57847 .30908 Metetra
.661 .732 .903 r
.57847 .30908 .58885 .32223 .60895 .31481 .59868 .30226 Metetra
.665 .746 .91 r
.59868 .30226 .60895 .31481 .62922 .30826 .61903 .29518 Metetra
.66 .736 .906 r
.61903 .29518 .62922 .30826 .64961 .30119 .63954 .28832 Metetra
.655 .74 .912 r
.63954 .28832 .64961 .30119 .67015 .29391 .66022 .28164 Metetra
.668 .757 .917 r
.66022 .28164 .67015 .29391 .69085 .28684 .68102 .27428 Metetra
.672 .755 .913 r
.68102 .27428 .69085 .28684 .71172 .27992 .70196 .26664 Metetra
.665 .742 .907 r
.70196 .26664 .71172 .27992 .73272 .27271 .72307 .25928 Metetra
.661 .739 .908 r
.72307 .25928 .73272 .27271 .75389 .26549 .74435 .25208 Metetra
.667 .744 .908 r
.74435 .25208 .75389 .26549 .77521 .25829 .76577 .24454 Metetra
.655 .734 .908 r
.76577 .24454 .77521 .25829 .79668 .25079 .7874 .23758 Metetra
.659 .747 .915 r
.7874 .23758 .79668 .25079 .81832 .24344 .80918 .23035 Metetra
.667 .755 .916 r
.80918 .23035 .81832 .24344 .84014 .23614 .83109 .22265 Metetra
.659 .735 .906 r
.20852 .42075 .22058 .43229 .23825 .42637 .22625 .41482 Metetra
.658 .736 .907 r
.22625 .41482 .23825 .42637 .25604 .42041 .2441 .4089 Metetra
.668 .74 .905 r
.2441 .4089 .25604 .42041 .27398 .41401 .26212 .40246 Metetra
.669 .742 .904 r
.26212 .40246 .27398 .41401 .29207 .40735 .28026 .39588 Metetra
.661 .742 .91 r
.28026 .39588 .29207 .40735 .31023 .40128 .2985 .38966 Metetra
.665 .742 .907 r
.2985 .38966 .31023 .40128 .32853 .39489 .31688 .3832 Metetra
.662 .742 .909 r
.31688 .3832 .32853 .39489 .34695 .38865 .33538 .37685 Metetra
.66 .74 .91 r
.33538 .37685 .34695 .38865 .36548 .3827 .35401 .37058 Metetra
.653 .734 .909 r
.35401 .37058 .36548 .3827 .38416 .37649 .37275 .3646 Metetra
.668 .744 .907 r
.37275 .3646 .38416 .37649 .40299 .36961 .39166 .35783 Metetra
.674 .749 .907 r
.39166 .35783 .40299 .36961 .42195 .36292 .41071 .3507 Metetra
.653 .737 .911 r
.41071 .3507 .42195 .36292 .44103 .35644 .42986 .34459 Metetra
.668 .749 .911 r
.42986 .34459 .44103 .35644 .46025 .34971 .44917 .33768 Metetra
.669 .748 .909 r
.44917 .33768 .46025 .34971 .47959 .34341 .46862 .33066 Metetra
.654 .732 .907 r
.46862 .33066 .47959 .34341 .49909 .33663 .4882 .32433 Metetra
.661 .744 .912 r
.4882 .32433 .49909 .33663 .51872 .32976 .50792 .31764 Metetra
.667 .751 .913 r
.50792 .31764 .51872 .32976 .5385 .32309 .52779 .31061 Metetra
.673 .748 .907 r
.52779 .31061 .5385 .32309 .55842 .31632 .5478 .30321 Metetra
.658 .733 .905 r
.5478 .30321 .55842 .31632 .57847 .30908 .56796 .2965 Metetra
.659 .745 .913 r
.56796 .2965 .57847 .30908 .59868 .30226 .58827 .28969 Metetra
.674 .752 .909 r
.58827 .28969 .59868 .30226 .61903 .29518 .60872 .28206 Metetra
.653 .736 .91 r
.60872 .28206 .61903 .29518 .63954 .28832 .62934 .27546 Metetra
.659 .745 .913 r
.62934 .27546 .63954 .28832 .66022 .28164 .65011 .26849 Metetra
.673 .747 .906 r
.65011 .26849 .66022 .28164 .68102 .27428 .671 .2607 Metetra
.667 .739 .904 r
.671 .2607 .68102 .27428 .70196 .26664 .69206 .2532 Metetra
.665 .742 .908 r
.69206 .2532 .70196 .26664 .72307 .25928 .71328 .24578 Metetra
.662 .741 .909 r
.71328 .24578 .72307 .25928 .74435 .25208 .73467 .23846 Metetra
.666 .743 .908 r
.73467 .23846 .74435 .25208 .76577 .24454 .75621 .23088 Metetra
.658 .741 .911 r
.75621 .23088 .76577 .24454 .7874 .23758 .77794 .22366 Metetra
.66 .738 .908 r
.77794 .22366 .7874 .23758 .80918 .23035 .79984 .21629 Metetra
.669 .742 .905 r
.79984 .21629 .80918 .23035 .83109 .22265 .82186 .20836 Metetra
.67 .755 .914 r
.19621 .41002 .20852 .42075 .22625 .41482 .21407 .40348 Metetra
.673 .746 .906 r
.21407 .40348 .22625 .41482 .2441 .4089 .23206 .39677 Metetra
.662 .731 .901 r
.23206 .39677 .2441 .4089 .26212 .40246 .25012 .3905 Metetra
.655 .733 .907 r
.25012 .3905 .26212 .40246 .28026 .39588 .26829 .38453 Metetra
.666 .748 .912 r
.26829 .38453 .28026 .39588 .2985 .38966 .28662 .37803 Metetra
.664 .744 .91 r
.28662 .37803 .2985 .38966 .31688 .3832 .30507 .37156 Metetra
.653 .743 .915 r
.30507 .37156 .31688 .3832 .33538 .37685 .32363 .36557 Metetra
.671 .756 .914 r
.32363 .36557 .33538 .37685 .35401 .37058 .34236 .35868 Metetra
.669 .745 .908 r
.34236 .35868 .35401 .37058 .37275 .3646 .36122 .35181 Metetra
.659 .729 .901 r
.36122 .35181 .37275 .3646 .39166 .35783 .3802 .34538 Metetra
.67 .739 .902 r
.3802 .34538 .39166 .35783 .41071 .3507 .39933 .33835 Metetra
.652 .737 .912 r
.39933 .33835 .41071 .3507 .42986 .34459 .41856 .33217 Metetra
.663 .741 .908 r
.41856 .33217 .42986 .34459 .44917 .33768 .43795 .32542 Metetra
.671 .748 .908 r
.43795 .32542 .44917 .33768 .46862 .33066 .4575 .31821 Metetra
.668 .745 .908 r
.4575 .31821 .46862 .33066 .4882 .32433 .47717 .3111 Metetra
.661 .731 .901 r
.47717 .3111 .4882 .32433 .50792 .31764 .49699 .3043 Metetra
.665 .732 .899 r
.49699 .3043 .50792 .31764 .52779 .31061 .51695 .29719 Metetra
.659 .73 .902 r
.51695 .29719 .52779 .31061 .5478 .30321 .53705 .29039 Metetra
.656 .741 .912 r
.53705 .29039 .5478 .30321 .56796 .2965 .55731 .28369 Metetra
.664 .745 .911 r
.55731 .28369 .56796 .2965 .58827 .28969 .57772 .27653 Metetra
.674 .745 .904 r
.57772 .27653 .58827 .28969 .60872 .28206 .59826 .26878 Metetra
.657 .738 .91 r
.59826 .26878 .60872 .28206 .62934 .27546 .61898 .26189 Metetra
.667 .739 .904 r
.61898 .26189 .62934 .27546 .65011 .26849 .63983 .25439 Metetra
.658 .728 .901 r
.63983 .25439 .65011 .26849 .671 .2607 .66086 .24732 Metetra
.657 .741 .912 r
.66086 .24732 .671 .2607 .69206 .2532 .68206 .24027 Metetra
.673 .757 .914 r
.68206 .24027 .69206 .2532 .71328 .24578 .70337 .2323 Metetra
.663 .745 .911 r
.70337 .2323 .71328 .24578 .73467 .23846 .72487 .22479 Metetra
.662 .743 .911 r
.72487 .22479 .73467 .23846 .75621 .23088 .74654 .21732 Metetra
.671 .751 .91 r
.74654 .21732 .75621 .23088 .77794 .22366 .76833 .20928 Metetra
.664 .736 .903 r
.76833 .20928 .77794 .22366 .79984 .21629 .79032 .20153 Metetra
.655 .728 .903 r
.79032 .20153 .79984 .21629 .82186 .20836 .81253 .19424 Metetra
.671 .741 .903 r
.18383 .39836 .19621 .41002 .21407 .40348 .20176 .3917 Metetra
.664 .739 .905 r
.20176 .3917 .21407 .40348 .23206 .39677 .21979 .38529 Metetra
.666 .746 .91 r
.21979 .38529 .23206 .39677 .25012 .3905 .23794 .37878 Metetra
.657 .74 .912 r
.23794 .37878 .25012 .3905 .26829 .38453 .25618 .37266 Metetra
.661 .741 .909 r
.25618 .37266 .26829 .38453 .28662 .37803 .27458 .36628 Metetra
.672 .747 .907 r
.27458 .36628 .28662 .37803 .30507 .37156 .29314 .35932 Metetra
.648 .733 .911 r
.29314 .35932 .30507 .37156 .32363 .36557 .31175 .35348 Metetra
.664 .742 .908 r
.31175 .35348 .32363 .36557 .34236 .35868 .33055 .34684 Metetra
.676 .751 .908 r
.33055 .34684 .34236 .35868 .36122 .35181 .34952 .33957 Metetra
.666 .743 .907 r
.34952 .33957 .36122 .35181 .3802 .34538 .36859 .33271 Metetra
.664 .737 .904 r
.36859 .33271 .3802 .34538 .39933 .33835 .38779 .32589 Metetra
.664 .742 .908 r
.38779 .32589 .39933 .33835 .41856 .33217 .40713 .31906 Metetra
.662 .731 .901 r
.40713 .31906 .41856 .33217 .43795 .32542 .42661 .31224 Metetra
.662 .732 .902 r
.42661 .31224 .43795 .32542 .4575 .31821 .44622 .30539 Metetra
.659 .739 .908 r
.44622 .30539 .4575 .31821 .47717 .3111 .46598 .29862 Metetra
.661 .747 .913 r
.46598 .29862 .47717 .3111 .49699 .3043 .48589 .29173 Metetra
.666 .748 .912 r
.48589 .29173 .49699 .3043 .51695 .29719 .50595 .28453 Metetra
.668 .749 .911 r
.50595 .28453 .51695 .29719 .53705 .29039 .52615 .27719 Metetra
.665 .74 .906 r
.52615 .27719 .53705 .29039 .55731 .28369 .54651 .26994 Metetra
.664 .733 .901 r
.54651 .26994 .55731 .28369 .57772 .27653 .56701 .26266 Metetra
.663 .732 .901 r
.56701 .26266 .57772 .27653 .59826 .26878 .58766 .25538 Metetra
.663 .741 .908 r
.58766 .25538 .59826 .26878 .61898 .26189 .60847 .24808 Metetra
.661 .735 .905 r
.60847 .24808 .61898 .26189 .63983 .25439 .62945 .24083 Metetra
.652 .738 .912 r
.62945 .24083 .63983 .25439 .66086 .24732 .6506 .23398 Metetra
.663 .748 .913 r
.6506 .23398 .66086 .24732 .68206 .24027 .67189 .22648 Metetra
.677 .747 .904 r
.67189 .22648 .68206 .24027 .70337 .2323 .6933 .21816 Metetra
.655 .734 .908 r
.6933 .21816 .70337 .2323 .72487 .22479 .71493 .21097 Metetra
.666 .746 .91 r
.71493 .21097 .72487 .22479 .74654 .21732 .7367 .20318 Metetra
.67 .744 .906 r
.7367 .20318 .74654 .21732 .76833 .20928 .75862 .1951 Metetra
.661 .741 .909 r
.75862 .1951 .76833 .20928 .79032 .20153 .78074 .18742 Metetra
.663 .745 .911 r
.78074 .18742 .79032 .20153 .81253 .19424 .80303 .17961 Metetra
.672 .74 .901 r
.17129 .38648 .18383 .39836 .20176 .3917 .18931 .37966 Metetra
.647 .732 .911 r
.18931 .37966 .20176 .3917 .21979 .38529 .20732 .37398 Metetra
.662 .75 .916 r
.20732 .37398 .21979 .38529 .23794 .37878 .22554 .36758 Metetra
.677 .758 .912 r
.22554 .36758 .23794 .37878 .25618 .37266 .24394 .36042 Metetra
.662 .737 .906 r
.24394 .36042 .25618 .37266 .27458 .36628 .26241 .35391 Metetra
.665 .737 .904 r
.26241 .35391 .27458 .36628 .29314 .35932 .28103 .3472 Metetra
.665 .743 .908 r
.28103 .3472 .29314 .35932 .31175 .35348 .29978 .34048 Metetra
.661 .728 .899 r
.29978 .34048 .31175 .35348 .33055 .34684 .31864 .33384 Metetra
.666 .731 .899 r
.31864 .33384 .33055 .34684 .34952 .33957 .33767 .32692 Metetra
.664 .738 .905 r
.33767 .32692 .34952 .33957 .36859 .33271 .35682 .32005 Metetra
.661 .739 .907 r
.35682 .32005 .36859 .33271 .38779 .32589 .3761 .3133 Metetra
.658 .74 .911 r
.3761 .3133 .38779 .32589 .40713 .31906 .39551 .30668 Metetra
.659 .746 .914 r
.39551 .30668 .40713 .31906 .42661 .31224 .41507 .29996 Metetra
.669 .752 .913 r
.41507 .29996 .42661 .31224 .44622 .30539 .43479 .29267 Metetra
.666 .745 .91 r
.43479 .29267 .44622 .30539 .46598 .29862 .45465 .2855 Metetra
.656 .737 .909 r
.45465 .2855 .46598 .29862 .48589 .29173 .47465 .27876 Metetra
.671 .746 .907 r
.47465 .27876 .48589 .29173 .50595 .28453 .49481 .27121 Metetra
.662 .739 .907 r
.49481 .27121 .50595 .28453 .52615 .27719 .51511 .26409 Metetra
.658 .743 .912 r
.51511 .26409 .52615 .27719 .54651 .26994 .53556 .25709 Metetra
.668 .752 .913 r
.53556 .25709 .54651 .26994 .56701 .26266 .55616 .24951 Metetra
.669 .749 .91 r
.55616 .24951 .56701 .26266 .58766 .25538 .57692 .24183 Metetra
.666 .743 .908 r
.57692 .24183 .58766 .25538 .60847 .24808 .59783 .23427 Metetra
.662 .739 .907 r
.59783 .23427 .60847 .24808 .62945 .24083 .6189 .22683 Metetra
.66 .737 .906 r
.6189 .22683 .62945 .24083 .6506 .23398 .64014 .21943 Metetra
.665 .731 .899 r
.64014 .21943 .6506 .23398 .67189 .22648 .66153 .21173 Metetra
.662 .728 .899 r
.66153 .21173 .67189 .22648 .6933 .21816 .68309 .20411 Metetra
.662 .742 .909 r
.68309 .20411 .6933 .21816 .71493 .21097 .70482 .19647 Metetra
.665 .737 .904 r
.70482 .19647 .71493 .21097 .7367 .20318 .72671 .18861 Metetra
.651 .732 .909 r
.72671 .18861 .7367 .20318 .75862 .1951 .74882 .18142 Metetra
.666 .755 .917 r
.74882 .18142 .75862 .1951 .78074 .18742 .77105 .17341 Metetra
.678 .757 .91 r
.77105 .17341 .78074 .18742 .80303 .17961 .79339 .16465 Metetra
.675 .854 .968 r
.15793 .38031 .17129 .38648 .18931 .37966 .17609 .37294 Metetra
.706 .848 .95 r
.17609 .37294 .18931 .37966 .20732 .37398 .1945 .3644 Metetra
.703 .793 .921 r
.1945 .3644 .20732 .37398 .22554 .36758 .21299 .35597 Metetra
.685 .755 .905 r
.21299 .35597 .22554 .36758 .24394 .36042 .23152 .34831 Metetra
.668 .744 .907 r
.23152 .34831 .24394 .36042 .26241 .35391 .25009 .34141 Metetra
.664 .737 .905 r
.25009 .34141 .26241 .35391 .28103 .3472 .26878 .33468 Metetra
.659 .737 .907 r
.26878 .33468 .28103 .3472 .29978 .34048 .28758 .32813 Metetra
.658 .741 .911 r
.28758 .32813 .29978 .34048 .31864 .33384 .30652 .3216 Metetra
.666 .747 .911 r
.30652 .3216 .31864 .33384 .33767 .32692 .32563 .31462 Metetra
.67 .749 .909 r
.32563 .31462 .33767 .32692 .35682 .32005 .34488 .3074 Metetra
.66 .741 .91 r
.34488 .3074 .35682 .32005 .3761 .3133 .36424 .30064 Metetra
.665 .744 .909 r
.36424 .30064 .3761 .3133 .39551 .30668 .38376 .29358 Metetra
.65 .734 .91 r
.38376 .29358 .39551 .30668 .41507 .29996 .40339 .28719 Metetra
.665 .746 .91 r
.40339 .28719 .41507 .29996 .43479 .29267 .4232 .28 Metetra
.679 .753 .907 r
.4232 .28 .43479 .29267 .45465 .2855 .44317 .27204 Metetra
.655 .734 .908 r
.44317 .27204 .45465 .2855 .47465 .27876 .46326 .26526 Metetra
.672 .74 .902 r
.46326 .26526 .47465 .27876 .49481 .27121 .48351 .25755 Metetra
.648 .731 .91 r
.48351 .25755 .49481 .27121 .51511 .26409 .5039 .25103 Metetra
.662 .748 .914 r
.5039 .25103 .51511 .26409 .53556 .25709 .52446 .24374 Metetra
.676 .75 .906 r
.52446 .24374 .53556 .25709 .55616 .24951 .54516 .23563 Metetra
.662 .738 .906 r
.54516 .23563 .55616 .24951 .57692 .24183 .56603 .22818 Metetra
.667 .745 .908 r
.56603 .22818 .57692 .24183 .59783 .23427 .58704 .22044 Metetra
.657 .74 .911 r
.58704 .22044 .59783 .23427 .6189 .22683 .60823 .21316 Metetra
.661 .746 .913 r
.60823 .21316 .6189 .22683 .64014 .21943 .62958 .20562 Metetra
.669 .748 .91 r
.62958 .20562 .64014 .21943 .66153 .21173 .65107 .19761 Metetra
.668 .744 .908 r
.65107 .19761 .66153 .21173 .68309 .20411 .67274 .18962 Metetra
.663 .738 .906 r
.67274 .18962 .68309 .20411 .70482 .19647 .69457 .1818 Metetra
.659 .735 .906 r
.69457 .1818 .70482 .19647 .72671 .18861 .7166 .17414 Metetra
.643 .734 .915 r
.7166 .17414 .72671 .18861 .74882 .18142 .73886 .16725 Metetra
.626 .733 .925 r
.73886 .16725 .74882 .18142 .77105 .17341 .76137 .16117 Metetra
.616 .767 .952 r
.76137 .16117 .77105 .17341 .79339 .16465 .78411 .15519 Metetra
.14263 .38837 .15793 .38031 .17609 .37294 .1611 .37994 Metetra
.49 .887 .731 r
.1611 .37994 .17609 .37294 .1945 .3644 .18 .36837 Metetra
.681 .979 .865 r
.18 .36837 .1945 .3644 .21299 .35597 .19913 .35533 Metetra
.764 .961 .932 r
.19913 .35533 .21299 .35597 .23152 .34831 .2183 .34251 Metetra
.756 .876 .933 r
.2183 .34251 .23152 .34831 .25009 .34141 .23738 .33119 Metetra
.709 .79 .915 r
.23738 .33119 .25009 .34141 .26878 .33468 .25635 .32217 Metetra
.659 .74 .91 r
.25635 .32217 .26878 .33468 .28758 .32813 .27524 .31553 Metetra
.66 .74 .909 r
.27524 .31553 .28758 .32813 .30652 .3216 .29426 .3088 Metetra
.661 .739 .907 r
.29426 .3088 .30652 .3216 .32563 .31462 .31343 .30196 Metetra
.669 .745 .907 r
.31343 .30196 .32563 .31462 .34488 .3074 .33277 .29467 Metetra
.651 .74 .915 r
.33277 .29467 .34488 .3074 .36424 .30064 .3522 .28826 Metetra
.671 .754 .913 r
.3522 .28826 .36424 .30064 .38376 .29358 .37182 .28079 Metetra
.667 .747 .91 r
.37182 .28079 .38376 .29358 .40339 .28719 .39158 .27349 Metetra
.658 .731 .903 r
.39158 .27349 .40339 .28719 .4232 .28 .41146 .26652 Metetra
.675 .741 .901 r
.41146 .26652 .4232 .28 .44317 .27204 .43153 .25866 Metetra
.656 .738 .911 r
.43153 .25866 .44317 .27204 .46326 .26526 .45171 .25175 Metetra
.671 .743 .904 r
.45171 .25175 .46326 .26526 .48351 .25755 .47206 .24397 Metetra
.652 .737 .912 r
.47206 .24397 .48351 .25755 .5039 .25103 .49255 .23715 Metetra
.668 .739 .904 r
.49255 .23715 .5039 .25103 .52446 .24374 .5132 .22943 Metetra
.66 .731 .902 r
.5132 .22943 .52446 .24374 .54516 .23563 .53401 .22203 Metetra
.656 .743 .914 r
.53401 .22203 .54516 .23563 .56603 .22818 .55498 .21481 Metetra
.676 .756 .911 r
.55498 .21481 .56603 .22818 .58704 .22044 .5761 .20651 Metetra
.658 .742 .912 r
.5761 .20651 .58704 .22044 .60823 .21316 .5974 .19909 Metetra
.666 .744 .909 r
.5974 .19909 .60823 .21316 .62958 .20562 .61885 .19121 Metetra
.667 .741 .906 r
.61885 .19121 .62958 .20562 .65107 .19761 .64046 .1832 Metetra
.667 .743 .907 r
.64046 .1832 .65107 .19761 .67274 .18962 .66224 .1751 Metetra
.619 .723 .921 r
.66224 .1751 .67274 .18962 .69457 .1818 .68431 .16943 Metetra
.55 .733 .96 r
.68431 .16943 .69457 .1818 .7166 .17414 .70674 .16614 Metetra
.427 .764 .996 r
.70674 .16614 .7166 .17414 .73886 .16725 .72953 .16441 Metetra
.218 .727 .892 r
.72953 .16441 .73886 .16725 .76137 .16117 .75262 .16294 Metetra
.75262 .16294 .76137 .16117 .78411 .15519 .77587 .15996 Metetra
.228 0 .073 r
.12469 .41484 .14263 .38837 .1611 .37994 .1436 .40502 Metetra
.006 0 0 r
.1436 .40502 .1611 .37994 .18 .36837 .16328 .38923 Metetra
.16328 .38923 .18 .36837 .19913 .35533 .18342 .36932 Metetra
.631 .905 .601 r
.18342 .36932 .19913 .35533 .2183 .34251 .2037 .34795 Metetra
.824 1 .825 r
.2037 .34795 .2183 .34251 .23738 .33119 .22378 .32823 Metetra
.819 .925 .905 r
.22378 .32823 .23738 .33119 .25635 .32217 .24346 .31279 Metetra
.729 .813 .917 r
.24346 .31279 .25635 .32217 .27524 .31553 .26273 .30264 Metetra
.661 .739 .907 r
.26273 .30264 .27524 .31553 .29426 .3088 .28185 .29576 Metetra
.663 .738 .906 r
.28185 .29576 .29426 .3088 .31343 .30196 .30111 .28872 Metetra
.665 .737 .904 r
.30111 .28872 .31343 .30196 .33277 .29467 .32052 .28153 Metetra
.648 .735 .913 r
.32052 .28153 .33277 .29467 .3522 .28826 .34002 .27512 Metetra
.664 .742 .908 r
.34002 .27512 .3522 .28826 .37182 .28079 .35972 .26789 Metetra
.677 .751 .907 r
.35972 .26789 .37182 .28079 .39158 .27349 .37959 .25995 Metetra
.663 .738 .905 r
.37959 .25995 .39158 .27349 .41146 .26652 .39958 .25263 Metetra
.663 .734 .903 r
.39958 .25263 .41146 .26652 .43153 .25866 .41971 .24529 Metetra
.658 .742 .912 r
.41971 .24529 .43153 .25866 .45171 .25175 .43999 .23818 Metetra
.669 .745 .907 r
.43999 .23818 .45171 .25175 .47206 .24397 .46044 .2304 Metetra
.664 .745 .91 r
.46044 .2304 .47206 .24397 .49255 .23715 .48104 .22285 Metetra
.663 .734 .903 r
.48104 .22285 .49255 .23715 .5132 .22943 .50179 .21527 Metetra
.65 .733 .91 r
.50179 .21527 .5132 .22943 .53401 .22203 .5227 .20832 Metetra
.663 .747 .913 r
.5227 .20832 .53401 .22203 .55498 .21481 .54377 .20065 Metetra
.677 .746 .903 r
.54377 .20065 .55498 .21481 .5761 .20651 .565 .19214 Metetra
.662 .739 .907 r
.565 .19214 .5761 .20651 .5974 .19909 .5864 .18441 Metetra
.663 .737 .904 r
.5864 .18441 .5974 .19909 .61885 .19121 .60796 .17653 Metetra
.665 .739 .905 r
.60796 .17653 .61885 .19121 .64046 .1832 .62969 .16847 Metetra
.597 .711 .924 r
.62969 .16847 .64046 .1832 .66224 .1751 .65173 .16375 Metetra
.403 .68 .974 r
.65173 .16375 .66224 .1751 .68431 .16943 .67427 .1645 Metetra
0 .513 .823 r
.67427 .1645 .68431 .16943 .70674 .16614 .69738 .1697 Metetra
.402 0 0 r
.69738 .1697 .70674 .16614 .72953 .16441 .72099 .17669 Metetra
.469 0 0 r
.72099 .17669 .72953 .16441 .75262 .16294 .74492 .18225 Metetra
.434 0 .088 r
.74492 .18225 .75262 .16294 .77587 .15996 .76891 .18356 Metetra
.31 0 .204 r
.10455 .45412 .12469 .41484 .1436 .40502 .12396 .44321 Metetra
.119 0 .095 r
.12396 .44321 .1436 .40502 .16328 .38923 .14444 .42384 Metetra
.14444 .42384 .16328 .38923 .18342 .36932 .16572 .39727 Metetra
.16572 .39727 .18342 .36932 .2037 .34795 .18737 .36638 Metetra
.756 .927 .57 r
.18737 .36638 .2037 .34795 .22378 .32823 .20885 .33577 Metetra
.88 .993 .774 r
.20885 .33577 .22378 .32823 .24346 .31279 .2297 .31036 Metetra
.842 .93 .887 r
.2297 .31036 .24346 .31279 .26273 .30264 .24977 .29291 Metetra
.73 .811 .915 r
.24977 .29291 .26273 .30264 .28185 .29576 .26926 .28252 Metetra
.664 .738 .905 r
.26926 .28252 .28185 .29576 .30111 .28872 .28861 .27537 Metetra
.66 .737 .907 r
.28861 .27537 .30111 .28872 .32052 .28153 .30809 .26834 Metetra
.665 .743 .908 r
.30809 .26834 .32052 .28153 .34002 .27512 .32773 .26103 Metetra
.659 .728 .9 r
.32773 .26103 .34002 .27512 .35972 .26789 .34749 .25395 Metetra
.668 .734 .9 r
.34749 .25395 .35972 .26789 .37959 .25995 .36744 .24635 Metetra
.664 .741 .907 r
.36744 .24635 .37959 .25995 .39958 .25263 .38752 .2389 Metetra
.662 .739 .907 r
.38752 .2389 .39958 .25263 .41971 .24529 .40774 .2315 Metetra
.66 .739 .909 r
.40774 .2315 .41971 .24529 .43999 .23818 .42812 .22417 Metetra
.667 .74 .904 r
.42812 .22417 .43999 .23818 .46044 .2304 .44867 .2164 Metetra
.665 .741 .907 r
.44867 .2164 .46044 .2304 .48104 .22285 .46936 .2087 Metetra
.663 .739 .907 r
.46936 .2087 .48104 .22285 .50179 .21527 .49022 .20105 Metetra
.659 .739 .909 r
.49022 .20105 .50179 .21527 .5227 .20832 .51123 .19354 Metetra
.667 .734 .9 r
.51123 .19354 .5227 .20832 .54377 .20065 .53241 .18551 Metetra
.661 .728 .899 r
.53241 .18551 .54377 .20065 .565 .19214 .55375 .1777 Metetra
.667 .743 .907 r
.55375 .1777 .565 .19214 .5864 .18441 .57525 .16959 Metetra
.663 .738 .905 r
.57525 .16959 .5864 .18441 .60796 .17653 .59692 .1616 Metetra
.594 .709 .924 r
.59692 .1616 .60796 .17653 .62969 .16847 .61888 .15693 Metetra
.329 .638 .964 r
.61888 .15693 .62969 .16847 .65173 .16375 .64133 .15951 Metetra
.323 0 0 r
.64133 .15951 .65173 .16375 .67427 .1645 .66452 .17034 Metetra
.622 .08 0 r
.66452 .17034 .67427 .1645 .69738 .1697 .68848 .18667 Metetra
.629 .165 .133 r
.68848 .18667 .69738 .1697 .72099 .17669 .71303 .20345 Metetra
.577 .16 .216 r
.71303 .20345 .72099 .17669 .74492 .18225 .73787 .21589 Metetra
.508 .123 .246 r
.73787 .21589 .74492 .18225 .76891 .18356 .76266 .22092 Metetra
.292 0 .178 r
.08388 .49212 .10455 .45412 .12396 .44321 .10366 .48115 Metetra
.082 0 .062 r
.10366 .48115 .12396 .44321 .14444 .42384 .12466 .46094 Metetra
.12466 .46094 .14444 .42384 .16572 .39727 .14675 .43119 Metetra
.14675 .43119 .16572 .39727 .18737 .36638 .1696 .39353 Metetra
.753 .882 .469 r
.1696 .39353 .18737 .36638 .20885 .33577 .19255 .35278 Metetra
.885 .962 .631 r
.19255 .35278 .20885 .33577 .2297 .31036 .21487 .31589 Metetra
.913 .975 .783 r
.21487 .31589 .2297 .31036 .24977 .29291 .2361 .28842 Metetra
.831 .903 .889 r
.2361 .28842 .24977 .29291 .26926 .28252 .2563 .27154 Metetra
.709 .79 .915 r
.2563 .27154 .26926 .28252 .28861 .27537 .27592 .26207 Metetra
.659 .74 .91 r
.27592 .26207 .28861 .27537 .30809 .26834 .29548 .25502 Metetra
.658 .741 .911 r
.29548 .25502 .30809 .26834 .32773 .26103 .31519 .24795 Metetra
.668 .75 .912 r
.31519 .24795 .32773 .26103 .34749 .25395 .33507 .24034 Metetra
.667 .743 .907 r
.33507 .24034 .34749 .25395 .36744 .24635 .3551 .23272 Metetra
.664 .743 .909 r
.3551 .23272 .36744 .24635 .38752 .2389 .37528 .22518 Metetra
.665 .743 .909 r
.37528 .22518 .38752 .2389 .40774 .2315 .39561 .21756 Metetra
.664 .741 .907 r
.39561 .21756 .40774 .2315 .42812 .22417 .41609 .20989 Metetra
.662 .737 .905 r
.41609 .20989 .42812 .22417 .44867 .2164 .43672 .20225 Metetra
.663 .741 .908 r
.43672 .20225 .44867 .2164 .46936 .2087 .45752 .19456 Metetra
.663 .743 .909 r
.45752 .19456 .46936 .2087 .49022 .20105 .47847 .18678 Metetra
.66 .742 .91 r
.47847 .18678 .49022 .20105 .51123 .19354 .49959 .17908 Metetra
.66 .74 .909 r
.49959 .17908 .51123 .19354 .53241 .18551 .52088 .17136 Metetra
.669 .75 .911 r
.52088 .17136 .53241 .18551 .55375 .1777 .54233 .1631 Metetra
.668 .745 .908 r
.54233 .1631 .55375 .1777 .57525 .16959 .56394 .1548 Metetra
.618 .724 .922 r
.56394 .1548 .57525 .16959 .59692 .1616 .58578 .14896 Metetra
.377 .646 .961 r
.58578 .14896 .59692 .1616 .61888 .15693 .60803 .15072 Metetra
0 .232 .629 r
.60803 .15072 .61888 .15693 .64133 .15951 .631 .16339 Metetra
.696 .166 0 r
.631 .16339 .64133 .15951 .66452 .17034 .6549 .18592 Metetra
.713 .253 .158 r
.6549 .18592 .66452 .17034 .68848 .18667 .67967 .21266 Metetra
.664 .243 .234 r
.67967 .21266 .68848 .18667 .71303 .20345 .70502 .23646 Metetra
.594 .196 .257 r
.70502 .23646 .71303 .20345 .73787 .21589 .73054 .25222 Metetra
.512 .13 .253 r
.73054 .25222 .73787 .21589 .76266 .22092 .75593 .25812 Metetra
.145 0 0 r
.06458 .51512 .08388 .49212 .10366 .48115 .08449 .50529 Metetra
.08449 .50529 .10366 .48115 .12466 .46094 .1055 .48773 Metetra
.1055 .48773 .12466 .46094 .14675 .43119 .12776 .45994 Metetra
.699 .859 .446 r
.12776 .45994 .14675 .43119 .1696 .39353 .15123 .42086 Metetra
.851 .919 .524 r
.15123 .42086 .1696 .39353 .19255 .35278 .17534 .3738 Metetra
.927 .945 .6 r
.17534 .3738 .19255 .35278 .21487 .31589 .19912 .32669 Metetra
.95 .956 .699 r
.19912 .32669 .21487 .31589 .2361 .28842 .22174 .2882 Metetra
.907 .93 .818 r
.22174 .2882 .2361 .28842 .2563 .27154 .24292 .26279 Metetra
.783 .839 .895 r
.24292 .26279 .2563 .27154 .27592 .26207 .26304 .24881 Metetra
.665 .746 .91 r
.26304 .24881 .27592 .26207 .29548 .25502 .28271 .24135 Metetra
.659 .739 .909 r
.28271 .24135 .29548 .25502 .31519 .24795 .30251 .23413 Metetra
.663 .74 .907 r
.30251 .23413 .31519 .24795 .33507 .24034 .32247 .22663 Metetra
.671 .745 .906 r
.32247 .22663 .33507 .24034 .3551 .23272 .34261 .2187 Metetra
.665 .74 .906 r
.34261 .2187 .3551 .23272 .37528 .22518 .36288 .21098 Metetra
.659 .737 .907 r
.36288 .21098 .37528 .22518 .39561 .21756 .38329 .20351 Metetra
.661 .742 .91 r
.38329 .20351 .39561 .21756 .41609 .20989 .40387 .1959 Metetra
.666 .746 .91 r
.40387 .1959 .41609 .20989 .43672 .20225 .42461 .18798 Metetra
.667 .744 .907 r
.42461 .18798 .43672 .20225 .45752 .19456 .44551 .17992 Metetra
.662 .738 .906 r
.44551 .17992 .45752 .19456 .47847 .18678 .46657 .1721 Metetra
.656 .737 .909 r
.46657 .1721 .47847 .18678 .49959 .17908 .48779 .16449 Metetra
.664 .743 .909 r
.48779 .16449 .49959 .17908 .52088 .17136 .50918 .15645 Metetra
.668 .741 .905 r
.50918 .15645 .52088 .17136 .54233 .1631 .53074 .14811 Metetra
.662 .74 .908 r
.53074 .14811 .54233 .1631 .56394 .1548 .55247 .14002 Metetra
.505 .676 .941 r
.55247 .14002 .56394 .1548 .58578 .14896 .57449 .13856 Metetra
0 .389 .824 r
.57449 .13856 .58578 .14896 .60803 .15072 .59707 .14884 Metetra
.686 .141 0 r
.59707 .14884 .60803 .15072 .631 .16339 .62054 .17267 Metetra
.769 .294 .111 r
.62054 .17267 .631 .16339 .6549 .18592 .64506 .20563 Metetra
.737 .298 .208 r
.64506 .20563 .6549 .18592 .67967 .21266 .67044 .23886 Metetra
.67 .245 .229 r
.67044 .23886 .67967 .21266 .70502 .23646 .69623 .26412 Metetra
.578 .155 .203 r
.69623 .26412 .70502 .23646 .73054 .25222 .72204 .27779 Metetra
.462 .035 .141 r
.72204 .27779 .73054 .25222 .75593 .25812 .74766 .28083 Metetra
.427 .87 .831 r
.04747 .51873 .06458 .51512 .08449 .50529 .06732 .51065 Metetra
.605 .953 .84 r
.06732 .51065 .08449 .50529 .1055 .48773 .08791 .49788 Metetra
.775 .991 .765 r
.08791 .49788 .1055 .48773 .12776 .45994 .10975 .47592 Metetra
.892 .976 .678 r
.10975 .47592 .12776 .45994 .15123 .42086 .13318 .44044 Metetra
.949 .946 .632 r
.13318 .44044 .15123 .42086 .17534 .3738 .15792 .3919 Metetra
.972 .927 .631 r
.15792 .3919 .17534 .3738 .19912 .32669 .1829 .33787 Metetra
.974 .919 .673 r
.1829 .33787 .19912 .32669 .22174 .2882 .20688 .28964 Metetra
.942 .908 .757 r
.20688 .28964 .22174 .2882 .24292 .26279 .22916 .25547 Metetra
.842 .858 .855 r
.22916 .25547 .24292 .26279 .26304 .24881 .24991 .23618 Metetra
.674 .762 .917 r
.24991 .23618 .26304 .24881 .28271 .24135 .2697 .22821 Metetra
.679 .756 .91 r
.2697 .22821 .28271 .24135 .30251 .23413 .28967 .21989 Metetra
.664 .736 .903 r
.28967 .21989 .30251 .23413 .32247 .22663 .30973 .21223 Metetra
.657 .733 .906 r
.30973 .21223 .32247 .22663 .34261 .2187 .32991 .20489 Metetra
.662 .746 .912 r
.32991 .20489 .34261 .2187 .36288 .21098 .35027 .19724 Metetra
.673 .752 .91 r
.35027 .19724 .36288 .21098 .38329 .20351 .37081 .189 Metetra
.657 .736 .908 r
.37081 .189 .38329 .20351 .40387 .1959 .39148 .18147 Metetra
.67 .743 .906 r
.39148 .18147 .40387 .1959 .42461 .18798 .41233 .17324 Metetra
.655 .735 .909 r
.41233 .17324 .42461 .18798 .44551 .17992 .43331 .16573 Metetra
.665 .75 .913 r
.43331 .16573 .44551 .17992 .46657 .1721 .45448 .15763 Metetra
.67 .749 .909 r
.45448 .15763 .46657 .1721 .48779 .16449 .47582 .14919 Metetra
.662 .734 .904 r
.47582 .14919 .48779 .16449 .50918 .15645 .49732 .14109 Metetra
.649 .73 .909 r
.49732 .14109 .50918 .15645 .53074 .14811 .51899 .13364 Metetra
.655 .749 .919 r
.51899 .13364 .53074 .14811 .55247 .14002 .54084 .12585 Metetra
.317 .589 .941 r
.54084 .12585 .55247 .14002 .57449 .13856 .56302 .12958 Metetra
.471 0 0 r
.56302 .12958 .57449 .13856 .59707 .14884 .58588 .14862 Metetra
.782 .28 0 r
.58588 .14862 .59707 .14884 .62054 .17267 .60975 .18229 Metetra
.799 .338 .14 r
.60975 .18229 .62054 .17267 .64506 .20563 .63471 .2223 Metetra
.751 .299 .178 r
.63471 .2223 .64506 .20563 .67044 .23886 .66039 .25701 Metetra
.655 .189 .134 r
.66039 .25701 .67044 .23886 .69623 .26412 .68629 .27842 Metetra
.483 0 0 r
.68629 .27842 .69623 .26412 .72204 .27779 .71204 .28586 Metetra
.179 0 0 r
.71204 .28586 .72204 .27779 .74766 .28083 .73763 .28371 Metetra
.637 .797 .96 r
.03199 .50859 .04747 .51873 .06732 .51065 .05171 .50205 Metetra
.671 .833 .961 r
.05171 .50205 .06732 .51065 .08791 .49788 .0718 .49388 Metetra
.8 .912 .916 r
.0718 .49388 .08791 .49788 .10975 .47592 .09298 .47848 Metetra
.92 .934 .799 r
.09298 .47848 .10975 .47592 .13318 .44044 .11599 .44881 Metetra
.968 .907 .702 r
.11599 .44881 .13318 .44044 .15792 .3919 .14091 .40215 Metetra
.98 .883 .662 r
.14091 .40215 .15792 .3919 .1829 .33787 .16672 .34473 Metetra
.975 .872 .669 r
.16672 .34473 .1829 .33787 .20688 .28964 .19184 .28958 Metetra
.949 .868 .723 r
.19184 .28958 .20688 .28964 .22916 .25547 .21512 .24828 Metetra
.874 .85 .817 r
.21512 .24828 .22916 .25547 .24991 .23618 .23649 .22423 Metetra
.713 .785 .908 r
.23649 .22423 .24991 .23618 .2697 .22821 .25658 .21413 Metetra
.674 .743 .903 r
.25658 .21413 .2697 .22821 .28967 .21989 .27662 .20592 Metetra
.668 .745 .907 r
.27662 .20592 .28967 .21989 .30973 .21223 .29678 .19796 Metetra
.652 .737 .912 r
.29678 .19796 .30973 .21223 .32991 .20489 .31704 .19079 Metetra
.662 .744 .911 r
.31704 .19079 .32991 .20489 .35027 .19724 .33749 .18307 Metetra
.677 .749 .906 r
.33749 .18307 .35027 .19724 .37081 .189 .35815 .17449 Metetra
.656 .739 .911 r
.35815 .17449 .37081 .189 .39148 .18147 .37891 .1669 Metetra
.671 .745 .906 r
.37891 .1669 .39148 .18147 .41233 .17324 .39986 .1585 Metetra
.65 .737 .913 r
.39986 .1585 .41233 .17324 .43331 .16573 .42094 .1511 Metetra
.666 .746 .91 r
.42094 .1511 .43331 .16573 .45448 .15763 .44222 .14284 Metetra
.675 .749 .906 r
.44222 .14284 .45448 .15763 .47582 .14919 .46367 .13402 Metetra
.659 .739 .909 r
.46367 .13402 .47582 .14919 .49732 .14109 .48528 .12598 Metetra
.653 .739 .913 r
.48528 .12598 .49732 .14109 .51899 .13364 .50706 .1182 Metetra
.612 .72 .922 r
.50706 .1182 .51899 .13364 .54084 .12585 .52902 .11233 Metetra
.098 .465 .89 r
.52902 .11233 .54084 .12585 .56302 .12958 .55133 .1207 Metetra
.635 .113 0 r
.55133 .1207 .56302 .12958 .58588 .14862 .57437 .14683 Metetra
.816 .332 0 r
.57437 .14683 .58588 .14862 .60975 .18229 .59849 .18744 Metetra
.819 .35 .097 r
.59849 .18744 .60975 .18229 .63471 .2223 .62367 .23082 Metetra
.756 .266 .069 r
.62367 .23082 .63471 .2223 .66039 .25701 .64946 .26345 Metetra
.573 .019 0 r
.64946 .26345 .66039 .25701 .68629 .27842 .67527 .27864 Metetra
.025 0 0 r
.67527 .27864 .68629 .27842 .71204 .28586 .70086 .27901 Metetra
.537 .869 .993 r
.70086 .27901 .71204 .28586 .73763 .28371 .72634 .27178 Metetra
.621 .714 .913 r
.017 .49349 .03199 .50859 .05171 .50205 .03664 .48782 Metetra
.609 .726 .928 r
.03664 .48782 .05171 .50205 .0718 .49388 .05639 .48257 Metetra
.72 .798 .913 r
.05639 .48257 .0718 .49388 .09298 .47848 .07706 .47178 Metetra
.87 .849 .82 r
.07706 .47178 .09298 .47848 .11599 .44881 .09968 .44688 Metetra
.938 .841 .722 r
.09968 .44688 .11599 .44881 .14091 .40215 .12463 .40276 Metetra
.957 .826 .673 r
.12463 .40276 .14091 .40215 .16672 .34473 .15098 .34428 Metetra
.956 .82 .668 r
.15098 .34428 .16672 .34473 .19184 .28958 .17692 .28526 Metetra
.937 .823 .706 r
.17692 .28526 .19184 .28958 .21512 .24828 .20098 .23949 Metetra
.879 .824 .789 r
.20098 .23949 .21512 .24828 .23649 .22423 .22286 .21225 Metetra
.756 .794 .884 r
.22286 .21225 .23649 .22423 .25658 .21413 .24333 .19916 Metetra
.657 .727 .901 r
.24333 .19916 .25658 .21413 .27662 .20592 .26338 .19167 Metetra
.66 .741 .91 r
.26338 .19167 .27662 .20592 .29678 .19796 .28361 .18402 Metetra
.667 .75 .912 r
.28361 .18402 .29678 .19796 .31704 .19079 .30402 .17599 Metetra
.659 .735 .906 r
.30402 .17599 .31704 .19079 .33749 .18307 .32455 .16827 Metetra
.67 .741 .903 r
.32455 .16827 .33749 .18307 .35815 .17449 .34529 .15988 Metetra
.654 .74 .913 r
.34529 .15988 .35815 .17449 .37891 .1669 .36614 .15232 Metetra
.674 .749 .907 r
.36614 .15232 .37891 .1669 .39986 .1585 .38721 .14367 Metetra
.656 .741 .912 r
.38721 .14367 .39986 .1585 .42094 .1511 .40841 .13584 Metetra
.668 .74 .904 r
.40841 .13584 .42094 .1511 .44222 .14284 .42979 .12734 Metetra
.66 .736 .906 r
.42979 .12734 .44222 .14284 .46367 .13402 .45134 .11915 Metetra
.667 .75 .912 r
.45134 .11915 .46367 .13402 .48528 .12598 .47306 .11058 Metetra
.669 .744 .907 r
.47306 .11058 .48528 .12598 .50706 .1182 .49496 .10182 Metetra
.546 .679 .926 r
.49496 .10182 .50706 .1182 .52902 .11233 .51701 .09876 Metetra
0 .367 .829 r
.51701 .09876 .52902 .11233 .55133 .1207 .5394 .11015 Metetra
.674 .173 0 r
.5394 .11015 .55133 .1207 .57437 .14683 .56253 .14062 Metetra
.819 .345 0 r
.56253 .14062 .57437 .14683 .59849 .18744 .58674 .18502 Metetra
.82 .34 0 r
.58674 .18502 .59849 .18744 .62367 .23082 .61199 .22931 Metetra
.719 .187 0 r
.61199 .22931 .62367 .23082 .64946 .26345 .63778 .25911 Metetra
.262 0 0 r
.63778 .25911 .64946 .26345 .67527 .27864 .66352 .2691 Metetra
.501 .807 1 r
.66352 .2691 .67527 .27864 .70086 .27901 .68903 .26439 Metetra
.677 .798 .939 r
.68903 .26439 .70086 .27901 .72634 .27178 .71447 .25385 Metetra
.613 .73 .929 r
.00163 .47933 .017 .49349 .03664 .48782 .0213 .47387 Metetra
.583 .725 .941 r
.0213 .47387 .03664 .48782 .05639 .48257 .04097 .4695 Metetra
.689 .769 .912 r
.04097 .4695 .05639 .48257 .07706 .47178 .06152 .46024 Metetra
.837 .796 .812 r
.06152 .46024 .07706 .47178 .09968 .44688 .08409 .43704 Metetra
.904 .784 .718 r
.08409 .43704 .09968 .44688 .12463 .40276 .10919 .3939 Metetra
.925 .772 .672 r
.10919 .3939 .12463 .40276 .15098 .34428 .13595 .33511 Metetra
.928 .77 .665 r
.13595 .33511 .15098 .34428 .17692 .28526 .16242 .27474 Metetra
.914 .776 .696 r
.16242 .27474 .17692 .28526 .20098 .23949 .18694 .22735 Metetra
.866 .787 .771 r
.18694 .22735 .20098 .23949 .22286 .21225 .20914 .19891 Metetra
.757 .777 .869 r
.20914 .19891 .22286 .21225 .24333 .19916 .22977 .18522 Metetra
.66 .747 .915 r
.22977 .18522 .24333 .19916 .26338 .19167 .24993 .17754 Metetra
.661 .747 .913 r
.24993 .17754 .26338 .19167 .28361 .18402 .27025 .16973 Metetra
.677 .75 .906 r
.27025 .16973 .28361 .18402 .30402 .17599 .2908 .16103 Metetra
.657 .736 .907 r
.2908 .16103 .30402 .17599 .32455 .16827 .31143 .15327 Metetra
.664 .739 .906 r
.31143 .15327 .32455 .16827 .34529 .15988 .33225 .14508 Metetra
.653 .74 .914 r
.33225 .14508 .34529 .15988 .36614 .15232 .3532 .13742 Metetra
.674 .747 .906 r
.3532 .13742 .36614 .15232 .38721 .14367 .37437 .12863 Metetra
.663 .744 .91 r
.37437 .12863 .38721 .14367 .40841 .13584 .39569 .12036 Metetra
.669 .741 .904 r
.39569 .12036 .40841 .13584 .42979 .12734 .41718 .11167 Metetra
.65 .733 .91 r
.41718 .11167 .42979 .12734 .45134 .11915 .43882 .10391 Metetra
.666 .747 .911 r
.43882 .10391 .45134 .11915 .47306 .11058 .46065 .09526 Metetra
.668 .749 .911 r
.46065 .09526 .47306 .11058 .49496 .10182 .48267 .08646 Metetra
.527 .69 .943 r
.48267 .08646 .49496 .10182 .51701 .09876 .50481 .08377 Metetra
0 .342 .818 r
.50481 .08377 .51701 .09876 .5394 .11015 .52725 .09614 Metetra
.634 .161 0 r
.52725 .09614 .5394 .11015 .56253 .14062 .55036 .12801 Metetra
.782 .324 0 r
.55036 .12801 .56253 .14062 .58674 .18502 .57454 .17355 Metetra
.77 .301 0 r
.57454 .17355 .58674 .18502 .61199 .22931 .59977 .21791 Metetra
.575 .069 0 r
.59977 .21791 .61199 .22931 .63778 .25911 .62555 .24646 Metetra
.092 .501 .902 r
.62555 .24646 .63778 .25911 .66352 .2691 .65133 .25443 Metetra
.595 .765 .96 r
.65133 .25443 .66352 .2691 .68903 .26439 .6769 .24786 Metetra
.694 .778 .916 r
.6769 .24786 .68903 .26439 .71447 .25385 .70244 .23612 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.21035 .18732 m
.21487 .19208 L
s
[(10)] .20131 .17781 .94967 1 Mshowa
.41738 .10625 m
.42153 .11134 L
s
[(20)] .40909 .09608 .81515 1 Mshowa
.64163 .01845 m
.64532 .02387 L
s
[(30)] .63425 .0076 .68064 1 Mshowa
.125 Mabswid
.25047 .17161 m
.25314 .1745 L
s
.29122 .15565 m
.29385 .15859 L
s
.33262 .13945 m
.3352 .14242 L
s
.37466 .12298 m
.3772 .12599 L
s
.46079 .08926 m
.46322 .09235 L
s
.5049 .07199 m
.50728 .07512 L
s
.54973 .05443 m
.55206 .0576 L
s
.5953 .03659 m
.59757 .0398 L
s
.17084 .20279 m
.17359 .20561 L
s
.13192 .21803 m
.13471 .22081 L
s
.09359 .23304 m
.09641 .23578 L
s
.05583 .24783 m
.05869 .25053 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[61]:=",
  ImageSize->{288, 233.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
]Goo0P0017oo00<007ooOol0HWoo002gOol01P00Oomoo`00Ool006=oo`00]Woo00L007ooOomoo`00
Ool0001SOol00;Moo`06001oogoo001oo`00Hgoo002eOol00`00Ool00002Ool00`00Ool0001SOol0
0;Ioo`03001oogoo009oo`03001oogoo069oo`00bGoo0P00EGoo0037Ool200000goo0000001DOol0
0<Aoo`<000=oo`8005Aoo`00`Woo0P001Woo00<007oo0000Dgoo002nOol40008Ool01000Ool00000
DWoo002mOol2000;Ool01000Oomoo`00DWoo002jOol30002Ool00`00Oomoo`08Ool01@00Oomoogoo
0000DGoo002gOol3000@Ool00`00Oomoo`02Ool00`00Oomoo`1>Ool00;Eoo`8001Aoo`05001oogoo
Ool0001@Ool00;9oo`<001Ioo`03001oogoo009oo`03001oogoo04eoo`00/7oo0P0000=oo`00Ool0
5Woo00<007ooOol00goo00<007ooOol0C7oo002]Ool3000KOol00`00Oomoo`03Ool00`00Oomoo`1<
Ool00:]oo`8001ioo`03001oogoo00Aoo`03001oogoo04]oo`00Z7oo0`0087oo00<007ooOol017oo
0P00C7oo002VOol2000SOol00`00Oomoo`05Ool00`00Oomoo`1:Ool00:=oo`<00003Ool007oo029o
o`03001oogoo00Ioo`03001oogoo04Uoo`00XGoo0P00:7oo00<007ooOol01goo00<007ooOol0B7oo
001jOol30003Ool00`00Oomoo`0KOol3000ZOol00`00Oomoo`07Ool00`00Oomoo`18Ool007Yoo`03
001oogoo009oo`03001oo`0001Uoo`<002eoo`03001oogoo00Qoo`03001oogoo04Moo`00Ngoo00L0
07ooOomoo`00Ool0000GOol3000_Ool00`00Oomoo`08Ool00`00Oomoo`17Ool007]oo`07001oogoo
Ool007oo000057oo0`00<Woo00<007ooOol02Goo00<007ooOol0AWoo001jOol00`00Ool00002Ool0
0`00Ool0000BOol20003Ool3000_Ool00`00Oomoo`09Ool20017Ool007]oo`03001oogoo009oo`03
001oogoo00ioo`P000=2gP8002eoo`03001oogoo00Yoo`03001oogoo04Eoo`00Sgoo1@000UKm00<0
04;N@]h00d;N00<0005J0000;7oo00<007ooOol02goo00<007ooOol0A7oo002<Ool50005E_d00`00
@]i2gP04@]h010000EX00000:goo00<007ooOol02goo00<007ooOol0@goo002:Ool200001Goo0000
05Km00001UKm00<004;N@]h00T;N0`000P5J00<007ooOol0:7oo00<007ooOol02goo00<007ooOol0
@goo0027Ool300000goo00000004E_d00`00E_eFo@03E_d50003A[d200000`5J001oo`0XOol00`00
Oomoo`0<Ool00`00Oomoo`12Ool008Aoo`<0009oo`8000MFo@03001FoEKm0080009Fo@030016_DJm
00=6_@030001NP00008002Qoo`03001oogoo00eoo`03001oogoo045oo`00PWoo0`0000Aoo`000000
009Bo@03001FoEKm00EFo@8000AFo@030016_DJm00A6_@030001NP5j008002Moo`03001oogoo00eo
o`03001oogoo045oo`00Ogoo0`0000Aoo`00000000EBo@03001FoEKm00=Fo@800003E_d005Km00AF
o@030016_DJm0096_@@000030GX0000002Ioo`03001oogoo00ioo`80045oo`00OGoo0P0000Aoo`00
0000009Fo003001BoE;m00ABo@03001FoEKm008000=Fo@03001FoEKm00=Fo@D000=>o@D002Eoo`03
001oogoo00ioo`80045oo`00NWoo1P001EKl00<005;mD_d015;m0`001UKm00<005KmE_d00P000U;m
00<004kmC_d014km00<000gL00000P0097oo00<007ooOol03goo00<007ooOol0?goo001hOol50002
E_d00`00E_aFo004E_`00`00D_eBo@030002E_`00`00E_eFo@04E_d30004D_d00`00C_e>o@04C_d7
000ROol00`00Oomoo`0@Ool00`00Oomoo`04Ool50002Ool00`00Oomoo`0`Ool007Eoo`H000EFo@03
001Fo5Kl00=Fo0<000IFo003001FoEKm00<0009Fo@03001BoE;m00=Bo@03001>oDkm00<0009Bo@03
000ZGP0000<0025oo`03001oogoo015oo`03001oogoo00Eoo`07001oogooOol007oo0000<Goo001c
Ool50002E_`00`00E_eFo@04E_d00`00E_aFo0020002E_`00`00E_aFo005E_`20005E_d00`00D_eB
o@03D_d30005D_d01@00:Uh00000E:000P0087oo00<007ooOol04Goo00<007ooOol01Goo00L007oo
Oomoo`00Ool0000aOol0071oo`D000EFo003001FoEKm00AFo@<000EFo003001Fo5Kl009Fo0800003
E_`005Km00EFo@03001BoE;m0080009Bo@03001BoE;m00ABo@03000ZGP0000800003D60007oo01io
o`03001oogoo019oo`03001oogoo00Aoo`07001oogooOol007oo0000<Goo001^Ool40002D_d00`00
E_aFo004E_`00`00E_eFo@030002D_d00`00E_aFo004E_`01000E_`000000eKl00<005KmE_d015Km
0`0015;m00<005;mD_d015;m0`0000AU@000001@H08001eoo`03001oogoo01=oo`03001oogoo00=o
o`07001oogooOol007oo0000<Goo001[Ool50005D_d00`00E_aFo003E_`30005D_d00`00E_aFo004
E_`20006E_`00`00E_eFo@030002E_`00`00D_eBo@03D_d00`00D_eBo@030002E_d50002D603000J
Ool00`00Oomoo`0COol20003Ool20004Ool00`00Oomoo`0`Ool0049oo`D0009oo`03001oogoo01eo
o`@0009Fo003001BoE;m00ABo@03001Fo5Kl0080009Fo@03001BoE;m00ABo@03001Fo5Kl00<0009F
o@03001Fo5Kl00AFo08000EFo003001BoE;m00=Bo@<000EFo@800003ID0006UP00L001Qoo`03001o
ogoo019oo`<003aoo`00A7oo00L007ooOomoo`00Ool0000KOol50004E_`00`00D_eBo@04D_d30005
E_d00`00D_eBo@03D_d30005E_d00`00E_aFo002E_`200000eKm001Fo005E_`00`00D_eBo@020002
E_`00`00E_eFo@04E_d30002JF001000JD1Y@0000VD00`005Goo00<007ooOol05Goo00<007ooOol0
>Goo0014Ool01`00Oomoogoo001oo`0001Qoo`D0009Fo@03001Fo5Kl00=Fo003001BoE;m00<0009B
o@03001FoEKm00AFo@03001BoE;m0080009Bo@03001FoEKm00AFo@04001Fo0000003E_d00`00E_aF
o004E_`30004E_`00`00E_eFo@04E_d2000016E0001YH0000VU000@006D0I@1U00H0019oo`03001o
ogoo015oo`@003]oo`00A7oo00L007ooOomoo`00Ool0000FOol40005E_d00`00E_aFo003E_`30005
D_d00`00E_eFo@04E_d30004D_d00`00E_eFo@04E_d20006E_d00`00E_aFo0030002E_d00`00E_aF
o003E_`00`00E_eFo@030002E_d20002JF001000JD1Y@0000fD000D005B00000003d00D000eoo`03
001oogoo00aoo`L00003Cah0000003Yoo`00A7oo00L007ooOomoo`00Ool0000COol500000eKl001F
o@05E_d00`00E_aFo0020002E_`00`00D_eBo@04D_d00`00E_eFo@030002E_`00`00D_eBo@03D_d0
0`00E_eFo@030002E_d00`00E_eFo@03E_d30005E_d00`00E_aFo003E_`30005E_d01@00ID0006UP
00000fU000D006D0I@1U0000009DP0<0009HX0X000Aoo`03001oogoo00=oo``0008d0P03001?7TlN
009?7P03001oogoo03Moo`00@goo0P0017oo00<007ooOol047oo0P0000=oo`00000015Kl00<005Km
E_d00eKm0`001EKl00<005;mD_d00e;m0`001EKl00<005;mD_d00e;m0`001UKm00<005KmE_d00P00
0U;m00<005KmE_d015Km00<005KlE_`00P000UKm00<005KmE_d015Km0P000VUP00@006U0JD0000AU
0005001DP000HB<00004F:020002:0020002C40300000goo0000000400000c00000l0005?0000`00
=08d0P02=0801000Cai?7TlN0`00>Goo001IOol300000goo00000007E_`00`00E_eFo@020002E_`0
0`00E_aFo004E_`00`00D_eBo@020002D_d00`00E_aFo004E_`00`00D_eBo@020002D_d00`00E_eF
o@04E_d30004D_d00`00E_eFo@04E_d30004E_d00`00E_eFo@04E_d00`00ID000002JF001000JD1Y
@00016D000D0064SHB=Q8`0000EHX08000M<@0@000@`0003000l03`000<l0003000d0S@200<d0P04
001?7P000003Ead00`00Oomoo`0fOol005Moo`800004Ool000000002E_d00`00E_aFo004E_`30004
E_`00`00E_aFo004E_`30004D_d00`00E_aFo004E_`30005D_d00`00E_eFo@030002E_`00`00D_eB
o@03D_d00`00E_eFo@030002E_d00`00E_eFo@03E_d00`00E_eFo@0300000eKm00000002JF001@00
JD1Y@6U000000VD000<006E400000f4S0P000eRP00@005T5000000E<@080009@Y0D000Dl0003000d
0S@200<d0P8000EG7@8003Moo`00E7oo0`0000Aoo`00000000EFo@03001Fo5Kl00<0009Fo@03001F
o5Kl00=Fo003001Fo5Kl00<0009Fo003001BoE;m00=Bo@03001Fo5Kl00<0009Fo003001BoE;m00=B
o@<000EFo003001BoE;m00=Bo@<000EFo@03001FoEKm00=Fo@<000EFo@80009YH006001Y@6U0001U
00000VE400<0064SHB<00f4S00@005RPF:0000=I1@07001<@4a0C400052T00001E2T00<004RV0000
0P0000<l0000=08013@200<005LM00001ELM0P00=goo001BOol20002Ool20002E_d00`00E_eFo@03
E_d30005E_d00`00E_aFo003E_`30005E_`00`00D_eBo@03D_d30006E_`00`00D_eBo@020002E_d0
0`00E_aFo004E_`00`00D_eBo@020002E_d00`00E_eFo@04E_d00`00E_eFo@020002E_`00`00E_eF
o@03E_d20002JF000`00JD1Y@0020004ID@00`00HB=Q8`03HB<20005F@D2000014a0001@Y000152T
00<004RVB:H00dRV200000AG7@00EaeG7@<00003E_d0000003Ioo`00CWoo10000Woo0P001EKm00<0
05KmE_d00P000UKm00<005KmE_d015Km00<005KlE_`00P000UKm00<005KlE_`015Kl00<005;mD_d0
0P000UKm00<005KlE_`015Kl0`0015Km00<005KlE_`015Kl0`0015Km00<005KmE_d015Km0`001EKl
00<005KmE_d02@000VUS00<006E4ID@00VE400<0064SHB<00f4S00<005T5F@D01ET500@0052TD:@0
00A@Y0030018YTRV00A8YP030010Id1W00=0I`03001G7@00008000EFo@8003Eoo`00CGoo100000Eo
o`00001S6`0000EFo@<000EFo@03001FoEKm00=Fo@<000EFo@03001Fo5Kl00=Fo0<000EFo@80009F
o080009Fo@03001FoEKm00=Fo@03001Fo5Kl00<0009Fo@03001FoEKm00=Fo@03001FoEKm00<0009F
o003001Fo5Kl00AFo08000=Fo@03001Q8000009Y@004001YHfUS0004ID@00`00HB=Q8`02HB<00`00
GBH00006F@D40004D:@00`00B:I8YP04B:H00`00@6M0I`03@6L20002E_d00`00E_eFo@03E_d2000e
Ool004Yoo`<000=oo`8000AS6`03001FoEKm0080009Fo003001FoEKm00AFo@03001FoEKm0080009B
o@03001FoEKm00AFo@03001Fo5Kl0080009G7@03001FoEKm00AFo@<000AFo@03001FoEKm00=Fo@<0
00EFo@03001FoEKm00=Fo@<000EFo003001Fo5Kl009Fo0800003E_`005Km00=Fo@80009Y@005001Y
HfUSJF<00004ID@01@00HB=Q8f4S00000UdV00<005T5F@D00UT500@005CWE>MDi`8000=@Y0030018
YTRV00=8YP030010Id1W00A0I`05001FoEKmE_d00005E_d3000dOol004Moo`<000Aoo`8000MS6`80
00EFo003001FoEKm00=Fo@<000ABo@03001FoEKm00AFo@<000EG7@03001FoEKm00<0009Fo@03001F
oEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm00AFo@03001FoEKm0080009Fo@03001Fo5Kl00AF
o004001Fo0000003E_`00`00E_eFo@02E_d00`00HB000002JD001000JF=YH`001FE400<0064S0000
15dV00D005T5F@EI1@0000=Di`03001Di`00008000I8YP030010Id1W00A0I`03001FoEKm009Fo@03
001FoEKm0080009Bo08003=oo`00A7oo0`001Woo00<006lh00001V<K00<006<l00001UKl00<005Km
E_d00P000UKm00<005;mD_d00e;m00<005KmE_d00`000UKm00<005LMEad00eLM0`001EKm00<005Km
E_d00eKm0`001EKm00<005KmE_d00eKm0`0015Km00<005KlE_`015Kl0P001UKl00<005KmE_d00`00
00EQ8000JD1Y@000009YH`03001UA6E4009UA003001Q8`0000AM9P05001I1ET5F@D00003E>L01@00
E>MDieCW00001TRV00<0041W@6L00d1W00<005KmE_d00eKm0`0015;l0`00<Woo0012Ool40006Ool0
1@00KcQ_>6lh00000f<K0P000V<l00<005KlE_`015Kl0`0015Km00<005;mD_d00e;m0`001UKm00<0
05LMEad00P000UKm00<005KmE_d015Km00<005KmE_d00P000UKl00<005KmE_d015Km00<005KmE_d0
0P000UKm00<005KmE_d00eKm00<005KlE_`00`000UKm00<005KlE_`00eKl0`000UKm00<0064P0000
0VU000D006USJF=YH`0000AUA003001M9UdV00AM9P04001I1ET50003E>L01000E>MDieCW0`0014RV
00<0041W@6L00d1W00<005KmE_d00`0000=Fo000D_`01E;l0P00<Woo0010Ool2000:Ool00`00KcQ_
>002KcP00`00Ha/00005Hc`00`00E_aFo0030002E_`00`00E_eFo@03E_d00`00D_eBo@020002E_`0
0`00E_eFo@04E_d30004E_d00`00E_eFo@04E_d30004E_`00`00E_eFo@04E_d30005E_d01000E_eF
oEKm10001UKm00<005KlE_`00P000ULM00L005KmE_eFo@00HB000002JD001000JF=YH`000fE400<0
064U00001UdV0P0015CW00D005CWE>MDi`00009<b0040018YTRV0006@6L30005E_`00`00D_aBo003
D_`3000aOol003eoo`<000]oo`03001_>6lh00A_>003001S?6<l00ES?08000EFo003001FoEKm00=F
o@<000EFo080009Fo@80009Fo003001FoEKm00=Fo@03001FoEKm00<0009Fo@03001Fo5Kl00=Fo003
001FoEKm00<0009Fo@03001FoEKm00=Fo@@000=Bo@03001FoEKm00AFo@<000AG7@07001FoEKmE_d0
064P00000VU000L006USJF=YH`00ID@00003HBD00`00GBIM9P04GBH00`00E>MDi`02E>L01000E>MD
i`0014c80`001T1W0P001UKl00<005;lD_`00`000UKl00<007ooOol0;goo000jOol3000=Ool00`00
KcQ_>004KcP00`00LeT00004Hc`200000e/m001Fo005E_`00`00E_eFo@020002E_`00`00E_aFo004
E_`30004E_`00`00E_eFo@03E_d30005E_d00`00E_aFo003E_`30006E_d00`00E_eFo@020002E_`0
0`00D_eBo@03D_d00`00E_eFo@030002D_d00`00EaeG7@03Ead00`00E_eFo@0200001F4P001Y@6U0
00000VUS00<006E400000f4U00<005dVGBH015dV0P0015CW00<005CW00001Tc810000d1W00<005LM
00001EKl0`001EKl0P00<7oo000hOol4000=Ool00`00KcQ_>004KcP01P00LeUcFG=I001S?08000AK
?@03001Fo5Kl00=Fo0<000EFo080009Fo080009Fo003001Fo5Kl00=Fo003001FoEKm0080009Fo@03
001FoEKm00AFo@03001Fo5Kl0080009Fo003001FoEKm00AFo@<000AFo003001BoE;m00=Bo@<000EB
o@03001G7ELM00=G7@<0009Fo@03001Q8000009Y@004001YHfUS0005HBD00`00GBIM9P02GBH01000
E>MDi`000eCW00<005CW00001Tc800@00428@8Q0R0@00004Ead005KlE_`30002E_d00`00E_aFo003
E_`2000`Ool003Ioo`80015oo`03001_>6lh00=_>003001cFG=I00=cF@03001K?E/m00EK?@03001F
o5Kl0080009G7@03001Fo5Kl00AFo0<000AFo003001Fo5Kl00=Fo0<000EFo@03001FoEKm00=Fo@<0
00EFo003001FoEKm00<0009Fo@03001Fo5Kl00=Fo003001BoE;m0080009Fo003001BoE;m00ABo@03
001G7ELM0080009Fo@04001FoEKmE_d20002JD001@00JF<0064200001F4U00D005dVGBIM9P0000=D
i`800004E>L005CW0006C<P00`00@8Q0R004@8P50006E_d00`00E_aFo0020002Ead00`00Oomoo`0]
Ool003=oo`<0019oo`03001_>6lh00A_>003001cFG=I009cF@03001_NP0000IK?@<000EG7@03001F
o5Kl00<0009Fo@03001Fo5Kl00=Fo003001Fo5Kl0080009Fo@03001FoEKm00AFo@03001FoEKm0080
009Fo@03001Fo5Kl00=Fo0<000EFo@03001Fo5Kl00=Fo0<000AFo003001BoE;m00ABo@<000EFo@03
001FoEKm00H000=Q0P03001Q9F4U00=Q9@04001M9UdV0005E>L30006C<P00`00@8Q0R005@8P01@00
E_eFoEKm00001UKm0`0015LM0P00;Woo000`Ool3000DOol00`00MaH00004KcP00`00LeUcF@02LeT0
1000KgY_NVmj0P000U/m0P000ULM00<005LMEad00eLM0`001EKm00<005KlE_`00eKl0`0015Km00<0
05KmE_d015Km0`001EKm00<005KlE_`00P000UKm00<005KmE_d015Km00<005KlE_`00P000UKl00<0
05KlE_`00eKl00<005;mD_d00`000UKl00<005KmE_d00eKm0`0000AFo@00B400009LX004001Q0V42
0005HBD01000GBIM9P001UCW0P001Tc800<00428@8P0142800<005KmE_d00eKm00<005KmE_d00`00
00=Fo@00Ead01ELM00<007ooOol0;7oo000^Ool4000EOol00`00MaIg5P0200000flh001cF@03LeT0
0`00KgY_NP04KgX20005Ead00`00EaeG7@020002E_d00`00E_eFo@04E_d00`00E_aFo0020002E_d0
0`00E_eFo@03E_d00`00E_eFo@030002E_d00`00E_eFo@03E_d30004E_d00`00E_eFo@04E_d30004
E_`00`00E_aFo003E_`30005E_`00`00E_eFo@030002E_d00`00E_eFo@020002G:001@00H@9Q0V42
00001F4U0P001UCW0`001Tc800<00428@8P0142800<005KmE_d00eKm0`001EKm00<005LMEad00eLM
0P00;Goo000[Ool3000HOol00`00MaIg5P03MaH00`00LeUcF@03LeT00`00KgY_NP03KgX00`00Jg/0
0005Ead30005E_d00`00E_eFo@03E_d30005E_d01000E_eFoEKm10001UKm00<005KmE_d00P000UKm
00<005KmE_d00eKm00<005KmE_d00`000U;m00<005KlE_`00eKl00<005KlE_`00P000UKl00<005Kl
E_`00eKl0`001EKm00@005KmE_eFo@80009LX005001Q0V42H@800005HBD00`00E>MDi`02E>L20000
0e/M000000020004C<P00`00@8Q0R004@8P00`00E_eFo@0300000e;m001Fo@05E_d00`00EaeG7@03
00000eKl0000000/Ool002Uoo`8001]oo`03001g5WLF009g5P04001gEP000002LeT00`00KgY_NP03
KgX01@00Jg][Nf]k00000ULM0P000UKm00<005KmE_d015Km00<005KmE_d00P000UKm00<005KmE_d0
0eKm10000eKm00<005KmE_d015Km0`0015Km00<005KmE_d00eKm0`001E;m00<005KlE_`00eKl0`00
1EKl00<005KlE_`00P000UKm00<005KmE_d015Km00<005KmE_d00`000UbP00D00642H@9Q0P0000=Q
9@04001@a000E>L20002Fad30002B8H01000C<Q<b0001d280`001E;m00<005KmE_d00eKm0`001EKl
00<007ooOol0:Woo000VOol3000LOol00`00MaIg5P03MaH01000MeIgEWMF0P0016mj0P001F]k0P00
1EKm00<005KmE_d00eKm0`001EKm00<005KmE_d00P000UKl00<005KmE_d00eKm00<005KmE_d00`00
0UKl00<005KmE_d00eKm00<005KmE_d00P000UKl00<005;mD_d015;m00<005KlE_`00P000UKm00<0
05KlE_`00eKl0`0015Km00<005KmE_d015Km0`000UKl0P0000=LX000H@800V4200D0064UHBD00534
00<00004Fad000000002Fad20002B8H30007@8P00`00E_d00005D_d00`00E_eFo@030002E_`00`00
E_aFo003E_`2000[Ool002Aoo`800003Ool007oo01aoo`03001g5WLF009g5P03001gEWMF009gEP06
001kM`00001_NP001V]k00<006ML00001UKm00<005KmE_d00P000UKm00<005KmE_d00eKm0`0015Kl
00<005KmE_d00eKm0`001EKl00<005KmE_d00eKm0`001EKl00<005;mD_d00U;m10001EKm00<005Kl
E_`00P000ULM00<005KmE_d00eKm00<005KmE_d00`0000=Fo@00E_`00eKl1@000V42100000A?7P00
000000EK7@<000=8QP8000E0R004001FoEKm0005D_d30005E_`00`00E_aFo002E_`4000ZOol0029o
o`80021oo`03001g5WLF00=g5P03001gEWMF009gEP05001kMg]gNgL00005Jg/20002Ie`00`00E_eF
o@04E_d30005E_d00`00E_eFo@020002E_`00`00E_aFo003E_`00`00E_eFo@020002E_`00`00E_aF
o004E_`00`00E_eFo@020002D_d00`00E_aFo003E_`50003D_d00`00E_eFo@03E_d30004Ead00`00
E_eFo@03E_d30005E_d00`00E_aFo002E_`010002Q`:70XL0`000TlN0P0000=?7P00Fad015/M0`00
00IG?P00B8I8QP00>2@400000d28001Fo@02E_d00`00D_eBo@020002E_`00`00E_aFo003E_`50003
E_d2000YOol0025oo`<0021oo`03001g5WLF009g5P03001gEWMF009gEP06001kMg]gNgL007^h0P00
0V]k00<006MLIe`00fML00<005KmE_d00`000UKm00<005KmE_d00eKm0`0015Kl00<005KlE_`00eKl
0`001EKl00<005KlE_`00eKl0`001E;m00<005KlE_`00P000UKl00<005;mD_d00e;m00<005KmE_d0
0`000UKm00<005LMEad00eLM00<005KmE_d00P000UKl00<005KmE_d00eKm00<005KlE_`01@000`XL
0`0014lN00<005/MFad00P000eLn0P0000=8QP00>2@01CPT0P000UKm10001EKl00<005KlE_`00P00
0UKm00<005KmE_d00eKm0P00:Goo000ROol00`00Ool0000NOol00`00MaIg5P03MaH00`00MeIgEP02
MeH01@00NgMkMg]g00000g^h0P001VML0`001UKm00<005KmE_d00P000UKm00<005KlE_`00eKl00<0
05KlE_`00P000ULM00<005KlE_`015Kl00<005KlE_`00P000UKl00<005;mD_d00e;m0`0015Kl00<0
05;mD_d00e;m0`001EKm00<005LMEad00eLM0`001EKl00@005KmE_eFo@@000EFo0D000A?7P@000IG
?P<000Lh90<000=Fo@03001Fo5Kl00=Fo0<000AFo@03001FoEKm00=Fo@<000Moo`<000=oo`03001o
ogoo01Qoo`006goo00<007ooOol017oo00@007ooOol001eoo`03001g5WLF009g5P03001gEWMF009g
EP05001kMg]gNgL00004NkP01000MkX000000VML0P000U/m00<005KmE_d015Km0`0015Km00<005Kl
E_`00eKl0`0015LM00<005KlE_`015Kl0`001EKl00<005;mD_d00P000U;m00<005KlE_`00eKl00<0
05;mD_d00P000UKm00<005KmE_d015Km00<005LMEad00P000UKl00<005KlE_`00eKl10000eKm00<0
05KlE_`030000d<o00<005LnEch015Ln0`001SPT0P001EKm00<005KlE_`00`0000=Fo@00E_d01EKm
00<005KmE_d00P000UKl00<007ooOol01Goo00<007ooOol00Woo00<007oo00006Goo000JOol00`00
Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00MaIg5P03MaH00`00MeIgEP02MeH01@00
NgMkMg]g00000g^h00<007NjMkX00WNj0P001E/m0P000UKm0P000UKm00<005KmE_d00eKm00<005Kl
E_`00P000UKm00<005LMEad00eLM00<005KlE_`00`000UKl00<005KlE_`00eKl0`0015;m00<005Kl
E_`00eKl0`001EKm00<005KmE_d00UKm10001EKl00<005KlE_`00P000UKl00<005KmE_d00UKm0`00
00=Fo00000000UKm00<005Kl00000P001T<o00<005LnEch015Ln0P001SPT0P001EKm0`001EKm00<0
05KmE_d00eKm0`0015Kl0P001goo00L007ooOomoo`00Ool0000IOol001Yoo`03001oo`0000Aoo`03
001oogoo00=oo`03001oogoo01Qoo`03001g5WLF009g5P03001gEWMF009gEP05001kMg]gNgL00003
NkP00`00MkYg^P02MkX00`00Ji`00006Fcd30004E_d00`00E_eFo@03E_d30005E_d01000EaeG7ELM
10001UKl00<005KlE_`00P000ULM00<005;mD_d00e;m00<005KlE_`00P000UKm00<005KmE_d00eKm
1@000eKl00<005KlE_`00eKl0`0015Kl00<005Km00000P0000AFo@00000000AFo@04001Fo5KlE_`2
0006@cl00`00EciG?P0300000dMo00000004>2@01000E_aFo0000UKm0P000UKm00<005KmE_d00eKm
00<005KmE_d00`000UKl00<005KlE_`00UKl0`001Woo00L007ooOomoo`00Ool0000IOol001Yoo`03
001oo`0000Aoo`03001oogoo00Aoo`03001oogoo01Moo`8000=g5P03001gEWMF009gEP05001kMg]g
NgL00002NkP01000MkYg^WNj0P000f^L0P000U/m0P000UKl00<005KmE_d00eKm00<005KmE_d00P00
0U;m00<005KmE_d00eKm10000eKm00<005KlE_`015Kl0`0015LM00<005;mD_d00e;m0`001EKm00<0
05KmE_d00P000UKm00<005KlE_`00eKl00<005KlE_`00`0000=Fo@00E_`00eKl0`000UKm0P000U;m
00<005KmE_d00eKm00<005KlE_`02`001DMo1P000UKl0`001EKm00@005KmE_eFo@@000EFo003001F
o5Kl0080009Fo@03001oogoo00=oo`03001oo`00009oo`03001oo`0001Uoo`006Woo00<007oo0000
17oo00<007ooOol01Goo0P005Woo00<007LEMaD00`0017MF00D007]gNgMkM`00009k^005001g^WNj
MkX00007Ji`20005E_`01000E_eFoEKm10001E;m00<005KmE_d00P000ULM00<005KmE_d00eKm00<0
05KlE_`00`000UKm00<005LMEad00eLM00<005;mD_d00P000U;m00<005KmE_d00eKm0`0015Km00<0
05KlE_`00eKl0`001EKm00@005Kl0000009Fo0<000EBo@04001FoEKmE_d40005Ead00`00Ead00003
0004Agl5000015Kl000000000UKm00<005KmE_d00eKm10000eKm00<005KlE_`00eKl0`0015Km0`00
17oo00<007ooOol00Woo00<007ooOol067oo000KOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`0COol00`00MaEg5@02MaD20003MeH01000NgMkMg]g1`001V^L0P0000=O?@00E_`015Kl1000
0eKl00<005;mD_d00e;m0`0015LM00<005KmE_d00eKm0`001UKm00@005LMEaeG7@@000EBo@03001F
oEKm0080009Fo@03001FoEKm00=Fo@03001Fo5Kl0080009Bo@03001FoEKm009Fo@<00004E_`00000
0002Ead00`00D_eBo@03D_d40003D_d00`00EaeG7@03Ead30002E_`50002E_`40005E_d00`00E_eF
o@0300000eKm001Fo@04E_d00`00E_aFo00300000eKm001Fo@05E_d2000TOol0021oo`8000Yoo`03
001oogoo015oo`03001g5GLE00=g5@03001kE@0000P000=keP04001gn@000002Ji`20004Gcd00`00
E_aFo0020002E_`00`00E_aFo003E_`00`00D_eBo@020002D_d00`00EaeG7@03Ead00`00E_eFo@02
0002D_d00`00E_eFo@04E_d40003E_d00`00D_eBo@03D_d30004E_d00`00E_eFo@03E_d30005D_d8
0005Ead00`00D_eBo@0300000eKl001Bo@05D_d00`00EaeG7@020002E_`00`00E_aFo003E_`00`00
E_aFo00300000eKm001Fo@04E_d30005E_d00`00E_eFo@02E_d30005E_d00`00E_eFo@03E_d2000T
Ool0021oo`03001oogoo00Yoo`03001oogoo011oo`03001g5GLE009g5@05001kEG]ENeD00003OgD0
1000OkEo]@000g_F00@007OiMoUgn@8000IO?@<000AFo003001Fo5Kl00=Fo0<000ABo@03001G7ELM
00=G7@<000EBo@80009Fo@80009G7@03001FoEKm00=Fo@03001BoE;m0080009Fo@03001FoEKm00=F
o@03001FoEKm0080009Fo004001BoE;mD_d60003E_d00`00EaeG7@03Ead30005E_`00`00D_eBo@03
D_d30004E_`00`00E_aFo002E_`40002E_d01000E_eFo@000UKm0P0000=Fo@00E_d01EKm00<005Km
E_d00P000U;m00<005KmE_d00eKm00<005KmE_d00`000ULM00<007ooOol08Goo000POol00`00Oomo
o`0;Ool00`00Oomoo`0>Ool00`00MaEg5@03MaD01@00NeEkEG]E00000gme00<007ne00000g_F00@0
07OiMoUgn@800003Jk`00000009O?@80009Fo@03001Fo5Kl00=Fo003001Fo5Kl0080009Fo@03001B
oE;m00=Bo@03001G7ELM0080009Fo@03001BoE;m00ABo@<000AG7@03001FoEKm00=Fo@<000EFo@04
001FoEKmE_d40005E_`50002E_`00`00E_eFo@03E_d00`00EaeG7@020002E_d00`00E_aFo003E_`0
0`00D_eBo@030002E_`00`00E_aFo002E_`50003E_d01P00E_eFoEKm001Fo@<000AFo@03001FoEKm
00=Fo@<000EBo@04001FoEKmE_d40005Ead2000ROol0021oo`8000eoo`03001oogoo00eoo`03001g
5GLE009g5@05001kEG]ENeD00003OgD01000OkEo]@000W_F00D007OiMoUgn@0000E[_08000AFo@03
001Fo5Kl00=Fo0<000EFo@04001BoE;mD_d40005E_d00`00D_eBo@0300000eKm001G7@05Ead00`00
E_eFo@020002E_d00`00E_eFo@03E_d40003E_`00`00E_aFo0060004E_`00`00E_eFo@03E_d30004
E_d00`00E_aFo003E_`30005E_`00`00E_aFo0020002E_d00`00E_eFo@03E_d00`00E_eFo@030002
E_d00`00E_eFo@02E_d00`00E_eFo@030002E_d00`00D_eBo@03D_d40003E_d00`00EaeG7@03Ead2
000ROol0021oo`03001oogoo00eoo`03001oogoo00]oo`03001g5GLE00=g5@05001kEG]ENeD00003
OgD00`00OkD00003NmH01000MoT0000016^l0P0000=OG@00E_d015Km00<005KlE_`00P000UKm00<0
05KmE_d00eKm10000eKm00<005KmE_d00eKm0`001EKm00<005LMEad00eLM0`001EKm00<005KmE_d0
0P000UKl00<005KlE_`00eKl0P0000=Fo00000000UKm00<005KlE_`00eKl00<005KmE_d00P000UKl
00<005KmE_d00eKm00<005KlE_`00P000UKl00<005KlE_`00eKl0`0015Km00<005KmE_d00eKm0`00
0eKm00<005Km00000eKm10001EKm00<005;mD_d00`0000=Fo000E_d015Km00<005LMEad00`000U;m
00<007ooOol07goo000POol2000?Ool00`00Oomoo`0:Ool00`00MaEg5@02MaD01@00NeEkEG]E0000
0gme00@007neOkD0009keP04001gn@000003Jk`20004Ged01000E_eFoEKm10001EKm00<005KmE_d0
0P000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d00eKm00<005LMEad00`000UKl
00<005KmE_d00eKm0`0015Kl00<005KlE_`01P0015Km00<005KlE_`00eKl0`001EKl00@005KmE_eF
o@@000EFo003001Fo5Kl0080009Fo@03001FoEKm00=Fo@03001FoEKm0080009Fo006001FoEKmE_d0
05Km10000eKm00<005KmE_d00eKm0`001EKl00<005KmE_d00UKm0`001E;m0P0087oo000OOol2000A
Ool00`00Oomoo`08Ool00`00MaEg5@03MaD01@00NeEkEG]E00000Wme00@007neOkD000=keP80009c
n0<000IOG@@000=Fo@03001FoEKm00=Fo@<000AFo@03001FoEKm00=Fo@<000EFo@04001FoEKmE_d4
0005E_`00`00E_eFo@0300000eKm001Fo004E_`300000eKl00000002Ead00`00E_eFo@03E_d00`00
E_aFo0020002E_`00`00E_aFo003E_`40003E_d00`00E_aFo003E_`30005E_d01000E_eFoEKm1000
1EKl00<005KmE_d00P0000=Fo@00E_d01EKm00<005KmE_d00P000UKl00<005KlE_`00eKl00<005Km
E_d00P000UKm00<005;mD_d00e;m0P0087oo000:Ool00`00Oomoo`02Ool01000Oomoogoo0`000goo
00<007ooOol00goo00<007ooOol04Goo00<007ooOol01goo00<007LEMaD00WLE00D007]ENeEkE@00
00=oM@04001o]Gne0002NmH00`00Lm@00003LoP01000Jk`000000UmM0P000UKm00<005KmE_d00eKm
00<005KmE_d00P000UKm00<005KmE_d00eKm00<005KmE_d00P000UKm00<005KmE_d00eKm10000eKl
00<005KlE_`00eKl0`001EKm00<005Kl00000P0000AFo000000000AG7@03001FoEKm009Fo@@000EF
o003001Fo5Kl00800003E_`005Km00EFo@03001Fo5Kl0080009Fo@03001FoEKm00=Fo@@000=Fo003
001Fo5Kl00=Fo0<0009Fo@03001Fo@0000EFo@<000AFo003001Fo5Kl00=Fo0<000EFo@03001BoE;m
00800003E_`0000001moo`002Goo00<007oo00001goo00<007ooOol00Woo00<007oo000017oo0P00
4goo00<007ooOol01Goo00<007LEMaD00gLE00D007]ENeEkE@00009oM@05001o]Gne001keP020000
17?D001cn7?h0P000f^l0`0015Km00<005KmE_d00eKm0`001EKm00@005KmE_eFo@@000EFo@03001F
oEKm0080009Fo@03001Fo5Kl00=Fo003001Fo5Kl0080009Fo@03001FoEKm009Fo@<00004E_`00000
0002E_d00`00EaeG7@02Ead50003E_d00`00E_aFo003E_`30004E_`00`00E_eFo@03E_d30004E_d0
0`00E_eFo@0300000eKl001Fo004E_`00`00E_aFo0030002E_d01000E_eFoEKm0P000UKm0`000UKl
00<005KlE_`00eKl00<005KlE_`00P000UKl00<005KmE_d00eKm0`0015Kl0P007Woo0009Ool00`00
Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00
MaEg5@02MaD01@00NeEkEG]E00000gme00<007neOkD00P0000=gd`0000000W?h00@006^lJka[_080
009K?@03001FoEKm00=Fo@03001FoEKm0080009Fo@03001FoEKm00AFo@<000=Fo003001FoEKm00=F
o@<000AFo@03001Fo5Kl00=Fo0<000EFo@P000EFo@03001G7ELM0080009Fo003001FoEKm00=Fo@03
001Fo5Kl00<0009Fo@03001Fo5Kl009Fo003001FoEKm00<0009Fo@03001FoEKm009Fo@<000EFo003
001Fo5Kl009Fo0<000EFo@04001FoEKmE_d40005E_`00`00E_aFo002E_`40004E_`00`00E_eFo@03
00000eKl001Fo004E_`2000NOol000Uoo`03001oo`0000Qoo`04001oogooOol20005Ool00`00Oomo
o`0DOol00`00Oomoo`02Ool00`00MaEg5@03MaD01@00NeEkEG]E00000Wme00@007ne0000009gd`80
009cn0D000EK?@8000=Fo@<000EFo@80009Fo@800003E_`005Kl00AFo003001FoEKm0080009Fo003
001FoEKm00=Fo@03001Fo5Kl0080009Fo@03001FoEKm009Fo@D000=Bo@03001FoEKm00=Fo@<000AF
o003001FoEKm00=Fo@<000EFo@04001Fo5KlE_`40005E_d00`00E_eFo@020002E_d00`00E_aFo003
E_`00`00E_aFo0020002E_`00`00E_eFo@03E_d4000015Kl001Fo0001EKl1@000eKl00<005KlE_`0
0UKl0`001EKl00<005KlE_`00UKl0`007Goo0009Ool00`00Ool00007Ool00`00Ool00002Ool00`00
Oomoo`03Ool2000GOol01@00Oomoogoo000017LE00D007]ENeEkE@0000=oM@800005Ok@007OC001c
e0030002JoX00`00Hid00006Fcd40002E_d00`00E_eFo@04E_d30004E_`00`00E_aFo003E_`20005
E_`01000E_eFoEKm10001EKm1@000UKm00<005;mD_d00e;m00<005KmE_d00P000UKm00<005KlE_`0
0eKl00<005KmE_d00P000UKl00<005KmE_d00eKm10000eKl00<005KmE_d00eKm0`0015Km00<005Kl
E_`00eKl0`001EKl00<005KmE_d00P000UKl00L005KlE_aFo000E_`00002E_`200000eKm001Fo005
E_`00`00E_aFo0020002E_d00`00E_aFo003E_`00`00E_aFo002000015KK001oo`0077oo000:Ool0
0`00Oomoo`07Ool01000Oomoogoo0`0017oo00<007ooOol05Woo00<007ooOol00P000gLE00D007]E
NeEkE@00009oM@04001o]7nd0002Mm<400000f_j00000003Hid20002Fcd20002E_`00`00E_eFo@02
E_d20002E_d20002E_`00`00E_aFo003E_`00`00E_aFo00200000eKm001Fo004E_`40003D_d01000
E_eFoEKm1@0015Km00<005;mD_d00e;m0`001EKm00@005KlE_aFo0@000EFo003001FoEKm0080009B
o@03001Fo5Kl00=Fo003001FoEKm0080009Fo@03001FoEKm00=Fo@03001Fo5Kl0080009Bo@03001F
o5Kl00=Fo0<000AFo006001Fo5KlE_`005Kl0`0015Km00<005KlE_`00eKl0`0015Km00<005KlE_`0
0UKl100015KK0P0077oo000NOol00`00Oomoo`0HOol20002MaD30003NeD00`00OgD000020002Ok@0
2000Mm<00000Hk8006_j0006Hid30004E_`00`00E_eFo@03E_d30004E_`00`00E_aFo003E_`30004
E_d00`00E_aFo0020002E_`00`00D_eBo@03D_d50002E_d00`00E_eFo@03E_d00`00D_eBo@020002
E_d00`00E_eFo@03E_d40003E_`00`00E_aFo003E_`30004D_d00`00E_aFo003E_`30005E_d01000
E_eFoEKm10001E;m00<005KlE_`00P000ULM00<005KlE_`00eKl00<005KlE_`00P000UKl00<005Km
E_d00UKm00<005KlE_`00`000UKm00<005KmE_d00UKm1@000eKl00<005KKE]/00UKK00<007oo0000
6goo000NOol2000JOol00`00MaEg5@02MaD600001WnE001o]7nd001gd`H00003Hmd00000009SW@80
009Fo@03001Fo5Kl00=Fo003001FoEKm0080009Fo@03001Fo5Kl00=Fo003001Fo5Kl0080009G7@03
001FoEKm00=Fo@8000AFo003001BoE;m00H000EFo@04001FoEKmE_d40005E_d00`00E_eFo@020002
D_`00`00E_aFo003E_`00`00E_aFo0020002Ead00`00D_eBo@03D_d00`00E_aFo0020002Ead00`00
E_eFo@03E_d40003E_d00`00D_eBo@03D_d30004Ead00`00E_aFo002E_`40002E_`00`00E_`00003
E_d40005E_d00`00E_eFo@020002D_d00`00E_aFo003E_`01000E]]FfeKK0`0000=oo`00Ool06Goo
000NOol00`00Oomoo`0HOol00`00MaEg5@03MaD01@00NeEkEG]E00000WnE00D007ndOk@007OC00D0
00=Sg@<000EFo@04001Fo5KlE_`40005E_d01000E_aFo5Kl10001ELM00<005KmE_d00P0000=Fo000
E_`00eKl0`0000=Bo@0000000U;m00<005KmE_d00eKm10000e;l00<005KmE_d00eKm0`0015;l00<0
05KlE_`00eKl0`001ELM00@005;mD_eBo@@000EG7@03001FoEKm0080009Fo003001FoEKm009Fo@03
001BoE;m00<0009Fo@03001G7ELM009G7@D000=Fo004001Fo5KlE_`50003D_d00`00E_eFo@03E_d3
0004D_d00`00E_aFo003E_`40002CSP00`00Ool0000JOol001ioo`03001oogoo01Qoo`03001g5GLE
009g5@05001kEG]ENeD00002OiD01@00OkAo]000Mm<010000f?M0P000ULL00<005KmE_d00eKm1000
0eKl00<005KmE_d00eKm10000eKm00<005LMEad00eLM0`0015Kl20001E;m00<005KmE_d00P000UKm
00<005;lD_`00e;l00<005KmE_d00P000UKm00<005;lD_`00e;l00<005KlE_`00P000ULM00<005LM
Ead00eLM10000eKm00<005LMEad00eLM0`0015Kl00@005KmE_eFo@@000EFo@03001G7ELM0080009F
o@03001Fo5Kl00=Fo003001Fo5Kl0080009G7@03001BoE;m00=Bo@03001FoEKm0080009Fo@03001B
oE;m00=Bo@03001Fo5Kl00800003CUT004hh00A>>003001oo`0001Uoo`007Goo0P006Goo00<007LE
MaD00gLE00D007]ENeEkE@00009oU@03001o]7nd00800003Hhl0000000@000EG7003001FoEKm0080
009Fo003001Fo5Kl00=Fo003001FoEKm0080009Bo@03001FoEKm00=Fo@03001G7ELM0080009Fo@04
001Fo5KlE_`50003E_d00`00D_eBo@03D_d30004E_d00`00D_aBo003D_`30005E_d01000D_aBo5;l
10001ELM00<005LMEad00P000UKm00<005KmE_d00UKm00<005LMEad00`000UKl00<005KlE_`00UKl
10000e;m00<005KmE_d00eKm0`0015Km00<005KlE_`00eKl0`000ULM00<005LM000015;m100015Km
00<005;mD_d00U;m100014iI00<004hhCSP00Thh00@007ooOol001Qoo`007Woo00<007ooOol05goo
00<007LEMaD00WLE00D007]ENeEkE@00009oU@03001o]7nd00L0009K?@03001G75LL00=G70<000AF
o003001Fo5Kl00=Fo0<000EBo@04001FoEKmE_d40005E_d500000eKm001Fo@04E_d00`00D_eBo@02
0002E_`00`00E_eFo@03E_d00`00D_aBo0020002E_`00`00E_eFo@03E_d40003D_d00`00EaeG7@03
Ead30004E_d01000E_eFoEKm10001EKl00<005KlE_`00P000UKl00<005;mD_d00e;m00<005KmE_d0
0P000UKm00<005KmE_d00eKm00<005KlE_`00P000ULM00@005LMEaeG7@H000=Fo@03001FoEKm009F
o@D0009BVP03001>FDiI00=>F@03001>>4hh009>>004001oo`00000HOol001eoo`03001oo`0001Mo
o`03001g5GLE00=g5@05001kEG]ENeD00002OiD00`00OkAo]00200000f>?00000005Fcd00`00EaaG
70020002Ead00`00E_aFo003E_`00`00E_aFo0020002E_d00`00D_eBo@03D_d40003Ead00`00E_eF
o@060004E_d01000E_eFoEKm10001EKl00@005KmE_eFo@@000EFo003001FoEKm0080009Bo@03001B
oE;m00=Bo@03001G7ELM0080009G7@03001FoEKm009Fo@@000=Fo@03001Fo5Kl00=Fo0<000EFo004
001BoE;mD_d40004E_d00`00E_eFo@02E_d40004Ead00`00EaeG7@0300000eKm001Fo@04E_d00`00
E_eFo@020002E]`00`00DYYBVP03DYX00`00CUU>F@02CUT00`00CSQ>>003CSP01000Oomoo`005goo
000MOol2000HOol00`00MaEg5@02MaD01@00NeEkEG]E00000gnE00<007nd00000`0000=KOP00Fcd0
1E/m0P001ELM00@005KlE_aFo0@000EFo@03001BoE;m0080009Bo@03001G7ELM009G7@<00003E_d0
0000009Bo@03001FoEKm009Fo@@000=Fo@03001Fo5Kl00=Fo0@000=Bo@03001Fo5Kl00=Fo0<000EB
o@04001BoE;mD_d40004Ead00`00E_eFo@020002E_`00`00E_eFo@03E_d00`00E_aFo0020002E_`0
0`00E_aFo003E_`40003E_d00`00E_eFo@02E_d50003D_d00`00EaeG7@02Ead30002E_d01000E_eF
o@000eKm100015KL00<005:JDYX00e:J00<004iICUT00diI00<004hhCSP00Thh00@007ooOol001Mo
o`003Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol05goo00<007LE
MaD00WLE00D007]ENeEkE@00009oU@03001o]7nd00<000=KOP80009K?@800003E_d005LM00EG7@<0
00=Fo@03001FoEKm00=Fo@<000EBo@P000ABo@03001FoEKm0080009G7@03001FoEKm00=Fo@03001F
o5Kl0080009Fo003001BoE;m00=Bo@03001Fo5Kl0080009Fo003001BoE;m00=Bo@@000=Bo@03001G
7ELM009G7@<000EFo004001FoEKmE_d40005E_`00`00E_aFo00200000eLM001Fo@04E_d00`00E_eF
o@020002E_d00`00D_eBo@03D_d00`00EaeG7@020002E_`01P00E_eFoEKm001Fo@@000=Fo@03001F
g5KL00=Fg003001BVU:J009BVP03001>FDiI00=>F@03001>>4hh00=>>004001oogoo000FOol000ao
o`03001oo`0000Moo`03001oo`0000Aoo`8001Moo`03001g5GLE009g5@05001kEG]ENeD00003OiD0
1000Ok@006n`0P000e]n100015Km0P000ULM0P0000=Fo@00E_d015Km00<005KmE_d00P000UKm00@0
05;mD_eBo@H000=Fo@03001BoE;m00=Bo@8000EG7@04001FoEKmE_d40005E_`01000D_eBoE;m1000
1EKl00<005;mD_d00P000UKm00<005;mD_d00U;m00<005LMEad00P000UKl00<005KlE_`00eKl1000
0eKm00<005KlE_`00eKl0`0015LM00<005KmE_d00UKm0`001EKm00@005;mD_eBo@@000AFo003001F
oEKm00<0009Fo@03001FoEKm009Fo@03001Fg5KL00=Fg003001BVU:J00=BVP03001>FDiI00=>F@03
001>>4hh00<000=oo`03001oogoo01=oo`0037oo00<007oo00002Goo00<007ooOol00Woo00<007oo
Ool05Woo00<007LEMaD00WLE00D007]ENeEkE@00009oU@04001o]000Kk060003D_d20003E_d40004
E_d01000E_eFoEKm10001EKm1@000UKm00<005KmE_d00eKm00<005;mD_d00P0000=G7@00Ead015LM
10000eKl00<005KlE_`00eKl10000e;m00<005KlE_`00eKl0`0015Km00@005;mD_eBo@@000EFo003
001Fo5Kl00800003Ead005Km00AFo@03001Fo5Kl00<0009G7@03001G7ELM009G7@03001FoEKm0080
009Fo@03001FoEKm00=Fo@@000=Fo003001Fo5Kl009Fo0<0009Fo@04001FoEKm0003E_dF0002BOH0
1@00Oomoogoo00005Goo000<Ool00`00Ool00007Ool20005Ool00`00Oomoo`0EOol00`00MaEg5@02
MaD01@00NeEkEG]E00000gnE0`0000=_/00000000UKl00<005;mD_d00e;m10000eKm00<005KmE_d0
0eKm0`000eKm00@005KmE_eFo@D000EFo@04001FoEKmE_d40004Ead00`00EaeG7@020002E_`00`00
E_aFo003E_`00`00E_aFo0020002E_d00`00D_eBo@03D_d00`00E_aFo0020002Ead00`00E_eFo@02
E_d40003E_`00`00E_aFo003E_`30004Ead00`00E_eFo@02E_d30005Ead01000EaeG7ELM10001EKm
00<005KmE_d00P000UKm00<005KlE_`00UKl00<005KlE_`00P000UKm00H005KmE_eFo@00E_d40002
C[/00`00BUU:F@03BUT00`00BQQ:6002BQP00`00BOI9mP03BOH00`00BOI9mP02BOH01000Oomoogoo
0P0057oo000<Ool00`00Ool00007Ool00`00Oomoo`03Ool2000GOol00`00MaEg5@02MaD01@00NeEk
EG]E00000WnE0`0000=_/000E_`015Kl00<005;mD_d00P000UKl00<005KmE_d00eKm00<005KmE_d0
0P0000=Bo@00E_d015Km1@000UKm00<005KmE_d00eKm10000e;m00<005LMEad00eLM0P0015Kl00<0
05KlE_`00eKl0`001EKm00@005;mD_eBo@@000AG7@03001FoEKm0080009Fo@03001Fo5Kl00=Fo003
001Fo5Kl0080009G7@03001G7ELM009G7@03001FoEKm0080009Bo@03001G7ELM00=G7@@000=Fo003
001FoEKm00=Fo@<000AFo@04001Fo5KlE_`40005E_d00`00E_eFo@0200000eKm001>^`04C[/00`00
BUU:F@03BUT00`00BQQ:6002BQP00`00BOI9mP03BOH00`00BOI9mP02BOH00`00Oomoo`02Ool00`00
Oomoo`05Ool20004Ool00`00Oomoo`03Ool000eoo`03001oogoo00Ioo`<000=oo`03001oogoo01Eo
o`03001g5GLE009g5@05001kEG]ENeD00003OiD01@00Nm@006n`00001UKl0P001EKl00@005KmE_eF
o@@000ABo@P000EFo@03001FoEKm0080009Fo@03001BoE;m00=Bo@03001G7ELM00800003E_`005Kl
00AFo003001Fo5Kl0080009Fo@03001FoEKm00=Fo@@000=Bo@03001G7ELM009G7@<000EFo@04001F
o5KlE_`40004Ead01000EaeG7ELM10001E;m00<005LMEad00P000UKl00<005KlE_`00UKl00<005Km
E_d00`000UKl00<005KmE_d00UKm10000eKm00<005KmE_d00eKm0`000UKm00<005Km000014jk00<0
04YIBUT00dYI00<004XHBQP00TXH00<004WfBOH00dWf00<004WfBOH00TWf00<007ooOol00Woo00<0
07ooOol01goo00H007ooOol007oo0004Ool001aoo`03001oogoo01Eoo`03001g5GLE009g5@06001k
EG]ENeD007nE0P0000Eke000Kk0007oo0080009Fo0800003E_`005Kl00AFo0@000=Fo004001BoE;m
D_d60002E_d00`00E_eFo@03E_d30005E_d01000D_eBoE;m100015Kl00@005KlE_aFo0@000EFo@03
001FoEKm0080009Fo@03001BoE;m009Bo@03001G7ELM0080009Fo@03001FoEKm00=Fo@@000=G7@03
001G7ELM009G7@@000=Fo003001BoE;m00=Bo@<000AFo004001Fo5KlE_`40005E_`00`00E_eFo@02
0002E_d00`00E_eFo@02E_d00`00E_eFo@030002E_d01P00E_eFo@00E_d000E>^`03001:FDYI009:
F@03001:64XH009:60030019mTWf00=9mP030019mTWf0099mP03001oogoo00=oo`03001oogoo00Eo
o`07001oogooOol007oo000017oo000LOol2000EOol01P00LcH00000MaD000=kE@<00003NkH007_D
008000Aoo`8000AFo003001Fo5Kl0080009Fo003001Fo5Kl00=Fo0D0009Fo003001FoEKm009Fo@03
001FoEKm0080009Fo@03001FoEKm00=Fo@@000=Fo003001Fo5Kl009Fo0@000=Fo@03001FoEKm00=F
o@<000AFo@04001BoE;mD_d40005E_d00`00E_eFo@020002D_d00`00EaeG7@02Ead00`00EaeG7@02
0002E_`00`00E_aFo003E_`00`00D_eBo@020002E_`00`00E_aFo002E_`40003E_d00`00E_aFo003
E_`30004E_d01000E_eFoEKm10001EKm00@005KmE_eFo@D0009>^`03001:FDYI009:F@03001:64XH
009:60030019mTWf00=9mP030019mTWf0099mP03001oogoo00Aoo`03001oogoo00Eoo`06001oogoo
001oo`0017oo000LOol00`00Oomoo`0DOol01000LcIc=W<f1P000W^f00D007_D001_/00000Eoo`03
001Fo5Kl00=Fo08000AFo003001Fo5Kl00H000EFo004001FoEKmE_d30005E_d00`00E_eFo@020002
E_`00`00E_aFo002E_`00`00E_aFo0020002E_d00`00E_eFo@03E_d00`00E_eFo@020002E_d00`00
E_eFo@03E_d30003E_`00`00E_eFo@03E_d30004D_d01000EaeG7ELM10001EKl00@005KlE_aFo0@0
00AFo003001Fo5Kl0080009Fo003001FoEKm00=Fo@03001Fo5Kl0080009Fo003001FoEKm009Fo@@0
00=Fo@03001FoEKm00=Fo@@00003C[`000000096>@H0009:F@03001:64XH009:60030019mTWf00=9
mP030019mTWf0099mP03001oogoo00=oo`03001oogoo00=oo`03001oo`00009oo`03001oo`0000Ao
o`0077oo00<007ooOol04goo00<007<fLcH00W<f00D007]GNeMkE`0000=k]P04001ke0000007Ool0
0`00E_aFo00200000eLM001Fo004E_`200000eKl00000002E_`00`00E_aFo003E_`40002E_d00`00
E_eFo@03E_d30005E_`01000E_aFo5Kl0`001EKm00@005KmE_eFo@@000EFo@03001FoEKm00800003
E_d005Kl00AFo003001FoEKm0080009Fo003001BoE;m00=Bo@<000=Fo003001Fo5Kl00=Fo0@000=F
o@03001Fo5Kl009Fo0<000EFo004001FoEKmE_d40004E_`00`00E_eFo@020002E_d00`00E_eFo@03
E_d00`00E_eFo@0200000eKm001>_003C[`20004AST00`00@MM1e`030004BQP00`00BOI9mP03BOH0
0`00BOI9mP02BOH00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
01]oo`8001Eoo`03001c=W<f009c=P05001kEg]GNeL00002NkH01000Nm@000002Goo0P0015LM2000
1EKl00<005KlE_`00P000ULM00<005KmE_d00UKm00<005KmE_d00P000UKm00<005KlE_`00eKl1000
0UKm00<005KmE_d00eKm10000eKl00<005KmE_d00eKm0`0015Km00@005KlE_aFo0@000EFo003001B
oE;m00800003E_d005Kl00AFo003001Fo5Kl0080009Fo003001FoEKm009Fo@03001Fo5Kl0080009F
o003001Fo5Kl00=Fo0@000=Fo003001Fo5Kl009Fo0<000EFo@04001FoEKmE_d40004E_d01000C[a>
_4jl0P0014Hi00<0047G@ML00T7G0`000TXH00<004WfBOH00dWf00<004WfBOH00TWf00<007ooOol0
0goo00<007oo00003goo000KOol00`00Oomoo`0COol00`00LcIc=P02LcH01@00NeMkEg]G00000g^f
00@007_D000000Yoo`04001G7ELMEad60002E_d00`00E_aFo003E_`30005Ead01000E_eFoEKm0`00
1EKm00<005KlE_`00P000UKm00<005KmE_d00UKm00<005KmE_d00P000UKl00<005KlE_`00eKl00<0
05KmE_d00P000UKl00<005KmE_d00UKm10000eKm00<005KlE_`00eKl0`0015Km00@005KlE_aFo0@0
00AFo004001FoEKmE_d40005E_`00`00E_aFo0020002Ead00`00E_aFo002E_`00`00E_aFo0020002
E_`00`00E_eFo@03E_d40003E_d00`00E_eFo@02E_d00`00C[a>_002C[`20004AST00`00@MM1e`02
@ML01P00@KH00000BQP000A9mP030019mTWf0099mP03001oogoo00Eoo`03001oogoo00eoo`006goo
00<007ooOol04goo00<007<fLcH00W<f00D007]GNeMkE`00009k]P04001ke000000<Ool50002E_`0
0`00E_eFo@02E_d00`00E_aFo0020002Ead00`00EaeG7@03Ead40002E_`00`00E_eFo@03E_d30005
E_d01000E_eFoEKm0`001EKl00@005KlE_aFo0@000AFo003001FoEKm0080009Bo@03001FoEKm00=F
o@03001Fo5Kl0080009G7@03001FoEKm009Fo@@000=Fo@03001Fo5Kl009Fo0@000=Fo@03001Fo5Kl
00=Fo0<000AG7@04001Fo5KlE_`40005E_`00`00E_eFo@020002E_d00`00E_eFo@02E_d01000E_eF
oEKm1@000Tjl00<004HiAST00THi00<0047G@ML00T7G00@0046f@KI1]P@000=9mP030019mTWf0099
mP03001oogoo00Eoo`03001oogoo00aoo`006goo0P004goo00<007<fLcH00W<f00D007]GNeMkE`00
00=k]P03001ke00000Yoo`<00003Ool0000000EFo004001FoEKmE_d30005Ead00`00EaeG7@020002
E_`00`00E_aFo002E_`00`00E_eFo@020002E_d00`00E_eFo@03E_d40002E_d00`00E_aFo003E_`4
0003E_`00`00E_aFo002E_`30005D_d01000E_eFoEKm100015LM00<005KmE_d00P000UKm00<005Km
E_d00UKm00<005KlE_`00P000UKm00<005KmE_d00eKm00<005KlE_`00P000UKm00<005LMEad00ULM
10000eKl00<005KlE_`00eKl0`0015Km00@005KmE_eFo@D0009>_003000n>Shj00@000=6>@030011
ed7G0091e`030011]T6f0091]P030015]DFe00H00099mP03001oogoo00Ioo`03001oogoo00]oo`00
6goo00<007ooOol04Woo00<007<fLcH00W<f00D007]GNeMkE`00009k]P04001ke0000007Ool30005
Ool00`00E_aFo003E_`40002E_d20003Ead40005E_`01000E_aFo5Kl0`001EKm00<005KmE_d00P00
0UKm00<005KmE_d00UKm00<005KlE_`00P000UKm00<005KlE_`00UKl00<005KlE_`00P000UKm00<0
05;mD_d00e;m10000eLM00@005LMEaeG7@@000EFo@04001FoEKmE_d30005E_d01000E_eFoEKm1000
15Km00<005LMEad00P000UKm00<005KlE_`00eKl00<005KlE_`00P000ULM00<005KmE_d00UKm1000
0eKm00<004jlC[`00Tjl00<003hj?SX00Shj0`0000=6>@00@ML00d7G00<0046f@KH00T6f00<004Fe
AKD00dFe00<004FeAKD00`0027oo00<007ooOol02goo0006Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00LcIc=P02LcH01@00NeMkEg]G
00000g^f0`001Woo0P002Goo00<005KlE_`00P000UKm00<005KmE_d00eKm0`000eKl00<005KlE_`0
0eKl10000UKm0P000eKm100015Km00@005KmE_eFo@@000EFo@04001Fo5KlE_`30005E_d00`00D_eB
o@020002D_d00`00EaeG7@02Ead40003E_`00`00E_eFo@03E_d40002D_d00`00E_eFo@03E_d40003
D_d01000E_eFoEKm10001EKm00@005KlE_aFo0@000AG7@03001FoEKm0080009Fo003001FoEKm009F
o@03001>_4jl009>_003000n>Shj008n>P800004=KP000000004@ML00`00@KI1]P02@KH00`00AKE5
]@02AKD00`00AKE5]@02AKD00`00Oomoo`06Ool2000<Ool000Eoo`03001oo`0000Qoo`07001oogoo
Ool007oo00000goo0P004goo00<007<fLcH00W<f00D007]GNeMkE`00009k]P<000Aoo`<000aoo`80
00EFo@03001FoEKm00800003E_`005Kl00AFo003001Fo5Kl0080009Fo@03001FoEKm00=Fo@<000=F
o@03001FoEKm00=Fo@<000=Bo@03001FoEKm00=Fo@@0009G7@8000=Fo@@000ABo@03001G7ELM0080
009Fo003001Fo5Kl00=Fo003001FoEKm0080009Fo003001BoE;m009Bo@03001FoEKm0080009Fo003
001BoE;m009Bo@@000=G7@03001FoEKm00=Fo@@000=G7@04001G7ELMEad40004E_`01000E_eFoEKm
1@000Tjl00<003hj?SX00Shj0P000SFh00<0047G@ML00T7G00<0046f@KH00T6f00<004FeAKD00dFe
00D004FeAKE5]@0000Eoo`<00003Ool007oo00]oo`001Goo00<007oo000027oo00<007ooOol00goo
00D007ooOomoo`0001=oo`03001c=W<f009c=P05001kEg]GNeL00003NkH01000LoD007oo0`0047oo
00<005KmE_d00eKm0`0015Kl00@005KlE_aFo0@000EFo@03001FoEKm00800003E_d005Km00AFo@03
001FoEKm00800003E_d005;m00ABo@03001FoEKm0080009Bo@03001G7ELM009G7@@000=Fo@03001B
oE;m00=Bo@8000EFo004001Fo5KlE_`40004E_`01000D_eBoE;m100015Kl00<005;mD_d00P000U;m
00<005LMEad00eLM00<005KmE_d00P000U;m00<005LMEad00ULM10000eKl00<005KlE_`00UKl1000
0Tkm00<003iL?U`00`0013hj0P000SFh0`000T7G00<0046f@KH00T6f00<004FeAKD00dFe00<004Fe
AKD00TFe1@0017oo00<007ooOol02Woo0005Ool00`00Ool00009Ool00`00Oomoo`020004Ool00`00
Oomoo`0@Ool01000JcT000000W<f00D007]GNeMkE`00009k]P03001cm@00008001Aoo`03001FoEKm
0080009Fo003001Fo5Kl00=Fo0<000=Fo@03001FoEKm00=Fo@<000AFo@04001FoEKmE_d40004E_d0
1000D_eBoE;m100015;m00<005LMEad00P000UKm00<005KmE_d00eKm00<005;mD_d00P0000=Fo@00
E_`015Kl10000eKl00<005KlE_`00UKl10000e;m00@005KlE_aFo0@000EBo@04001G7ELMEad40004
D_d00`00EaeG7@020002E_`00`00E_aFo002E_`00`00E_aFo0020002E_d00`00C_e>o@02C_d01000
?U`nG3iL0`000Shj00<003Fh00000SFh00D003FF0011e`0000A1]P030015]DFe00=5]@030015]DFe
0095]@03001oogoo00Ioo`03001oogoo00Yoo`001Goo00<007oo00001goo00<007oo00000Woo00<0
07ooOol00goo0P0047oo00<006/iJcT00V/i0`000W]G00<007^f00000`0067oo0P001EKl00<005Kl
E_`00P0000=G7@00E_d015Km00<005KmE_d00P000UKl00<005KmE_d00UKm10000eKm00<005KmE_d0
0eKm0`000eKl0P000e;m0`001EKm00@005KmE_eFo@@000AFo@03001Fo5Kl0080009Fo@03001Fo5Kl
009Fo003001Fo5Kl0080009Fo003001BoE;m00=Bo@<000=Fo003001BoE;m00=Bo@@000=Fo@04001B
oE;mD_d40004E_`01000E_aFo5Kl100015Km00<004kmC_d00Tkm00<003iL?U`00SiL00D002fi000n
>P00008e^003000e^000008eUP<000A1]P030015]DFe0095]@030015]DFe0095]@03001oogoo00Mo
o`03001oogoo00Uoo`001Woo00<007ooOol01Woo0`000Woo0`000goo00<007ooOol03Woo00<006/i
JcT00f/i00<006mjKgX01P0000=cm@00Ool067oo0P000eKl100015LM00@005KmE_eFo@@000AFo003
001FoEKm0080009Fo@03001FoEKm00=Fo@03001FoEKm00800003E_`005Kl00AFo0@0009Fo003001F
oEKm00=Fo@@000=Fo@04001FoEKmE_d40004E_d01000E_aFo5Kl10001EKl00<005;mD_d00P0000=B
o@00E_`015Kl00<005;mD_d00P000UKm00<005KmE_d00UKm10000eKm00<005KlE_`00UKl10000eKm
00<005KmE_d00UKm1`000ciL00<002fi;KT00`0000@e^000=KP000@eUP030011]T6f0091]P030015
]DFe0095]@030015]DFe0095]@03001oogoo00Moo`03001oogoo00Uoo`006Woo00<007ooOol03Goo
00<006/iJcT00f/i00@006mjKgY_NP80009g^@03001cm@0001aoo`<000=G7@03001G7ELM00=G7@<0
00=Fo08000=Fo0<000EFo@04001FoEKmE_d40004E_`00`00E_aFo0020002E_`00`00E_aFo002E_`0
0`00E_eFo@020002E_d00`00E_eFo@03E_d30003E_d00`00E_eFo@03E_d30003Ead00`00E_aFo003
E_`30004D_d01000E_aFo5Kl100015Km00<005KmE_d00P000UKm00<005KmE_d00UKm00<005KlE_`0
0P000UKm00<005KmE_d00UKm00<005KmE_d00P000UKl00<004:m@[d00T:m0P000SiL00D002fi;KT]
^@00008e^08000@eUP8000=1]P030015]DFe00=5]@030015]DFe0095]@03001oogoo00Ioo`03001o
ogoo00Uoo`006Goo0P003Woo00<006/iJcT00f/i00<006mj00000`000WNi00@007?eLoD001eoo`03
001G7ELM00=G7@03001G7ELM00800003E_`005Kl00AFo0@0009Fo003001FoEKm00=Fo@@000=Fo004
001Fo5KlE_`40004E_`01000E_aFo5Kl10001EKm00<005KmE_d00P0000=Fo@00E_d015Km00<005Km
E_d00P0000=Bo@00Ead015LM00<005KlE_`00P000ULM00<005;mD_d00U;m10000eKm00<005KmE_d0
0UKm0`0015Km00@005KmE_eFo@@000AFo@04001FoEKmE_d40004E_`00`00@[e2_@02@[d00`009M/0
00020003;KT20002=KP20003=IH00`00>ID00002@KH00`00AKE5]@03AKD00`00AKE5]@02AKD00`00
Oomoo`06Ool00`00Oomoo`09Ool001Uoo`03001oogoo00]oo`8000E[>@<000=_NP06001g^GNi001c
m@007goo00@005LMEaeG7@@000AFo003001Fo5Kl0080009Fo@03001Fo5Kl009Fo003001FoEKm0080
009Fo003001Fo5Kl00=Fo0<000=Bo@03001Fo5Kl00=Fo0<000=G7@8000=Fo@@000AFo@04001FoEKm
E_d40004D_d01000EaeG7ELM100015LM00<005;mD_d00P000UKm00<005KmE_d00UKm00<005KmE_d0
0P000UKm00<005KmE_d00UKm10000eKm00<005KmE_d00UKm10000eKm00<005KlE_`00UKl0`000d:m
00<002GK9M/00P000bfi0P000SFh00<003FF=IH00SFF00H003VE0000046f0004AKD00`00AKE5]@02
AKD00`00Oomoo`06Ool00`00Oomoo`09Ool001Uoo`03001oogoo00Uoo`80009K7@03001[>@0000<0
00A_NP06001g^GNi001cm@008Goo0`000eKl0P000eKl0`001EKm00@005KlE_aFo0<000EFo003001F
o5Kl00800003E_`005;m00ABo@03001Fo5Kl00800003Ead005LM00AG7@@000=Fo003001FoEKm009F
o@@000=Fo003001BoE;m009Bo@@000=Fo@04001G7ELMEad40004E_d01000E_eFoEKm100015Km00<0
05KmE_d00P000UKm00<005KmE_d00UKm00<005KmE_d00P000UKm00<005KmE_d00UKm00<005KlE_`0
0P000U;m1@000bGK0P000Rfi00<002UF00000P0013FF00@003VE>IDiU@8000A5]@030015]DFe0095
]@03001oogoo00Ioo`03001oogoo00Uoo`006Goo0P001Woo10000e/M100000=[>@00KgX00fmj00<0
07NiMkT00`008goo00<005KlE_`00eKl10000UKm00<005KmE_d00eKm10000UKm00<005KlE_`00eKl
0`0015Kl00@005;mD_eBo@@000AG7@03001G7ELM0080009Fo003001Fo5Kl009Fo003001FoEKm0080
009Fo@03001Fo5Kl009Fo003001BoE;m0080009Fo003001FoEKm009Fo@@000=Fo@03001FoEKm009F
o@@000=Fo@04001FoEKmE_d40004E_d01000E_eFoEKm100015Km00@005KmE_eFo@@000EBo@03000b
GC9M008000<Uf`800003;KT002UF008YEP8000<eUP03000iUCVE008iU@030015]DFe0095]@030015
]DFe00=5]@03001oogoo00Eoo`03001oogoo00Uoo`006Goo00@007ooOomoo`@000=:oP@000AK7@03
001_NVmj009_NP04001g^GNiMkT2000UOol00`00E_aFo0020002E_d00`00E_eFo@02E_d00`00E_eF
o@020002Ead00`00E_eFo@02E_d00`00E_aFo0020002E_d00`00E_aFo003E_`30003D_d20003Ead3
0004E_`01000E_aFo5Kl100015Km00@005KlE_aFo0@000AFo003001FoEKm0080009Fo@03001FoEKm
009Fo@03001FoEKm0080009Fo@03001FoEKm00=Fo@<000=Fo@03001FoEKm00=Fo@<000=Fo08000=F
o@@000=Bo@8000=Bo@<0008bG@80008Uf`05000E=`00;KT00003:EH20002=IH00`00>IDiU@02>ID3
0003AKD00`00AKE5]@02AKD00`00Oomoo`06Ool00`00Oomoo`08Ool001Uoo`@0009>o@03001:oT[n
00@000AK7@800003Gcd00000009_NP06001g^@00001Sn0009Woo0P001EKm00@005KmE_eFo@<000EG
7@04001FoEKmE_d30005E_d00`00E_aFo00200000eKm001Bo@04D_d40002E_d00`00E_aFo003E_`3
0003E_`00`00E_eFo@03E_d30003E_`20003E_`30005E_d01000E_eFoEKm0`001EKm00<005KmE_d0
0P0000=Fo000E_d015Km00<005KmE_d00P0000=Fo000E_`015Kl10000UKm00<005;mD_d00e;m1000
0Tkm0`0000DbG@00000Uf`00008E=`8000<YEP<0008eUP03000iUCVE008iU@06000mU@000015]@00
14Fe00<007ooOol01Woo00<007ooOol027oo000HOol20005C_d30004B_h01000Fad000001Elm1@00
00=Sn000Ool09goo00<005KmE_d00eKm10000UKm0P000eLM1@000U;m0P000eKm100015Km00<005;m
D_d00P000UKm00<005KmE_d00UKm00<005KlE_`00P0000=Fo@00E_`015Kl00<005KmE_d00P0000=B
o@00E_`015Kl10000ULM00<005KmE_d00eKm10000UKm0P000eKm100015Kl00@005KmE_eFo@@000AF
o003001Fo5Kl0080009Fo003001FoEKm009Fo@03001BoE;m0080009Bo@03001>oDkm009>o@05000M
o0000005>00200035CL20002:EH00`00;ED00002=IH00`00>IDiU@02>ID01000?IDmUCfE0`000dFe
00<007ooOol01Woo00<007ooOol027oo000HOol20003C_d40004B_h30007Gcd01P00IkeW_@00HoP0
02Yoo`03001FoEKm0080009Fo003001FoEKm00=Fo@<000=Fo003001BoE;m009Bo@@000=Fo@04001F
oEKmE_d40004E_d01000E_eFoEKm100015Km00@005KlE_aFo0@000ABo@03001Fo5Kl0080009G7@03
001G7ELM009G7@03001FoEKm0080009Fo003001FoEKm009Fo@@000=Fo@03001Fo5Kl009Fo0@000=F
o@04001Fo5KlE_`40004E_`01000E_eFoEKm100015;m00<004kmC_d00Tkm00H001gl7O`Mo0001CP2
00035CL02@00:EHYERUF000]E@00=IH00004>ID00`00?IDmU@02?ID00`00AKD0000200000dFe001o
o`06Ool00`00Oomoo`08Ool0011oo`D000=oo`03001oo`00008000=>o@D000=>o@03001O?Elm009O
?@80009W_@03001Sn00002aoo`8000EFo003001FoEKm00800003E_`005Kl00=Fo003001BoE;m0080
009Fo003001FoEKm00=Fo@<000=Fo@03001FoEKm00=Fo@<000=Fo@03001FoEKm009Fo@@000=Fo@04
001BoE;mD_d40004Ead01000EaeG7ELM100015Kl00<005KmE_d00P000UKm00<005KmE_d00UKm00<0
05KlE_`00P000UKm00<005KmE_d00UKm10000eKl00<005KlE_`00UKl10000eKl00@005;mD_eBo@P0
008Mo08000031CP001Dg008E=`80008YEP03000]E@00008000@iU@03000mUCfE008mU@030015]DFe
0095]@8000Moo`03001oogoo00Qoo`004Woo00<007ooOol00goo0P0000Aoo`00C_e>o@80009>g@03
001>oDkm00A>o@800003Gcd006Nm00=W_@8002ioo`8000=Fo0@000AFo004001Fo5KlE_`30005E_`0
0`00E_eFo@0200000eKm001Fo@04E_d00`00E_eFo@0200000eKm001Fo@03E_d00`00E_eFo@020002
E_d00`00E_eFo@03E_d30003D_d01000EaeG7ELM1@000eKl00@005KlE_aFo0@000AFo@04001FoEKm
E_d40004E_d00`00E_eFo@020002D_d00`00E_aFo002E_`00`00E_aFo0020002Ead00`00E_aFo002
E_`40008Ool200000agl0000000200035CL01000:EHYEP000ReE00<003FF000013VE00<003fE?ID0
0SfE00<004FeAKD00TFe00<007ooOol01Goo00<007ooOol027oo000BOol00`00Oomoo`04Ool00`00
Oomoo`020005C]d00`00C_e>o@04C_d30003Ikd2000aOol30003E_d00`00E_aFo002E_`40002E_`0
0`00E_aFo003E_`30004E_d01000E_eFoEKm100015Km00@005KmE_eFo@<000EFo@03001FoEKm0080
0003E_d005;m00ABo@<000=Fo003001Fo5Kl00=Fo0<000=Fo@04001FoEKmE_d50003E_d01000E_eF
oEKm100015;m00@005KlE_aFo0@000AG7@03001Fo5Kl008000ioo`80000407D0000000025CL20000
0bUF000]E@02;ED20004>ID00`00?IDmU@02?ID00`00AKE5]@02AKD00`00Oomoo`05Ool00`00Oomo
o`08Ool0019oo`03001oogoo00Eoo`800003Ool004kM00E>g@03001>oDkm00<000=GGP@003=oo`03
001FoEKm009Fo@03001Fo5Kl0080009Fo@03001Fo5Kl009Fo003001Fo5Kl0080009Fo003001FoEKm
009Fo@@000=Fg004001FoEKmE_d50002E_d20003E_d40004E_d00`00D_eBo@0200000eKl001Fo004
E_`00`00E_aFo00200000eKl001Fo@04E_d30003E_`00`00E_eFo@03E_d30003E_`01000D_eBoE;m
1@000eKm00@005LMEaeG7@@0019oo`<0000809D001Dg000DmP00:EH000<]E@03000iUCVE008iU@03
000mUCfE008mU@030015]DFe00=5]@03001oogoo00Aoo`03001oogoo00Qoo`004Woo00<007ooOol0
1goo00@007oo000000=>g@@000IGGP<003Eoo`04001FoEKmE_d30005E_d01000E_aFo5Kl0`0015Kl
00<005KmE_d00P000UJJ00<005KLE]`00eKL0`000eJk00<005KmE_d00UKm10000eKm00@005KmE_eF
o@@000AFo004001Fo5KlE_`40004E_`00`00E_eFo@0200000eKl001Fo004E_`00`00E_eFo@020000
0eKm001Fo004E_`30003D_d00`00E_eFo@02E_d4000GOol400025CL200000bUF000]E@02;ED20003
>ID00`00?IDmU@02?ID00`00AKE5]@03AKD00`00Oomoo`05Ool00`00Oomoo`07Ool0015oo`8000Yo
o`03001oogoo00<000=C?P8000=GGP@003Moo`<0009Fo@8000=Fo@D0009Ff`8000=Fo0<000EFVP03
001Fg5KL00800003EWT005Jk00=F^`03001FoEKm0080009F^`03001FoEKm00=Fo@<000=Fo@03001F
o5Kl009Fo0@000=Fo@04001Fo5KlE_`40004E_`01000E_aFo5Kl100015Km00<005KlE_`00P0000=F
o000D_d00e;m00<005KmE_d00P006goo00P0001e0000U@005CL001Cf0P0012eE0P000cVE00<003fE
?ID00SfE00<004FeAKD00TFe00<007ooOol01Goo00<007ooOol01goo000NOol01000Oomoo`001U<n
1@00>Woo00<005KmE_d00eKm0`000e:K00<005KKE]/00UKK10000U9h00<005JJEYX015JJ0P000eIi
00<005JkE[/00eJk0P001EJk00<005KmE_d00P0000=Fg000E_d00eKm00<005KlE_`00P000UKm00<0
05KmE_d00UKm10000eLM00<005KlE_`00UKl10000eKl00@005KmE_eFo@@000AFo004001BoE;mD_d3
000NOol0100007D0002E0P000QCf00<002eE;ED00ReE0`000SVE00<003fE?ID00SfE00<004FeAKD0
0TFe00<007ooOol01Goo00<007ooOol01goo000OOol200000goo00000002Dch5000mOol00`00E_eF
o@0200000eJJ001BV`03DY/00`00E]]Ff`0200000e9G001BN003DWP00`00EYYFVP02EYX30005EWT0
0`00E[]F^`0200000eIh001F^`04E[/30004E]`01000E_eFoEKm0`0015Km00<005KmE_d00P000UKm
00<005LMEad00ULM00<005KlE_`00P000UKl00<005KlE_`00UKl10000eKm00<005KlE_`00UKl1000
8Woo0`0000@0U@00000DmP8000<]E@06000eM@00000iU@0013fE00<004FeAKD00dFe00<007ooOol0
17oo00<007ooOol01goo000QOol00`00Oomoo`030012Ool20003EYX00`00DY]BV`03DY/20004DUL0
0`00DWQBN002DWP01000EYX000000eIG00<005IiEWT00eIi0P0015Ih00<005JkE[/00P000UZI00<0
05KLE]`00UKL10000UKl0P000eKm0`0015Km00@005LMEaeG7@@000AFo003001Fo5Kl0080009Fo003
001FoEKm009Fo@03001Fo5Kl008002Moo`800080U@04000DmQCf0004;ED00`00=GD000020004?ID0
0`00AKE5]@03AKD00`00Oomoo`04Ool00`00Oomoo`07Ool0029oo`03001oogoo04Eoo`03001FVUJJ
009FVP03001BVe:K00<000EBE`03001BN59h00=BN003001FEeIG00=FE`04001FNEIiEWT30006EWP2
0004FYT00`00E]aFg0020002F[X00`00E_aFo002E_`40002E_`20003E_d40003E_d01000E_aFo5Kl
100015Kl00@005KmE_eFo@@002Uoo`<0000409D000005?H20003;ED01000=GD003Ee0P0013fE00<0
04FeAKD00TFe00<007ooOol017oo00<007ooOol01goo000SOol00`00Oomoo`14Ool00`00EYYFVP03
EYX20003DSL00`00DUMBE`03DUL01000DWQBN59h0P001UIG0`000eYF00<005IhEWP00UIh00<005YG
00001EZI0P0015Zj00<005KlE_`00P000UKl00<005KlE_`00UKl10000UKl00<005KmE_d00eKm0`00
0eKm00@005KlE_aFo0D002ioo`80000309D00000008DmP80008]E@06000eMCEe000eM@0013fE00<0
04FeAKD00TFe00<007ooOol017oo00<007ooOol01goo000TOol20015Ool00`00EYYFVP030004DSL0
0`00DUMBE`03DUL01000DWP000000UHf00<005IGEUL00eIG00<005YFFUH00eYF00<005IhEWP00P00
0UYG00<005ZIFYT00UZI00<005ig00001EZj0P0015Kl00<005KlE_`00P000UKl00<005KlE_`00UKl
00<005KmE_d00P0000=Bo000E_d015Km0`00=7oo0P0000T0U@00000DmP008AD002eE00000cEe1000
0SfE00<004FeAKD00dFe00<007ooOol017oo00<007ooOol01Woo000VOol00`00Oomoo`13Ool20003
DSL00`00DSMB=`02DSL00`00DUMBE`03DUL00`00ESIF=P02ESH00`00EUMFE`02EUL20006FUH20005
FUL01000FYUJV@000Uig00<005ZjF[X00UZj00@005ji000000=Fo0<000AFo004001Fo5KlE_`40004
D_`00`00E_eFo@02000hOol4000011Cf000Q5@000ReE00<003Ee=GD00P000SfE00<003fE00001DFe
00<007ooOol017oo00<007ooOol01Woo000WOol00`00Oomoo`12Ool00`00DSMB=`02DSL00`00DSMB
=`02DSL01000DUMBEe9G0`001EHf00@005IGEUL0009J=@03001JEUYF00=JEP03001JEeYG00AJE`03
001JV@0000ANM`04001J^P000004G[T30002E]`20003E_`40003E_`01000D_aBo5;l1000>Woo0`00
00<0U00000000R4E00<002eE00000cEe0P000SfE0`0014Fe00<007ooOol017oo00<007ooOol01Woo
000XOol00`00Oomoo`12Ool01@00DSMB=e8g00001E8g0`000U8E00<005HfESH00eHf00@005IGEUL0
009J=@03001JEUYF009JEP8000MJE`03001NMeig00ANM`03001N^Eji00=N^@03001R^00000AFg0@0
009G7@03001Fo5Kl00=Fo0<003moo`800080U080008Q5@8000@eM@03000mUCfE008mU@8000=5]@03
001oogoo00Aoo`03001oogoo00Ioo`00:Goo00<007ooOol0@Goo00D0058gDSMB=`0000AB=`8000EB
5@03001F=UHf00=F=P8000=J=@03001JEUYF009JEP03001J=@0000EJE`8000ENM`8000AN^@04001R
^6:h0002E]`20002F]/00`00EaeG7@02Ead00`00E_aFo0020013Ool200000`2D000000038AD20003
=GD20003?ID00`00AKD0000200000dFe001oo`04Ool00`00Oomoo`06Ool002Yoo`80045oo`03001B
=e8g009B=`06001B=`00001Am@001E8E00<005HfESH00eHf00<005XeFSD00eXe00@005YFFUH0009J
=@03001JEeYG009JE`04001NEEiE0003GWL01000HYIRUP000Uji00<006:hH[P00V:h0P0015[K00@0
05LMEaeG7@@004Eoo`800080U003000Q5B4E008Q5@04000eMCEe=GD20003?ID00`00AKE5]@02AKD2
0005Ool00`00Oomoo`06Ool002aoo`03001oogoo03ioo`03001B=e8g009B=`8000=Am@03001B5E8E
00=B5@03001F=UHf009F=P8000EJ=@03001JEP0000AJ=@04001JEeYG0003GUD01000GWMNM`000f:F
00<005ji000016:h00<006KH000015[K1000BWoo0P0000<0U00000000b4E0P000cEe0P000cfE00<0
04FeAKD00TFe00<007ooOol00goo00<007ooOol01Woo000]Ool00`00Oomoo`0nOol00`00DSL00002
0005DOD00`00DQEB5@02DQD01`00ESIF=UHf001F5@0000IJ=@8000AJ=@04001JEeYG0004GUD20005
HYH00`00H[QR^003H[P00`00I]P00002F]/2001>Ool2000209@00`008ADQ5@028AD20002=GD00`00
?ID00002?ID00`00AKE5]@02AKD00`00Oomoo`04Ool00`00Oomoo`05Ool002ioo`03001oogoo03eo
o`80009=m@03001AmE7e00=Am@03001B5E8E00=B5@03001F=P0000=F5@03001J=EXe00=J=@03001J
=EXe00AJ=@8000ENE@03001RUV:F00=RUP03001VUP0000=R^004001Vf6KHI]P2001AOol200000`2D
000000038AD01@00;EH003Ee00000SfE00<003fE00001DFe00<007ooOol00goo00<007ooOol01Goo
000_Ool2000mOol00`00COE=m@02COD00`00DOEAm@02DOD00`00DQEB5@03DQD20004EQD00`00FSEJ
=@02FSD20006FSD00`00GUENE@03GUD20005HYH00`00IYH00002H[P01@00I]QVf6KH0000E7oo0P00
00<0U00000000R4E00D002eF000eM@00008mU@03000mU@0000E5]@03001oogoo00=oo`03001oogoo
00Eoo`00<Goo00<007ooOol0>Woo00<004geCOD00Tge00<0057eDOD00U7e00<0058EDQD00e8E00<0
05HEEQD00eHE00<005XeFSD00UXe0P001EXe0P001EiE00<0069e00000f:F00L006JFIYIVUP00H[P0
0003I]P00`00Oomoo`1BOol200000`2D000000028AD01P00;EH]EP00=GD0008mU@03000mU@0000A5
]@03001oogoo00=oo`03001oogoo00Eoo`00<Woo00<007ooOol0>Goo00<004geCOD00Tge00<0057e
DOD00U7e00<0058EDQD00U8E0P001EHE00D005XeFSEJ=@00009J=@03001J=EXe009J=@8000ANE@04
001RMF9e0003HYH00`00IYIVUP02IYH01@00I]QVf6KH0000EWoo0`0000D@mP008ADQ5@00008]EP80
00<mU@8000A5]@03001oogoo00=oo`03001oogoo00Eoo`00<goo00<007ooOol0>Goo00D004geCOE=
m@0000AAm@07001B5E8EDQD005HD00001EHE00@005XeFSD000=J=@05001J=EXeFSD00002GUD01@00
GUENEEiE00000f9e00<006:F000016JF00D006Zf001Vf00005Qoo`070000U0004?H0024E00000beF
00@003fE?IDmU@8000E5]@03001oogoo009oo`03001oogoo00Eoo`00=7oo0P00>Goo00<004geCOD0
0Tge00<0057eDOD00U7e00<0058E00000UHD00<005HEEQD015HE0P0015Xe00D005XeFSEJ=@00009N
E@04001NEEiE0004HWD00`00HYH00004IYH01@00J[H006KH0000F7oo0`000Q3f0P000beF0`000SfE
00<004FeAKD00dFe00<007ooOol00Woo00<007ooOol01Goo000fOol00`00Oomoo`0fOol00`00COE=
m@02COD00`00DOEAm@02DOD20004EQ@00`00EQEF5@03EQD20004FSD01000FSEJ=@000eiE00@005iE
GUD000ERM@03001VUVJF009VUP05001Z]VZfJ[H0001JOol200024?H20004;EH00`00>KH00002?ID0
0`00AKE5]@02AKD00`00Oomoo`03Ool00`00Oomoo`04Ool003Moo`03001oogoo03Eoo`03001=mDge
009=m@03001AmE7e009Am@03001F55HD00=F5003001F5EHE00=F5@03001J=EXe00=J=@04001J=EXe
0003GUD00`00GUD00006HWD00`00IYIVUP02IYH01@00J[IZ]VZf0000FWoo0`000Q3f0P000beF00<0
03Vf>KH010000dFe00<007ooOol00goo00<007ooOol017oo000hOol00`00Oomoo`0dOol00`00COE=
m@02COD01000DOEAmE7e0P001EHD00<005HEEQD00UHE0P001UXe0P001EiE0P001V9e00D006JFIYIV
UP0000=Z]P03001oogoo05Yoo`8000<@mP05000]EReF;EH00004>KH30003AKD00`00Oomoo`02Ool0
0`00Oomoo`04Ool003Uoo`8003Aoo`03001=mDge00==m@<00003DO@005HD00AF5003001F5EHE009F
5@8000IJ=@8000ENE@03001RMF9e00ARM@03001ZU@00009VUP05001Z]VZfJ[H0001LOol300024?H2
0002;EH00`00>KHi]P02>KH00`00AOL000040004Ool00`00Oomoo`04Ool003]oo`03001oogoo039o
o`04001=mDgeCOD20004DO@00`00EQAF5002EQ@01`00EQEF5EHE001J500000IJ=@03001NEEiE00AN
E@03001RMF9e00ARM@05001ZU@00IYH00003J[H00`00Oomoo`1LOol200024?H00`00:GL00002;EH0
0`00>KHi]P02>KH00`00AOL00002AOL00`00Oomoo`02Ool00`00Oomoo`04Ool003aoo`03001oogoo
035oo`06001=m@00001=e000157d00<005HDEQ@00UHD00@005HEEQD000=J5003001J=EXe009J=@80
00ENE@03001RM00000ARM@04001ZUFZEJYD20003J[H00`00Oomoo`1LOol300024?H01@00:GL002eF
000013Vf00@004GgAOL00095m`05001oogooOol00006Ool003eoo`03001oogoo031oo`8000==e003
001Am57d009Am003001F55HD00=F508000AJ5003001J=EXe009J=@03001NE00000ANE@03001RM000
00ARM@05001ZUFZEJYD00003J[H00`00Oomoo`1NOol01@000;H0013f00000RUg0P0013Vf00@004Gg
AOL00095m`05001oogooOol00006Ool003ioo`80031oo`03001=e4gD009=e003001Am57d009Am003
001F55HD00=F508000AJ5005001J=EXeFSD00002GU@00`00GUENE@02GUD00`00HW@00003HWD00`00
JYEZU@02JYD01@00J[IZ]VZf0000H7oo0P0000<0]P0000000bUg0P0013Vf00@004GgAOL00095m`04
001oogoo0006Ool0041oo`03001oogoo02eoo`03001=e4gD00==e003001Am57d009Am003001F55HD
009F5003001J55XD00=J5005001J=EXeFSD00002GU@01@00GUENEEiE00000f9d00@0069eHWD000=Z
U@05001^]@00J[H0001ROol010000;H0000012Ug0P000cVf00L004GgAOM5m`00AOL00003Ool00`00
Oomoo`03Ool0045oo`03001oogoo02aoo`03001=e4gD00==e003001Am57d009Am004001F55HDEQ@2
0005FQ@01000FSEJ=@000eiD00D005iEGUENE@0000=RM003001RM@0000AZU@05001^]@00J[H0001S
Ool010000;H000000bUg00<003Wi00000P0000Di]P00AOM5m`000095m`04001oogoo0005Ool0049o
o`03001oogoo02aoo`03001=e4gD009=e003001Am57d009Am004001F55HDEQ@20005FQ@01000FSEJ
=@0015iD00<005iE0000169d00<0069e00000fZE00D006jeK[E^]@0006Eoo`030000]P0000@YM`04
000inCWi>OT80002Ool00`00Oomoo`03Ool004=oo`8002aoo`03001=e4gD009=e003001Am57d009A
m004001F55HD0002EQ@00`00FQAJ5003FQ@20005GU@00`00GUD00005HW@00`00JYEZU@02JYD01@00
K[E^]Fje0000IWoo10000RUg00<003Wi>OT00SWi00<004YjBWX00TYj0P000Woo00<007ooOol00goo
0015Ool00`00Oomoo`0YOol00`00CMA=e002CM@00`00DOAAm003DO@20003EQ@00`00FQAJ5003FQ@2
0005GU@00`00GUD00005HW@00`00JYEZU@02JYD01@00K[E^]Fje0000IWoo00L0002f000UV@00:GL0
0005>OT00`00BWY:NP02BWX200000goo001oo`04Ool004Ioo`03001oogoo02Qoo`03001=e4gD009=
e003001Am57d00=Am08000=F5003001J55XD00=J5003001NE5iD00ENE003001RM69d00ARM005001Z
UFZEJYD00003K[D00`00Oomoo`1VOol200029IT30004>OT00`00BWY:NP02BWX200000goo001oo`04
Ool004Moo`03001oogoo02Moo`03001=e4gD009=e003001Am57d00=Am003001F55HD009F5003001J
55XD00=J5003001NE5iD00ENE003001RM69d00=RM003001ZU@00009ZU@05001^]FjeK[D0001YOol2
00039IT30003>OT01000BWY:NTYj10001Goo0018Ool2000WOol00`00CMA=e002CM@00`00DOAAm002
DO@20004EQ@00`00FQAJ5002FQ@20007GU@00`00HWARM003HW@00`00JYD00002JYD01@00K[E^]Fje
0000JWoo00<002FI9IT00RFI00<0049k00001P000Tkm0`0017oo001:Ool00`00Oomoo`0TOol00`00
CMA=e003CM@01P00DOAAm000EO@000EF5007001J55XDFQ@005hd00001EiD0P00169d00H006ZEJYD0
06ZE0003K[D00`00Oomoo`1ZOol200029IT00`00@W]2N`03@W/00`00C_e>o@03C_d20004Ool004]o
o`03001oogoo02=oo`03001=e4gD00==e003001Am000009Em003001F55HD00=F5004001J55XD0002
GS@00`00GUANE003GU@00`00HW@00003HW@01P00JYEZU@00JYD000=^]@03001oogoo06aoo`@000A2
N`03001>oDkm00D000Aoo`00C7oo00<007ooOol08goo00<004gDCM@00TgD0P0015Gd00<005HDEQ@0
0UHD00@005XDFQ@0009N=003001NE5iD009NE004001RM69d0002HW@00`00JYEZU@02JYD00`00K[E^
]@02K[D00`00Oomoo`1_Ool80003Ool20004Ool004eoo`03001oogoo029oo`04001=e4gDCM@20005
EO@00`00EQAF5002EQ@00`00FQ@00003GS@00`00GUANE002GU@01000HWARM0000V9d00<006ZEJYD0
0VZE00<006jeK[D00Vje00<007ooOol0MWoo10001Woo001>Ool2000ROol01P00CM@00000CO@000EE
m003001F55HD00=F508000AN=004001NE5iD0003HW@01000HWARM00016ZE0P000Vje00<007ooOol0
Lgoo10002Woo001@Ool00`00Oomoo`0OOol20003CO@00`00EOAEm003EO@00`00EQAF5003EQ@00`00
GSAN=003GS@01000GUANE0000f9d00<0069d000016ZE00<006je00000Vje00<007ooOol0Kgoo1000
3Woo001AOol00`00Oomoo`0NOol00`00COA=m002CO@00`00EOAEm003EO@00`00EQAF5003EQ@00`00
GSAN=003GS@00`00GU@00005HW@20004JYD01P00K[E^]@00K[D006eoo`@0019oo`00DWoo00<007oo
Ool07Goo00<004gdCO@00dgd00<005GdEO@00UGd00<005HDEQ@00UHD0P001Ehd00<005iD00001F9d
00<006ZEJYD00fZE00<006jeK[D00P00Jgoo0`005Woo001COol2000NOol00`00COA=m002CO@00`00
EOAEm002EO@00`00EQAF5002EQ@20006GS@00`00HWARM004HW@00`00JYEZU@02JYD00`00K[E^]@02
K[D00`00Oomoo`1UOol4000IOol005Eoo`03001oogoo01]oo`03001=m4gd009=m003001Em5Gd009E
m007001F55HDEQ@005Xe00001Uhd00<0069dHW@0169d00<006ZEJYD00VZE00<006jeK[D00Vje00<0
07ooOol0HGoo10007Goo001FOol00`00Oomoo`0JOol00`00COA=m002CO@00`00EOAEm003EO@00`00
EQ@00003FSD00`00GSAN=002GS@20005HW@00`00IYD00003JYD01@00K[E^]Fje0000H7oo10008Goo
001GOol00`00Oomoo`0IOol00`00COA=m002CO@00`00EOAEm003EO@20004FSD00`00GSAN=002GS@2
0005HW@00`00IYD00003JYD01@00K[E^]Fje0000G7oo10009Goo001HOol2000IOol00`00COA=m002
CO@00`00EOAEm003EO@20004FSD01@00GSAN=5hd00000V9e00D0069dHWARM000009VU@04001ZUFZE
0004K[D00`00Oomoo`1GOol3000YOol005Yoo`03001oogoo01Moo`05001=m4gdCO@00005EO@00`00
FSEJ=@03FSD01@00GSAN=5hd00000V9e00D0069dHWARM00000=VU@03001ZU@0000=^]@03001oogoo
05Aoo`@002aoo`00Fgoo00<007ooOol05Woo00<004gdCO@00Tgd00@005GdEOAEm08000EJ=@04001N
=5hd0003HWD01000HWARM00016JE00<006ZE00000fje00<007ooOol0D7oo1000<7oo001LOol00`00
Oomoo`0EOol00`00COA=m002CO@01P00EO@00000ESD000EJ=@04001N=5hd0003HWD01000HWARM000
1FJE00D006jeK[E^]@0004moo`@003Aoo`00GGoo0P005Goo00<004gdCO@00Tgd0P000eHe00<005Xe
FSD015Xe0P00169e00<0069d00001VJE00D006jeK[E^]@0004]oo`@003Qoo`00Ggoo00<007ooOol0
4Woo00<004gdCO@00Tgd00<005HeESD00eHe00<005XeFSD00eXe0P001F9e0P001VJE00D006jeK[E^
]@0004Qoo`<003aoo`00H7oo00<007ooOol04Woo00<004gdCO@00P001EHe00<005XeFSD00eXe00<0
069eHWD0169e00<006JEIYD016JE00D006Ze001^]@0004Eoo`@003moo`00HGoo00<007ooOol04Goo
0`000U8E00<005HeESD00UHe00<005XeFSD00UXe0P001V9e00<006JEIYD016JE00D006Ze001^]@00
045oo`@004=oo`00HWoo0P004Goo00<0058EDQD00U8E00<005HeESD00UHe00<005XeFSD00UXe00<0
05if0000169e0P001FJE00H006ZeJ[D006je000mOol40017Ool006Aoo`03001oogoo00ioo`03001B
5E8E009B5@03001F=EHe009F=@05001J=EXeFSD00002GWH00`00HWERM@02HWD00`00IYH00004IYD0
1@00J[EZ]FZe0000>Woo1000Bgoo001UOol00`00Oomoo`0=Ool00`00DQEB5@02DQD00`00ESEF=@02
ESD01000FSEJ=@000eif00D0069eHWERM@00009VUP05001VUFJEIYD00004J[D00`00Oomoo`0eOol3
001?Ool006Ioo`03001oogoo00eoo`03001B5E8E009B5@03001F=EHe009F=@8000ENMP04001RMF9e
0002IYH01@00IYEVUFJE00000fZe00<007ooOol0<Woo1000DWoo001WOol2000=Ool00`00DQEB5@02
DQD00`00ESEF=@02ESD20005GWH00`00HWD00004IYH00`00IYD00004J[D00`00Oomoo`0^Ool4001F
Ool006Uoo`03001oogoo00Yoo`03001B5E8E009B5@03001F=EHe009F=@03001NMUif00ANMP03001R
M@0000AVUP03001VU@0000=Z]@03001oogoo02]oo`@005Yoo`00JWoo00<007ooOol02Goo00<0058E
DQD00U8E00@005HeESEF=@8000MNMP03001VUVJF00AVUP03001Z]FZe009Z]@03001oogoo02Moo`@0
05ioo`00Jgoo00<007ooOol027oo00<0058EDQD00e8E0`000UYg00<005ifGWH015if00<006JFIYH0
16JF00D006ZeJ[EZ]@0002Ioo`@0069oo`00K7oo0P002Goo00@0058EDQEB5@8000AJM`03001NMUif
00=NMP8000EVUP8000=Z]@03001oogoo025oo`<006Ioo`00KWoo00<007ooOol01Woo00H0058E0000
05IH0005FWL01@00GWINMUif00000V:h00D006JFIYIVUP00009Ze`03001Z]@00021oo`@006Uoo`00
Kgoo00<007ooOol01Goo0P0015IH00<005YgFWL00UYg00@005ifGWH000=R^004001VUVJF0003J]L0
0`00J[D0000LOol4001]Ool0071oo`03001oogoo00Aoo`03001FF5IH00=FF003001JMeYg00=JM`80
00AR^004001VUVJF0004J]L00`00Oomoo`0GOol4001aOol0075oo`03001oogoo00Aoo`03001FF5IH
009FF003001JMeYg00=JM`03001R^6:h00AR^08000EZe`03001oogoo01=oo`@007Eoo`00LWoo0P00
17oo00<005IHEUP00UIH00@005YgFWMJM`800003G_X006:h00AR^003001Zef[G00=Ze`03001oogoo
015oo`<007Uoo`00M7oo00<007ooOol00Woo00<005IHEUP00UIH0`000ekj00<006:hH[P00V:h00<0
06<K00000f[G00<007ooOol03Woo1000O7oo001eOol01@00Oomoogoo00000eIH0P001Ukj00@006:h
0000009S6`05001Zef[GJ]L0000<Ool40020Ool007Ioo`04001oogooOol30002E_`00`00G_YNnP03
G_X20005Ha/00`00J]L00009Ool40024Ool007Moo`80009oo`03001Fo5Kl009Fo003001NnUkj0080
009G?P03001S6f<K009S6`8000Ioo`@008Qoo`00NGoo00<007oo00000eKl100015Ln00<006<KHa/0
0P001Goo0`00S7oo001jOol00`00Ool000020003Ccl20003Ech30003Ool4002?Ool007]oo`04001o
o`000003Ccl50002Ool4002COol007aoo`800004Ool000000003Ool4002GOol007ioo`800003Ool0
0000008009]oo`00Ogoo0P00Wgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0900352, 0.0105313, 
  0.00367745, 0.00367745}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{599, 547},
WindowMargins->{{Automatic, 271}, {Automatic, 42}},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 57, 3, 111, "Title"],
Cell[1769, 54, 52, 1, 31, "Input"],
Cell[1824, 57, 72, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[1921, 63, 35, 0, 56, "Section"],
Cell[1959, 65, 961, 15, 180, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2957, 85, 64, 0, 56, "Section"],
Cell[3024, 87, 72, 0, 43, "Subsection"],
Cell[3099, 89, 204, 4, 44, "Text"],
Cell[3306, 95, 262, 9, 27, "NumberedEquation"],
Cell[3571, 106, 344, 9, 44, "Text"],
Cell[3918, 117, 474, 13, 40, "NumberedEquation"],
Cell[4395, 132, 284, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[4704, 143, 210, 4, 67, "Input"],
Cell[4917, 149, 76, 1, 43, "Output"]
}, Open  ]],
Cell[5008, 153, 706, 20, 69, "Text"],
Cell[5717, 175, 203, 4, 105, "Input"],
Cell[5923, 181, 86, 1, 27, "Text"],

Cell[CellGroupData[{
Cell[6034, 186, 71, 1, 31, "Input"],
Cell[6108, 189, 57123, 1200, 242, 20274, 741, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[63246, 1392, 244, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[63515, 1403, 84, 2, 31, "Input"],
Cell[63602, 1407, 20582, 666, 186, 7479, 499, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84221, 2078, 71, 0, 43, "Subsection"],
Cell[84295, 2080, 374, 6, 78, "Text"],
Cell[84672, 2088, 134, 4, 27, "NumberedEquation"],
Cell[84809, 2094, 593, 14, 78, "Text"],
Cell[85405, 2110, 124, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[85554, 2117, 96, 2, 31, "Input"],
Cell[85653, 2121, 56761, 1194, 242, 20291, 739, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[142429, 3318, 107, 2, 27, "Text"],
Cell[142539, 3322, 112, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[142676, 3328, 95, 2, 31, "Input"],
Cell[142774, 3332, 142934, 3047, 242, 81417, 2282, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[285723, 6382, 333, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[286081, 6394, 94, 2, 31, "Input"],
Cell[286178, 6398, 18261, 618, 186, 7053, 474, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[304500, 7023, 61, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[304586, 7027, 93, 2, 43, "Subsection"],
Cell[304682, 7031, 285, 5, 61, "Text"],
Cell[304970, 7038, 266, 8, 72, "NumberedEquation"],
Cell[305239, 7048, 372, 12, 64, "Text"],
Cell[305614, 7062, 377, 8, 119, "Input"],

Cell[CellGroupData[{
Cell[306016, 7074, 98, 2, 31, "Input"],
Cell[306117, 7078, 57774, 1194, 242, 20003, 723, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[363906, 8275, 115, 2, 27, "Text"],
Cell[364024, 8279, 327, 9, 72, "NumberedEquation"],
Cell[364354, 8290, 447, 12, 64, "Text"],
Cell[364804, 8304, 150, 4, 31, "Input"],
Cell[364957, 8310, 134, 3, 27, "Text"],
Cell[365094, 8315, 97, 2, 31, "Input"],
Cell[365194, 8319, 99, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[365318, 8325, 182, 4, 71, "Input"],
Cell[365503, 8331, 217240, 5266, 170, 163189, 4594, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[582792, 13603, 76, 0, 43, "Subsection"],
Cell[582871, 13605, 472, 7, 95, "Text"],
Cell[583346, 13614, 149, 5, 35, "NumberedEquation"],
Cell[583498, 13621, 368, 12, 44, "Text"],
Cell[583869, 13635, 119, 3, 31, "Input"],
Cell[583991, 13640, 96, 1, 27, "Text"],
Cell[584090, 13643, 112, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[584227, 13649, 95, 2, 31, "Input"],
Cell[584325, 13653, 141999, 3034, 242, 81268, 2279, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

