(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    520644,      15605]*)
(*NotebookOutlinePosition[    521619,      15638]*)
(*  CellTagsIndexPosition[    521575,      15634]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["DISCRETE FOURIER TRANSFORM", "Title"],

Cell["\<\
Mariusz Jankowski
Department of Electrical Engineering
University of Southern Maine
mjkcc@usm.maine.edu\
\>", "Address"],

Cell[BoxData[
    \(<< ImageProcessing`\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(<< LinearAlgebra`MatrixManipulation`\)], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Section"],

Cell[TextData[{
  "The Fourier transform of a finite length sequence is typically evaluated \
using the Discrete Fourier Transform (DFT). Related Fourier transformations \
include the discrete-time Fourier transform (DTFT) and discrete-time Fourier \
series (DTFS) [Oppenheim 1989]. The DFT of a discrete-time sequence is itself \
a sequence rather than a function of a continuous frequency variable. The \
values of the DFT are evenly spaced samples of the DTFT of a discrete-time \
sequence. For reasons of computational efficency, the DFT plays a central \
role in the implementation of many signal and image processing algorithms. \
Particularly important has been the discovery of a fast algorithm, the \
so-called ",
  StyleBox["Fast Fourier Transform",
    FontSlant->"Italic"],
  " (FFT) [Cooley 1965], that reduces the number of complex multiplications \
needed to compute an ",
  Cell[BoxData[
      \(TraditionalForm\`N - point\)]],
  " DFT by a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`N\/\(\(log\_2\) N\)\)]],
  ". "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" BASIC DEFINITION AND SELECTED PROPERTIES", "Section"],

Cell[TextData[{
  "The DFT is a unique decomposition of a discrete-time finite length signal \
onto a finite family (",
  StyleBox["basis",
    FontSlant->"Italic"],
  ") of discrete, periodic, complex exponentials of the form ",
  Cell[BoxData[
      \(TraditionalForm
      \`W\_\[ScriptCapitalN]\^\(k\ n\) = 
        \[ExponentialE]\^\(\ \(-j\)\ \(\(2\ \[Pi]\)\/N\) k\ n\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k, n, N\  \[Element] \[DoubleStruckCapitalZ]\)]],
  " (integers). ",
  Cell[BoxData[
      \(TraditionalForm\`\(2  \[Pi]\)\/N\)]],
  " is the so-called ",
  StyleBox["fundamental frequency",
    FontSlant->"Italic"],
  ". The DFT is defined by the following pair of equations:\n"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(X[k]\), " ", "=", " ", 
        RowBox[{"{", GridBox[{
              {
                RowBox[{
                \(\[Sum]\+\(n = 0\)\%\(N - 1\)x[n]\ 
                      \[ExponentialE]\^\(\(-j\)\ \(\(2  \[Pi]\)\/N\) k\ n\ 
                        \)\), ",", "\t\t", 
                  FormBox[\(0 \[LessEqual] \ k\  \[LessEqual] \ N - 1\),
                    "TraditionalForm"]}]},
              {\(0, \ \ \ otherwise\)}
              },
            ColumnAlignments->{Left}], "\n"}]}], TraditionalForm]], 
  "NumberedEquation"],

Cell[BoxData[
    FormBox[
      RowBox[{\(x[n]\), " ", "=", "  ", 
        RowBox[{"{", GridBox[{
              {
                RowBox[{
                \(1\/N\ \(\[Sum]\+\(k = 0\)\%\(N - 1\)X[k]\ 
                        \[ExponentialE]\^\(\ j\ \(\(2  \[Pi]\)\/N\) k\ n\ 
                          \)\)\), ",", "\t\t", 
                  FormBox[\(0 \[LessEqual] \ n\  \[LessEqual] \ N - 1\),
                    "TraditionalForm"]}]},
              {\(0, \ \ \ \ otherwise\)}
              },
            ColumnAlignments->{Left}], "\n"}]}], TraditionalForm]], 
  "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`X[k]\)]],
  " is known as the ",
  StyleBox["N",
    FontSlant->"Italic"],
  "-point DFT of the sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  ".  (1) and (2) are known as the ",
  StyleBox["analysis",
    FontSlant->"Italic"],
  " and ",
  StyleBox["synthesis",
    FontSlant->"Italic"],
  " equations, respectively. The synthesis equation states that any finite \
length sequence of length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " may be represented by a superposition of not more than ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " harmonically related complex exponentials. The ",
  Cell[BoxData[
      \(TraditionalForm\`N - point\)]],
  " DFT basis consists of the following complex valued sequences,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`{1, \ W\_N\^n, \ W\_N\^\(2  n\),  ... , \ W\_N\^\(\((N - 1)\) n\)}
      \)]]], "NumberedEquation"],

Cell[TextData[{
  "Each of the basis sequences (",
  Cell[BoxData[
      \(TraditionalForm\`k \[NotEqual] 0\)]],
  ") is periodic with period ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`W\_N\^\(\ k\ \((n + N)\)\ \)\  = \ 
      \(W\_N\^\(k\ n\)\ W\_N\^\(k\ N\)\  = \ W\_N\^\(k\ n\)\)\)]]], 
  "NumberedEquation"],

Cell[TextData[{
  "There are only ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " distinct harmonically related complex exponentials with fundamental \
frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\(2  \[Pi]\)\/N\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`W\_N\^n\  = \ W\_N\^\(\((N + 1)\) n\), \ \ 
      W\_N\^\(2\ n\)\  = \ W\_N\^\(\((N + 2)\) n\), \  ... \)]],
  " and in general, ",
  Cell[BoxData[
      \(TraditionalForm
      \`W\_N\^\(\ k\ n\)\  = \ W\_N\^\(\((k + \ i\ N)\)\ n\)\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is an integer."
}], "Text"],

Cell["\<\
Three properties of the DFT are of particular interest in a variety of signal \
processing applications: symmetry, convolution and energy preservations.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Symmetry Properties", "Subsubsection"],

Cell[TextData[{
  "For any real signal ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(X[k]\  = \ \(X\^*\)[\(-k\)]\)},
          {\(Re[X[k]]\  = \ Re[X[\(-k\)]]\)},
          {\(Im[X[k]]\  = \ \(-\ Im[X[\(-k\)]]\)\)},
          {\(\( | X[k] | \)\  = \ \( | X[\(-k\)] | \)\)},
          {\(\[Angle]\ X[k]\  = \ \(-\[Angle]\)\ X[\(-k\)]\)}
          },
        ColumnAlignments->{Left}], TraditionalForm]]]], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Circular Convolution", "Subsubsection"],

Cell[TextData[{
  "The circular convolution DFT theorem relates time-domain convolution, a \
fundamentally important linear signal operation to multiplication in the DFT \
domain. Due to the existence of the FFT algorithm, this permits a fast \
implementation of the convolution operation. Given three sequences of length \
",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1[n]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2[n]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_3[n]\)]],
  ", and their respective DFTs, ",
  Cell[BoxData[
      \(TraditionalForm\`X\_1[k]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_2[k]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_3[k]\)]],
  ", and further given that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`X\_3[k]\  = \ X\_1[k]\ X\_2[k]\)]],
  " "
}], "NumberedEquation"],

Cell["\<\
it can be shown that the following convolution relationship exists between \
the sequences:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`x\_3[n]\  = \ 
        \[Sum]\+\(i = 0\)\%\(N - 1\)x\_1[i]\ x\_2[\((n - i)\)\_N]\)]],
  ",\t\t",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ n\  \[LessEqual] \ N - 1\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`x[\((n - i)\)\_N]\)]],
  " represents a circular shift of the length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  ". The convolution operation defined by (8) is called ",
  StyleBox["circular convolution",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parseval's Relation", "Subsubsection"],

Cell["\<\
The following relation exists between the time domain and frequency domain \
sequences:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\[Sum]\+\(n = 0\)\%\(N - 1\)\(( | x[n] | )\)\^2\  = \ \ 
      1\/N\ \(\[Sum]\+\(k = 0\)\%\(N - 1\)\(( | X[k] | )\)\^2\)\)]]], 
  "NumberedEquation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TWO-DIMENSIONAL DISCRETE FOURIER TRANSFORM", "Section"],

Cell[TextData[{
  "The two-dimensional Discrete Fourier Transform (2D DFT) is a  \
straightforward extension of the one-dimensional formulation.  The  DFT ",
  Cell[BoxData[
      \(TraditionalForm\`X[k, l]\)]],
  " of a two-dimensional sequence",
  StyleBox[" x[m,n]",
    FontSlant->"Italic"],
  " is defined as\n "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(X[k, l]\), " ", "=", " ", 
        RowBox[{"{", GridBox[{
              {
                \(\[Sum]\+\(m = 0\)\%\(M - 1
                      \)\(\[Sum]\+\(n = 0\)\%\(N - 1\)x[m, n]\ \ 
                      W\_M\^\(k\ m\)\ W\_N\^\(l\ n\)\), \), 
                RowBox[{" ", 
                  
                  FormBox[\(0\  \[LessEqual] \ k\  \[LessEqual] \ M - 1, 
                    0\  \[LessEqual] \ l \[LessEqual] \ N - 1\),
                    "TraditionalForm"]}]},
              {\(\(0, \)\ \), "otherwise"}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]]]], 
  "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(x[m, n]\), " ", "=", " ", 
          RowBox[{"{", GridBox[{
                {
                  \(1\/\(N\ M\)\ 
                    \(\[Sum]\+\(k = 0\)\%\(M - 1
                          \)\(\[Sum]\+\(l = 0\)\%\(N - 1\)X[k, l]\ \ 
                          W\_M\^\(\(-k\)\ m\)\ W\_N\^\(\(-\ l\)\ n\)\)\), \), 
                  \(0\  \[LessEqual] \ m\  \[LessEqual] \ M - 1, \ 
                  0\  \[LessEqual] \ n\  \[LessEqual] \ N - 1\)},
                {\(0, \), "otherwise"}
                },
              ColumnAlignments->{Left}]}]}], TraditionalForm]]],
  "\t "
}], "NumberedEquation"],

Cell[TextData[{
  "\nwith ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          \(W\_N\  = \ \[ExponentialE]\^\(\(-\ j\)\ \(2\ \[Pi]\)\/N\)\),
          FontSize->14], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The 2D DFT is a separable transform that may be implemented as a sequence \
of 1D DFTs of the rows of a matrix followed by 1D DFTs of the columns of the \
result. Analogously with the 1D case, any finite length sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x[n, m]\)]],
  " may be represented by a superposition of ",
  Cell[BoxData[
      \(TraditionalForm\`N\^2\)]],
  " distinct, separable, bi-variate sequences (called ",
  StyleBox["basis images",
    FontSlant->"Italic"],
  "). Assuming same dimension ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " for  each of the two spatial variables ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", we obtain the following family of basis images:"
}], "Text"],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"1", \(W\_N\^n\), \(W\_N\^\(2  n\)\), ".", 
                \(W\_N\^\(\((N - 1)\) n\)\)},
              {\(W\_N\^m\), \(\(W\_N\^n\) W\_N\^m\), 
                \(\(W\_N\^\(2  n\)\) W\_N\^m\), ".", 
                \(\(\(W\_N\^\((N - 1)\)\)\^n\) W\_N\^m\)},
              {".", ".", ".", ".", "."},
              {\(W\_N\^\(\((N - 1)\) m\)\), 
                \(\(W\_N\^n\) W\_N\^\(\((N - 1)\) m\)\), 
                \(\(W\_N\^\(2  n\)\) W\_N\^\(\((N - 1)\) m\)\), ".", 
                \(\(W\_N\^\(\((N - 1)\) n\)\) W\_N\^\(\((N - 1)\) m\)\)}
              }], ")"}], TraditionalForm]]],
  "\n"
}], "NumberedEquation"],

Cell[TextData[{
  "Here is a plot of the real part of the 2D DFT basis images of order ",
  Cell[BoxData[
      \(TraditionalForm\`N = 4\)]],
  ". "
}], "Text"],

Cell[BoxData[
    \(W\_\[ScriptCapitalN]_ := Exp[\(-I\)\ \(2  \[Pi]\)\/\[ScriptCapitalN]]; 
    \nfbasis = 
      Table[Table[
          \(W\_4\^\(k\ \ m\)\) W\_4\^\(l\ \ n\), {m, 0, 3}, {n, 0, 3}], 
        \ {k, 0, 3}, {l, 0, 3}]; \)], "Input",
  CellLabel->"In[17]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        Map[ListDensityPlot[#, Mesh \[Rule] False, 
              PlotRange \[Rule] {\(-1\), 1}, FrameTicks \[Rule] None, 
              DisplayFunction \[Rule] Identity]\ &, Re[fbasis], {2}]]]; 
    \)\)], "Input",
  CellLabel->"In[18]:="],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: 1 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.238095 0.0238095 0.238095 [

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.0238095 0.245293 0.245293 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FFFFFFFF

80808080

00000000

80808080

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.267442 0.0238095 0.488926 0.245293 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF800080

80FF8000

0080FF80

800080FF

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.511074 0.0238095 0.732558 0.245293 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF00FF00

80808080

00FF00FF

80808080

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.754707 0.0238095 0.97619 0.245293 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF800080

800080FF

0080FF80

80FF8000

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.0238095 0.267442 0.245293 0.488926 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FFFFFFFF

00000000

FFFFFFFF

00000000

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.267442 0.267442 0.488926 0.488926 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF800080

0080FF80

FF800080

0080FF80

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.511074 0.267442 0.732558 0.488926 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF00FF00

00FF00FF

FF00FF00

00FF00FF

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.754707 0.267442 0.97619 0.488926 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF800080

0080FF80

FF800080

0080FF80

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.0238095 0.511074 0.245293 0.732558 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FFFFFFFF

80808080

00000000

80808080

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.267442 0.511074 0.488926 0.732558 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF800080

800080FF

0080FF80

80FF8000

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.511074 0.511074 0.732558 0.732558 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF00FF00

80808080

00FF00FF

80808080

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.754707 0.511074 0.97619 0.732558 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF800080

80FF8000

0080FF80

800080FF

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.0238095 0.754707 0.245293 0.97619 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FFFFFFFF

FFFFFFFF

FFFFFFFF

FFFFFFFF

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.267442 0.754707 0.488926 0.97619 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF800080

FF800080

FF800080

FF800080

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.511074 0.754707 0.732558 0.97619 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF00FF00

FF00FF00

FF00FF00

FF00FF00

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.754707 0.754707 0.97619 0.97619 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.240385 0.0192308 0.240385 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

4 string

4 4 8 [4 0 0 4 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FF800080

FF800080

FF800080

FF800080

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd


\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{316, 316},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004l0001?1000`40O003h00Oogoo?Goo003oOolm
Ool00?mooceoo`00ogoo?Goo003oOolmOol00?mooceoo`00ogoo?Goo003oOolmOol000MoodL000Io
odH000MoodH000IoodL000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol0@Woo
00<007ooOol01Goo00<007ooOol0@Woo00<007ooOol017oo00<007ooOol0@goo00<007ooOol01Woo
0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007
Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool0
00Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Mo
o`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`00
1goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo
00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007
Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool0
0`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Mo
o`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03
001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo
00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<0
07ooOol03goo4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool0
0`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00
Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03
001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001o
ogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<0
07ooOol0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007oo
Ool03goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00
Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomo
o`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001o
ogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo
00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007oo
Ool0@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol0
3goo4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomo
o`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?
OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo
04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mo
oa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0
@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo
4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13
Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA
000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q00
4@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=o
o`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
k`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40
015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A
00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo04L0048@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nmoo`0000Ioo`0B000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_4Goo014m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_018000Moo`16001243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
0006Ool04`00Oolmkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000A?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol00`00Oomoo`06Ool000Moo`17000mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@Ool00006Ool04P00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2415oo`0A@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400B0007Ool0AP00?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm24000
1Woo01<007oo@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004D8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo00<007ooOol01Woo0007Ool0A`00@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkgoo00001Woo018003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?NlAOol04Cg_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04P001goo04H0048@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Io
o`0C001oocg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00014mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`03001oogoo00Ioo`001goo04L003g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q1oo`0000Ioo`0B001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@4Goo015243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@018000Moo`16000mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0006Ool0
4`00Oom243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000A@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm2400AOol00`00Oomoo`06Ool000Moo`17001243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
Ool00006Ool04P00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mka5oo`0A?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0B0007Ool0AP00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001Woo01<0
07oo?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Cg_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nl04Goo00<007ooOol01Woo0007Ool0A`00?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm247oo
00001Woo0180048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0AOol04D8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004P001goo04H003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Ioo`0C001o
od8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00015243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@015oo`03001oogoo00Ioo`001goo04L0048@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nmoo`00
00Ioo`0B000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_4Goo014mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_018000Moo`16001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0006Ool04`00Oolm
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000A?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0AOol00`00Oomoo`06Ool000Moo`17000mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@Ool00006
Ool04P00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2415oo`0A@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm2400B0007Ool0AP00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001Woo01<007oo@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q004Goo00<007ooOol01Woo0007Ool0A`00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkgoo00001Woo
018003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?NlAOol04Cg_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nl04P001goo04H0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Ioo`0C001oocg_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_015oo`03001oogoo00Ioo`001goo04L003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q1oo`0000Ioo`0B
001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@4Goo015243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@018000Moo`16000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0006Ool04`00Oom243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm2400AOol00`00Oomoo`06Ool000Moo`17001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_Ool00006Ool04P00
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mka5oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0B0007Ool0AP00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001Woo01<007oo?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nl04Goo00<007ooOol01Woo0007Ool0A`00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm247oo00001Woo0180048@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0AOol04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q004P001goo04H003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Ioo`0C001ood8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@015oo`03001oogoo00Ioo`001goo04L0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nmoo`0000Ioo`0B000mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_4Goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_018000Moo`16001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0006Ool04`00Oolmkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_0140000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
k`0AOol00`00Oomoo`06Ool000Moo`17000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@Ool00006Ool04P00@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2415oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm2400B0007Ool0AP00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001Woo01<007oo@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm2400A00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q00
4Goo00<007ooOol01Woo0007Ool0A`00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkgoo00001Woo018003g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?NlAOol04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nl04P001goo04H0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Ioo`0C001oocg_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nl04@00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015o
o`03001oogoo00Ioo`001goo04L003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q1oo`0000Ioo`0B001243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@4Goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@018000Moo`16000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0006Ool04`00Oom243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@0140000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol0
0`00Oomoo`06Ool000MoodD00003Ool007oo00Eooa80000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Mooa80015o
oa40015oo`03001oogoo00Aoo`03001oo`000100000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001gooA@00
00=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0B?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo4P004Goo4@004Goo00<007ooOol017oo
00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0B?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Oom500000goo001oo`05OolB00004D8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@00004D8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@0008Ool000MoodD00003Ool007oo00Eooa80000A?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Mooa80
015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo
A@0000=oo`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo4P004Goo4@004Goo00<007ooOol0
17oo00<007oo00004000015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Oom500000goo001oo`05OolB0000
4Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@00004Cg_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_0008Ool000MoodD00003Ool007oo00Eooa80000A@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Mo
oa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`00
1gooA@0000=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015o
o`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo4P004Goo4@004Goo00<007oo
Ool017oo00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0B
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Oom500000goo001oo`05OolB
00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@0000
4D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@0008Ool000MoodD00003Ool007oo00Eooa80000A?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl0
00Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qo
o`001gooA@0000=oo`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
015oo`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo4P004Goo4@004Goo00<0
07ooOol017oo00<007oo00004000015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015o
o`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Oom500000goo001oo`05
OolB00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@
00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_0008Ool000MoodD00003Ool007oo00Eooa80000A@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0000Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q00
00Qoo`001gooA@0000=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_015oo`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo4P004Goo4@004Goo
00<007ooOol017oo00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
015oo`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Oom500000goo001o
o`05OolB00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0
000@00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000MoodD00003Ool007oo00Eooa80000A?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nl000Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nl000Qoo`001gooA@0000=oo`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@015oo`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo4P004Goo4@00
4Goo00<007ooOol017oo00<007oo00004000015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@015oo`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool0A`00?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm247oo00001Woo0180048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0A
00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo00<007ooOol01Goo04H003g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0000Ioo`0C001ood8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q00
4Goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@018000Qoo`001goo04L0048@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nmoo`0000Ioo`0B000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_4@00
014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`03001oogoo00Eoo`16001243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_0006Ool04`00Oolmkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015o
o`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0B0008Ool000Moo`17000mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@Ool00006Ool04P00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm24140000A
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol00`00Oomoo`05Ool0AP00?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm240001Woo01<007oo@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol0
4D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004P0027oo0007Ool0A`00@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkgoo00001Woo018003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?NlA00004Cg_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo00<007ooOol01Goo04H0048@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nl000Ioo`0C001oocg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo014m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_018000Qoo`001goo04L003g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q1oo`0000Ioo`0B001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@4@00015243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`03001oogoo00Eoo`16000mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@0006Ool04`00Oom243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0A@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400B0008Ool000Moo`17001243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_Ool00006Ool04P00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mka40000A?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol00`00Oomoo`05Ool0AP00@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mk`001Woo01<007oo?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Cg_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04P0027oo0007Ool0A`00?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
47oo00001Woo0180048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0A00004D8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo00<007ooOol01Goo04H003g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0000Ioo`0C001ood8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo015243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@018000Qoo`001goo04L0048@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nmo
o`0000Ioo`0B000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_4@00014mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`03001oogoo00Eoo`16001243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
0006Ool04`00Oolmkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0A?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0B0008Ool000Moo`17000mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@Ool0
0006Ool04P00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm24140000A@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol00`00Oomoo`05Ool0AP00?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm24000
1Woo01<007oo@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04D8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004P0027oo0007Ool0A`00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkgoo0000
1Woo018003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?NlA00004Cg_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo00<007ooOol01Goo04H0048@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Io
o`0C001oocg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo014mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_018000Qoo`001goo04L003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q1oo`0000Io
o`0B001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@4@00015243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@015oo`03001oogoo00Eoo`16000mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0006Ool0
4`00Oom243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0A@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm2400B0008Ool000Moo`17001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_Ool00006Ool0
4P00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mka40000A?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mk`0AOol00`00Oomoo`05Ool0AP00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001Woo01<0
07oo?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Cg_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nl04P0027oo0007Ool0A`00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm247oo00001Woo0180
048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0A00004D8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q004Goo00<007ooOol01Goo04H003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Ioo`0C001o
od8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo015243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@018000Qoo`001goo04L0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nmoo`0000Ioo`0B000m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_4@00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_015oo`03001oogoo00Eoo`16001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0006Ool04`00Oolm
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0B0008Ool000Moo`17000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@Ool00006Ool04P00@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm24140000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400AOol00`00Oomoo`05Ool0AP00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001Woo01<007oo@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q004P0027oo0007Ool0A`00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkgoo00001Woo018003g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?NlA00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nl04Goo00<007ooOol01Goo04H0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Ioo`0C001oocg_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_018000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol0@Woo00<0
07ooOol01Goo00<007ooOol0@Woo00<007ooOol017oo00<007ooOol0@goo00<007ooOol01Woo0007
Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`12Ool00`00Oomoo`05Ool00`00Oomoo`12
Ool00`00Oomoo`04Ool00`00Oomoo`13Ool00`00Oomoo`06Ool000MoodL000IoodH000MoodH000Io
odL000Qoo`00ogoo?Goo003oOolmOol00?mooceoo`00ogoo?Goo003oOolmOol00?mooceoo`001goo
A`001WooAP001gooAP001WooA`0027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomo
o`12Ool00`00Oomoo`05Ool00`00Oomoo`12Ool00`00Oomoo`04Ool00`00Oomoo`13Ool00`00Oomo
o`06Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0000Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q00
00Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
k`001goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`00
27oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008
Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl0
00Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qo
o`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm24000
1goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo
0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007
Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool0
00Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Mo
o`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`00
1goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo
00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007
Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool0
0`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Mo
o`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03
001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo
00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<0
07ooOol03goo4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool0
0`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00
Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03
001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001o
ogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<0
07ooOol0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007oo
Ool03goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00
Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomo
o`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001o
ogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo
00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007oo
Ool0@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol0
3goo4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Oom500000goo
001oo`05OolB00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00
Ool0000@00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000MoodD00003Ool007oo00Eooa80000A@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0000Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0000Qoo`001gooA@0000=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_015oo`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo4P004Goo
4@004Goo00<007ooOol017oo00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_015oo`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Oom50000
0goo001oo`05OolB00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007OolB000AOolA000AOol00`00Oomoo`04Ool0
0`00Ool0000@00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000MoodD00003Ool007oo00Eooa80000A?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nl000Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nl000Qoo`001gooA@0000=oo`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@015oo`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo4P00
4Goo4@004Goo00<007ooOol017oo00<007oo00004000015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@015oo`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Oom5
00000goo001oo`05OolB00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007OolB000AOolA000AOol00`00Oomoo`04
Ool00`00Ool0000@00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000MoodD00003Ool007oo00Eooa80000A
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0000Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0000Qoo`001gooA@0000=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_015oo`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo
4P004Goo4@004Goo00<007ooOol017oo00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_015oo`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007
Oom500000goo001oo`05OolB00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo
019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007OolB000AOolA000AOol00`00Oomo
o`04Ool00`00Ool0000@00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo0192
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000MoodD00003Ool007oo00Eooa80
000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nl000Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nl000Qoo`001gooA@0000=oo`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm24000
1goo4P004Goo4@004Goo00<007ooOol017oo00<007oo00004000015243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@015oo`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo
0007Oom500000goo001oo`05OolB00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl0
4Goo018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007OolB000AOolA000AOol00`00
Oomoo`04Ool00`00Ool0000@00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo
018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000MoodD00003Ool007oo00Eo
oa80000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0000Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100
000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0000Qoo`001gooA@0000=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
k`001goo4P004Goo4@004Goo00<007ooOol017oo00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_015oo`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`00
27oo0007Oom500000goo001oo`05OolB00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007OolB000AOolA000AOol0
0`00Oomoo`04Ool00`00Ool0000@00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q00
4Goo019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=o
o`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
k`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40
015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A
00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0@goo
00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol03goo4@00
4Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140
000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13Ool0
0`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl0
4@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000A
OolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00
018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03
001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A
00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015o
oa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A0000
4T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<0
07ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140
000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo
4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool00`00
Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00
019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000AOolB
0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@000192
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=oo`03001o
ogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A0000
4Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40015ooa80
00Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0@goo00<007oo
Ool017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol03goo4@004Goo4P00
1Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13Ool00`00Oomo
o`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB0006
Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001oogoo
00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015ooa8000Io
o`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<007ooOol0
17oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo4P001Woo
00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04
Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000AOolB0006Ool0
0`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=oo`03001oogoo00Ao
o`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40015ooa8000Ioo`03
001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo
00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol03goo4@004Goo4P001Woo00<0
07ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool0
0`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00
Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03
001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015ooa8000Ioo`03001o
ogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<0
07ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo4P001Woo00<007oo
Ool047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Oom500000goo001oo`05OolB00004D8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@00004D8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@0008Ool000MoodD00003Ool007oo00Eooa80000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Mooa80015ooa40
015oo`03001oogoo00Aoo`03001oo`000100000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001gooA@0000=o
o`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo4P004Goo4@004Goo00<007ooOol017oo00<0
07oo00004000015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Oom500000goo001oo`05OolB00004Cg_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@00004Cg_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_0008Ool000MoodD00003Ool007oo00Eooa80000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Mooa80015o
oa40015oo`03001oogoo00Aoo`03001oo`000100000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001gooA@00
00=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0B?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo4P004Goo4@004Goo00<007ooOol017oo
00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0B?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Oom500000goo001oo`05OolB00004D8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@00004D8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@0008Ool000MoodD00003Ool007oo00Eooa80000A?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Mooa80
015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo
A@0000=oo`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo4P004Goo4@004Goo00<007ooOol0
17oo00<007oo00004000015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Oom500000goo001oo`05OolB0000
4Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@00004Cg_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_0008Ool000MoodD00003Ool007oo00Eooa80000A@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Mo
oa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`00
1gooA@0000=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015o
o`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo4P004Goo4@004Goo00<007oo
Ool017oo00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0B
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Oom500000goo001oo`05OolB
00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@0000
4D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@0008Ool000MoodD00003Ool007oo00Eooa80000A?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl0
00Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qo
o`001gooA@0000=oo`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
015oo`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo4P004Goo4@004Goo00<0
07ooOol017oo00<007oo00004000015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015o
o`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Oom500000goo001oo`05
OolB00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@
00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo
049oo`03001oogoo00Eoo`03001oogoo049oo`03001oogoo00Aoo`03001oogoo04=oo`03001oogoo
00Ioo`001gooA`001WooAP001gooAP001WooA`0027oo003oOolmOol00?mooceoo`00ogoo?Goo003o
OolmOol00?mooceoo`00ogoo?Goo003oOolmOol000MoodL000IoodH000MoodH000IoodL000Qoo`00
1goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol0@Woo00<007ooOol01Goo00<007ooOol0
@Woo00<007ooOol017oo00<007ooOol0@goo00<007ooOol01Woo0007Ool00`00Oomoo`13Ool00`00
Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00
018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB
0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001o
ogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A0000
4T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015ooa80
00Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<007oo
Ool017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo4P00
1Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool00`00Oomo
o`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@000192
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000AOolB0006
Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=oo`03001oogoo
00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40015ooa8000Io
o`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0@goo00<007ooOol0
17oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol03goo4@004Goo4P001Woo
00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04
Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB0006Ool0
0`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001oogoo00Ao
o`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015ooa8000Ioo`03
001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo
00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo4P001Woo00<0
07ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool0
0`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00
Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03
001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40015ooa8000Ioo`03001o
ogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<0
07ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol03goo4@004Goo4P001Woo00<007oo
Ool047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00
Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomo
o`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001o
ogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo
011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007oo
Ool03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol0
47oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomo
o`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@
Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`17000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@Ool00006Ool04P00
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm24140000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm2400AOol00`00Oomoo`05Ool0AP00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001Woo01<007oo
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04D8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q004P0027oo0007Ool0A`00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkgoo00001Woo018003g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?NlA00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nl04Goo00<007ooOol01Goo04H0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Ioo`0C001oocg_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_018000Qoo`001goo04L003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q1oo`0000Ioo`0B001243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@4@00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@015oo`03001oogoo00Eoo`16000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0006Ool04`00Oom243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400B0008Ool000Moo`17001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_Ool00006Ool04P00?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mka40000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mk`0AOol00`00Oomoo`05Ool0AP00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001Woo01<007oo?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nl04P0027oo0007Ool0A`00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm247oo00001Woo0180048@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0A00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q004Goo00<007ooOol01Goo04H003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Ioo`0C001ood8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@018000Qoo`001goo04L0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nmoo`0000Ioo`0B000mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_4@00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_015oo`03001oogoo00Eoo`16001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0006Ool04`00Oolmkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mk`0B0008Ool000Moo`17000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@Ool00006Ool04P00@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm24140000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
400AOol00`00Oomoo`05Ool0AP00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001Woo01<007oo@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q004P0027oo0007Ool0A`00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkgoo00001Woo018003g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?NlA00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl0
4Goo00<007ooOol01Goo04H0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Ioo`0C001oocg_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
018000Qoo`001goo04L003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q1oo`0000Ioo`0B001243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@4@00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015o
o`03001oogoo00Eoo`16000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0006Ool04`00Oom243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400B
0008Ool000Moo`17001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_Ool00006Ool04P00?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mka40000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol0
0`00Oomoo`05Ool0AP00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001Woo01<007oo?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mk`0AOol04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04P00
27oo0007Ool0A`00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm247oo00001Woo0180048@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0A00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo00<0
07ooOol01Goo04H003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Ioo`0C001ood8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q004Goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@018000Qo
o`001goo04L0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nmoo`0000Ioo`0B000mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_4@00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`03001o
ogoo00Eoo`16001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0006Ool04`00Oolmkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_015oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0B0008Ool0
00Moo`17000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@Ool00006Ool04P00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm24140000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol00`00Oomo
o`05Ool0AP00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001Woo01<007oo@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400AOol04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004P0027oo0007
Ool0A`00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkgoo00001Woo018003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?NlA00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo00<007ooOol0
1Goo04H0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Ioo`0C001oocg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nl04Goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_018000Qoo`001goo
04L003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q1oo`0000Ioo`0B001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@4@00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`03001oogoo00Eo
o`16000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@0006Ool04`00Oom243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@015oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400B0008Ool000Moo`17
001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_Ool00006Ool04P00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mka40000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol00`00Oomoo`05Ool0
AP00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`001Woo01<007oo?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mk`0AOol04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04P0027oo0007Ool0A`00
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm247oo00001Woo0180048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0A00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo00<007ooOol01Goo04H0
03g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0000Ioo`0C001ood8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q004Goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@018000Qoo`001gooA@0000=o
o`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo4P004Goo4@004Goo00<007ooOol017oo00<0
07oo00004000015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Oom500000goo001oo`05OolB00004Cg_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@00004Cg_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_0008Ool000MoodD00003Ool007oo00Eooa80000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Mooa80015o
oa40015oo`03001oogoo00Aoo`03001oo`000100000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001gooA@00
00=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0B?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo4P004Goo4@004Goo00<007ooOol017oo
00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0B?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Oom500000goo001oo`05OolB00004D8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@00004D8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@0008Ool000MoodD00003Ool007oo00Eooa80000A?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Mooa80
015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo
A@0000=oo`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo4P004Goo4@004Goo00<007ooOol0
17oo00<007oo00004000015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`0B@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Oom500000goo001oo`05OolB0000
4Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@00004Cg_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_0008Ool000MoodD00003Ool007oo00Eooa80000A@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Mo
oa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`00
1gooA@0000=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015o
o`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo4P004Goo4@004Goo00<007oo
Ool017oo00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`0B
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Oom500000goo001oo`05OolB
00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@0000
4D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004Goo019243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@0008Ool000MoodD00003Ool007oo00Eooa80000A?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl0
00Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mk`0AOol04Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qo
o`001gooA@0000=oo`00Ool01Goo4P00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
015oo`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo4P004Goo4@004Goo00<0
07ooOol017oo00<007oo00004000015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015o
o`0B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Oom500000goo001oo`05
OolB00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_0007OolB000AOolA000AOol00`00Oomoo`04Ool00`00Ool0000@
00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo018mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_0008Ool000MoodD00003Ool007oo00Eooa80000A@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0000Mooa80015ooa40015oo`03001oogoo00Aoo`03001oo`000100000A@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm2400AOol04T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q00
00Qoo`001gooA@0000=oo`00Ool01Goo4P00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_015oo`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo4P004Goo4@004Goo
00<007ooOol017oo00<007oo00004000014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
015oo`0B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool0A`00@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkgoo00001Woo018003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?NlAOol0
4Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04P001goo04H0048@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nl000Ioo`0C001oocg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00014mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_015oo`03001oogoo00Ioo`001goo04L003g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q1oo`0000Ioo`0B001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@4Goo0152
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@018000Moo`16000mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
0006Ool04`00Oom243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000A@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400AOol00`00Oomoo`06Ool000Moo`17001243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_Ool00006Ool04P00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mka5oo`0A?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0B0007Ool0AP00@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`00
1Woo01<007oo?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Cg_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04Goo00<007ooOol01Woo0007Ool0A`00?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm247oo00001Woo0180048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0AOol04D8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004P001goo04H003g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Io
o`0C001ood8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00015243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@015oo`03001oogoo00Ioo`001goo04L0048@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nmoo`0000Ioo`0B000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_4Goo014mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_018000Moo`16001243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0006Ool0
4`00Oolmkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000A?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`0AOol00`00Oomoo`06Ool000Moo`17000mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
Ool00006Ool04P00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2415oo`0A@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400B0007Ool0AP00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001Woo01<0
07oo@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004D8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q004Goo00<007ooOol01Woo0007Ool0A`00@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkgoo
00001Woo018003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?NlAOol04Cg_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04P001goo04H0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Ioo`0C001o
ocg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00014mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_015oo`03001oogoo00Ioo`001goo04L003g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q1oo`00
00Ioo`0B001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@4Goo015243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@018000Moo`16000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0006Ool04`00Oom2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm2400AOol00`00Oomoo`06Ool000Moo`17001243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_Ool00006
Ool04P00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mka5oo`0A?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`0B0007Ool0AP00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001Woo01<007oo?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nl04Goo00<007ooOol01Woo0007Ool0A`00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm247oo00001Woo
0180048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0AOol04D8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q004P001goo04H003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Ioo`0C001ood8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@015oo`03001oogoo00Ioo`001goo04L0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nmoo`0000Ioo`0B
000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_4Goo014mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_018000Moo`16001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0006Ool04`00Oolmkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mk`0AOol00`00Oomoo`06Ool000Moo`17000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@Ool00006Ool04P00
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2415oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm2400B0007Ool0AP00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001Woo01<007oo@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q004Goo00<007ooOol01Woo0007Ool0A`00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkgoo00001Woo018003g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?NlAOol04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nl04P001goo04H0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Ioo`0C001oocg_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_015oo`03001oogoo00Ioo`001goo04L003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q1oo`0000Ioo`0B001243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@4Goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@018000Moo`16000mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0006Ool04`00Oom243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
400AOol00`00Oomoo`06Ool000Moo`17001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_Ool00006Ool04P00?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mka5oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mk`0B0007Ool0AP00@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001Woo01<007oo?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl0
4Goo00<007ooOol01Woo0007Ool0A`00?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm247oo00001Woo0180048@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0AOol04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q004P001goo04H003g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Ioo`0C001ood8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q004@00015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@015o
o`03001oogoo00Ioo`001goo04L0048@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nmoo`0000Ioo`0B000mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_4Goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_018000Moo`16001243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0006Ool04`00Oolmkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_0140000A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0AOol0
0`00Oomoo`06Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo049oo`03001oogoo
00Eoo`03001oogoo049oo`03001oogoo00Aoo`03001oogoo04=oo`03001oogoo00Ioo`001gooA`00
1WooAP001gooAP001WooA`0027oo003oOolmOol00?mooceoo`00ogoo?Goo003oOolmOol00?mooceo
o`00ogoo?Goo0007Oom70006Oom60007Oom60006Oom70008Ool000Moo`03001oogoo04=oo`03001o
ogoo00Aoo`03001oogoo049oo`03001oogoo00Eoo`03001oogoo049oo`03001oogoo00Aoo`03001o
ogoo04=oo`03001oogoo00Ioo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol0@Woo
00<007ooOol01Goo00<007ooOol0@Woo00<007ooOol017oo00<007ooOol0@goo00<007ooOol01Woo
0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007
Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool0
00Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Mo
o`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`00
1goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo
00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007
Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool0
0`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Mo
o`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03
001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo
00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<0
07ooOol03goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool0
0`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00
Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03
001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001o
ogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<0
07ooOol0@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007oo
Ool03goo4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00
Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomo
o`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001o
ogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo
00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007oo
Ool0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol0
3goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomo
o`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?
OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo
04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mo
oa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
k`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0
@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol03goo
4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13
Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA
000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl0
4@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=o
o`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40
015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A
00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo
00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@00
4Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140
000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool0
0`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q00
4@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000A
OolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00
019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=oo`03
001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A
00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40015o
oa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A0000
4Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0@goo00<0
07ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140
000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol03goo4@004Goo
4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13Ool00`00
Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00
018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB
0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001o
ogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A0000
4T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015ooa80
00Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<007oo
Ool017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo4P00
1Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool00`00Oomo
o`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@000192
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000AOolB0006
Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=oo`03001oogoo
00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40015ooa8000Io
o`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0@goo00<007ooOol0
17oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol03goo4@004Goo4P001Woo
00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04
Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB0006Ool0
0`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001oogoo00Ao
o`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015ooa8000Ioo`03
001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo
00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo4P001Woo00<0
07ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool0
0`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00
Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03
001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40015ooa8000Ioo`03001o
ogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<0
07ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol03goo4@004Goo4P001Woo00<007oo
Ool047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00
Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomo
o`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001o
ogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo
011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007oo
Ool03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol0
47oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomo
o`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@
Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo
00moo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011o
o`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol0
3goo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm240001goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo
015243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?
Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool0
4Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00mo
o`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo
014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo014m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool0
4D8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nl000Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nl000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo0152
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm240001goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo015243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0000Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mk`001goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mk`0027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nl000Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nl000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm240001goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm2400027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0000Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0000Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mk`001goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
k`0027oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
0008Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nl000Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl0
00Qoo`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
40001goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm24000
27oo0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
0007Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008
Ool000Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q00
00Moo`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qo
o`001goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`00
1goo00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo
0007Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04D8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0007
Ool00`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04D8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q004@00019243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@0008Ool0
00Moo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Mo
o`03001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mk`0A00004Sg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nl000Qoo`00
1goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo015243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm240001goo
00<007ooOol03goo4@004Goo4P001Woo00<007ooOol047oo015243g_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@0140000B@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2400027oo0007
Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@
?Nm243g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0007Ool0
0`00Oomoo`0?OolA000AOolB0006Ool00`00Oomoo`0@Ool04Cg_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nl04@00018mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_0008Ool000Mo
o`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo00moo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm2
43g_@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Moo`03
001oogoo00mooa40015ooa8000Ioo`03001oogoo011oo`0A@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm2400A00004T8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0000Qoo`001goo
00<007ooOol0@goo00<007ooOol017oo00<007ooOol03goo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_
@Q0mkd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`001goo00<0
07ooOol03goo4@004Goo4P001Woo00<007ooOol047oo014mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0m
kd8@?Nm243g_0140000B?Nm243g_@Q0mkd8@?Nm243g_@Q0mkd8@?Nm243g_@Q0mk`0027oo0007Ool0
0`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`12Ool00`00Oomoo`05Ool00`00Oomoo`12Ool0
0`00Oomoo`04Ool00`00Oomoo`13Ool00`00Oomoo`06Ool000MoodL000IoodH000MoodH000IoodL0
00Qoo`00ogoo?Goo003oOolmOol00?mooceoo`00ogoo?Goo003oOolmOol00?mooceoo`00ogoo?Goo
0000\
\>"],
  ImageRangeCache->{{{137.5, 452.5}, {451.938, 136.938}} -> {-1.93337, 
  1.72583, 0.0133335, 0.0133335}, {{145, 214.75}, {444.438, 
  374.625}} -> {-8.76671, 7.65832, 0.0598566, 0.0598566}, {{221.688, 291.5}, {
  444.438, 374.625}} -> {-13.345, 7.65323, 0.0598028, 0.0598028}, {{298.438, 
  368.25}, {444.438, 374.625}} -> {-17.9349, 7.65323, 0.0598028, 
  0.0598028}, {{375.188, 445}, {444.438, 374.625}} -> {-22.5248, 7.65323, 
  0.0598028, 0.0598028}, {{145, 214.75}, {367.688, 297.875}} -> {-8.76671, 
  3.06432, 0.0598566, 0.0598566}, {{221.688, 291.5}, {367.688, 
  297.875}} -> {-13.345, 3.06337, 0.0598028, 0.0598028}, {{298.438, 368.25}, {
  367.688, 297.875}} -> {-17.9349, 3.06337, 0.0598028, 0.0598028}, {{375.188, 
  445}, {367.688, 297.875}} -> {-22.5248, 3.06337, 0.0598028, 0.0598028}, {{
  145, 214.75}, {290.938, 221.125}} -> {-8.76671, -1.52967, 0.0598566, 
  0.0598566}, {{221.688, 291.5}, {290.938, 221.125}} -> {-13.345, -1.5265, 
  0.0598028, 0.0598028}, {{298.438, 368.25}, {290.938, 
  221.125}} -> {-17.9349, -1.5265, 0.0598028, 0.0598028}, {{375.188, 445}, {
  290.938, 221.125}} -> {-22.5248, -1.5265, 0.0598028, 0.0598028}, {{145, 
  214.75}, {214.188, 144.438}} -> {-8.76671, -6.1218, 0.0598566, 
  0.0598566}, {{221.688, 291.5}, {214.188, 144.438}} -> {-13.345, -6.1145, 
  0.0598028, 0.0598028}, {{298.438, 368.25}, {214.188, 
  144.438}} -> {-17.9349, -6.1145, 0.0598028, 0.0598028}, {{375.188, 445}, {
  214.188, 144.438}} -> {-22.5248, -6.1145, 0.0598028, 0.0598028}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DFT AS A MATRIX OPERATION", "Section"],

Cell[TextData[{
  "The 1-D DFT is a sum of point-by-point products of samples of the input \
sequence with samples of the Fourier basis sequences. As such, this summation \
can be represented as a matrix product of a matrix \[ScriptCapitalF] (for \
Fourier) with the sequence ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " represented by a vector of length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ". The elements of \[ScriptCapitalF] are obtained by sampling the basis \
sequences ",
  Cell[BoxData[
      \(TraditionalForm\`W\_N\^\(k\ n\)\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ k, n\  \[LessEqual] N - 1\)]],
  ". The function ",
  StyleBox["FourierKernel", "Program"],
  " returns a sampled Fourier basis sequence of any  desired size."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[ScriptCapitalF] = FourierKernel[4])\)\  // MatrixForm\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(1\/2\), \(1\/2\), \(1\/2\), \(1\/2\)},
            {\(1\/2\), \(-\(I\/2\)\), \(-\(1\/2\)\), \(I\/2\)},
            {\(1\/2\), \(-\(1\/2\)\), \(1\/2\), \(-\(1\/2\)\)},
            {\(1\/2\), \(I\/2\), \(-\(1\/2\)\), \(-\(I\/2\)\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[5]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The matrix \[ScriptCapitalF] is an example of an important class of \
matrices called ",
  StyleBox["unitary",
    FontSlant->"Italic"],
  " matrices. Unitary matrices have the property"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalF]\  . \ \((\(\[ScriptCapitalF]\^*\))\)\^T\  = \ I
        \)]],
  "\tor\t",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalF]\^\(-1\)\  = \ \((\(\[ScriptCapitalF]\^*\))\)\^T\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\[ScriptCapitalF]\^*\))\)\^T\)]],
  " stands for the complex conjugate transpose (or ",
  StyleBox["Hermitian",
    FontSlant->"Italic"],
  ") of matrix \[ScriptCapitalF]. This property of the Fourier matrix may be \
immediately verified."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalF] . Conjugate[\[ScriptCapitalF]]\  == \ 
      IdentityMatrix[4]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  "where we have omitted the transpose operation, since the Fourier matrix \
\[ScriptCapitalF] is symmetric, i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\^T\  = \ \[ScriptCapitalF]\)]],
  ". Unitary matrices are nice, because their matrix inverses may be easily \
obtained which leads to fast algorithms."
}], "Text"],

Cell[CellGroupData[{

Cell["Analysis and Synthesis Formulations, 1D DFT", "Subsubsection"],

Cell[TextData[{
  "Given an ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " Fourier matrix and an  ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-point vector ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",  the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-point forward and inverse DFTs  can be computed using matrix \
multiplication:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`X\  = \ \[ScriptCapitalF] . \ x\)]],
  "\t(analysis)"
}], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ \(\[ScriptCapitalF]\^*\) . \ X\)]],
  "\t(synthesis)"
}], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analysis and Synthesis Formulations, 2D DFT", "Subsubsection"],

Cell["\<\
To obtain the 2D DFT matrix formulations, note that the 2-D DFT is a \
separable transformation, therefore it may be computed using a sequence of \
row and column 1-D DFT transformations. The row and column operations may be \
concisely expressed with the following matrix operation:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`X\  = \ \(\[ScriptCapitalF] . \ x . \ \[ScriptCapitalF]\^T = \ \ 
          \[ScriptCapitalF] . \ x . \ \[ScriptCapitalF]\)\)]],
  "\t\t\t(analysis)"
}], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`x\  = \ \(\(\[ScriptCapitalF]\^*\) . \ X . \ 
            \((\(\[ScriptCapitalF]\^*\))\)\^T\  = \ \ 
          \(\[ScriptCapitalF]\^*\) . \ X . \ \(\[ScriptCapitalF]\^*\)\)\)]],
  "\t\t(synthesis)"
}], "NumberedEquation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EXAMPLES", "Section"],

Cell[TextData[{
  "In this final section we will show examples of computing and visualizing \
the 2D DFT. We first consider the direct approach of using (10) to compute \
the DFT of a unit pulse signal ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " defined as"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x[m, \ n]\), " ", "=", " ", 
          RowBox[{"{", GridBox[{
                {"1", \(for\ \ \ \ \ \ 0 \[LessEqual] m, n \[LessEqual] 2\ 
                  \)},
                {"0", "otherwise"}
                }]}]}], TraditionalForm]]]
}], "Text"],

Cell["\<\
For this particular example we use an 8-point DFT. (10) reduces to the  \
following expression:\
\>", "Text"],

Cell[BoxData[
    \(X[k_, l_] := 
      \(X[k, \ l] = 
        \(1\/64\) 
          \(\[Sum]\+\(n = 0\)\%2\(\[Sum]\+\(m = 0\)\%2\ \ 
              W\_8\^\(l\ m\)\ W\_8\^\(k\ n\)\)\)\)\)], "Input",
  CellLabel->"In[16]:="],

Cell["The algebraic form of the 2D DFT is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X[k, \ l]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(1\/64\ 
      \((1 + \((E\^\(-\(\(I\ \[Pi]\)\/4\)\))\)\^k + 
          \((E\^\(-\(\(I\ \[Pi]\)\/4\)\))\)\^\(2\ k\) + 
          \((E\^\(-\(\(I\ \[Pi]\)\/4\)\))\)\^l + 
          \((E\^\(-\(\(I\ \[Pi]\)\/4\)\))\)\^\(2\ l\) + 
          \((E\^\(-\(\(I\ \[Pi]\)\/4\)\))\)\^\(k + l\) + 
          \((E\^\(-\(\(I\ \[Pi]\)\/4\)\))\)\^\(2\ k + l\) + 
          \((E\^\(-\(\(I\ \[Pi]\)\/4\)\))\)\^\(k + 2\ l\) + 
          \((E\^\(-\(\(I\ \[Pi]\)\/4\)\))\)\^\(2\ k + 2\ l\))\)\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[{
  "We now evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`X[k, l]\)]],
  " over all values of the frequency variables ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ". This gives the 2D DFT of the unit pulse. "
}], "Text"],

Cell[BoxData[
    \(\(Table[X[k, l], {k, 0, 7}, {l, 0, 7}]; \)\)], "Input",
  CellLabel->"In[18]:="],

Cell[TextData[{
  "Here we plot the ",
  StyleBox["magnitude,",
    FontSlant->"Italic"],
  " ",
  StyleBox["phase, real",
    FontSlant->"Italic"],
  " and ",
  StyleBox["imaginary",
    FontSlant->"Italic"],
  " parts of ",
  Cell[BoxData[
      \(TraditionalForm\`X[k, l]\)]],
  ". The magnitude plot is typically referred to as the ",
  StyleBox["magnitude response",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        Map[ListPlot3D[#, PlotRange \[Rule] All, 
              DisplayFunction \[Rule] Identity]\ &, 
          \ {{Abs[%], \ Arg[%]}, {Re[%], \ Im[%]}}, \ {2}]]]; \)\)], "Input",
  CellLabel->"In[19]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.11158 .21312 -6 -8.95035 ]
[.11158 .21312 0 .04965 ]
[.28836 .14356 -5.67606 -9 ]
[.28836 .14356 .32394 0 ]
[.47788 .06904 -5.31864 -9 ]
[.47788 .06904 .68136 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.74908 .0689 0 -6.18931 ]
[.74908 .0689 6 2.81069 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 6 2.93953 ]
[.9134 .32052 0 -5.94988 ]
[.9134 .32052 6 3.05012 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.01877 .2986 -6 -2.77062 ]
[.01877 .2986 0 6.22938 ]
[.00843 .36338 -24 -2.82553 ]
[.00843 .36338 0 6.17447 ]
[-0.00234 .43092 -18 -2.88302 ]
[-0.00234 .43092 0 6.11698 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7368 .07352 m
.73065 .07582 L
s
[(2)] .74908 .0689 -1 .3754 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(4)] .83635 .20254 -1 .34677 Mshowa
.90091 .32455 m
.89466 .32656 L
s
[(6)] .9134 .32052 -1 .3222 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(8)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.75965 .10848 m
.75596 .10983 L
s
.78177 .14231 m
.77807 .14365 L
s
.8032 .17508 m
.79948 .1764 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.88252 .29643 m
.87878 .29766 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03102 .29389 m
.03714 .29154 L
s
[(0)] .01877 .2986 1 -0.38431 Mshowa
.02073 .35881 m
.02688 .35652 L
s
[(0.05)] .00843 .36338 1 -0.3721 Mshowa
.01001 .42649 m
.01618 .42427 L
s
[(0.1)] -0.00234 .43092 1 -0.35933 Mshowa
.125 Mabswid
.02899 .30666 m
.03267 .30526 L
s
.02695 .31954 m
.03063 .31814 L
s
.0249 .33252 m
.02858 .33113 L
s
.02282 .34561 m
.02651 .34423 L
s
.01862 .37212 m
.02231 .37075 L
s
.0165 .38554 m
.02019 .38418 L
s
.01435 .39907 m
.01805 .39772 L
s
.01219 .41272 m
.01589 .41138 L
s
.03303 .28123 m
.0367 .27981 L
s
.03502 .26866 m
.03869 .26723 L
s
.03699 .2562 m
.04066 .25476 L
s
.00781 .44037 m
.01151 .43905 L
s
.00559 .45437 m
.0093 .45306 L
s
.00335 .46849 m
.00706 .46719 L
s
.00109 .48274 m
.00481 .48144 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.553 .482 .73 r
.35905 .59333 .40071 .72988 .47727 .72236 .43423 .60211 Metetra
.66 .563 .735 r
.43423 .60211 .47727 .72236 .55583 .62154 .51323 .56513 Metetra
.736 .716 .832 r
.51323 .56513 .55583 .62154 .63454 .56656 .59369 .51635 Metetra
.637 .712 .901 r
.59369 .51635 .63454 .56656 .71765 .57484 .67671 .4966 Metetra
.635 .625 .823 r
.67671 .4966 .71765 .57484 .80105 .53693 .76253 .47618 Metetra
.737 .721 .836 r
.76253 .47618 .80105 .53693 .88217 .4606 .84827 .42468 Metetra
.721 .828 .931 r
.84827 .42468 .88217 .4606 .97444 .46651 .93675 .38345 Metetra
.738 .836 .925 r
.31062 .56653 .35905 .59333 .43423 .60211 .38904 .52566 Metetra
.668 .641 .814 r
.38904 .52566 .43423 .60211 .51323 .56513 .46881 .495 Metetra
.623 .642 .849 r
.46881 .495 .51323 .56513 .59369 .51635 .55083 .47791 Metetra
.645 .781 .946 r
.55083 .47791 .59369 .51635 .67671 .4966 .63559 .45358 Metetra
.686 .778 .921 r
.63559 .45358 .67671 .4966 .76253 .47618 .72262 .42044 Metetra
.637 .712 .901 r
.72262 .42044 .76253 .47618 .84827 .42468 .81311 .39776 Metetra
.519 .815 .999 r
.81311 .39776 .84827 .42468 .93675 .38345 .90783 .38246 Metetra
.754 .949 .942 r
.25711 .56211 .31062 .56653 .38904 .52566 .33862 .51148 Metetra
.801 .912 .916 r
.33862 .51148 .38904 .52566 .46881 .495 .42164 .45211 Metetra
.63 .76 .941 r
.42164 .45211 .46881 .495 .55083 .47791 .5053 .43039 Metetra
.586 .729 .942 r
.5053 .43039 .55083 .47791 .63559 .45358 .59208 .41603 Metetra
.721 .825 .93 r
.59208 .41603 .63559 .45358 .72262 .42044 .68106 .37307 Metetra
.686 .778 .921 r
.68106 .37307 .72262 .42044 .81311 .39776 .77278 .33722 Metetra
.495 .643 .922 r
.77278 .33722 .81311 .39776 .90783 .38246 .87158 .34034 Metetra
.636 .613 .81 r
.20725 .47316 .25711 .56211 .33862 .51148 .28768 .44839 Metetra
.705 .709 .851 r
.28768 .44839 .33862 .51148 .42164 .45211 .37155 .40658 Metetra
.687 .775 .918 r
.37155 .40658 .42164 .45211 .5053 .43039 .45719 .37187 Metetra
.635 .713 .904 r
.45719 .37187 .5053 .43039 .59208 .41603 .54538 .34769 Metetra
.666 .697 .869 r
.54538 .34769 .59208 .41603 .68106 .37307 .63651 .31438 Metetra
.697 .748 .891 r
.63651 .31438 .68106 .37307 .77278 .33722 .73011 .27317 Metetra
.637 .712 .901 r
.73011 .27317 .77278 .33722 .87158 .34034 .82781 .24593 Metetra
.751 .709 .813 r
.15302 .40526 .20725 .47316 .28768 .44839 .2377 .34341 Metetra
.595 .57 .796 r
.2377 .34341 .28768 .44839 .37155 .40658 .3203 .32706 Metetra
.544 .611 .87 r
.3203 .32706 .37155 .40658 .45719 .37187 .40591 .32161 Metetra
.687 .775 .918 r
.40591 .32161 .45719 .37187 .54538 .34769 .49614 .28399 Metetra
.683 .731 .887 r
.49614 .28399 .54538 .34769 .63651 .31438 .58909 .24524 Metetra
.54 .657 .912 r
.58909 .24524 .63651 .31438 .73011 .27317 .68658 .23735 Metetra
.542 .813 .996 r
.68658 .23735 .73011 .27317 .82781 .24593 .78823 .21684 Metetra
.906 .984 .74 r
.07974 .45508 .15302 .40526 .2377 .34341 .17702 .32061 Metetra
.802 .889 .907 r
.17702 .32061 .2377 .34341 .3203 .32706 .26581 .25536 Metetra
.317 .534 .905 r
.26581 .25536 .3203 .32706 .40591 .32161 .35072 .27637 Metetra
.568 .773 .975 r
.35072 .27637 .40591 .32161 .49614 .28399 .44287 .25714 Metetra
.801 .912 .916 r
.44287 .25714 .49614 .28399 .58909 .24524 .53897 .18732 Metetra
.456 .676 .959 r
.53897 .18732 .58909 .24524 .68658 .23735 .63888 .18621 Metetra
0 .395 .841 r
.63888 .18621 .68658 .23735 .78823 .21684 .74882 .23782 Metetra
.893 .98 .813 r
.00095 .48363 .07974 .45508 .17702 .32061 .10168 .36727 Metetra
.906 .984 .74 r
.10168 .36727 .17702 .32061 .26581 .25536 .20337 .22766 Metetra
.481 .82 .999 r
.20337 .22766 .26581 .25536 .35072 .27637 .29271 .21068 Metetra
.379 .614 .943 r
.29271 .21068 .35072 .27637 .44287 .25714 .38515 .21903 Metetra
.822 .878 .886 r
.38515 .21903 .44287 .25714 .53897 .18732 .48513 .13737 Metetra
.738 .836 .925 r
.48513 .13737 .53897 .18732 .63888 .18621 .58632 .08049 Metetra
.122 .329 .797 r
.58632 .08049 .63888 .18621 .74882 .23782 .69745 .15011 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.11158 .21312 -6 -8.95035 ]
[.11158 .21312 0 .04965 ]
[.28836 .14356 -5.67606 -9 ]
[.28836 .14356 .32394 0 ]
[.47788 .06904 -5.31864 -9 ]
[.47788 .06904 .68136 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.74908 .0689 0 -6.18931 ]
[.74908 .0689 6 2.81069 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 6 2.93953 ]
[.9134 .32052 0 -5.94988 ]
[.9134 .32052 6 3.05012 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.01652 .31269 -30 -2.78254 ]
[.01652 .31269 0 6.21746 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00298 .43493 -24 -2.88644 ]
[-0.00298 .43493 0 6.11356 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7368 .07352 m
.73065 .07582 L
s
[(2)] .74908 .0689 -1 .3754 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(4)] .83635 .20254 -1 .34677 Mshowa
.90091 .32455 m
.89466 .32656 L
s
[(6)] .9134 .32052 -1 .3222 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(8)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.75965 .10848 m
.75596 .10983 L
s
.78177 .14231 m
.77807 .14365 L
s
.8032 .17508 m
.79948 .1764 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.88252 .29643 m
.87878 .29766 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02878 .30801 m
.03491 .30567 L
s
[(-0.05)] .01652 .31269 1 -0.38166 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00937 .4305 m
.01555 .42829 L
s
[(0.05)] -0.00298 .43493 1 -0.35857 Mshowa
.125 Mabswid
.02691 .31984 m
.03059 .31845 L
s
.02502 .33176 m
.0287 .33037 L
s
.02311 .34378 m
.0268 .3424 L
s
.02119 .35588 m
.02488 .35451 L
s
.01731 .38037 m
.02101 .37901 L
s
.01535 .39276 m
.01905 .39141 L
s
.01337 .40524 m
.01707 .4039 L
s
.01138 .41782 m
.01508 .41649 L
s
.03064 .29627 m
.03432 .29485 L
s
.03249 .28461 m
.03616 .28319 L
s
.03432 .27304 m
.03799 .27162 L
s
.03614 .26156 m
.03981 .26012 L
s
.00734 .44328 m
.01105 .44196 L
s
.0053 .45616 m
.00902 .45485 L
s
.00325 .46914 m
.00696 .46784 L
s
.00117 .48223 m
.00489 .48093 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.707 .649 .789 r
.35313 .71528 .39851 .79284 .47783 .68039 .43244 .66962 Metetra
.786 .924 .928 r
.43244 .66962 .47783 .68039 .55589 .62852 .51305 .61582 Metetra
.507 .863 .989 r
.51305 .61582 .55589 .62852 .63735 .6534 .59535 .59711 Metetra
.599 .678 .896 r
.59535 .59711 .63735 .6534 .72151 .64297 .68077 .58534 Metetra
.701 .717 .862 r
.68077 .58534 .72151 .64297 .80525 .58807 .76763 .54699 Metetra
.678 .785 .93 r
.76763 .54699 .80525 .58807 .89675 .59453 .85729 .51534 Metetra
.541 .586 .849 r
.85729 .51534 .89675 .59453 .99922 .6478 .95432 .52021 Metetra
.639 .565 .756 r
.30826 .60385 .35313 .71528 .43244 .66962 .38693 .57768 Metetra
.603 .581 .802 r
.38693 .57768 .43244 .66962 .51305 .61582 .46762 .56566 Metetra
.632 .721 .911 r
.46762 .56566 .51305 .61582 .59535 .59711 .55136 .54559 Metetra
.679 .736 .894 r
.55136 .54559 .59535 .59711 .68077 .58534 .63763 .51405 Metetra
.645 .661 .851 r
.63763 .51405 .68077 .58534 .76763 .54699 .72682 .48927 Metetra
.62 .701 .903 r
.72682 .48927 .76763 .54699 .85729 .51534 .81959 .47006 Metetra
.678 .785 .93 r
.81959 .47006 .85729 .51534 .95432 .52021 .9142 .43581 Metetra
.783 .833 .891 r
.25611 .57479 .30826 .60385 .38693 .57768 .33822 .5187 Metetra
.598 .678 .897 r
.33822 .5187 .38693 .57768 .46762 .56566 .41996 .50524 Metetra
.537 .653 .91 r
.41996 .50524 .46762 .56566 .55136 .54559 .50487 .50209 Metetra
.68 .783 .928 r
.50487 .50209 .55136 .54559 .63763 .51405 .59318 .46893 Metetra
.68 .783 .928 r
.59318 .46893 .63763 .51405 .72682 .48927 .68408 .4348 Metetra
.529 .687 .939 r
.68408 .4348 .72682 .48927 .81959 .47006 .78004 .42976 Metetra
.562 .777 .979 r
.78004 .42976 .81959 .47006 .9142 .43581 .87955 .41303 Metetra
.73 .835 .929 r
.20044 .54378 .25611 .57479 .33822 .5187 .28388 .50084 Metetra
.649 .893 .983 r
.28388 .50084 .33822 .5187 .41996 .50524 .36864 .4678 Metetra
.593 .79 .974 r
.36864 .4678 .41996 .50524 .50487 .50209 .45558 .44799 Metetra
.645 .739 .918 r
.45558 .44799 .50487 .50209 .59318 .46893 .54585 .42088 Metetra
.68 .783 .928 r
.54585 .42088 .59318 .46893 .68408 .4348 .63902 .3849 Metetra
.626 .764 .945 r
.63902 .3849 .68408 .4348 .78004 .42976 .7358 .35905 Metetra
.599 .678 .896 r
.7358 .35905 .78004 .42976 .87955 .41303 .83713 .34029 Metetra
.555 .522 .773 r
.15102 .42263 .20044 .54378 .28388 .50084 .23097 .41749 Metetra
.504 .581 .866 r
.23097 .41749 .28388 .50084 .36864 .4678 .31426 .41992 Metetra
.681 .78 .925 r
.31426 .41992 .36864 .4678 .45558 .44799 .40354 .38408 Metetra
.705 .734 .874 r
.40354 .38408 .45558 .44799 .54585 .42088 .49563 .33927 Metetra
.599 .645 .867 r
.49563 .33927 .54585 .42088 .63902 .3849 .59066 .32028 Metetra
.632 .721 .911 r
.59066 .32028 .63902 .3849 .7358 .35905 .68949 .29238 Metetra
.763 .769 .858 r
.68949 .29238 .7358 .35905 .83713 .34029 .7889 .22456 Metetra
.681 .64 .802 r
.09664 .33061 .15102 .42263 .23097 .41749 .18072 .28723 Metetra
.31 .368 .761 r
.18072 .28723 .23097 .41749 .31426 .41992 .25945 .33085 Metetra
.504 .581 .866 r
.25945 .33085 .31426 .41992 .40354 .38408 .34766 .33099 Metetra
.774 .798 .873 r
.34766 .33099 .40354 .38408 .49563 .33927 .44267 .26481 Metetra
.598 .678 .897 r
.44267 .26481 .49563 .33927 .59066 .32028 .53924 .24361 Metetra
.376 .564 .909 r
.53924 .24361 .59066 .32028 .68949 .29238 .64172 .26118 Metetra
.786 .924 .928 r
.64172 .26118 .68949 .29238 .7889 .22456 .74532 .19002 Metetra
.912 .977 .78 r
.01926 .36808 .09664 .33061 .18072 .28723 .11852 .24033 Metetra
.33 .661 .973 r
.11852 .24033 .18072 .28723 .25945 .33085 .20147 .24569 Metetra
.152 .407 .851 r
.20147 .24569 .25945 .33085 .34766 .33099 .28697 .2857 Metetra
.73 .835 .929 r
.28697 .2857 .34766 .33099 .44267 .26481 .38452 .2328 Metetra
.726 .896 .956 r
.38452 .2328 .44267 .26481 .53924 .24361 .48457 .17855 Metetra
.105 .457 .887 r
.48457 .17855 .53924 .24361 .64172 .26118 .58924 .2184 Metetra
.294 .681 .974 r
.58924 .2184 .64172 .26118 .74532 .19002 .70173 .22383 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.11158 .21312 -6 -8.95035 ]
[.11158 .21312 0 .04965 ]
[.28836 .14356 -5.67606 -9 ]
[.28836 .14356 .32394 0 ]
[.47788 .06904 -5.31864 -9 ]
[.47788 .06904 .68136 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.74908 .0689 0 -6.18931 ]
[.74908 .0689 6 2.81069 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 6 2.93953 ]
[.9134 .32052 0 -5.94988 ]
[.9134 .32052 6 3.05012 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02476 .26107 -6 -2.73891 ]
[.02476 .26107 0 6.26109 ]
[.01247 .33808 -24 -2.80405 ]
[.01247 .33808 0 6.19595 ]
[-0.00045 .41904 -18 -2.87289 ]
[-0.00045 .41904 0 6.12711 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7368 .07352 m
.73065 .07582 L
s
[(2)] .74908 .0689 -1 .3754 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(4)] .83635 .20254 -1 .34677 Mshowa
.90091 .32455 m
.89466 .32656 L
s
[(6)] .9134 .32052 -1 .3222 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(8)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.75965 .10848 m
.75596 .10983 L
s
.78177 .14231 m
.77807 .14365 L
s
.8032 .17508 m
.79948 .1764 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.88252 .29643 m
.87878 .29766 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03698 .25629 m
.04309 .2539 L
s
[(0)] .02476 .26107 1 -0.39135 Mshowa
.02475 .33345 m
.03089 .33114 L
s
[(0.05)] .01247 .33808 1 -0.37688 Mshowa
.01189 .41458 m
.01806 .41235 L
s
[(0.1)] -0.00045 .41904 1 -0.36158 Mshowa
.125 Mabswid
.03458 .27142 m
.03825 .27 L
s
.03216 .2867 m
.03583 .28528 L
s
.02971 .30213 m
.03339 .30072 L
s
.02724 .31771 m
.03092 .31631 L
s
.02223 .34935 m
.02592 .34797 L
s
.01969 .36541 m
.02338 .36404 L
s
.01711 .38163 m
.02081 .38027 L
s
.01452 .39802 m
.01822 .39667 L
s
.00924 .43131 m
.01295 .42998 L
s
.00656 .44821 m
.01027 .44689 L
s
.00386 .46529 m
.00757 .46398 L
s
.00112 .48255 m
.00484 .48125 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.651 .54 .716 r
.3575 .62532 .39953 .76368 .47744 .70927 .43457 .58905 Metetra
.692 .581 .726 r
.43457 .58905 .47744 .70927 .55571 .60856 .51334 .53331 Metetra
.69 .648 .803 r
.51334 .53331 .55571 .60856 .63412 .55359 .59326 .49549 Metetra
.605 .667 .883 r
.59326 .49549 .63412 .55359 .7169 .56167 .67611 .48335 Metetra
.69 .649 .804 r
.67611 .48335 .7169 .56167 .79841 .50484 .7602 .44386 Metetra
.608 .666 .88 r
.7602 .44386 .79841 .50484 .88776 .51195 .84883 .43034 Metetra
.542 .575 .838 r
.84883 .43034 .88776 .51195 .9883 .56793 .94348 .43583 Metetra
.663 .621 .797 r
.31214 .54248 .3575 .62532 .43457 .58905 .38957 .51253 Metetra
.69 .649 .804 r
.38957 .51253 .43457 .58905 .51334 .53331 .46917 .47402 Metetra
.681 .697 .858 r
.46917 .47402 .51334 .53331 .59326 .49549 .55055 .44243 Metetra
.639 .71 .899 r
.55055 .44243 .59326 .49549 .67611 .48335 .63449 .42107 Metetra
.68 .698 .859 r
.63449 .42107 .67611 .48335 .7602 .44386 .72063 .38779 Metetra
.64 .709 .897 r
.72063 .38779 .7602 .44386 .84883 .43034 .81016 .3648 Metetra
.608 .666 .88 r
.81016 .3648 .84883 .43034 .94348 .43583 .90383 .34906 Metetra
.679 .94 .964 r
.25907 .53732 .31214 .54248 .38957 .51253 .33937 .49806 Metetra
.801 .91 .915 r
.33937 .49806 .38957 .51253 .46917 .47402 .42206 .4387 Metetra
.724 .817 .922 r
.42206 .4387 .46917 .47402 .55055 .44243 .5055 .39769 Metetra
.586 .74 .949 r
.5055 .39769 .55055 .44243 .63449 .42107 .5914 .38289 Metetra
.723 .821 .926 r
.5914 .38289 .63449 .42107 .72063 .38779 .67944 .33992 Metetra
.59 .738 .946 r
.67944 .33992 .72063 .38779 .81016 .3648 .7717 .32345 Metetra
.429 .698 .977 r
.7717 .32345 .81016 .3648 .90383 .34906 .87004 .32633 Metetra
.661 .623 .8 r
.20963 .44845 .25907 .53732 .33937 .49806 .29007 .41551 Metetra
.689 .651 .807 r
.29007 .41551 .33937 .49806 .42206 .4387 .37311 .37369 Metetra
.68 .699 .861 r
.37311 .37369 .42206 .4387 .5055 .39769 .45789 .33885 Metetra
.638 .711 .9 r
.45789 .33885 .5055 .39769 .5914 .38289 .54516 .31436 Metetra
.679 .699 .862 r
.54516 .31436 .5914 .38289 .67944 .33992 .6352 .27753 Metetra
.639 .71 .899 r
.6352 .27753 .67944 .33992 .7717 .32345 .72865 .2511 Metetra
.605 .667 .883 r
.72865 .2511 .7717 .32345 .87004 .32633 .82643 .23191 Metetra
.699 .931 .966 r
.14913 .43903 .20963 .44845 .29007 .41551 .2329 .39629 Metetra
.802 .898 .91 r
.2329 .39629 .29007 .41551 .37311 .37369 .31992 .33284 Metetra
.725 .813 .919 r
.31992 .33284 .37311 .37369 .45789 .33885 .40717 .2881 Metetra
.588 .739 .948 r
.40717 .2881 .45789 .33885 .54516 .31436 .49627 .27007 Metetra
.724 .817 .922 r
.49627 .27007 .54516 .31436 .6352 .27753 .58863 .22305 Metetra
.592 .737 .944 r
.58863 .22305 .6352 .27753 .72865 .2511 .68476 .20297 Metetra
.439 .699 .975 r
.68476 .20297 .72865 .2511 .82643 .23191 .78699 .2025 Metetra
.432 .819 .587 r
.07471 .49209 .14913 .43903 .2329 .39629 .16537 .42587 Metetra
.892 .988 .787 r
.16537 .42587 .2329 .39629 .31992 .33284 .26127 .30923 Metetra
.802 .898 .91 r
.26127 .30923 .31992 .33284 .40717 .2881 .35264 .24223 Metetra
.403 .695 .98 r
.35264 .24223 .40717 .2881 .49627 .27007 .44325 .2429 Metetra
.801 .91 .915 r
.44325 .2429 .49627 .27007 .58863 .22305 .53891 .17316 Metetra
.432 .699 .977 r
.53891 .17316 .58863 .22305 .68476 .20297 .63834 .1718 Metetra
0 .329 .732 r
.63834 .1718 .68476 .20297 .78699 .2025 .74773 .22287 Metetra
.828 .931 .899 r
.00095 .48363 .07471 .49209 .16537 .42587 .09666 .40509 Metetra
.908 .851 .775 r
.09666 .40509 .16537 .42587 .26127 .30923 .19968 .26272 Metetra
.808 .82 .86 r
.19968 .26272 .26127 .30923 .35264 .24223 .29471 .18456 Metetra
.357 .634 .959 r
.29471 .18456 .35264 .24223 .44325 .2429 .38639 .19218 Metetra
.811 .831 .866 r
.38639 .19218 .44325 .2429 .53891 .17316 .48548 .11096 Metetra
.393 .641 .955 r
.48548 .11096 .53891 .17316 .63834 .1718 .58708 .11636 Metetra
0 .249 .735 r
.58708 .11636 .63834 .1718 .74773 .22287 .69974 .18955 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.11158 .21312 -6 -8.95035 ]
[.11158 .21312 0 .04965 ]
[.28836 .14356 -5.67606 -9 ]
[.28836 .14356 .32394 0 ]
[.47788 .06904 -5.31864 -9 ]
[.47788 .06904 .68136 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.74908 .0689 0 -6.18931 ]
[.74908 .0689 6 2.81069 ]
[.83635 .20254 0 -6.06047 ]
[.83635 .20254 6 2.93953 ]
[.9134 .32052 0 -5.94988 ]
[.9134 .32052 6 3.05012 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02196 .27863 -12 -2.75374 ]
[.02196 .27863 0 6.24626 ]
[.00948 .35682 -6 -2.81995 ]
[.00948 .35682 0 6.18005 ]
[-0.00364 .43906 -6 -2.88997 ]
[-0.00364 .43906 0 6.11003 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7368 .07352 m
.73065 .07582 L
s
[(2)] .74908 .0689 -1 .3754 Mshowa
.82395 .20683 m
.81775 .20898 L
s
[(4)] .83635 .20254 -1 .34677 Mshowa
.90091 .32455 m
.89466 .32656 L
s
[(6)] .9134 .32052 -1 .3222 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(8)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.75965 .10848 m
.75596 .10983 L
s
.78177 .14231 m
.77807 .14365 L
s
.8032 .17508 m
.79948 .1764 L
s
.84407 .23761 m
.84035 .23888 L
s
.86359 .26746 m
.85986 .26871 L
s
.88252 .29643 m
.87878 .29766 L
s
.91876 .35185 m
.915 .35304 L
s
.9361 .37838 m
.93234 .37955 L
s
.95296 .40417 m
.94919 .40532 L
s
.71317 .03738 m
.7095 .03879 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03419 .27388 m
.04031 .27151 L
s
[(-2)] .02196 .27863 1 -0.38806 Mshowa
.02177 .35223 m
.02792 .34993 L
s
[(0)] .00948 .35682 1 -0.37334 Mshowa
.00871 .43464 m
.01489 .43243 L
s
[(2)] -0.00364 .43906 1 -0.35779 Mshowa
.125 Mabswid
.03114 .2931 m
.03482 .29169 L
s
.02806 .31257 m
.03174 .31117 L
s
.02494 .33227 m
.02862 .33088 L
s
.01857 .37244 m
.02226 .37107 L
s
.01533 .39291 m
.01902 .39156 L
s
.01204 .41364 m
.01574 .4123 L
s
.00534 .45592 m
.00905 .45461 L
s
.00193 .47748 m
.00564 .47618 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.784 .918 .928 r
.35357 .7062 .40119 .71633 .47803 .66591 .43286 .65393 Metetra
.784 .918 .928 r
.43286 .65393 .47803 .66591 .55577 .61489 .5131 .60102 Metetra
.643 .084 0 r
.5131 .60102 .55577 .61489 .63822 .68046 .59682 .66844 Metetra
.775 .939 .934 r
.59682 .66844 .63822 .68046 .72061 .62713 .68204 .61303 Metetra
.775 .939 .934 r
.68204 .61303 .72061 .62713 .80402 .57314 .76835 .55691 Metetra
.507 0 0 r
.76835 .55691 .80402 .57314 .90176 .64057 .86834 .62628 Metetra
.758 .959 .935 r
.86834 .62628 .90176 .64057 .9905 .58398 .96038 .56735 Metetra
.681 .566 .719 r
.31006 .57547 .35357 .7062 .43286 .65393 .38918 .52233 Metetra
.681 .566 .719 r
.38918 .52233 .43286 .65393 .5131 .60102 .46926 .46855 Metetra
.352 .368 .738 r
.46926 .46855 .5131 .60102 .59682 .66844 .55124 .53046 Metetra
.68 .566 .72 r
.55124 .53046 .59682 .66844 .68204 .61303 .63628 .4741 Metetra
.68 .566 .72 r
.63628 .4741 .68204 .61303 .76835 .55691 .72241 .41701 Metetra
.392 .393 .741 r
.72241 .41701 .76835 .55691 .86834 .62628 .82049 .48021 Metetra
.679 .566 .72 r
.82049 .48021 .86834 .62628 .96038 .56735 .91234 .42021 Metetra
.788 .896 .92 r
.2573 .55979 .31006 .57547 .38918 .52233 .339 .5046 Metetra
.788 .896 .92 r
.339 .5046 .38918 .52233 .46926 .46855 .42174 .44871 Metetra
.582 .012 0 r
.42174 .44871 .46926 .46855 .55124 .53046 .50481 .51215 Metetra
.784 .918 .928 r
.50481 .51215 .55124 .53046 .63628 .4741 .59286 .45346 Metetra
.784 .918 .928 r
.59286 .45346 .63628 .4741 .72241 .41701 .68208 .394 Metetra
.418 0 0 r
.68208 .394 .72241 .41701 .82049 .48021 .78232 .45873 Metetra
.775 .939 .934 r
.78232 .45873 .82049 .48021 .91234 .42021 .87769 .39609 Metetra
.788 .896 .92 r
.20052 .54293 .2573 .55979 .339 .5046 .28499 .48551 Metetra
.788 .896 .92 r
.28499 .48551 .339 .5046 .42174 .44871 .37056 .42734 Metetra
.582 .012 0 r
.37056 .42734 .42174 .44871 .50481 .51215 .45464 .49236 Metetra
.784 .918 .928 r
.45464 .49236 .50481 .51215 .59286 .45346 .54592 .43116 Metetra
.784 .918 .928 r
.54592 .43116 .59286 .45346 .68208 .394 .63846 .3691 Metetra
.418 0 0 r
.63846 .3691 .68208 .394 .78232 .45873 .74086 .4354 Metetra
.775 .939 .934 r
.74086 .4354 .78232 .45873 .87769 .39609 .84005 .36988 Metetra
.679 .566 .72 r
.15342 .40182 .20052 .54293 .28499 .48551 .2377 .34341 Metetra
0 0 .285 r
.2377 .34341 .28499 .48551 .37056 .42734 .30686 .53394 Metetra
.753 .864 .433 r
.30686 .53394 .37056 .42734 .45464 .49236 .4051 .34278 Metetra
.677 .565 .721 r
.4051 .34278 .45464 .49236 .54592 .43116 .49617 .28046 Metetra
.677 .565 .721 r
.49617 .28046 .54592 .43116 .63846 .3691 .5885 .21727 Metetra
.352 .368 .738 r
.5885 .21727 .63846 .3691 .74086 .4354 .68864 .27627 Metetra
.676 .564 .722 r
.68864 .27627 .74086 .4354 .84005 .36988 .78759 .20949 Metetra
.79 .876 .91 r
.0902 .37801 .15342 .40182 .2377 .34341 .17741 .3171 Metetra
.79 .876 .91 r
.17741 .3171 .2377 .34341 .30686 .53394 .26581 .25536 Metetra
.405 .308 .631 r
.26581 .25536 .30686 .53394 .4051 .34278 .34855 .31501 Metetra
.788 .896 .92 r
.34855 .31501 .4051 .34278 .49617 .28046 .44307 .24984 Metetra
.788 .896 .92 r
.44307 .24984 .49617 .28046 .5885 .21727 .53896 .18373 Metetra
0 .229 .652 r
.53896 .18373 .5885 .21727 .68864 .27627 .64106 .24368 Metetra
.784 .918 .928 r
.64106 .24368 .68864 .27627 .78759 .20949 .74412 .17363 Metetra
.79 .876 .91 r
.02177 .35223 .0902 .37801 .17741 .3171 .11212 .28861 Metetra
.79 .876 .91 r
.11212 .28861 .17741 .3171 .26581 .25536 .20375 .22409 Metetra
.507 0 0 r
.20375 .22409 .26581 .25536 .34855 .31501 .28704 .28479 Metetra
.788 .896 .92 r
.28704 .28479 .34855 .31501 .44307 .24984 .38527 .21652 Metetra
.788 .896 .92 r
.38527 .21652 .44307 .24984 .53896 .18373 .48499 .14721 Metetra
0 .229 .652 r
.48499 .14721 .53896 .18373 .64106 .24368 .58902 .20803 Metetra
.784 .918 .928 r
.58902 .20803 .64106 .24368 .74412 .17363 .69654 .13437 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.12091 .22234 m
.12558 .22696 L
s
[(2)] .11158 .21312 1 .98897 Mshowa
.2971 .15335 m
.30147 .15825 L
s
[(4)] .28836 .14356 .89202 1 Mshowa
.4859 .07942 m
.48992 .08461 L
s
[(6)] .47788 .06904 .77288 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(8)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.16384 .20553 m
.1666 .20834 L
s
.20751 .18843 m
.21022 .19129 L
s
.25192 .17104 m
.25459 .17394 L
s
.34306 .13535 m
.34564 .13834 L
s
.38984 .11704 m
.39236 .12006 L
s
.43745 .0984 m
.43991 .10147 L
s
.53524 .06011 m
.53759 .06327 L
s
.58547 .04044 m
.58776 .04364 L
s
.63663 .0204 m
.63885 .02365 L
s
.07869 .23888 m
.08153 .2416 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{284.625, 230.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004L0000iQ000`40O003h00Oogoo7Goo003oOolM
Ool00?mooaeoo`00ogoo7Goo003oOolMOol00?mooaeoo`00ogoo7Goo003oOolMOol00?mooaeoo`00
ogoo7Goo003oOolMOol00?mooaeoo`00H7oo00<007ooOol0^Goo001OOol00`00Ool0002jOol005mo
o`03001oo`0008eoo`03001oogoo02Yoo`00H7oo00<007ooOol0Rgoo00<007oo0000:goo001OOol0
0`00Ool0002<Ool00`00Ool0000[Ool0061oo`03001oogoo08aoo`03001oogoo02Yoo`00kWoo00<0
07oo0000:goo003_Ool00`00Oomoo`0ZOol004Yoo`800=1oo`00BWoo00<007oo00005Goo0P00^7oo
001:Ool00`00Ool0000COol200000goo0000001eOol20010Ool004Yoo`80015oo`<000=oo`8007Eo
o`03001oo`0003moo`00BWoo00<007ooOol03Woo0P0000=oo`00Ool00goo00<007oo000017oo0`00
KGoo00<007oo000057oo0P00:Goo001;Ool2000;Ool30008Ool01000Ool000000goo00<007ooOol0
KGoo0P004Goo00D007oo000007oo008002Qoo`00EWoo0P0000=oo`00Ool027oo00@007ooOol000Ao
o`03001oogoo06aoo`03001oogoo00moo`<000=oo`8000Eoo`<0021oo`00Dgoo0`003Goo00D007oo
Oomoo`0000=oo`03001oogoo06eoo`8000]oo`@000Ioo`03001oo`0000Aoo`03001oogoo021oo`00
>7oo0`005Goo0`0000=oo`00Ool03Woo00T007ooOomoo`00Ool007oo0000NWoo0P002Goo00@007oo
Ool000Aoo`03001oogoo01moo`00>Goo00<007ooOol04Woo0P0057oo00<007ooOol00P000Woo00<0
07ooOol0Fgoo0`005goo10002goo00@007ooOol000Aoo`03001oogoo01moo`00=goo100047oo0`00
00=oo`00Ool027oo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0GWoo00<007ooOol05Goo
0`003Goo00D007ooOomoo`00009oo`03001oo`00021oo`00=goo00<007oo00003goo0P0037oo1@00
27oo00<007ooOol00goo00<007ooOol0Fgoo10004goo0`0047oo00@007ooOomoo`80009oo`03001o
ogoo01moo`00>7oo0P0037oo0`0000=oo`00Ool02Goo0P000emM00<000eI00001goo00<007ooOol0
0goo00<007ooOol0Fgoo00<007oo00004Woo0`004Woo00<007ooOol00Woo00<007ooOol08Woo000i
Ool00`00Oomoo`08Ool2000=Ool20005Ged00`003ET=F@020005Ool00`00Oomoo`04Ool00`00Oomo
o`1KOol2000?Ool3000EOol00`00Oomoo`03Ool00`00Oomoo`0QOol0045oo`<00003Ool007oo00Yo
o`8000QOG@04000=F@eI3ET20003Ool00`00Oomoo`05Ool00`00Oomoo`1KOol00`00Oomoo`0:Ool3
000HOol00`00Oomoo`04Ool00`00Oomoo`0POol002Eoo`<001Moo`<000eoo`8000YOG@03000=F@eI
00<=F@04001oogoo0007Ool00`00Oomoo`1VOol2000KOol00`00Oomoo`04Ool00`00Oomoo`0POol0
02Eoo`03001oogoo01Aoo`<000moo`03001[W00000]OG@03000=F@eI00<=F@<000Moo`8004Uoo`<0
01Moo`@001ioo`03001oogoo00Aoo`03001oogoo01moo`009Woo00<007ooOol04Goo0`0047oo00D0
06^LJia[W00000YOG@03000=F@eI00D=F@03001oogoo00Moo`03001oogoo04Ioo`03001oogoo01Io
o`80025oo`03001oogoo00Eoo`03001oogoo01ioo`009Woo00<007ooOol03Woo0`004Woo00<006^L
Ji`00f^L00<005mMGed025mM00<000eI3ET010eI0P0027oo00<007ooOol00goo0`00@Goo00<007oo
Ool04Woo0`008goo00<007ooOol01Goo00<007ooOol07Woo000UOol00`00Ool0000=Ool3000COol0
0`00Jia[W005Ji`00`00GeeOG@07Ged00`003ET=F@043ET20008Ool20005Ool00`00Oomoo`10Ool0
0`00Oomoo`0?Ool4000UOol00`00Oomoo`06Ool00`00Oomoo`03Ool3000GOol002Ioo`03001oogoo
00Uoo`<001Aoo`8000U[W0`000D=F@8000Uoo`03001oogoo00@0041oo`03001oo`0000ioo`8002Uo
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo01Ioo`00;goo0`0000=oo`00Ool04goo00<0
06^LJi`01f^L0P0000=W_@00>[h023Zn0`000`eI0P002Goo00H007ooOol007oo0012Ool00`00Oomo
o`0:Ool3000GOol2000BOol00`00Oomoo`07Ool01000Oomoogoo10005goo000]Ool2000HOol00`00
Jia[W007Ji`00`00IkeW_@02Ikd00`00>[hj_P07>[h020000IX000003ET000eI0009Ool00`00Oomo
o`02001=Ool2000HOol200000enN00000002000?Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01P00
Oomoo`00Ool001Qoo`00:Woo0`002Woo2@001Woo00<006^LJi`01f^L00<006NmIkd00fNm00<003Zn
>[h023Zn00<0006J0IX00P000PeI00<007ooOol00`000Woo0P000goo00<007ooOol0B7oo0`0067oo
0P0015nN00<000gL3M`010002goo00<007ooOol00P0000=W_@00Ool017oo00<007ooOol00P0067oo
000XOol30007Ool50005?el01000<WhbOS9n1P0026^L0P001fNm00<003Zn>[h023Zn00<0006J0IX0
200000=7G`00Ool00Woo00<007ooOol0BGoo0P006Goo0P001UnN00<000gL3M`010gL1P001Goo0`00
16Nm0P000Woo0P000goo00<007ooOol05Woo000UOol30009Ool01000LoL0000023mO00<0039n<Wh0
1S9n0P001F^L00<006NmIkd026Nm00<003Zn>[h013Zn1`000TMO0`0014MO0P000Woo00<007ooOol0
AGoo0`006Goo0P002EnN00<000gL3M`01@gL00@002Jo9[lV_`L000MW_@05001oogooOol0000KOol0
02=oo`800003Ool007oo00Uoo`04001cmg?gLoL20007?el00`00<WhbOP07<Wh200000f^L0000000;
Ikd70005A[d2000:Ael200000goo001oo`13Ool3000JOol2000<Gih00`003M`=g0053M`00`009[lV
_`049[l20006Ikd30003Ool2000JOol0025oo`8000eoo`03001cmg?g00Acm`@000@oG`03000bOS9n
00HbOP<000]W_@80009Fo0030016_DJm00A6_@<00003A[d0000000I7G`<00005D]`007ooOol00011
Ool30002Ool:000>Ool200000emM0000000:Gih500053M`00`009[lV_`029[l30005Ikd01@00Ha]S
6f<K00000goo00<007ooOol067oo000QOol2000<Ool00`00LoMcm`05LoL01000Iid002Xl100000<o
G`00<Wh00S9n10000d/O0P001fNm0P0015Kl00@004JmA[e6_@<000E6_@030017GdMO00@000EBg004
001oogoo000nOol20004Ool01000MoP000001RZo0`002Woo0P001EmM0P0015nN10000djl00<0039M
0000100000<=g0009[l00`000VNm00D006NmIkeW_@0000AS6`03001oogoo009oo`03001oogoo01Mo
o`008Goo00<007oo00002goo00<007?gLoL00g?g0P000fNM00<002Xl:S`00RXl1@002D/O0P000fNm
0P001eKl0`0024Jm0`002E;L00@007ooOol003ioo`8000=oo`03001gn7Oh009gn003000Z_bZo00<Z
_`03000A^a6k008000Ioo`8000UOG@@000M>_003000bGC9M00@bG@<000EW_@04001W_@000005Ha/0
0`00Oomoo`02Ool2000HOol0025oo`04001oogoo0009Ool00`00LoMcm`03LoL00`00IieWW@04Iid0
0`00:S`Z?004:S`00`00Bam;7`0:Bal30007E_`40007A[d20002F_`00`00D]aBg008D]`01000Oomo
o`0017oo0P00=Woo0P0000Eoo`00Oomoo`0000Egn08000@Z_`04000A^a6k4K/20002Ool2000:Ged2
00000f<k001>_008C[`00`00<UdbG@030003<Ud00`00IkeW_@03Ikd00`00Ha]S6`06Ha/00`00Oomo
o`02Ool00`00Oomoo`03Ool2000AOol0021oo`8000=oo`03001oogoo00Eoo`03001cmg?g00=cm`03
001WWFNM00EWW@03000Z?2Xl00DZ?003001;7d/O00M;7`80009G7@03001Fo5Kl009Fo0<000AFo003
0016_DJm0096_@8000EJo003001Bg5;L00MBg003001oogoo008000=oo`03001oo`0003Eoo`80009o
o`8000Qgn003000Z_bZo008Z_`03000A^a6k008A^`8000YOG@8000=S>`03001>_4jl00M>_0<000Lb
G@800005Ikd00000Ha/00007Ha/00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Ool0000@Ool001ao
o`04001oogooOol20004Ool00`00Oomoo`04Ool01000LoMcmg?g0P002FNM00<002Xl:S`01BXl0P00
1D/O0P0015LM00<005Kl00000P001eKl00<004JmA[d00P001e[l00<005;LD]`025;L00@007ooOol0
00=oo`03001oo`0003Eoo`05001oogooOol00007MoP50003:[l00`004K/A^`034K/00`00GeeOG@06
Ged00`00Hc]S>`04Hc/00`00C[a>_003C[`30002C[`00`00<UdbG@05<Ud30004Ha/00`00Ha]S6`05
Ha/00`00Oomoo`02Ool20003Ool00`00Ool0000@Ool001]oo`03001oo`00009oo`03001oogoo00Ao
o`8000=oo`05001cmg?gLoL0000<Iid00`00:S`Z?006:S`00`00Bam;7`020005Ead3000:E_`3000:
F_`00`00D]aBg007D]`01@00Oomoogoo00000Woo0P00=Woo00@007ooOol000Ign08000=FV@06000U
N000000Z_`001Q6k0P0015mM0P0026<k00<004jlC[`00P001Djl00@0039M<UdbG@@000=Bo@05001S
6f<KHa/00007Ha/00`00Oomoo`03Ool01000Oomoogoo0P004Goo000KOol00`00Ool00002Ool20007
Ool00`00Ool00003LoL2000<Iid<0004Ead30003Ead00`00E_aFo005E_`20002E]/00`00F_aJo009
F_`00`00D]aBg007D]`00`00Oomoo`0200000goo001oo`0SOol00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007OhMoP00WOh0P001EJI00@002Eh9GPUN0<0
00LA^`04001OG@00000:Hc/30006C[`50008D_d01@00Ha]S6f<K00001V<K00<007ooOol017oo00@0
07ooOol0019oo`006goo00<007oo00000Woo00<007ooOol01goo0P0000=cm`0000000W?g100016NM
10000TiI00<004IkAW/01TIk00<005LMEad00P001eLM00<005KlE_`00UKl0P0015KK00<005[lF_`0
2E[l1P0015;L00D007ooOomoo`00009oo`80025oo`03001oo`0000Moo`03001oo`00009oo`03001o
o`00009oo`03001oo`0000=gn08000QFV@03000UN2Eh008UN0X000US>`<00003Hc/004jl009>_0@0
00=>V`03001BoE;m00MBo@03001S6f<K009S6`03001S6f<K00AS6`03001oogoo00=oo`04001oogoo
Ool2000@Ool001]oo`03001oo`00009oo`03001oogoo00Moo`05001cm`00LoX00006LoL40006CUT0
0`00AW]6N`06AW/30009Ead00`00E_aFo0020007E]/00`00F_aJo006F_`200000eLM00000003?Yd6
0003Ool00`00Oomoo`0MOol30002Ool00`00Ool00007Ool00`00Ool00004Ool00`00Ool000020002
MoP200000goo001FV@07EYT00`009GPUN0049GP00`00@U]2F`05@U/00`00Hc]S>`03Hc/30004Hc/4
0007CY/00`00D_eBo@08D_d00`00Ha]S6`02Ha/01000Ha]S6f<K0`001Woo00<007ooOol04Woo000L
Ool01@00Oomoogoo000027oo00D007?g001cnP0000Icm`<000U>F@030016NdIk0096N`<00096N`03
001G7ELM00IG7@@000YFf`03001Jo5[l009Jo0<000AG7@03000nWCjM00LnW@03001oogoo008002=o
o`03001oo`0000Moo`03001oo`00009oo`80009oo`800003MoP0000000=oo`03001FVEJI00IFV@03
000UN2Eh00@UN0030012Fd9K00I2F`03001S>`00008000ES>`800003F_/004jK00U>V`03001BoE;m
00QBo@04001S6f<KHa/40003C[`00`00Oomoo`04Ool00`00Oomoo`0AOol000aoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Ioo`800003LoX007?g
00Ecm`05001RfV;JH]X00008CUT00`00AW/000020006AW/01000EaeG7ELM10000e;L00<005KKE]/0
25KK00<005[lF_`00P0025LM00<003jM?Yd01SjM00D007ooOomoo`0002=oo`03001oo`0000Moo`03
001oo`00009oo`04001oogooOol30006Ool00`00EYUFV@06EYT00`009GPUN0049GP00`00@U]2F`04
@U/40005Hc/20004F_/00`00CY]>V`08CY/00`00D_eBo@06D_d500000djl001>_004C[`00`00Oomo
o`04Ool00`00Oomoo`0AOol000]oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`80
00Moo`05001cnW?jLoX00004LoL20004H]X00`00CUU>F@05CUT30009AW/40007D]`00`00E]]Ff`08
E]/3000:Ead20008?Yd01@00Oomoogoo00008goo00<007ooOol01goo00@007ooOomoo`<00003Ool0
000000Qoo`03001FVEJI00EFV@03000UN2Eh00@UN0040012Fd9K@U/30004@U/00`00Hc]S>`020006
F_/00`00CY]>V`08CY/01000D_eBoE;m1@000e<N00D004jlC[a>_00000E>_003001oogoo00Aoo`03
001oogoo011oo`002goo00<007oo00001goo00<007oo000017oo00<007ooOol00P001Woo00D007?j
LoYcnP0000Acm`03001RfV;J00ERfP04001>FDiICUT30003CUT00`00AW]6N`03AW/30002Ead00`00
D]aBg007D]`00`00E]]Ff`05E]/20002Ged00`00EaeG7@09Ead00`00?YdnW@05?Yd7000_Ool00`00
Ool00002Ool00`00Oomoo`07Ool00`00EYUFV@05EYT00`009GPUN0059GP30007@U/30009F_/00`00
CY]>V`07CY/40008Dah00`00C[a>_002C[`00`00C[a>_002C[`00`00Oomoo`04Ool2000AOol000]o
o`03001oo`0000Moo`03001oo`00009oo`8000=oo`03001oogoo00Aoo`05001cnW?jLoX00003LoL2
0008H]X40006CUT00`00AW]6N`030006Ead00`00D]aBg007D]`00`00E]]Ff`02E]/20005Ged00`00
EaeG7@08Ead20002?Yd40002@el200000emM00000005Ool00`00Oomoo`0WOol00`00Ool00002Ool0
0`00Oomoo`08Ool00`00EYUFV@05EYT010009GPUN2Eh10001d9K0P000ULM00<005[kF_/01e[k00<0
04jKCY/01DjK0P000ULm00<005<NDah025<N00D004jlC[a>_00000E>_003001oogoo00Aoo`03001o
ogoo00=oo`03001oogoo00Uoo`002goo00<007oo00001goo00<007oo00000Woo00<007ooOol00Woo
00<007ooOol00goo00D007?jLoYcnP0000=cm`03001RfV;J00MRfP<000U>F@8000UG7@03001Bg5;L
00MBg003001FfeKK008000QOG@03001G7ELM00IG7@D000A3G`8000AOG@8000=oo`03001oo`0002Qo
o`04001oo`00Ool2000;Ool00`00EYUFV@04EYT400049GP00`00@U]2F`02@U/20005Ead00`00F_]J
n`07F_/00`00CY]>V`02CY/20005Ecd00`00DaiC7P07Dah00`00C[a>_002C[`00`00C[a>_002C[`0
0`00Oomoo`05Ool01`00Oomoogoo001oo`0000Yoo`0037oo00<007ooOol01goo00@007ooOomoo`<0
009oo`03001oogoo009oo`03001cnW?j009cnP06001cm`00001oo`001F;J0`000V;J00<004iICUT0
1DiI0P0000=Jf`00Ead02ELM00<005;LD]`01U;L0`002emM00@005LMEaeG7@@000=Bg0800093G`80
00IOG@03001oo`00009oo`03001oo`0002Qoo`04001oo`00Ool2000;Ool00`00EYUFV@02EYT40006
9GP00`00@U]2F`020007Ead00`00F_]Jn`07F_/00`00CY]>V`020008Ecd00`00DaiC7P07Dah00`00
C[a>_002C[`00`00C[a>_0030007Ool01P00Oomoo`00Ool000Yoo`007goo00D007ooOomoo`0000Ac
nP03001cm`0000Aoo`03001RfP00008000IRfP03001>FDiI00=>F@03001Jfe[K009Jf`03001G7ELM
00QG7@04001Bg5;LD]`40002B_h00`00GeeOG@09Ged40008D]`30009Ged20003Ool00`00Oomoo`0X
Ool01000Oomoo`003Goo4@002ULM00<005[kF_/01U[k0`002eLm00<005<NDah01U<N00@004jlC[a>
_0@000=77`8000Eoo`05001oogooOol0000;Ool0011oo`03001oogoo009oo`03001oogoo00D0009o
o`05001oogooOol00003LoX00`00LoL00004Ool30009H]X01000CUU>FDiI0P001U[K00<005LMEad0
1ULM1@001d[n0P001UmM0`000ULM00<005;LD]`01e;L0`002EmM0`0000Aoo`00Ool001Uoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol2000;Ool30006AQP00`00@U]2
F`05@U/00`00EaeG7@09Ead01000F_]Jne[k10000U;m00<005LmEcd02ELm3@000TLO00<004LOAal0
14LO0P000goo0P0000Aoo`00Ool000Yoo`003goo00<007oo000027oo00@007ooOomoo`80009oo`03
001cnW?j009cnP80009oo`<0009oo`03001RfV;J00QRfP<000UJf`04001G7ELMEad40003Dah00`00
B_i:oP08B_h00`00GeeOG@030005Ead00`00D]aBg005D]`20002G_X20009Ged20002Ool00`00Oomo
o`0GOol00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`07Ool30002Ool0
0`00AQQ66004AQP00`00@U]2F`06@U/20008Ead50007D_d20006Ecd30002Ecd00`00@[i2_P06@[h0
0`00Aam77`02Aal01000Aam77dLO0P0000=G?@0000000P0000Eoo`00Oomoo`0000]oo`003goo00<0
07oo000027oo00@007ooOomoo`800003Ool007?j009cnP800004Ool000000006Ool00`00H]YRfP06
H]X2000<F]/30008Dah00`00B_i:oP07B_h30009Ead00`00D]aBg003D]`00`00G_YNnP02G_X00`00
G_X00008Ged2000LOol00`00Ool00007Ool00`00Ool00004Ool01000Oomoo`001Woo0`001Goo00<0
04HHAQP01DHH00<0049K@U/01d9K00@005LMEaeG7@@000=;?`03001BoE;m00QBo@03001G?ELm00<0
00IG?@030012_T:n00I2_P0300177dLO00977`<000AG?@05001oogooOol0000>Ool000moo`03001o
o`0000Qoo`07001oogooOol007oo00000W?j0P0000=oo`0000002Woo00@006;JH]YRfP@0009BN@03
001Jfe[K00QJf`03001W_@0000UC7P03001:oT[n00A:oP<0009C7P03001G7ELM00QG7@05001Bg5;L
D]`00006G_X00`00G_X000040004Ged00`00Oomoo`0JOol00`00Ool00007Ool00`00Ool00002Ool2
0002Ool20003Ool30008Ool00`00AQQ66006AQP00`00@U]2F`06@U/40007Bcl00`00D_eBo@08D_d3
0009Ecd00`00@[i2_P07@[h00`00Aam77`030005Ecd01@00Oomoogoo00003Woo000?Ool00`00Ool0
0008Ool01000Oomoogoo20003Goo0`001e9i00<005[KF]/01E[K0P000fNm0P0025<N00<004[nB_h0
0`001U<N00<005LMEad01eLM00@005;L000000QNnP03001oogoo00=oo`H001]oo`03001oo`0000Mo
o`03001oo`00009oo`06001oogooOol007oo0`0037oo00<004HHAQP01THH00<0049K@U/00d9K0P00
0U>O00<004/oBcl01d/o00<005;mD_d01E;m0P000ULm00<005LmEcd025Lm00<004:n@[h00d:n1P00
0ULm00<005LmEcd015Lm00D007ooOomoo`0000eoo`0047oo00<007ooOol01Woo0P000goo1@004Goo
00<0059iDWT01U9i00<005[KF]/015[K00<006NmIkd01FNm00<005<NDah00e<N1@002E<N00<005LM
Ead01ULM0`002Ekj00<007oo00002Goo00<007ooOol06Woo00<007ooOol01goo00@007ooOomoo`<0
0003Ool0000000moo`03001664HH00I660030012Fd9K00<000ECW`8000Q;?`03001BoE;m009Bo@80
00EG?@03001G?ELm00MG?@H000E>g005001G?ELmEcd00005Ecd01@00Oomoogoo00003Goo000NOol2
000DOol00`00DWUBN@07DWT00`00F]]Jf`02F]/00`00IkeW_@07Ikd50004CY/00`00DaiC7P08Dah0
1000EaeG7ELM10000e9j00<005kjG_X01Ekj00@007ooOol000Uoo`03001oogoo02eoo`03001oogoo
00eoo`03001664HH00M6608000YCW`03001;?d/o00E;?`03001BoE;m008000MG?@03001G?ELm00AG
?@<0009B^`03001>g4kL00I>g003001G?ELm009G?@03001G?ELm00=G?@04001oogoo000=Ool001mo
o`03001oogoo01=oo`03001BNE9i00MBN@04001Jf`000008Ikd30009CY/20008Dah40007DWX00`00
G_YNnP04G_X00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0^Ool2000>Ool00`00AQQ66004
AQP20002Ged30005Dil=000:Ecd00`00EceG?@030005D[/00`00C]a>g007C]`00`00EceG?@02Ecd0
0`00EceG?@02Ecd01000Oomoo`003Goo000POol2000COol00`00DWUBN@08DWT20007Ikd20003EYX0
0`00CY]>V`08CY/01000DaiC7U<N100000=Bg000DWX02E9j00<005kjG_X00Ukj00<007ooOol017oo
00<007ooOol01Goo00<007ooOol0<7oo00<007ooOol02goo00<004HHAQP00dHH00<005mMGed01EmM
1@0014jl00<004JMAYd01DJM00<005LmEcd025Lm0`002E:k00<004kLC]`01TkL300000=oo`00Ool0
37oo000ROol00`00Oomoo`0AOol00`00DWUBN@05DWT20002Hmh20003Ikd20005EYX00`00CY]>V`09
CY/30006D]`00`00DWYBNP08DWX01000G_YNnP001goo00<007ooOol01Goo00<007ooOol0<Goo00<0
07ooOol02Woo00@004HHAQQ6608000QOG@03001WG00000M>_0030016WDJM00E6W@8000IG?@80009F
o003001B^e:k00QB^`03001>g4kL00=>g080009G?@050016FdIKAU/00004AU/00`00Ool0000=Ool0
02=oo`03001oogoo011oo`03001BNE9i00ABN@03001SgV?N00ASgP<000QFVP03001>VdjK00I>V`80
0003G]X005;L00IBg003001BNU9j00QBNP03001NnP0000Uoo`03001oogoo00Aoo`03001oogoo039o
o`03001oogoo00Yoo`<000QOG@80009WG003001>_4jl00E>_0030016WDJM00M6W@03001G?ELm00<0
00AFo003001B^e:k00QB^`03001>g4kL00<000AG?@030016FdIK0096F`030016FdIK0096F`8000eo
o`0097oo00<007ooOol047oo00@0059iDWUBN@8000ISgP800003Ged005JJ00MFVP03001>VdjK00A>
V`8000ANfP03001Bg5;L00EBg003001BNU9j00MBNP8000]oo`03001oogoo00=oo`03001oogoo03=o
o`03001oogoo00Uoo`03001OGEmM00MOG@03001WG6ML00=WG003001>_4jl00E>_0030016WDJM00I6
W@<000QFo003001B^e:k00MB^`<000QG?@030016FdIK0096F`070016FdIKAU/007oo000037oo000U
Ool2000@Ool01000DWT000001V?N0P000emM00<005JJEYX01eJJ00@004jKCY]>V`8000INfP03001B
g5;L00EBg003001BNU9j00EBNP8000ioo`03001oogoo00=oo`03001oogoo03=oo`8000Yoo`8000IO
G@03001WG6ML00EWG003001>_4jl00E>_0040016WDJMAYd40002D_d00`00E_aFo006E_`00`00D[]B
^`05D[/20002F]/00`00EceG?@06Ecd00`00AU]6F`02AU/01`00AU]6FdIK001oo`0000aoo`009goo
00<007ooOol03Woo0`0016?N0P001UmM00<005JJEYX01UJJ00@004jK000000UNfP03001Bg5;L00EB
g003001BNU9j009BNP80011oo`03001oogoo00=oo`03001oogoo03Eoo`03001oogoo00Uoo`80009O
G@8000QWG003001>_4jl00=>_0H000MBo@03001Fo5Kl00IFo003001B^e:k009B^`8000AJf`03001G
?ELm00MG?@030016FdIK0096F`040016FdIKAU/2000<Ool002Qoo`03001oogoo011oo`@000QOG@03
001FVUJJ00IFVP8000aNfP@000=Bg003001BNU9j008001=oo`03001oogoo009oo`03001oogoo03Io
o`03001oogoo00Yoo`<000UWG0H000A>F@03001BoE;m00IBo@03001Fo5Kl00IFo003001B^e:k0080
00MJf`03001G?ELm00IG?@030016FdIK00=6F`030016FdIK008000aoo`00:Goo00<007ooOol04goo
0P001emM00<005JJEYX00eJJ0P000UIG00<005kJG]X01ekJ0P0017oo1P005Woo00D007ooOomoo`00
03Uoo`03001oogoo00aoo`8000=WG0@0009BF003001>FDiI00I>F@03001BoE;m00IBo@03001Fo5Kl
00=Fo0D000YJf`X000E6F`040016F`00000<Ool002Yoo`8001Eoo`D0009OG@03001FVUJJ00<000EF
E`03001NfUkJ00ENfP03001oogoo025oo`04001oogoo000jOol2000>Ool30006DUP00`00CUU>F@06
CUT00`00D_eBo@06D_d60004C[`00`00F]]Jf`06F]/2000:Ool20003AU/01000AU/0000037oo000/
Ool00`00Oomoo`0COol01000AOM5mdGg1@002EIG00<005kJG]X00UkJ0P0097oo00@007ooOol003ao
o`03001oogoo00aoo`03001BF59H00IBF003001>FDiI00I>F@04001BoE;mD_d40002@gl00`00C[a>
_006C[`00`00F]]Jf`04F]/00`00Oomoo`0<Ool20002AU/00`00AU/0000<Ool002eoo`03001oogoo
01=oo`030015mdGg00=5m`03001FEeIG00UFE`04001NfP00000WOol00`00Ool0000mOol00`00Oomo
o`0<Ool00`00DUQBF005DUP00`00CUU>F@07CUT30007@gl00`00C[a>_005C[`00`00F]]Jf`02F]/2
000AOol00`00AU]6F`03000;Ool002ioo`03001oogoo019oo`030015mdGg00A5m`03001FEeIG00UF
E`03001oogoo02Qoo`03001oo`0003eoo`03001oogoo00]oo`03001BF59H00IBF003001>FDiI00A>
F@80009W_@@000A3O`03001>_4jl00I>_004001Jf`00000DOol200000dIK0000000;Ool002moo`80
019oo`030015mdGg00A5m`03001FEeIG00QFE`03001oogoo02Yoo`8003ioo`03001oogoo00Yoo`03
001BF59H00IBF003001>FDiI00=>F@03001W_FNm009W_@80009oo`@00003@gl004jl00A>_0@001Qo
o`<000]oo`00<Goo00<007ooOol03goo00<004GgAOL01DGg00<005IGEUL01UIG00<007ooOol0:goo
0P00?goo0P002goo00<0059HDUP01U9H00D004iICUU>F@0000AW_@03001oogoo00Ioo`L001eoo`80
00]oo`00<Woo00<007ooOol03goo00<004GgAOL014Gg00<005IGEUL01UIG00<007ooOol0:goo0P00
@Goo00<007ooOol027oo00<0059HDUP01U9H00@004iI000000AW_@03001oogoo02Moo`@000eoo`00
<goo00<007ooOol03Woo00<004GgAOL014Gg00<005IGEUL01EIG00<007ooOol0:7oo1000A7oo00<0
07ooOol027oo00<0059HDUP01U9H0P000fNm0P009Woo10004Goo000dOol2000>Ool00`00AOM5m`05
AOL00`00EUMFE`03EUL00`00Oomoo`0UOol40019Ool00`00Oomoo`07Ool00`00DUQBF004DUP20002
FYT3000TOol4000EOol003Ioo`03001oogoo00aoo`030015mdGg00A5m`03001FEeIG009FE`03001o
ogoo029oo`@004ioo`8000Moo`03001BF59H009BF08000EJV@03001oogoo01moo`@001Uoo`00=goo
00<007ooOol02goo00<004GgAOL01DGg00@005IGEUL0025oo`@005Aoo`03001oogoo00Eoo`04001B
F0000006FYT00`00Oomoo`0LOol4000MOol003Qoo`03001oogoo00Yoo`030015mdGg00E5m`04001F
EeIG000NOol3001IOol00`00Oomoo`04Ool20008FYT00`00Oomoo`0HOol4000QOol003Uoo`8000Yo
o`030015mdGg00I5m`8001]oo`@005eoo`03001oogoo00Aoo`03001JVEZI00EJV@03001oogoo01Io
o`<002Eoo`00>goo00<007ooOol027oo00<004GgAOL00TGg100067oo1000HWoo0P0017oo00<005ZI
FYT015ZI00<007ooOol04goo1000:7oo000lOol00`00Oomoo`07Ool5000HOol4001XOol00`00Oomo
o`02Ool00`00FYUJV@02FYT00`00Oomoo`0@Ool4000/Ool003eoo`03001oogoo00Ioo`03001oogoo
01Ioo`@006eoo`05001oogooOol00003FYT00`00Oomoo`0=Ool4000`Ool003ioo`8000Ioo`03001o
ogoo019oo`@0079oo`05001oogooOol00002FYT00`00Oomoo`09Ool4000dOol0041oo`03001oogoo
00=oo`03001oogoo00moo`<007Moo`06001oogoo001JV@0027oo1000>7oo0011Ool00`00Oomoo`02
Ool00`00Oomoo`0;Ool4001kOol200000goo001oo`04Ool4000lOol0049oo`05001oogooOol00009
Ool40021Ool200000goo000000020010Ool004=oo`800003Ool007oo00Aoo`@008Ioo`8004Aoo`00
AGoo0P0000=oo`0000000P00d7oo0016Ool2003DOol00?mooaeoo`00ogoo7Goo003oOolMOol00?mo
oaeoo`00ogoo7Goo003oOolMOol00?mooaeoo`00ogoo7Goo003oOolMOol00?mooaeoo`00ogoo7Goo
003oOolMOol00?mooaeoo`00ogoo7Goo003oOolMOol00?mooaeoo`00ogoo7Goo003YOol00`00Oomo
o`0`Ool00>Qoo`03001oo`00035oo`00j7oo00<007oo0000<Goo003YOol00`00Oomoo`0`Ool00>Qo
o`03001oo`00035oo`00jGoo00<007ooOol0<7oo001POol00`00Oomoo`2iOol005moo`03001oo`00
0;Yoo`00Ggoo00<007oo0000^Woo001POol00`00Oomoo`1^Ool2000HOol2000_Ool005moo`03001o
o`0006moo`03001oo`0001Eoo`800003Ool0000002ioo`00H7oo00<007ooOol0KWoo00<007oo0000
4Woo0`000goo0P00;Woo003AOol2000AOol40004Ool00`00Ool0000]Ool00=5oo`03001oogoo00eo
o`<000Qoo`04001oogoo0004Ool3000UOol004Yoo`8008Ioo`8000]oo`<000Yoo`04001oogoo0004
Ool00`00Oomoo`0UOol004Yoo`03001oo`0001Eoo`8007Qoo`<000eoo`05001oogooOol00004Ool0
0`00Oomoo`0TOol004Yoo`03001oo`0001=oo`800003Ool0000007Eoo`80011oo`03001oogoo009o
o`05001oogooOol0000VOol004Yoo`80015oo`<000=oo`80079oo`<00003Ool007oo011oo`05001o
ogooOol00002Ool00`00Ool0000UOol004Yoo`03001oogoo00ioo`8000Ioo`03001oo`0000Aoo`<0
04moo`<001Ioo`8001Ioo`04001oogooOol20002Ool00`00Oomoo`0TOol004]oo`8000]oo`<000Qo
o`04001oo`000003Ool00`00Oomoo`1@Ool00`00Oomoo`0BOol5000FOol00`00Oomoo`03Ool00`00
Oomoo`0VOol005Ioo`8000]oo`04001oogoo0004Ool00`00Oomoo`1=Ool4000AOol2000KOol00`00
Oomoo`03Ool00`00Oomoo`0VOol003Qoo`<001Qoo`<000eoo`05001oogooOol00003Ool00`00Oomo
o`1=Ool00`00Ool0000?Ool4000LOol00`00Oomoo`04Ool00`00Oomoo`0UOol003Uoo`03001oogoo
01Aoo`<0015oo`09001oogooOol007oo001oo`0004moo`8000eoo`80021oo`03001oogoo00Aoo`80
02Ioo`00=goo10004goo0P0057oo00<007ooOol00P000Woo00<007ooOol0Cgoo00<007ooOol027oo
0`008Woo00<007ooOol01Goo00<007ooOol097oo000gOol00`00Ool0000AOol3000FOol00`00Oomo
o`02Ool00`00Oomoo`1JOol2000UOol00`00Oomoo`06Ool00`00Oomoo`0SOol003Qoo`8000moo`80
01Uoo`03001oogoo00=oo`03001oogoo05Ioo`<002Moo`03001oogoo00Moo`03001oogoo029oo`00
>Goo00<007ooOol02Woo0`001Goo1P0047oo00<007ooOol00goo00<007ooOol0>Goo0`0067oo0P00
4Woo00<007ooOol04goo1@001goo00<007ooOol08Woo0014Ool20007Ool00`00Ie/00004<Yh6000:
Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00`00Oomoo`0EOol3000BOol200000fNM0000000BOol0
1000IkeW_@000VNm00<007ooOol01Goo00<007ooOol08Goo0011Ool30007Ool20003Ie/00`00<Yhb
WP07<Yh20008Ool00`00Oomoo`05Ool00`00Oomoo`0hOol00`00Oomoo`0BOol20002Ool00`00Oomo
o`0?Ool00`00IieWW@02Iid3000>Ool20003Ikd01000IkeW_FNm0P001Woo00<007ooOol087oo000U
Ool3000GOol20009Ool00`00Ie]WF`04Ie/00`00<YhbWP07<Yh20007Ool00`00Oomoo`05Ool2000i
Ool00`00Oomoo`0?Ool3000EOol00`00IieWW@04Iid3000<Ool00`00IkeW_@03Ikd00`00IkeW_@03
Ikd00`00Oomoo`03Ool00`00Oomoo`03Ool3000JOol002Eoo`03001oogoo01=oo`@000Yoo`03001W
FfMK00IWF`03000bWS:N00LbWP<000Eoo`03001oogoo00Ioo`03001oogoo03Ioo`03001oo`0000io
o`8001Ioo`8000UWW@<000Qoo`8000IW_@04001W_FNmIkd200000fNm001oo`03Ool20005Ool00`00
Oomoo`0IOol002Ioo`03001oogoo015oo`<000]oo`03001WFfMK00QWF`03000bWS:N00LbWP040000
m`000003Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3000`Ool00`00Oomoo`0:Ool3000GOol00`00
IieWW@0:Iid010000?@000001Goo00<006NmIkd01fNm00<006Nm000016Nm00<007ooOol00goo00<0
07ooOol010006Woo000VOol00`00Oomoo`0>Ool3000<Ool2000<Ie/<00001@3g001oogoo00002Goo
00<007ooOol017oo00<007ooOol0>Woo0P006Goo00<006NMIid02FNM0P0000AWW@000000m0800003
Ool0000000YW_@8000IW_@03001oogoo009oo`06001oogoo001oo`006goo000UOol00`00Ool0000=
Ool3000=Ool00`00Ie]WF`0;Ie/00`00Ikd00009=]l60009Ool20003Ool4000hOol3000IOol2000;
Iid00`00IieWW@03Iid200000`3d001W_@0:Ikd20008Ikd01000Oomoogoo0P000Woo0P006goo000V
Ool00`00Oomoo`09Ool30006Ool:000<Ie/20003Ikd00`00=]lfg`08=]l5000:Ool01P00Oomoo`00
Ool003Moo`8001]oo`03001WWFNM00UWW@8000QWW@@000MW_@800003Ikd006Nm00QW_@05001oogoo
Ool00003Ool00`00Oomoo`0IOol002moo`<000Qoo`03001WF`0000P^WP03001WFfMK00QWF`03001W
_FNm00AW_@03000fgcKO00Lfg`d0009oo`04001oogooOol2000dOol30008Ool00`00Oomoo`0@Ool2
00000fNM00000007Iid20009Iid60005Ikd01@00IkeW_FNm00001fNm0`0017oo00<007ooOol077oo
000]Ool20009Ool20003Ie/00`00;Yh^WP06;Yh00`00Ie]WF`06Ie/00`00IkeW_@06Ikd01000=]lf
gcKO1@000d[n1@000P5G0P0000<jg`00Ool00P000goo00<007ooOol0<7oo0P000Woo00<007ooOol0
17oo0P0000=WW@0000003goo00<006NMIid00fNM00<006NMIid00fNM00<006NMIid026NM00H005IG
EUMFE`00;GL300000fNm00000004Ikd00`00IkeW_@03Ikd20003EUL00`00Oomoo`02Ool00`00Oomo
o`0KOol002Uoo`@000Yoo`03001WFfMK00AWF`8000L^WP03001WFfMK00AWF`03001W_FNm00QW_@<0
00U:oP03000jgc[O00<000@jg`800003Ool007oo035oo`<000Yoo`03001WWFNM009WW@<000]oo`80
00MWW@800003Iid0000000YWW@03001FEeIG009FE`03000]Mbeg00<000IW_@03001W_FNm009W_@03
001FEeIG00=FE`03001oogoo009oo`03001oogoo01]oo`00:7oo0`002goo00<006MKIe/01fMK00<0
02jN;Yh01BjN00@006MKIe]WF`8000UW_@800003Ged004[n00U:oP03000jgc[O00Ljg`<00003Ool0
07oo02ioo`8000aoo`03001WWFNM00EWW@<000Qoo`03001WWFNM00UWW@03001WWFNM00QWW@8000EF
E`03000]Mbeg008]M`8000AW_@80009W_@8000IFE`03001oogoo00=oo`03001oogoo01Yoo`009Goo
0`003Goo00<006MKIe/02FMK1@000bjN00<006MK00002FNm0P0015mM00<004[nB_h01d[n0P000c[O
1@000Tjl00<007oo0000;Goo0P0037oo0P002FNM00<0040000001Goo0P002VNM0P0000=WW@000000
1fNM00<005IGEUL01UIG00<002eg;GL00beg10000VNm0P002EIG00<007ooOol00goo00<007ooOol0
6Goo000SOol2000>Ool2000;Ie/00`00Iid00003<]l60007Ikd20006Ged00`00B_i:oP06B_h60008
C[`00`00Ool0000/Ool2000;Ool00`00IieWW@09Iid40003Ool00`00IieWW@09Iid00`00IieWW@03
Iid00`00IieWW@03Iid00`00EUMFE`07EUL01000;GL]Mbeg1@0000AW_@00000000YFE`03001oogoo
00=oo`8001Yoo`008Goo0P003goo00<006MKIe/02FMK0P000fNM00<003;O<]l01S;O0`000VNm0P00
2EmM00<004[nB_h00T[n1P0000=Bg000C[`024jl00@007ooOol002]oo`<000Uoo`03001WWFNM00UW
W@03001WWFNM00D000]WW@03001WWFNM00EWW@800003Iid0000000YFE`@000D]M`05001FEeIGEUL0
0009EUL00`00Oomoo`04Ool00`00Oomoo`0HOol001eoo`04001oogooOol2000>Ool00`00Ie]WF`09
Ie/00`00IieWW@04Iid20008<]l3000<Ged60003D]`00`00D]`0000:C[`3000VOol30002Ool01000
Oomoo`001Woo0P002fNM00L006NMIieWW@00<C@0000;Iid2000:Iid00`00EUMFE`08EUL40007;GL0
0`00EUMFE`02EUL00`00EUMFE`07EUL00`00Oomoo`04Ool00`00Oomoo`02Ool2000COol001aoo`03
001oo`00009oo`03001oo`0000aoo`04001gN0000008Ie/00`00IieWW@07Iid01000<]lbgc;O1000
0d[n00<005mMGed01emM1@001e;L00<005;L00002Djl00@007ooOol002Eoo`04001oogooOol20003
Ool00`00Oomoo`02Ool2000:Iid20004Iid00`00<C@a=0020008Iid00`00IieWW@08Iid30008EUL2
0003EUL00`00;GL]M`06;GL00`00EUMFE`02EUL00`00EUMFE`06EUL00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Ool0000BOol001aoo`04001oo`00Ool20002Ool00`00Oomoo`09Ool01000MgQgN7Mh
0P0016MK0P002fNM0`0024[n00<005mMGed015mM10000UKK00<005;LD]`01U;L0P002Tjl00@007oo
Ool000=oo`8001Yoo`<000=oo`04001oogoo0005Ool40002Iid20007Iid00`00IieWW@05Iid01000
<C@a=34d0P001FNM00<006NMIid026NM00D005IGEUMFE`0000AFE`<000EFE`03000]Mbeg00H]M`03
001FEeIG009FE`03001FEeIG00IFE`03001oogoo00Aoo`8000=oo`03001oo`00019oo`0077oo00@0
07oo001oo`8000=oo`03001oogoo00Moo`03001gN7Mh00AgN0800003Ie/006NM00YWW@800003Ged0
04[n00U:oP03001OGEmM00D000AFf`03001Bg5;L00MBg08000U>_004001oo`000003Ool00`00Ool0
000OOol00`00Oomoo`020005Ool00`00IieWW@04Iid30002Iid20008Iid00`00<C@a=003<C@20000
0fNM0000000:Iid00`00EUMFE`02EUL00`00EUL000020009EUL00`00;GL]M`05;GL00`00EUMFE`03
EUL00`00EUMFE`06EUL00`00Oomoo`05Ool00`00Oomoo`02000COol001aoo`05001oo`00Ool00005
Ool00`00Oomoo`05Ool00`00MgQgN007MgP00`00IieWW@08Iid20004Ged00`00B_i:oP07B_h30000
0emM00000007E]/00`00D]aBg006D]`00`00D]`00009C[`01000Oomoo`000Woo00<007oo00007Woo
00D007oo001oo`0000Eoo`03001WWFNM00QWW@<000UWW@03000a=34d00Da=08000UWW@8000AFE`<0
00aFE`03000]Mbeg00H]M`03001FEeIG00=FE`03001FEeIG00EFE`03001oogoo00Eoo`04001oogoo
000DOol001eoo`04001oogoo0006Ool00`00Oomoo`03Ool00`00MgQgN007MgP01000LoT000001VNM
0P001emM00<004[nB_h00d[n1`002UKK00<005;LD]`01U;L0P002Djl00H007ooOomoo`00Ool2000P
Ool01000Oomoo`000goo0P002VNM0P000VNM0P001fNM00<0034d<C@01c4d0P001VNM00@005IGEUMF
E`<0009FE`03001FEeIG00YFE`03000]Mbeg00H]M`03001FEeIG00AFE`03001FEeIG00AFE`03001o
ogoo00Eoo`80009oo`80019oo`0087oo00<007ooOol01Goo00<007ooOol00Woo00<007MhMgP01WMh
00<007?iLoT00W?i0P000VNM0P002UmM00<004[n00001@000e;L00<005KKE]/025KK00<005;LD]`0
15;L3`0000Eoo`00001oo`0002Aoo`04001oogoo000;Iid00`00IieWW@04Iid20005Iid00`00<C@a
=009<C@20002Iid2000015IG000000001EIG00<005IGEUL02eIG00<002eg;GL01Beg00<005IGEUL0
15IG00<005IGEUL01EIG00<007ooOol01Woo00<007ooOol04goo000<Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01000Oomoo`0027Mh00<0
07?iLoT01G?i0P002emM1@001e;L00<005KKE]/02EKK1P0014[n0P002CKO0P0000=oo`00Ool00P00
8Woo0`002fNM00<006NMIid01fNM0P000fNM00<0034d<C@02c4d1@0025IG00<005IGEUL02eIG00<0
02eg;GL01Reg00<005IGEUL015IG00<005IGEUL015IG00<007ooOol01Woo00<007ooOol04goo000;
Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool20009Ool20009MgP00`00LoUcn@04
LoT200000fNM001OG@06Ged40002E]/00`00D]aBg007D]`00`00E]]Ff`06E]/200000emM001:oP07
B_h20009=]l300000goo001oo`0ROol3000:Iid20009Iid30003Iid00`00<C@a=00:<C@3000<EUL0
0`00EUMFE`0:EUL00`00;GL]M`06;GL00`00EUMFE`05EUL00`00EUMFE`03EUL00`00Oomoo`06Ool2
000DOol000]oo`03001oo`0000Moo`03001oo`0000Aoo`04001oogoo000;Ool00`00MgQgN006MgP0
0`00LoUcn@04LoT00`00IieWW@02Iid20002Ged50005E]/00`00D]aBg006D]`00`00E]]Ff`04E]/2
0004Ged00`00B_i:oP06B_h20003=]l50002C[`3000OOol01@00Oomoogoo00000Woo0P001fNM00<0
06NMIid026NM00D005IGEUMFE`00009WW@03000a=34d00La=0<00004<C@006=]000;EUL00`00EUMF
E`0;EUL00`00;GL]M`05;GL00`00EUMFE`05EUL00`00EUMFE`04EUL00`00Oomoo`07Ool00`00Oomo
o`0AOol000]oo`03001oo`0000Moo`03001oo`00009oo`8000=oo`8000Uoo`03001gN7Mh00IgN003
001cnG?i00=cn@8000MWW@800003Ged0000000MFf`03001Bg5;L00MBg004001FfeKKE]/20006Ged0
0`00B_i:oP06B_h50008C[`00`00Ool0000MOol00`00Ool00002Ool20003Ool30002Iid2000:Iid0
0`00EUMFE`02EUL01@00IieWWFNM00001S4d0P000c4d00@006=]Hfd000aFE`03001FEeIG00YFE`03
000]Mbeg00D]M`03001FEeIG00IFE`03001FEeIG00=FE`03001oogoo00Moo`03001oogoo015oo`00
2goo00<007oo00001goo00<007oo00000Woo00<007ooOol00Woo00<007ooOol01goo00<007MhMgP0
1WMh00<007?iLoT00g?i00<006NMIid016NM0`0000=WW@0000002UKK00<005;LD]`01U;L00@005KK
000000UOG@04001:oT[nB_h40002D]`20009C[`01000Ool0000077oo00<007oo00000Woo00<007oo
Ool01Goo0`002FNM0P001EIG00D006NMIieWW@0000<a=0<000Da=004001SKF=]000<EUL00`00EUMF
E`08EUL200000fNm00000006;GL00`00EUMFE`06EUL00`00EUMFE`0200000f?M001oo`07Ool2000B
Ool000aoo`03001oogoo00Moo`04001oogooOol30002Ool00`00Oomoo`06Ool00`00MgQgN006MgP0
0`00LoUcn@02LoT20004Iid30002Iid200000eZI001Ff`0:E]/00`00D]aBg003D]`4000<Ged30006
D]`2000:C[`00`00Ool00005Ool00`00Oomoo`0DOol00`00Ool00002Ool00`00Oomoo`08Ool20006
Iid00`00EUMFE`06EUL00`00IieWW@040007<C@01@00HfeSKF=]000035IG00<005IGEUL01eIG00<0
06NmIkd00fNm00<002eg;GL00beg00<005IGEUL01eIG0P0016?M0P0027oo00<007ooOol03goo000O
Ool00`00Oomoo`06Ool00`00MgQgN005MgP01000LoUcnG?i0`000VNM0`000fNM0P0015ZI00<005KK
E]/025KK1P0014[n00<005mMGed01emM0P0000=Ff`00D]`01e;L0P002Djl00@007ooOol000=oo`03
001oo`0001Eoo`03001oo`00009oo`03001oogoo00Yoo`80009WW@8000UFE`@000Xa=003001SKF=]
009SK@03001FEeIG00YFE`03001FEeIG00AFE`8000MW_@03000]Mbeg008]M`03001FEeIG00IFE`80
00MSg@03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Uoo`007Woo00<007ooOol01Woo0P00
1gMh00@007?i0000009K_P@000=WW@8000IJV@03001FfeKK00IFf`80009OG@03001:oT[n00I:oP80
00EOG@8000=Ff`03001Bg5;L00MBg003001>_4jl00Q>_004001oo`000002Ool00`00Ool0000FOol0
1000Oomoo`003goo0P002EIG0`000VNM00<0034d<C@01c4d00<006=]Hfd00f=]00<005IGEUL02UIG
00<005IGEUL00UIG0P0026Nm10000beg00<005IGEUL015IG00@006?MHmd000ASg@800003Hmd007oo
00Eoo`8000=oo`03001oo`0000Yoo`007Woo0P001Woo00<006^lJk`010000WMh0`0000AK_P000000
00AK_P<000UJV@03001FfeKK00=Ff`8000EOG@03001:oT[n00M:oP03001OGEmM008000IFf`03001B
g5;L00IBg08000U>_004001oogoo0003Ool00`00Oomoo`0HOol2000?Ool00`00EUMFE`04EUL30002
EUL200000fNM000a=008<C@00`00HfeSK@03Hfd00`00EUMFE`0:EUL01@00EUMFEeIG00002FNm00<0
06NmIkd00VNm00@002eg;GL000AFE`8000ASg@04001SgF?M0004Hmd20006Ool01P00Oomoo`00Ool0
00Yoo`0047oo00<007ooOol00Woo00<007ooOol01@0000=oo`00Ool017oo0P001f^l1P0015^n0`00
0UIi00<005ZIFYT025ZI00<005KKE]/00P001emM00<004[nB_h01T[n10002EKK00<005;LD]`01U;L
00<004jlC[`024jl00P007oo000007oo001oo`006Goo00<007ooOol03goo00<005IGEUL00`001UIG
00<006NM0000234d00<006=]Hfd01F=]00<005IGEUL02UIG0`0026Nm0P001FNm0P0000<]M`00EUL0
0UIG00<006?MHmd016?M0`001f?M00<007ooOol00goo00D007ooOomoo`0000]oo`003goo00<007oo
000027oo00D007ooOomoo`0000Aoo`03001[_6^l00M[_0<000AK_P<000EFN@03001JVEZI00UJV@80
00YOG@04001:oT[nB_h40003D]`00`00E]]Ff`07E]/00`00D]aBg003D]`B0002Ool00`00Oomoo`0H
Ool2000@Ool30009EUL00`00Iid00008<C@20006Hfd00`00EUMFE`0:EUL00`00IkeW_@06Ikd20006
Ikd00`00EUMFE`050006Hmd30006Hmd30005Ool2000017oo001oo`002Woo000?Ool00`00Ool00008
Ool01@00Oomoogoo00000goo00<006^lJk`01F^l0`000Woo1@002EIi00<005ZIFYT01eZI00<006Nm
00002UmM10001e;L00<005KKE]/025KK1@0014jl0P0024IJ00@007ooOol001Qoo`<0009oo`03001o
ogoo00aoo`@000]FE`04001WWFNM0006<C@200000fNM001SK@04Hfd00`00EUMFE`08EUL200000fNm
00000005Ikd00`00IkeW_@05Ikd00`00EUMFE`02EUL30006Hmd01@00HmeSgF?M000016?M00@005IG
EUMFE`D00005Ool007ooOol0000;Ool000moo`03001oo`0000Qoo`05001oogooOol00002Ool00`00
Jka[_004Jk`30008Ool00`00EWUFN@07EWT00`00FYUJV@05FYT20003Ikd20006Ged20002E]/00`00
D]aBg007D]`00`00E]]Ff`05E]/200000eZI001>_007C[`00`00AUY6FP07AUX00`00Ool0000HOol0
0`00Oomoo`02Ool00`00Oomoo`0:Ool20004Ool00`00EUMFE`09EUL00`00Iid00005<C@00`00Hfd0
0002Iid20004Hfd00`00EUMFE`06EUL00`00IkeW_@03Ikd200000fNm00000006Ikd20005EUL00`00
<ILaU`020002Hmd20005Hmd01000HmeSg@0015IG00<007ooOol00goo00<007ooOol037oo000?Ool0
0`00Ool00008Ool00`00Oomoo`040004Jk`300000f^l001oo`08Ool00`00EWUFN@08EWT00`00FYUJ
V@03FYT00`00IkeW_@05Ikd00`00GeeOG@030005E]/00`00D]aBg007D]`00`00E]]Ff`02E]/20003
FYT00`00C[a>_006C[`20008AUX01000Oomoo`0067oo00D007ooOomoo`0000Uoo`<000Ioo`03001F
EeIG00UFE`03001WW@0000Da=08000EWW@05001SKF=]Hfd00006EUL20008Ikd20006Ikd00`00EUMF
E`06EUL01000<ILaUc6G0P001f?M0`001EIG00<007ooOol00goo00<007ooOol037oo000@Ool00`00
Oomoo`06Ool20002Ool20003Jk`30002Jk`2000;Ool00`00EWUFN@08EWT01@00FYUJVEZI00002FNm
0P0025KK00<005;LD]`01e;L00<005KKE]/00P001UZI00<004jlC[`01Tjl0P001dIJ00@007ooOol0
01Qoo`04001oogoo0007Ool30009Ool00`00EUMFE`09EUL00`00Iid00004<C@20004Iid200001FNM
001SKF=]000015IG0P0026Nm0P000VNm0P000VNm0P002EIG00<0036G<IL00c6G0P001F?M0P001eIG
00<007ooOol00Woo00<007ooOol037oo000MOol50004Jk`00`00Oomoo`0;Ool00`00EWUFN@08EWT0
1000FYT0000026Nm0P0000=JV@00E]/025KK00<005;LD]`00e;L1P002EZI00<004jlC[`01Djl00<0
04IJ00001dIJ00<007oo00005goo00@007oo001oo`8000=oo`<000aoo`03001FEeIG00YFE`8000@a
=08000=WW@03001WWFNM009WW@<000=FE`03001W_FNm00IW_@8000IW_@8000]FE`03000aUc6G00Da
U`800003Hmd00000009FE`03001FEeIG00AFE`03001oogoo00=oo`03001oogoo00]oo`007Goo0P00
0Woo1@003goo00<005IiEWT01eIi0`001fNm0P000eZI00<005KKE]/025KK1@0014jl00<005ZIFYT0
25ZI00<004jlC[`01Tjl0P001dIJ00<007oo000067oo00D007ooOol007oo00<0011oo`03001FEeIG
00UFE`8000<a=080009WW@8000MWW@@000QW_@03001W_FNm00EW_@<000aFE`03000aUc6G00HaU`03
001FEeIG00=FE`03001FEeIG00=FE`03001oogoo00=oo`03001oogoo00]oo`007Woo00<007ooOol0
57oo00<005IiEWT01EIi0P000eON0P000fNm0P001UZI00<005KKE]/01EKK0P0000=JV@00C[`01djl
00<005ZIFYT025ZI1@000djl00<004IJ00001TIJ00<007oo00006goo0P004goo00<005IGEUL01eIG
10000c4d00@006NM000000QWW@04001FE`000007Ikd20007Ikd01@00EUMFEeIG00002eIG00<0036G
<IL01S6G00<005IGEUL00eIG00<005IGEUL015IG00<007ooOol00Woo00<007ooOol02goo000OOol2
000EOol00`00EWUFN@02EWT20007Emh30009FYT00`00E]]Ff`02E]/20004FYT00`00C[a>_005C[`0
0`00FYUJV@07FYT00`00Oomoo`03Ool500000dIJ0016FP05AUX2000LOol00`00Oomoo`0AOol00`00
EUMFE`06EUL01@00IieWWFNM00000S4d0`002FNM00<005IGEUL00UIG0`000VNm0P001fNm0P0015IG
00<005IGEUL02UIG00<0036G<IL01S6G00<005IGEUL00eIG00<005IGEUL00eIG00<007ooOol00Woo
00<007ooOol02goo000QOol00`00Oomoo`0BOol00`00EWUFN@020007Emh200000eIi001JV@09FYT0
0`00E]]Ff`020006FYT00`00C[a>_006C[`00`00FYUJV@04FYT2000;Ool20006AUX2000MOol2000B
Ool00`00EUMFE`04EUL00`00IieWW@02Iid20000134d000006NM0P001FNM0P001eIG10001fNm00<0
05IGEUL015IG00<005IGEUL02UIG00<0036G<IL01S6G00<005IGEUL015IG00<005IGEUL00eIG00D0
07ooOomoo`0000eoo`008Woo00<007ooOol04Woo0`001EON0`0015Ii00<005ZIFYT025ZI0P002EZI
00<004jlC[`01Djl00<005ZIFYT00eZI00<007ooOol03Goo0P001DIJ00<007ooOol07Goo00<007oo
Ool03goo00<005IGEUL00UIG0P001FNM100016NM0P000VNM00<005IGEUL01eIG00@002eg;GL]M`<0
009W_@8000QFE`03001FEeIG00UFE`03000aUc6G00HaU`03001FEeIG00AFE`03001FEeIG00=FE`05
001oogooOol0000=Ool002=oo`8001Eoo`D000MFN@03001JVEZI00MJV@03001JE`0000YJV@03001>
_4jl00E>_005001JVEZIFYT0000AOol30003AUX2000OOol00`00Oomoo`0>Ool01@00EUMFEeIG0000
26NM0P001fNM0P002UIG00<002eg;GL012eg0P002UIG00<005IGEUL02UIG00<0036G<IL01C6G00<0
05IGEUL01EIG00<005IGEUL00UIG00D007ooOomoo`0000eoo`009Goo00<007ooOol05Goo00<005Ii
EWT01eIi00<005ZIFYT015ZI0P000UYG00<005ZIFYT02EZI10000djl00@005ZI000001=oo`05001o
o`000016FP02000POol00`00Oomoo`0>Ool30008Iid20007Iid3000:EUL00`00;GL]M`05;GL00`00
EUMFE`09EUL00`00EUMFE`09EUL00`00<ILaU`06<IL00`00EUMFE`05EUL00`00EUMFE`02EUL01000
Oomoo`003Goo000VOol00`00Oomoo`0EOol00`00EWUFN@06EWT00`00FYUJV@03FYT00`00FUMJE`03
FUL00`00FYUJV@07FYT00`00Oomoo`02Ool5000EOol01000Oomoogoo0`008Goo0P003Woo0P001fNM
0P0026NM00D005IGEUMFE`0000YFE`03000]Mbeg00D]M`03001FEeIG00QFE`03001FEeIG00UFE`03
000aUc6G00HaU`03001FEeIG00IFE`05001FEeIGEUL00002Ool00`00Oomoo`0;Ool002Moo`03001o
ogoo01Aoo`03001FNEIi00MFN@05001JVEZIFYT00006FUL00`00FYUJV@05FYT2000POol00`00Oomo
o`02Ool00`00Oomoo`0QOol00`00Oomoo`0=Ool40002Iid00`00IieWW@06Iid20004EUL00`00EUMF
E`08EUL00`00;GL]M`05;GL00`00EUMFE`08EUL00`00EUMFE`0:EUL00`00<ILaU`05<IL00`00EUMF
E`06EUL01@00EUMFEeIG00000goo00<007ooOol02Woo000XOol2000EOol00`00EWUFN@06EWT01000
FYT0000025YG00<005ZIFYT00eZI00<007ooOol08Goo00D007ooOomoo`0002Aoo`03001oogoo011o
o`<000MWW@03001FEeIG00AFE`03001FEeIG00QFE`03000]Mbeg00D]M`03001FEeIG00UFE`03001F
EeIG00UFE`03000aUc6G00HaU`03001FEeIG00IFE`05001FEeIGEUL00002Ool00`00Oomoo`0:Ool0
02Yoo`03001oogoo019oo`03001FNEIi00IFN@8000]JE`05001JVEZIFYT0000UOol01000Oomoo`00
9Goo00<007ooOol04Woo0`000VNM0P0025IG00<005IGEUL025IG00<002eg;GL01Beg00<005IGEUL0
25IG00<005IGEUL01eIG0P0000=Sg@0000001S6G00<005IGEUL01eIG00@005IGEUL0009oo`03001o
ogoo00Yoo`00:goo00<007ooOol04Woo00<005IiEWT00eIi0P0000=B=P00FUL02UYG00@005ZI0000
02Ioo`04001oogoo000VOol2000EOol2000:EUL00`00EUMFE`08EUL00`00;GL]M`05;GL00`00EUMF
E`08EUL00`00EUMFE`05EUL20004Hmd20005<IL00`00EUMFE`07EUL3000016?M0000000037oo000/
Ool2000BOol00`00EWUFN@030004DSH00`00FUMJE`09FUL00`00Oomoo`0WOol00`00Ool0000XOol0
0`00Oomoo`0COol00`00EUMFE`08EUL00`00EUMFE`08EUL00`00;GL]M`05;GL00`00EUMFE`09EUL0
0`00EUMFE`03EUL00`00HmeSg@03Hmd01000Oomoo`001C6G00<005IGEUL01UIG0P0016?M00<007oo
Ool02Woo000^Ool00`00Oomoo`0@Ool20007DSH00`00FUMJE`08FUL00`00Oomoo`0YOol00`00Ool0
000XOol00`00Oomoo`0COol00`00EUMFE`08EUL00`00EUMFE`08EUL00`00;GL]M`04;GL00`00EUMF
E`09EUL01000EUMFEeIG0P001F?M00<007ooOol00Woo0P000c6G00<005IGEUL015IG0P000V?M00<0
06?M00000P0037oo000_Ool00`00Oomoo`0?Ool00`00DSIB=P07DSH00`00FUMJE`06FUL00`00Oomo
o`0[Ool2000YOol00`00Oomoo`0BOol00`00EUMFE`08EUL00`00EUMFE`08EUL00`00;GL]M`05;GL0
0`00EUMFE`09EUL30005Hmd20007Ool01000<ILaU`0015IG0P0016?M0P000Woo00<007ooOol02Woo
000`Ool00`00Oomoo`0?Ool00`00DSIB=P06DSH00`00FUMJE`06FUL00`00Oomoo`0[Ool2000ZOol2
000BOol00`00EUMFE`08EUL00`00EUMFE`06EUL200000fNm00000005;GL00`00EUMFE`09EUL00`00
HmeSg@04Hmd00`00Oomoo`08Ool00`00<IL00003EUL00`00HmeSg@03Hmd00`00Ool00002Ool00`00
Oomoo`0:Ool0035oo`8000moo`03001B=U8f00IB=P03001JEeYG00EJE`03001oogoo02aoo`8002ao
o`03001oogoo011oo`03001FEeIG00QFE`03001FEeIG00AFE`03001W_FNm00=W_@03000]Mbeg008]
M`03001FEeIG00MFE`800003Hmd00000009Sg@8000aoo`D000ASg@8000=oo`04001oogoo000;Ool0
03=oo`03001oogoo00aoo`03001B=U8f00MB=P03001JEeYG00=JE`03001oogoo02Uoo`@002moo`03
001oogoo00moo`03001FEeIG00QFE`03001FEeIG009FE`8000EW_@03001oo`0000@]M`03001FEeIG
00AFE`8000ESg@80011oo`8000=Sg@8000Ioo`03001oo`0000]oo`00=7oo00<007ooOol037oo00<0
058fDSH01U8f00<005YGFUL00UYG00<007ooOol09Woo1000=7oo00<007ooOol03Woo00<005IGEUL0
25IG00D005IGEUMFE`0000EW_@8000=oo`80008]M`03001FEeIG00=FE`03001SgF?M00ASg@8001=o
o`<000Uoo`8000]oo`00=Goo00<007ooOol02goo00<0058fDSH01e8f00@005YGFUL002Eoo`@003Uo
o`03001oogoo00ioo`03001FEeIG00QFE`<000EW_@03001oogoo00Eoo`03000]M`0000=FE`8000IS
g@03001oogoo01moo`8000]oo`00=Woo0P002goo00<0058fDSH01e8f00@005YGFUL0025oo`@003io
o`8000ioo`03001FEeIG00QFE`<000=W_@8000Uoo`D000ISg@80029oo`8000]oo`00>7oo00<007oo
Ool02Goo00<0058fDSH01e8f0P007goo0`00A7oo00<007ooOol02goo00<005IGEUL01UIG0P000fNm
0`003Goo0P001V?M00<007ooOol07Woo10003Goo000iOol00`00Oomoo`08Ool00`00DSIB=P07DSH0
0`00Oomoo`0JOol40018Ool00`00Oomoo`0;Ool00`00EUMFE`04EUL00`00IkeW_@03Ikd2000@Ool2
0002Hmd2000MOol4000AOol003Yoo`8000Uoo`03001B=U8f00AB=P8001Uoo`@004eoo`03001oogoo
00Yoo`03001FEeIG009FE`8000EW_@03001oogoo019oo`8001]oo`@001Eoo`00?7oo00<007ooOol0
1Woo00<0058fDSH00e8f00<007ooOol05Goo1000DWoo0P002Woo00D005IGEUMFE`0000EW_@8002io
o`@001Uoo`00?Goo00<007ooOol01Goo00@0058fDSIB=P8001Aoo`@005Qoo`03001oogoo00Qoo`<0
00EW_@03001oogoo02Yoo`@001eoo`00?Woo00<007ooOol01Goo0`004Woo1000GGoo00<007ooOol0
1goo0`000fNm0P00:Woo0`008Goo000oOol20005Ool00`00Oomoo`0?Ool3001ROol00`00Oomoo`09
Ool3000XOol4000TOol0045oo`03001oogoo009oo`03001oogoo00]oo`@006Ioo`8000]oo`03001o
ogoo029oo`@002Qoo`00@Woo00D007ooOomoo`0000Uoo`@006aoo`03001oogoo00Qoo`03001oogoo
01ioo`@002aoo`00@goo0P0000=oo`00Ool017oo1000LGoo00<007ooOol01goo00<007ooOol06Woo
1000<7oo0015Ool200000goo00000002001fOol00`00Oomoo`06Ool00`00Oomoo`0FOol4000dOol0
04Ioo`8007]oo`8000Ioo`03001oogoo01=oo`<003Qoo`00aGoo00<007ooOol00goo00<007ooOol0
3goo1000>goo0036Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool4000oOol00<Moo`05001oogooOol0
0009Ool40013Ool00<Qoo`800003Ool007oo00Aoo`@004Moo`00bWoo0P0000=oo`0000000P00Bgoo
003;Ool2001?Ool00?mooaeoo`00ogoo7Goo003oOolMOol00?mooaeoo`00ogoo7Goo0000\
\>"],
  ImageRangeCache->{{{0, 283.625}, {229.75, 0}} -> {-0.0514254, -0.0405654, 
  0.0074142, 0.0074142}, {{6.9375, 135.375}, {224.25, 
  120.063}} -> {-0.283423, -0.139109, 0.00942056, 0.00942056}, {{148.188, 
  276.688}, {224.25, 120.063}} -> {-1.7558, -0.171484, 0.00994194, 
  0.00994194}, {{6.9375, 135.375}, {109.625, 
  5.4375}} -> {-0.278365, -1.21203, 0.00938146, 0.00938146}, {{148.188, 
  276.688}, {109.625, 5.4375}} -> {-1.30472, -1.01659, 0.00827554, 
  0.00827554}}]
}, Open  ]],

Cell["\<\
In the second example we compute the 2D DFT of one of the example images and \
display the magnitude and phase responses of the image.\
\>", "Text"],

Cell[BoxData[
    \(A = 
      ReadImage["\<head.tif\>", "\<TIFF\>", ImageOutput -> RawImageData] // 
        Reverse\ ; \n\[ScriptCapitalA] = DFT[A]; \)], "Input",
  CellLabel->"In[7]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \((\ ListDensityPlot[#, Mesh -> False, FrameTicks -> None, 
                DisplayFunction \[Rule] Identity]\ &\ )\)\ /@
          \ {A, Abs[\[ScriptCapitalA]], Arg[\[ScriptCapitalA]]}]]; \)\)], 
  "Input",
  CellLabel->"In[8]:="],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .3125 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.31746 0.00744048 0.31746 [

[ 0 0 0 0 ]

[ 1 .3125 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .3125 L

0 .3125 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00744048 0.321429 0.30506 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.00751202 0.0192308 0.00751202 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

128 string

128 128 8 [128 0 0 128 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

020201000501010300050302040302050503030202040500

010100030002050105020304050203050502020502040300

010301030301050104050100050105020303030000050005

020000010404030503020402010200050206030300000302

050201010304020301030302050200040300020103050302

0004030105030202

020202050500010304030304040302040005030004030105

000400020105010305050201020303040400040303030303

050204000505020300030502030603040503050204040503

030201020302070302020201000303020302040103040102

030404020300060802060305020400030302000503060403

0303030401030303

030001010005030100030300020204020103060001040303

020405040203040302000403020105030002000303030301

030305030503030804000503010203050504020100000202

010002020003030101050200030104030203000100050102

020202060302030504050202050001050002050203000505

0204030404000301

030303010602010002040305020302000005000405050501

020301030304020105010302020405050302030202000501

020303000101060303040100030104010402040201050002

050002030101040300000601080401040301020501000101

020103000005020003020001050104030000030104030605

0901060303030101

050403000205020101050001040305030502050302050504

000103050405020505000004050603000203000308040304

010303040002050003030005050202000202000503040305

000104040601030203010003050107050104040201020303

020103010401030204020401020400000301010505020007

0500010304030001

040509040401020504040301050104030202030203040501

010603020003020005030506000102030500010200020505

010502020101010003050103000201030100020301000305

030203040305000303030500030303050200000300020400

050300030303010100010103010500020402050505000402

0503000301000301

030302050105050405020204020105000304000002000404

000201020205000302040501020405000203020203000000

030402010002050500020400050205010503040400010503

050101040301030202000401010301050505050002050303

040101050305010201030200000200030203020302000003

0405050701000305

010003000103070202040103040301010206000403010100

010104050401060507010401030602000004010402060406

000105010402010100050004030202020402000000030302

040002030405020303050304040101020505040100030502

030003030403030502020400040501060202030502050405

0200040303000102

030302040503060101020305030001000400030203030305

020002030204030502010002050204030205020104060503

030302030303030606020301030103020503050100030404

040001030402040505000504030302030403030305000406

050101020100010000030105040104000202000605020201

0404020401030205

030102030503020500030302030500050502000203050502

030202040302050105020503050203000400000300010400

010402040102020003040004030402040505030002030000

010307010205030500000303040100030002010405030302

040205040202020104030502050205030300020100050302

0205040201050305

050400040002000106030105000003030202000500040202

050303050404030200000303020307010005020204000403

040302050403040405010102020500020301020202030504

050405000104020005030003020304070205020503020403

030007030703030402030504040200040304030203030004

0300000105010203

020404050500030305030103000303030501040704040203

010403000205030101050500010309010303050402030002

030000010300010603010405020500070002020003010403

000A04000404000201010203030205030503000200020102

000209020202050405030502010102000002000300030503

0305000301030401

030503070105020305030203000403000400010204000501

030302020300030002050200050203030204030203020201

020603040002020103040401060305020300010205050003

030500020205010500020105030001030005050007000203

080000050105000001000304010301020100030402020202

0304030104000202

020503000401050303020201050303030400050404010004

040204050501000204010403060201010003020504020302

040006050505010302000403030002030000040404010203

010202030103010304010001050503050303020302020401

030300050100030000040704000501050506020000010302

0005030102070000

000200030505020103010103050300030305020503020302

020301040501010003030202020004030505010301020003

030302050203070102050005010503050004010101020404

020203050101020504040002010500020502030200030103

030300050004030501030203020202040203050305010401

0402030200010704

010204020506000300020202000505000502000104020004

000102050402010503040303020102040505000203020402

000300010200050403000300000302000103050501060103

010500000303000404010201030000020001020301040200

050206050303040504040303020003040402030205030105

0205030001030301

010106030605000200010304010205000303040304040003

030103000504020203020505030002050104060201040603

030304000105050205000403030701010101030101010102

050303030303050308080400040300000305020401020101

010605030505030201010507070503000501030103020103

0501030103010405

030300020301030305020001050101030003000003010508

050404040405040303000203030203050400010203010502

030404040103030304000302040003050301000202010300

030101060604030104030002000501010300030200010504

030102040101050308010203000304000105030001040404

0101030005030505

050104030400020204050005040503010304030502010502

020200010301000300070100060503020304010306000002

020305040204040201030506000300050501030305030603

050003000100020503050201030300020105020202010203

010501040203030403050403030500030300050301010306

0100000207030205

060404020B06050905051105060701050513146958363748

1C192B0E18304253565E535E55504E3D47433A363724483F

4859441E10046C364C73697279311B292F596056625A270F

191C2B292D49454234513229352531371E24242C2B162D04

0B03070905040D03050505090501030407010B0502041304

0503030909080603

010B06070B01050C0607040B040B0C090705326F4B3D3C1B

0D0610113C3F554E68535E535353483D5345323D37253252

2A667F5E260C3C42291B1F1B1B161238375161525C523713

112B2E37444F42423C3C46151C1D2D3F2E35172533232714

020408000A0401050305070608030000050B060603060A0A

0304070506050903

01060C05020E0F0B03010909080F0E0B0B13596242513209

12281802051F474D635B59594F442F2A374C3C3D322F1132

4F4A6931210624581B21101D1016232235426966594C480B

1C38453A3944544D2E3D4C1E2D0B36383D21322F27402830

0B04090004050B07050305040303060A0D0C0503000E0605

0B07050707080505

040906020517050C0D09080303040B050A125F38515C4411

1F271901060B195B6955545B4D41373D4048403D21292028

5E5A5A7F1F0B1054291B16141E172823312A696C5C605825

2C2B23323F533C3736424C232C102C3241261B302F451735

070A0E05000712050405050409020B090205030D0C07020A

0700050204060308

0003050704100D0A0F040B0105090B0209136653645E4F1C

11310707111215446563605E554D4F42363D39370F162438

4067672B2525051C4F1019221921281B3231646C5B646459

413F423D292524262C22224222151E3B4244281D4242422D

3211120505060B0E0505050305030504080B07050F05020C

08000B0403020208

0304030E05050D050B070B0A050F0F060D105063576B5944

2A21210709130B646B6F4E5F584D4F39212F383F17222A2A

4D64412107111B146611141D1B1C131B3727487364595F44

6242524E372420120B031D301525212F484823263D334519

3110060A0203070B03050B07030B070A04020B070C050707

0A050602060D0307

0B03090B08050405050B0303090E070D0E0554715F646557

1B2D29050B04054C36394148524D5446292E4130382D2D12

42644D1B0A05210D481D120B0B1018091626367C7C667142

595F0D211B221E211B141D481D3D362937483926323D5F38

2C23060403030B0B0807040C050307030C0B050E05060508

0505020409030709

0907090D0F050A07010B0A0C0C1205020B05366F56616E4E

2139282C170C3F3330313B4547575348383130533C21231B

566F67161C130B136F210B0E1F130C0A202D3C696F6B7253

470E1C1D1816262A212B1F42303A32194A5355393A495A45

123C1411010207110B0C09050D070803070707060603060A

0F1001020A030402

05040A080F0A0A030B09061004090B0305071086676F6C56

143C3D383A2175424F504A4E666D6C68543A2E4139283334

675E595B1106190A5E475F83828A6D64712E2C3E6F7A6F64

3A130C0C1828312C1C252F422C1B41254646443320475066

4937220B000607000911060B0C08080C10050B0D05030900

0C100A0909050907

070204100D0B0F0A0C050B090B080C0E0B0B064D61596464

1B32133D0E5B61536F534D607373797953402B3B53373746

6669764E1D060B14551E48877B6C6D0D23252A267C7B6868

4256121312261E2E351C4E43453D3848294641432F3D4762

5621430F0B0A0E05030308080304060B0604121005080301

1004090A01050807

08000B0B0B0D0D0906050D09110B040F0C0804265E39765B

101E1321168D72616159535566726F6949341B42603C4444

71719390210F050C23311113210B1B1D1C331E217777686F

6F38462C1B102C363A41421B4C53264F4437473D37365566

584936330301080706050B090A030108060D0F0700060F15

0704100505050205

090B0D010E0F070005120B020B0C010609061429594A7771

1F1D0C0E5DAC745B585664596F72755E39312653523F3238

6763857610100B15182B201B0E1022150545262C5A7B6F73

7C2547421E251F2A322F412F3F4A373D4F132040563A5C52

5B5F1B370D02070A0E0907070310060209090A0B060F0511

090C0E0409010605

0505100501060A07020F05050611070B0F091C2368316F69

0317070D9E9F5E66645E6E66686D5D5D583F3D534A464144

615F68450A0D0C0525361B1C151F202C29302128327B7A7D

7841546B20112137262D212F423D4D4A50282B564B44365A

5C6F4E3F340B0907010A08040A0109010A090A060B12020B

04060D0308020502

090A0B0511090F050C0F0C0A101212224C376949918B786F

08100667B0856E575C7961745C6A59514E5653534F59424D

5A6D644C110A101D2263481B16070B28241F2B23267D7F6E

817330486041522A211B1B3D3E30535441482D39523F4847

6B6E691B650E05090C0E0F0B080F0B15060B07021607020D

0F0D0C0707010B0F

01111207050B07090B000703011805264F4D54364DAF702E

11041B909A8768657C6668686B6761604D46735342534940

5D714D1B01160B14103C2305381E2638232239212A4A8874

7D822C307C322938453B434D583C4C3D4E4B2B37594B604C

6A59595345201004070B0E0B020F050407100A0609020501

060D0A0B0703080A

02050F020B09090D070C030B060414586C6B675C7FB29027

051B3E88837D55686B67676E6E60725D4D5A635E544F566A

565F3D71232523180B1028452C36313434362C2E2D3D788D

7A8843425464727E7368646A6B444559475B3F3F56595054

635B6279285B0507080304070A0A0505010D0707020B0202

0910050B09060C03

050401070D040B02080B0E0B0B0B0C5C7579908C8A7C7436

0C177962495C6460756F76646C78586F63767180726C4D4D

6C514D8E3C31330A2652631D1B2108082A14344239217C74

6D7F6C2F3450683D5D765E3649465B595E67211E43455153

57543E7A5D4219030B04060304121406110504050D0F1505

07080D0508060F07

0F03060C060906080C100D060C0E084241756C6F9C625919

375182535C7289907C736A4D676450715E71856F6944496F

706E5379627552271E256C321E3117252B241E2523344E83

777A852A2F42091B0A242436373D567A4043523D413D5A4D

4B1E53AC892E51050801040A0B050B030908050A070C0E11

0F0E0F0B0C030406

080A06091007050A07100707030808190F748AA3220E4520

3A56744587837D756E6977697B73795F69717A6353426A8E

6D60537A7F857A392226413B2C22131B1B16133D28353385

84766D4339671B3332234F6F3C426D6251596F5E3C484F62

51426EB097534827160C050B10130505050B0A0D0D0A0A10

071002030B081007

1809070D03130D090C060E140B0D071F0A42754730330F6F

6E6C7466849B8D948C70787A7A5E5D696F727F7A5A467A85

6E66718C7F96AA69221C32253C2A251C3F1B062E34282984

8E696C7A393F6F103D1E2E372A3755556C545A602C293242

5354438088802C5610120E0D0C050F050B0809060F111007

030B0B0410160A02

0F0B110A10021308090809170D10123066227B7D43173057

86725C9084A7A4817A7A6B6E7A5E72746A6C736B655D876B

6D5C808D808B967D1521860D5D46101C22100A2E3830225E

83877A852437427F32496C362C5849422C65617384372B45

4D59514872904F30470605090A02070901050B080F07130B

050F070A0F090305

0D07030E07080B0B03050C0F090510694F688F6745293305

5CA5747F8C8589736C7565778D796D67695B6C5B736D6F5E

65566C7F8C779B902612700C4D412011202C082A142A2429

8B8F82804A3F3262822758435F6A37482C6F7A7974843B44

405658435388962D532C130A0A040A090406140610080F0A

0315040B0E051002

0D0A0400000208070B05010B030C66A56F7A6D816C162D0F

25596A8274767B69647E877579777663625E60636D81727A

587C766F907A904E14132B0B5E3D161819192A140E3F2720

958A8B986931333B4D5F392F5B6746754C584C4671645F3B

54485D4D4D5383702645220D0F050D09050C0B100A110D03

1108030A0C0B0C07

0C0B0C0B05031008050D090D0B1C636F755F5985573D2D27

0A184D6B7E6A7C857172807A66837F828265585E72787469

69778C85A6968A3A1F2A7B192E0B83161B210223141D2221

9885878E8B293D3F2E3D6E34422E555753493B4948915259

414E435A594A4E995927522B0606070B0A04030D0C120B08

0B01040B0A140B10

0E100A07050607110A0905031206594E5E68698D64692521

0F0A163E81937E6E898E6F8177707A7873715E6B7F6D6F55

7896699B8B9690171B17753C160F596922212F341B1C2E32

808B8A9383323332391B5D6D3752643D213E53382C673B6F

6F3D484D5450486B9553285C16160A070F0B0507050B0A0B

10110F080101100B

09070B01060F0F0C0B0C040A1003455D62616A78746F3719

08162A062779A58094A19A7A776C7B716F67697A887A606D

96678E9E8592501C100D531D260B2C7A13453230051D3026

778A898D864D3E37333242557F46090B0B16123A41293B53

546756595451483B8E8B4E3A551B0D060602010504061003

10160C070D0A0C05

0B0D07060F060D07120E0605090B237C6B6760728B585720

0B0B501B174271917A8E888D83727D74766664726F5E6773

717F9D88814E1B020B0D06520E16063E570B10091F183633

7D99879386833A2F2636412F256F1921181F2F1B1D0B1808

355D745953694E4B79B0923B4A360807000C0503080B0C09

121B03070E0B0102

0E0C10090A0C150313160B020B0D1C987267697A8D6C704B

12224E2C1B034B7194857470846F7A80857D6D765B64766A

7A969B9CAB260F100716396F212616302F1519293F222C32

7096868D839F322E2223272D302836321B2A1E2A26161123

0F1D193D6661697462583D69395203090603080507030F0B

1B16060708050307

12060A10050C1110141001040F04269C6962645D90897B59

1B305817172405404F5C778C696969906F7455515F8B726A

9489A1C05A0E0E132A142F714237463966104B2B23262230

5789988A86954135303521211D2E3B2853420B143A1C3C2A

35301B080E3D6859543E217244502803060105070C0E0D0C

140B10050B090B10

1B05070416050D0A100C070B0B0C30866B53676E918D8068

263C5F200B4139122831545C69748770666F617C9F6E5A98

8CB6D064210D10041B122E756F2626233A603B592C2B2D3D

4C918588828983372A21272C2B23373736584B5828251B05

17081F1F130C0B08181C0F727F4350080606010301060D0C

05060E050B0D0305

070D0906100D070D0A060D0A05062A485244526195858A6E

422C51210B5841061F1E242C36698D83755064536F4E8494

AAB74207130F010F050F206E714730294D7F3265162E2A10

5A8C85868680952E2D2C3C3A3D3130383B3D374227271623

362B22101D1621152F0B066185516411060B080505030B11

0A04100804120407

070A0F02101005050A0115000E051F2F162C40194E865D7A

7A0F30341D2B0B17371B0B09141C3D51B69D7E74928AA3B1

481B1C1B021B0D0B0C0E078C695A2102327F263932332C43

968E8F978D82713225384A44382F1B3366675D543B2D320F

2D463D15302F331604120D12885D6621140C0510050C0E0A

1408100B190D040B

0B070207040A0C010A0406060C2F335E582C1B498870402E

6832642E2C09292D0C0F171B1916031C2E181B3C39203B15

0512080B0106171E060E176A5B5B3A5C787E22143C2E5D3D

92838B8D87804E222738473C3C81757F8C6F75716934332C

3D2142414F2613211C18041B7C64523F07070C040200050B

0F03020102050303

050C040203080A0D070F0504110F251C180E1033401E451F

431E2C5E3A303A1F32233E1F242105151B19373221140931

181B120D100D0A050E0C122F6F444239822D171E2A56594D

99858388817B352623455B5974787B768A7D7B64876B4348

475930484E64490B231411197A873F580C030A0905050B05

0E060D0D09070802

0B040A070B0E0E435E551810051E290517212B2821170B25

2B342516443E6969695659656F6A59533D3C14314D5B2D24

320B062302120B070A081D4F6356484F221B00223D302D58

A8858B887F853D292D5058776E739181747E82697A715C46

375552543D755E2516300500769336564011020B020B0B0B

070D07010A060605

030B110310062F5B403F2A0E291301070F0A131D0B0F192B

2A1B0D467432485B554B4950503134473C4521204F3F3C28

372F141F0008051116140A4F595448341643183C302C3D63

8E93808B837A4D36154A64717F718F8A798583826F746E47

3D37596F7957414B242A1F0737A6565D6B1709040608090B

0A0B100B0A020C0D

0B060E0C0B05394616090E110A0F1353381B231F18052234

4DFFA5463D7B4E481D3745414A2C47444356523F40384830

32100F0A08090C080D0B06216E3B390B281928352D31375D

93877A82887F5C293C3B6E807D888B7F6A7D86776C76676F

6B3658644E46625E372A3411088F973E5243090205070807

0307100605070104

0B02050B03093853595A1F08081B221B21461B190C2D7B8A

90656548162308330B444037444C3056525459603F3C4D42

291B130E0F0E061F0E1124437251091B33432E1436353058

8B8084888E89772A3D54757F7A87858071867F8D70737A83

6F53355E5354793D191633260D09A08540592609070F1406

0405010710030605

041008050B050E54534E49192D180E2419424E412A759088

A1957A603E6481641810265043787C80695E454B29212724

2C1724162C4237424B3A442D4E161C325A3126362D38526A

89858E8B868D902721457A646E7B857A7A857C72846D6F83

765E2E42414C56511D182C301C080DB2682B540D01090604

0501040A07030B05

090F07040A050828415D4545313530415E674A34219EA890

B2A0B1A9B6715E3F12001B2D2C594A6E682642544249461C

2D1F25264F805A44345654282A212C2C243736313D778F8B

7B6F94958C80902A303F6E7B7A757F7584798A7A73897E7F

887E644E445D554C1035350D32160606A15E436F12050308

0805070707010601

02060B091608081118375A3F1D3F211C253D494F296AAC9C

B7AC9D8A835E241B220D171E2F37571631533154745E6965

351004172F3316122839052E22162C4B201F323144A67F82

848D888289898E293231575A7D76908E886B7F866B7C7F76

6F835A2C453F4C5F616C471B251B220B1D8F4B5A2D0A0904

0309050505000A0A

070C090410100C0C0C142A33271F092143614D4042408B79

74747A625A2D1E2C2D1B25814F513741371647284F5A521E

1739152A3D2006050D1408350B402C344E231B22AC96858E

8B8692868E94902B1C333027397F9A82728A877987687E5E

757F644C533C428083747B7F76483114077465445D090603

0409090C0B020506

0F000B0504080E080309212F28262B52594C48424F696457

4C485672646F4E343F648070346F1E0B444E776F4B3D7161

5D2317161200090A0C0F1F12292D3130422E2E4E8F8A8993

8F8B908B878F8A321D21172B7F838C7D887B5E6F748F7F74

63853D3E264B848D8769799896822B2B100DA05463310E0E

0B15060A0A030111

050A0703060C05040C01112B373E4D435A6446535E606E5A

524F5E687A5A395B6E5E2E3D4B5B3244163D644219082A3D

210F1B09050E05060F1712180D21260539332990818F938F

8E94929090878D4726252D8B9677819E7F648B7E42897285

83431B494D708592A18F748F9E69643A1919298154590D0A

0B13090E030A0408

07030103010D06060B0706152E574F645B3D325B4C1C652E

2C0A233B5569622F48677C73762D4D1F42461124223A3F4F

220E1019100C0608070E1305132A1B0C2E371E8982988B89

8A8E8A8C838A8C4423328B6B7D85818292757D84854B6785

8458684C7A7D878B9D938694855E8D681B0E19A6595C1008

0406030301050905

050105020A0007050F0D08051B41462A484C0F4A5C1F3547

38425F33132148482D13266474695058321133130B306114

1B0A170A070306100D09020B071210123D25328A88938C8B

8B968C8B7F8E7D543137857F80698687949881656E7E5C8A

785F4A677A7D8194A290949B81618B86421B16647256280D

09110A0808020E03

05060B0E100504080C100C0F1520495B405E25211C393237

2B3339592C376026232A50597C7F867938452D3229471016

052B0F000606030B030503101E110E0E2923388E8B8F9691

909299968B968B673C645582755F7669828283818C7F4A85

5E5152708281889191768B905A74968D5E1F09137561450E

0D090B040E100508

070B0907050E0A0C030D150A0714174452434D1F26313838

29331C31655D4B104D4D6E4347391B230D2C312B0C470B29

1E19040F0607040402150C1B19140728351D5AA18F939193

959896A68F8B8B6F487A777C77567D698590688D61818B38

3D4975677F8E9080717A95857D858B8F731B170A875E3708

080403030F080B09

050500050806090B0B061604070912494F576B4D4D3C3C2E

5039322F547798522321045E0F0D2C203831346042364825

09050109060410061405102A211116543A274D9293929694

9E9A939790868777534E757F8153686D758E62786D845E3E

38686F76798B90846983965A83907E7E6220240A51515905

100D000C03060403

080907080A060D050A110B160D0D0D1B3D545E685E4D3622

2F39457E8053732B0C4312291B2C2E142A48232B3B352124

10050A040507092D415921151C3413583D3465989C968F96

98959BA08A85908558424D7572505C837A84815B82794E42

7A797B808B8988807A7F90567F8C9485791C29035B536A0B

0E0507050E0B0A03

0514020C0B0505090413160E100E170E22493F4F6E81482B

23444F777A2659642B112D1347263B0C2B3D45371B213209

080B0B0816041E2854385E629B267B55393E529692979991

96969880858D83825E492D47715E836B5D827F746C6C4D68

74726E7D8F8C8986598996608B947F9B971C21254D665F26

0705080502030705

000502081B030908110E000709111E0A050F43474D6C5D4B

37321F323A4E182C4B584E3732531B0A22426A231224302E

05100511250B1258AA655747550B5A473E3232999797A398

9C8D87878A8D96895D473E3637725F8553857C6E62645F79

76767A9285726F63789083507E89838E8B54242227665B2B

030107000E130F05

00050B0B10140B0A15100D0A1412100D0A101B4243324667

2E38402C2A092C30175E2C3522211E0629290B09161B0B28

0C0B1B081014616146455972322D5E2C272D3D92A5A19795

91868B88818B947D7A94433934598C7C598569635E6C5A71

6D74838B7464667B908D7B4C6985917D905F1B15285A5A32

0A0D03091004150C

081407100B060A1611100C0E0F1019080909041B29263330

391B2C4A211F1014243732170B1D2D0F1612120B1B121816

000B0503053E4128373643614773312331303A71475F8B85

848F848B8286888B88907C383E3981834F735948485A6778

7D888D908A7B7A8A80697A597B958683A15E1F10108F6329

070B0A030B050B0B

090C050E030508100701030C04080309030B0610260E0721

142E1739441E0B1313421C262119030421353216200E370A

080B1105060B092A2C35343B454031363B3B8584487A887C

8B99968A83858A7A959B4239473D27273259536F6570627E

7F8D878A8870787A7B7A7C809A888C79906A2A160C7F5627

0D060E0D06040905

05000608070B05050705020805090B050E04030A19071515

0B211D2D4543352F2612192C01181F262C1B121B0C29190D

1906060512344A59A6A99A755D56323C3D34352F4C646D85

95988B978C8F7A7095992B37442C2B4253687F878B99938B

8E7F7569656885787E9A93959C9F8C99A99A13210A7B6324

0C0F0B090B0A0203

0703030B090D060D0C0C0E0B090C051203070508150F1304

212E3B2D3B3C3F07211004103928110C111610161B0D102F

54639A44354C527369676D718793BC85534D3D6C86748799

A2A0A1A6988F6D8F9B732F2C303B1D265D6478717A89938F

855960475087895D6B878B7A948D99969D8D0F100968681B

0C08070A02080702

0508050505080C13040A1009160D050F070B0B0208111B21

23534315290E1B210F271F10121F162027263D2419237A8D

6374B2A88A857C89887E8444264B499B8B718B908E99969B

A39B949090827E9A84352A282728415669666A6764777B6F

7D888884818D8D53696C899685818B899476220B016B6311

0F0504060D080909

00080B03090804050705050004050507060B0B02092C5179

712C1E2D241948480A060D1C2F283211165DA09D55686A90

9090A6AB9D87857F908F743D464A457884858E77908C9498

9C9298968E8E785D472537363F35515D6F717C78817E849D

A38F7A90A08F7F8A7E7D8E8F7D918D857E2A16140F806310

0607080705090903

0D090D03090B040804070307050405020511060B06532F9E

5B271E161E101C2F353D39160D1B3C60918B728479695C69

7D7B74848B8C7B76848F7D6727497F837F88898B8E819C97

A19B8E85696F4B404D61465558497B7E808E8E70767B797C

7F626481A192999A9D868279777C83745913160E27857719

0D050C020B0B0306

05050100050B07090805050003030306060A0B0716407A70

2E2407231E14160F0B141C186D8996C39B968C715D797E7D

7B8380909286818876847F636F7F91927A8A8B91917B908F

80797678607649323F3696A59C697E87939696877E786971

717C69859A9696999E888374737A836251040F073F796E1B

0A0D070605080305

0304050406070405050102070202020505090B092E428471

0805040F15140511041943928E8DACAC9E907A8D8D8D8F90

867F7F8383888995827C727F8887889086928985837D9685

8B8D857F747B363D2CA290969D89819B888F9592857A757D

82836C738890829897756F736D776F4A3D101C103C74780B

0802090405040604

030405050003020200040104040303070302040757659333

050F1910100510172369AF90847984A0AD838B9F9D908384

7C777F838D9493968F7E787A7E7B86A0938E8B8E85858C7F

88847F7F7B793A3C4CA4949B9C96849285747F93938E8B9F

A1908064908B7A8790786269707170591C1C0C0A506A6F0F

090C0A0605020004

0301040907050504050305050903030603090506746F7C1B

0A0A050C00051037929EA08D958F9D958A82999E917A7275

7A888A8B8C90979B9B8B84867A84828A898E8C8B8A838B85

87848381836A4A373F9C9B969A9D899F80656D6D908C8896

A0A67F6C7C69647988795A6F768274770212011C5359540B

070E0B0809050602

0100040504010004040602050107080407080207736A6907

01030504050D164785BBC2B0AC9B969EA7A2967F7477758B

93898784959DA49B8C8B80654F4A4D6E80738F948C888B8D

818488848364483460879EA29C978B9B90796969766F6877

85A6937353766D777474706F74867C6E0E110B315C69340B

0507090805070800

0203050401020205030408030207050304010B0A67536C15

1506030907095D8593AEB7B7B7B59A9089807370747B8E91

827C8BA4A2A6A197858071554D3B393E4F5C6F8F84868B8A

8C858A81696366888C8EA3A7AA7F909D9696775666786D6D

6A8F88666F7D7669775B656873786F390F180B3B5C6A1D09

0A0D0B0800040302

0404000701050702030307020209010305010A052A675A37

090705050B09A38D9692A0A2A6897E606E6F6A697B949081

7B989B9AA9AEA38A6E565E5A5645382A32444A85877B8B8B

858385817D9875617190A9AC967F9598886F756F858F847A

6D8D907A7E79755066664254696A5A0F170D0F3E6F620D0F

0908070604030103

00080102010503030105070100050300000502000D74484B

0C0807060D0C72868996999B886B606A6A787F8A9B8E8076

859BA3B7BBAF855A3B53645C574B3D33322D386F6E85878D

88907F74744A464D7099AFAD8A919B98725C6F85857F9890

8C9296988F7C6956747A807C3D606D031B141B3C72630B06

0A0C010B09030205

00050305010306040301050405060307010704050D4A7F77

280605010A073C686A6A93978449677F8A96A6AB90817276

9C9EA6B3B3A15B21364A4D5354473E4131273243597B8884

8475736F5F423D669EA6B392809E9F9B746F7891696F9591

84807674685D727B929E908B71444710020B2A596D3D0D02

0905080801020404

04040503070205000103000401060602060404050A1B8444

6E170E090C034F7A8C9BAA976C59778C8A7470A389747593

9A9BA3AAB19457252C393C464742393C322A212F31304189

907E5424212E6D8CA6A98983969891887761728C6A718D90

7A74766F6E7B889A8B858B8472592909120B545671180505

0306070700040100

050505020304010109020704050505000203080205084BA1

552C1003030263889A9F9687696D8BA0775F74847E717F9A

9AA5AAA9B1A56E37282E2F373D3F3C352E2E29211D212B2A

1E2932332A6493ACA48582989B978D786A62798E6C72747B

6F6D74908CA1867354525D66483F1F042A2C3D816C0B0704

0206030505040103

05040104030202000507020105030305050502090B0C1B74

566E0C0C0718888C96969C985B70AC8A63687A8578849E97

A19DA1A8A5B4A88B622C252830373731302C262722202226

29353649738FA997757F9C9C9490876C5E607A9677635455

544B6F798CA0906C65613C42350F0E03175948674D0E0A05

030705050A010302

050205030404030700040503050303040601030102050A62

9C2F17070C12858DABA9A3996B85A17D306D85898899A299

999C96A2A5A1A8B2AE8B6B37232529262826212023212C32

2D4D77889BA6947F959B9C9B9C90917B7167769893807562

706F63596A7E968B8A85714F32080A07193B957F10040304

0206000505030305

010207010303040103050302020705060102050507070913

8D6172160715AA907F8798A58595956D3C73897E7375869C

A39E9B9EA1A9A0A5B0B7AC9E90644D34211B27272C2E4865

859D9E9B9789889F9B9D968D8F8B7D7F685072689B9A7C77

72707B827E667F848B7A6F56100209095E2F6A6F0B070605

0506080808010706

090205020200030404040304010505020205030801030200

84614B12120D3276704C8DB0A8A69B7A2C5E62686A6A769D

A6A69DA99E98909B9FA6ACAFBABBB0A09A8885818B909BA1

A19C9089858E9C999A949E8F917E6F6F6B735D64818F8D90

5E5E5D74908577727B5D415906070D0D3B8C812D0A030303

010A050405030500

06020400030500030101010302030505030101010405050D

3D8575311F290E3B5D8689AFB3A1A77C647270806A697E95

7C7996A19D9B9597A19092949B9CA4B1ADAEB0ACA9ACA79C

947F869692999D9B978187948C8B7D927F856E4C618C8B8C

85693D5C6D8D745E51696F240C07081E3B695F0B03050007

0307050202050205

050505030204030400040304020000020404030806060505

0E967A430A1B16388E9EB69A96999B6F708E9882646E8974

676D7681929398A1A2939E9A9C99929598959C98938B8B8F

9297939A96968B8B71647685859681828DA17C5B6672829E

9D87784B517F8079837D3C0A060C16468B61350805030004

0303060501040607

030006030304030602050205030703050303040300050705

0C547E581B0B0B2A808B927F9AA39F857A91997B4964735F

6F6A6F776F798DA1A09C949AA1A19E9E9B9C9F9D9797969B

9B999B9D9690727272595F65727D98857A9686737B758BA8

9B90766457768E847D70290E14111F4F726F100801020305

0805050102030305

000003010803050502030401040200050405000106020607

0B1B96693742230B52786C6C93A9ACA08A9697867E56576A

7F745E685A64779996796F6F777E9098999B96A19DA09A9D

969D998D817A6B4D616F75693C6B877F7A8B87878C816E86

878B796F686B8982784A0F0E080A4874664A040302040109

0705030102060105

040205020003010105020403000500030403030403030503

0D0D7A96603B420C4B4E5B53909FAAA19E9E9BA18A757082

8B73656F626F7278796C616D695F6C6F8892969A95918B80

7D83947A6C6E50797C80868275626D7078677684936B5971

7B846F686C6485805F160D0A051B3684822D040508040708

0701030206050507

050205040201050107010503030303050406010102040500

020A18925235261501624132849598A796A2A49998A19A96

8D7A857F6753656E6E546F7F756C645E6B6C6E69838C6A66

6B6280826C62636F88828591775E5965656150686E4C4B73

75776F6D6B69807E4B100A1E135B35777916030505030308

0302040201010201

010504010903040304030105070003020205010305050002

0B070A75906126270532413D748B7E85958D97A69B989692

9B959882636F7B76646E828A8B81745B525A53566E7C6369

7A5E728B6D3C769186747E90907564383D46503B323D6185

8C797573695C62442A0A1D1314339D6D420B040500050405

0400020502050705

090400030503010002040601030303070300050803000503

030107169A646D240E1F4F35555E6F84A590939699968B89

9EA39C7F61798B8F7F7A959991917F6B61684E5664716172

8A735A6D59667A8B837A62768B907A786A6D74773349748A

8D968C8B6F514169180D160D2944866F1107050003020107

0305020306040304

030505000200030103020201040200010305010405030301

0105030132AF29461C071E4B4D5274A18F93928A838B8C8D

A29D8B89728C8D9B9E9F989F9D9B9A877D7776614E4F5972

8B81702F6D7990898C836F6E8784858C8A848069355B7590

8C837F766C35554202160F143F5F63460305020503080305

0104020202020105

050306050103090403020500000402010504020503040001

040005060951B01623160905745E707F8588947D818B9AA2

9E9691968C9B9E9B96929596998B929695937F7E6F3D7183

90867058748B8C878B8C727182838A9389817A5D46548486

818F796248555F1B1C12194C2C7C74100301040106040501

0503010006060704

030204030503010403030205020100030405000204010406

04080804041089B31F210C08113B8A7C7C908B738596A89C

96939695959AA1999098938E948B867F7F968F8D7A5E7385

919285727D8E8F86746F547E87878990918B7C5E41578587

74757754426A1F0D0B061B327D5E3F060503070505050A07

0302040105030302

060402050205010103020104050100030706030401020105

0205060303061B72D0271E11190C1D488479837492A0838F

92888287A191A198949E9D9AA08783836F7E8C8F7F667082

92938F8D8C908979757A65758687846F7D8487713E497E8C

6472734D583912211E055C4475710E020302000104040405

0500020501030004

060101050103000306040504030101000101040303030205

020102030302081D77C63719051015164B5D5E6585897083

7E6F7278969F9B9793929A8C8A8F9D8D7F7F969186796485

908885878585746F7386806A7A8A855F6474887C4D3B7986

675A484D59080D1B192E349A742203050801050303010506

0308010304040303

030001020103050205030808030401000102050401040502

02010503040703071789BD1D09201C000A4B216C79826775

7B666772948C808DA198786F728690897F7D89999287808A

9091908E8A786F71798F887A829486764B5D778759486474

6C3C5A69130F180C2042907F59070B030302040803020405

0504030202030305

060205000003050501020903040402070406040504010001

0300020204030503031790D0142C270C1213404C7F85575F

55494E718C8167808B906E6D6B809486807F8A90907E8785

848B8587856E6A6973868A807F878878424B7584654A4357

3E4B4A19071B1B0C6B50887E060203000104010504050403

0201020503010304

050707030009020301060304010203000205010103070402

030505030000030101051B5EDD1E4A15131E00154C42583D

373B3B6F7F817F7F967B6B3574748F8B7F83878C84817A6E

767F8185755D5E667384878F7E87867B5E3D74817B452D23

3C642610161B1078317A6E16060506040601000307020204

0504050202050100

000602000605050002030505020005050503000401050601

03050407020305030503041172BB28630922151013533B48

37372D6E7A8B878787806E3973718586838A7F88817F7570

6E75828571646173797F7F817A84857A6937708377292F37

6C1B1017110A4E1B9C85210805040505060B040603030203

0000070501050203

020302050100000503050205020501020604040302070501

030003050302000403040A070F64A6592C2B1C0C423D3F69

3A3442526C73746B707B77376A738B8578867E7878766453

59697D846E605B68676F767A8073786F5A38636726433065

03081C1910661D868F260407000303020103030506020103

0304030304020301

0A0100090803030100040403000205030003040304070704

02040904010301030203000502063F8E901B4816150E374D

534B41342F535E667378722C696D828583817F6E6A645741

5B65768B6F62595F5466767D7F717A703B3327324A56160B

121B20197118868055010206030405000405050305010205

0409010301050504

010505060105030505060700030302010100060402030305

030203030205020108020502040507268CB84A4A190E0F0D

1308090E1016192045562A275C64717D897B7F6A5D504732

57657F7D7266544D26757B7D7461512A32484D5516161342

777F186F138887620A050406030205050101080201050806

0406040107020505

050503070301040603000403010505030201050600010303

050405020500040301060500040004051477887A255F1617

0C260B0B0519100E070E0B0A1B5A747E766F7A553C3F3225

51697D85766C403D262C797374485352375E1B1515110775

1E354D2E8B934D08010506030A0503000001010305010005

0202010A03040103

060302000103030703020505080303020502030500000803

03050402030006040502000506050306030D457B974D1B32

281B15261E1F161C1F191415100A113A3735372B3236482F

29637D787E533C3D3A32304933284B481C190F0319231726

69074863872E080001050306040504070104020404050203

02030506020A0505

040306030503070502070601040304000501010401050903

07020400030405020504020101050102070705165E878667

0F372E190F0C16261B1B10142812070D043C553A06120E2E

2F3542452E5236533549484D3D22160F04132B0413206012

1C8794741001040203000502050302020403030401010A05

0405050100060203

030205000103040201050304030106010005020205000402

02050303000404020505030105040304000109040516738E

997525282F363518111D051F24250A040B1D131212070503

090C050D1208334B284B21020400152219091C3441190E89

8A8334100005040500030306000203030304030405040502

0302020A05000300

060503000202030403030200020006010200070203000402

040200040501040103040503020304030300030400060A14

5B80967A685C210D1B273E32191009040D140B130E071311

1B1C21131B13120817170E10141B090C1B3C2508307D7F7C

4B0D08030305010605030302000404010202030005030003

0505000401030305

030203030304020405010100000109010004020303020003

020005020003030502030304050601030204000500050605

020E114D7F8077896D602A0D0E212D21303D3B322C18191C

101B170B1513090611121B21191D183B182A6A8B717F4C0B

020006070202010303030204030401010206040503010500

0205030304020304

050100020302030104030103050409040303020101030100

000203020003020508040105030103030403050304040103

0003030B0F05364C7C817F92876F5E5F2F3019101E1B0F24

2C32323837362D2A212D282B352413187A6C8A7F3E0D0801

080302020505050007050300000306040506030302030001

0502020103000201

000302050103020100060101030303070302030002030003

050305050503000102050101030101050503000108000505

0B000601050408010C0B2B537A7489747C6973817C74735E

694E44324A181B211416253040576F7F7A732A13030C0504

060003060505040301010303010102000405010105000301

0504040200050303

030302000201040003070302000204050006040103000005

080505070003040300030500030101020406040302010009

03070303020605070203060B10080503132D3050546A606D

6F85817E64807C7A6E6976847D7F74592A0A050508050203

010207050101030503060105010102030502010403030604

0502010501020000

030502040504010305000600000303030502030003040501

000200000203030405040304010102000303020503030205

04040404040302050502040003030500050003050206080D

0605080F2633323A4E483229150704060304050303000307

030205030302030502040504050300040300000003030401

0303000002000301

020103020100060301030304000300040001050404050307

030003030305040203050204030100050105030105050200

040308010101030402000003000101050101050403040502

030405060501050505080505030502000403040509000304

050505020505000303020602050405030500050000030203

0101010200050103

050202030303030105000400000003030305000300020501

010005050000050001030100010104030302020506000503

050203050104030207010202000504010501000303050104

050002050201050408040303030204030300020204050402

030304000004010505020300040405030006020604020105

0201030500030001

010403020200070100020406030602030107020404050101

030403010503000205000405030104050600010404010205

000504030300040203020901030201050301050301050006

060300000700030102050301030300020208040103020901

030303050406050002020200000300010303000102010404

0200030305020102

050003010100020505070202010004020102030503000504

020105030205050304010303010303000400010300060402

020103040203030203000002030502030504090301060305

010101020103020104030105050502040305050304010003

050402050102040206030003030505050200000705000001

0303030401010301

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.35119 0.00744048 0.64881 0.30506 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.00751202 0.0192308 0.00751202 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

128 string

128 128 8 [128 0 0 128 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FFFFFFFFFFFFFFFFFFFFFFFFFF9AADFFDBFFD6FFBC345FCC

AD859891A6E07DA53C2F934B584D43115C1D464D1F695822

615E6538423D864C3A1B2E6C2E52202F3B2F20522E6C2E1B

3A4C863D4238655E612258691F4D461D5C11434D584B932F

3CA57DE0A6919885ADCC5F34BCFFD6FFDBFFAD9AFFFFFFFF

FFFFFFFFFFFFFFFF

FFFFFFFFFFFFFFFFFFFFACFFFFFFFFFF5259B2F1EC87D93A

989EFF9EE15B1AE10F231830D85B5C3B5878165029284A82

283F483C285861131F4A3161241D2340272D3A4C25320A1D

290F27232C5C135B5E6439743F3E3E4E6F4C76655A6F7C9A

736855CE1AC3543DC8F97B63F3FFFF4AFFFF5CFFFFCDFFFF

FFFFFFFFFFFFFFFF

FFFFFFFFFFFFFFFFFFFF18FFFFEBFFFF9CD43CC730FFD0FF

3775897B4D5155AA25784D5AAC446F1C206D633234163B06

2B1A47183E9D562738682A0F383922302C21141129350C28

312E0F364B478B0E1553384B476F27611E6120368D584649

AB4E4A5A36F35E428039FAF1FFFFFFFFFF67FFFFFFFFFFFF

FF64FFFFFFFFFFFF

FFFFFFFFFF7AFFFFFFFFFFAAFFB9FF5DEEEBC8DBFF7EA4FF

491A4E5F7559A245349E325708243E1E5E4D2B5022202131

121D24560B41401513552B3F1C3C2D402A2D5134282A4D15

1C314F28431870052D7B860C6D3A4B4D213B453484265055

26CCEC158CD5A25CACFF9BFF43FFFFFF8FFFB5FFFFEEFFFF

FFD5FFFFFAFFFFFF

FFFFFFFF8FFF8B32FFFFFFFFFFABFFFF54A3FF5CFF636394

898019465C7BFF6D50571E833015531B7D6346122C410745

3B542B3A1A430F3C36162C3F18282E1F0431521938304851

64322E24362C292D3457514241134D52461B268A88782014

32A673C5E7B08095FBFF207DD4EC65FF66FFFFFFFFFFFFFF

FF4BFFFFFF95FFFF

FFFFFFFFFFFFFFFFFFD1FFFFFFFFE9FFFFFFABFF9087D69E

948898807A7C8C28683336A348190EAD671E63500D714F5D

402F451B0E3D17260F582849321E353A171B3A5A3C6F3C4F

286F102D37292A491E43463490423D8D0A5171515B3D357E

73D9B9D170A7FF60FB7EFFFF49FFFFFF2D67FFFFDF33FFFF

E5FFFFFFB0FFFFFF

FFFFFFFFFF75FFFFFFFFFFFFFFA5FF8FFFFFF5D2ED4FFF60

C05063CC4D9B4A3A4118606064252E7B11626E511B452E40

501C3B27203926390933264B362C2C154D4129472E35492A

2E351D303F19145B342441379465773C7E9B2155756E8D26

B34F5B7535B9734AAE3612FF16529F95D7FFB463FFFFFFFF

FFFFFF9BFF9DFFFF

FFFFFFFF81FFFFFFFFFFFFFF81FF71FFFFEDFFFF6725C9FF

7E1219E7363A3D155D60052E602432507D502A4826542840

310B240B2C2211253D3930291105403E1C664335262F400F

6A1C175865331877675C45636A6F23276B80BF26CC5A5B1A

8B30446170717F7E34FFFF9AFFFFFAFFFFFFFFFFFFFBFF66

2EFFFFFFFFD7FFFF

9BA1FF81FFFFFFFFFFFFFFFFDCFFFFD0D9FFFFFFB1CC3AFF

5D574FB0B99817645546305C58394C6428283B25331A4129

612214483E4418027B361A2B252961882057355D1F472A26

49381C27740F2B19396F2E30418357BF158172282A46B048

6359295C1DB61B65A0FCFFCDFF9979DDFAFDA0FFC9FFFFFF

3D9DFFFFFFFFFF36

FFFFF4A8FFFFFFFFFFFFEFFD1BFFFF6C3AB6FF3499E7E65E

5AC43D3A3B60304608435F192660297151393048382B3A25

49773114175D21434A36542D3A1B8B5F2639595B5D4F3E27

155418604A104C5409446A215A551B853C5F7C357268A140

3E4C286C5646511D8554A0FF97D8FFFFCDFFFFA1FF2634FF

FFFF99FFFFFFFFFF

FFFFFFFFEAFF3E97FF6F63FF76946DFF7EFFE4C6B0FBFF87

C52987550E2B73647037AB762E2C192433425E35092D149C

5D4E242238431967182C57490A0C73072D2A2F1531072917

282E14543110344563553D3A4E205669274D6962545F5438

5C284A1595815CDECA5BDBFF976DFF1ECBFFF0FF2495769A

C0FFFFFFFFFFFFFF

FFFFFFA384FFB4FF7791EECB89FF6ADCA547FF8E1EA241D8

60EE4B606192101CCB3854626A5A4804485569525C2C1282

612D1E274349422E491C056613333661151F2E54160B5F47

3C7B343C276A492C493C394145617E0B788A68DA8888C625

2840940E815250C17936FF9C97FF53B5FFFFFF7AFFFFDCD7

FF66C787FFFFFFFF

0CC57677AD8AFFFFF77AFF54FFE111A9C56947DF56D5645D

6B459A5C59C5AA25B03E1A542032464023355A34751B0D2E

1A3223560F0E29072328233419174E441C326C29503F6556

183023254E733E3C2F642E234B1063875960773A817C4A39

625C5924701ACC5F48CC69FF97E27FE74B74DE43C165C4FF

FFFFFFA1FF4E38FF

D7FFFFFFFFFFFF87FFF4D6BE2269B9AB9D8366FFB447FF32

56A3363FB31751333510A7215C333E3F4E4D3059235A5E49

31074A3327222E30210F50493A305C3F443D51404B203D46

4434272C253B63101E2A5A433054645D8C1882955947962A

A241D92FB970695DFFE9FBC528473F4EFFF7B232A0BBFF9B

6782FFFFFFB0B3FF

FFFFB4FF93FFFF32684493CEFF646E814058D25DB9C59580

7455BF21623C9E40964A55B757664F8247601D132648424C

372F35324D39393027100B482E1E143844371540560E4A3A

481B4D4D48523C2D3C7D6C64234E152F5D344742601D3913

33373B862DE86CE3953BD33197617883C452FF97FFFFF4FF

DDFFFFFF7996FFFF

FFFFFFFF60FEFFFFFF9A889C7681BEFF6BA65155694D2B5D

C1B81E2F7887A5549B487B74866B137764435B461E3D4B15

0E233D303818323F41292745174839126554521F34204C41

755E4A253368511F21661E58666F47178328478A52842731

784B6993EE6883FFB05C4415AA7C72806FDAFFFFFFB887FF

3580CC9EFFFFFFFF

8576FFC597D5FFE57A61BA359936BEE5A25350A65BFF64BD

F832366D7048564D2A6D1845614E2538433A5A163D433312

553813256C352F2549342B332F333E0A3C0B3E20262D6F26

31165234474F466A4792173E5A202A5B627F7E2539451271

1547313D4827AC1D915EA54F8654F728FF8135A135B8FFDC

FFFFFFFFAC86FFEF

5E1435C132FFE4FD17FFBFEB1779725C75B2463DF2746AAD

413F7855944A6F4FA113576A2D82102A384940112C260E2C

5540203932121330144720492F32333E13343C692D453B41

6C232D2FA05958823C28637A412062213F308A5655155C60

344085187A1510522C2752445359D4FDE7E250BEFFFFB5E5

47A9B97EFFFF53B2

FF58A3A3FF376E6085EC88CFCD287FFF59C35A93864EFF2B

637D0E824D303E6C89873095559109303641232E3B3C4E5A

672632842E10572F2D2A44783A424C862E150E322A71350B

3657394A4645253D0433335B220F2E5F37504B962D566C05

6FA39D4338433C771F7F62AC4B7D36BC75D6F9AB4DC0C57D

4EFB77B05095FFFF

FFFFD6812A93FF907D0B815A968DF99DE4B177859660B9AE

4E033E466E553A942B0D336E300D3C2810453B50334D4B05

3324476090335D286717642C180E552A352414132635324E

853D2C131227311541424366753D6C5D8751605716982F60

7D8F7E4721339C74684B24720F58B3A8FFFF958E3FD572FF

FF87FFD6E4FAF688

BB914656A7B58332EFA81861961E3F9BA382A9643E408966

6B766732AF293E0F2E9A42885A3D14530D6A793D4B5E1B45

0F26443D3E5B43314D2820414414372E1119334A5E254280

36302934201D4F07215C33894839498946614B1187612A84

2179271648A325B963C56A9A0EDF8F6C4A95337BFFFFEE27

793D9C8F7BFFFF3C

A17041FF863950AA30ABC16A8B436F7B40915C3062D23E81

A6223C45151369114138233B47101F2D4D402A560D0E1E2C

3153403E49202C5A392B11161F22544931223B23291B3F33

644F1A343B51527C371B3635215B5412A81D9B17604D732D

683B50064919487F6336A04E2F57AF875385FFE09E406E77

AB4D51BDEDD1A569

88D9FFA99F66D190CDD46DFFC72488D618BA624428954E57

444EA13978431E8B682B3310482211271C67472F1F31441F

5621136E3C493B412E2E1B28442419262E393B407F252440

4955046131210D440C933A6F7D34409F431E7D653E0B4614

416F468C20CEA0AB95619DDC2BAD93588319663C80C06B88

9452416A70689689

FFDD9F886D43FFFAA842BD386D0CA48569527B24C6CE2B10

48710E68713D2747054344414D4E38184051282C3F4C2E32

143236620F566240331F6B4E5F33352A29461B1B7A190C12

41510E19512A692745261A1E4C61386C634537143D47124A

43178A5B6D40348E1A7B47608D9893877F76819A4D441852

C3BE65EFFFA581CF

532372581187D759937D1B75489F8152623A6B2B6A3A2421

5D117543603977625C3F2D25205841242B1B3C45325F3A27

39310E212C8529737A1F286751061F0D0E4B1C4B243F4169

3055277C3A67301B1640693D507D235B3E27512C48194D16

3C871D5E5B87365F4B634F574B8BCC365B5CB1A96C4C094F

3F808143B6C1D631

88382D7389F951690E1CBF6EC09D5D9E68BE6822492C0988

3D2B782C5F6C58321439102F42412B8227402A5E2F12534A

18163E522D1F4826403E437B336B52450011474536376727

661C7D4B3229164A4259544C5A4013452B274484258B5F38

9157D67341695B714D4DA66FAB8F99E3AF858B2B3C7C3D5A

67582178818A64E4

E88725624139558E26B5D89AE355AE7D492D274345414F4F

4B2D7F1A6A74127E49303B403F241B52253A50421C1F3A3D

282A132E774A251D4016301E112E2913063D1D385B19246F

283C286C1642201F6E72376138213E11551C46522D4E5841

6B56635B307EAB4F895A42913E4949637184137C274F5683

7C35451B8EB9A03A

77B132366CB1CC57A5696E7A93304A89AC6E21155A66404C

0B611E5F691B8D8B2D3E494D3926472533653D1833301A16

311037414F2E56192A3447282219714833166A412A6C3B2A

6A381C34532D2A4A2B27292F192936084E2639326B383945

29193F37354F315945155E6C5DBB3D5E2E52124ABCC3AF80

5847842237695C70

ADCD4C53ACC130FFFF402F666B754763983C38013C596828

41288157747A6D44925C363415682E2A1D1C27382580381C

105D2641335B2C432E45250C1B37521F2252631F7A361B4B

1646202576349F41521F214A283B181B53276F3B7F377A6C

077738782948A45A61860B5E60406D2836495A4A834070FF

E97C68B378C4E98E

6D4E49534C7D4CB94573665DEB9F838C4191683C5E3F4948

5C7146456C4C342F243D3E6C33467162203C2938235A1C73

421E382435421C2A172216133B36912F046E25744F7C212C

2B77383F162B5838371E0E1A224C325835551283962BAA14

42591B322C3A68525B1B254044A17A7D3B3F6F09242A5C63

48BC62AF7B646AD3

FF5C8E1E1EBBC19F81928C1EAE479F638429657C16594A24

7458310764216C3E462419414241191A01163B1D270C2B02

0E115A233F3D14661D43081D15382F171842851B11573313

166815370E313E09183C3524327E3A79463771670C923518

2045298F4638123124471B455B170E18312F8F93628DDC2A

271C2152808A368A

82E77B3B3F7844847B92635A50284397687D913B41296730

3172495429785B212F70226D57563224191A0B2F172A3423

1F705B1B271C113111105A0D53141F2721473E5B1C097D39

3C441150203E2D374F2D3C10814B5CBF1035645A4C264937

663A2B2F4323452C986070681A264D32721891204CB56151

69424A1E7964903C

486F745092465F2E3F526F0E4B34272E391620531ACAA244

261A56551C15253D5A3A3C2953154A2B4D444B280E431678

3148652416471E3A4C264C2A164E4C4B6F1E352819500E34

132D482E25290F2F57524D295152424B0A2E48563736501C

505F8A6249917B67383457395B312A412A573DA857A49E6D

785C4283A6651B2C

CE73529CFF4263635271377D434B241E211461405F3D2D0F

165410694E17373E11382E32042E2F1F5C201709424E1D73

06394F4A264B23483F115C2B533C1352012A1A251751301C

1F3E204E261C405C381B5630404D22BF19687E375E8E698A

914FB3474B550A07482D3B3F394D5F27345C719934524682

81B28E9DC8AFAEE1

FFBC54642A8A933F0D687936288D5E89528BD9972478154E

7A1070092A1D57594127173C4830231B2A4A3B421C282408

41153F4937182B3236175A254F2937222010415E30420C3D

404A4A373A593360435B837A5F185F6D2F744E6050532631

03563E6F76815E77230732360C212C414728357D6C3E6953

5A317086AA332A63

6CD28B24360A1C1F3437244D515675355C71213056607412

52525F1E4C330619294138284E392D4B7412687C2B551F19

3B131508132170611C42162D1E3227100D16260F1B2F1236

081B691E3C55483537481A2B651D5814152322A92D807A89

696F6D552494446B304D1C8B533B57317C21394314658A57

72426B4D375B4108

785B1A28350B696D838B537776548A6ECA20A7345C3E308D

052D4540BF4B0F3A1F15203021253A4E26793A3E0F3F3836

31223018313B14431C372E270716272E0D304A204519215C

40512A113808040F2F4F4053255B6C775A725CC85661202E

3E7A2F211B20604B51373B4C44174D2326540F3C4B83AE7A

4667507F4C57C25D

620E604989274B2A3B0FA9DA555D8278502636473837963D

85550B317A4A685612242B28154130343964333142603F46

2E443D33143E144B3D276826281C25062D30185F3375522A

204146473D334927286941385E313D753D631769255F722F

7474585E32575D4B556C3C243F5172154512221A47D88D2E

C2CF93CBE3D16610

6542995670611E4F36874F67596A177B3C454143557D6058

4847752766231E4E3128012A18284A60374D19483E0A6226

3D2D67511B3B123F311A3C3F0F382C1C20122404123D3A26

3D4C4022030D1B6844463A421420936390173654092A2E36

3E43414A6049844524622C41473D33152214293A5A0E1E30

487097705D225C72

5337441D4E113A5E75316137370E98A24C79396F32393D52

366F5C852C192A372A6A392730337A213A22362E42435318

2136414F1D3D231A2110361E2749272D451150334520541E

0F48272811104D232A723C3E282514212B2B4164266F575E

1618135D3A581530565B404F332F464433582C686A46274C

273373465E47556C

6C4F34291E23346C1A729D292358784F2A1CAA7328495645

4928615440072119364A553D18382F382C614446124A5C39

58231732151C18352539153E2546423327284D262852155F

432F222D2B110A232652465B181557206D50697D6721115F

3D494B1732385F3E253D1E3841095910421B43195B2E8C57

A683399293497640

6974413B3F3C72408A4C3B953957416F3F274D635412362B

252A4B45172932210D580F361E53572E3A1538342B133728

1C183111311915232B201C050C24292D2F2258275B165023

3A4E4E433E2030317D6F346E4C7B4B45622D8A383D714F52

4C634954550E0A73604F4A15201A4E194F5C1A4656072243

092C15126E779567

A554494F65432B872D5F49684140411C45769D454D933C64

13472D2C5108261745100E393D3E4F394B602D707B1F6A42

2D38062C33141622114C302425115A0A874B0F10313A3B2D

2F1E293B2A3616463B6C0D3D675354590756392C8E365954

265A2D2E293F20423D0E23525129432B1E464C50406395A3

3E866A2C179CB419

367D605A537927150A45191A657C37410B1E0C523B45290B

392E24635B2F4D2A10102A172E332B390111692F082E433A

273233103628203B3B18580F4816343F2C3A1D274013636A

463810672B592526383B39252E3C6154545AAD6F54685039

35464B413D17093D20213E2A534B345B3A0E2C3E4C375287

7560A28141461525

6C4D4D0E81703479754C3F1B2C3D2710502A38106A654244

33322F418B1D47224A1839270D52342F4B1D56483B291F18

355409263E102934231F3A04311B5734232237185032160B

2C3B303F262913411D403E5D492B55370C2115524E30381A

153C35410D584A6C3338132E204F16233E28196155615C1E

400B165651614678

731019191B795E5755594850252E5A6D2C6C328B2232141D

6B321E3E69302A341B2E30483A3A064F3313752E1D7B2671

2239171818231D462419122F272D39527A23021F09192D18

530E4A693B3A42440A382B3C2338443435542E3C2B08312E

352F2A3E48594442331633072C262E471B29393F3B281D12

3A391C3D626085CA

8177483C39342677531C27575D982B1F1D18266F3135132F

3B50152A3233463923150D4445264317293C5645294A4A20

59233919182B1019120F4032170B3927133E580630444D14

222327164242465A2F383D50153F532B44673C1E22452635

4F362F24222F22261F0D19333D4D46192F083D09293F6D3E

3B8429182283281F

3D467C6529425E154432284B01190F1A4549483D15401E20

1B2C08271C2B3424144D44343B2E521D46335919503A171C

353D651E073E2B2B0F2644342945381B5311192B4431153B

333A282B1A4E14265F234C3B1E5C46521B33342416312F81

4B542A3A16443218682A15171534310E1D0F824E6F4D0825

2B2F195F74094253

555A3E224E0526495333343640254B33143739214C3F2E0A

303118295E211916330D313629074C4024562F3152252F54

2B31111E2111243639302F1B1333123B1F211D062D5B1826

1E2A1547535A57720D09183F203529101339181F1F3F4235

34392F103E2A173A17543C44631D2354322D523C1A355693

2F335A5F82672126

B63F3310272A381D35120D254E4F40412A1B383525233360

301E05132A1C26062B423E4F223E3D0C40110A153A133738

0E101A1D0D281A2B1A0C203A205A1F3F28610D3118210829

0A360908370B231570496147321816383E200A6158295423

4541517244491E18243986592B131963904A4A302C0C623D

125A71452E49525D

AA52130732321E1C31102F2746184D0D233E1119154B6242

543A311D232D281F3D1B3D44373227611C3340172E58282B

1409343D2C47333E3A1819232029132D20322D1C0F232F1D

19322B1D5E3A566B1645293654381F4B2523333044292814

2611340B22170E1B374B6F1A2A4242371F20126B5847404B

5E471C377D5F1F58

727017408F916F9537172B2F552D404F4640117421442D35

57343F397A55472323272640351A5F2064234C3F36351D3F

4C2625150A1829374B2231071B4A0D2925270024480B3C13

1D21305438463C2F4E0B6C05284B2A201F2D261F3C1F3336

6D692E4E1B0413132447292D464C23424E2E7B4945351220

6F65355745234D06

6111575D2310374147034240271E4230531D394A946D1040

4F5232430A3D1A34583F3B3654195B4B15272D287B210F0D

213D38362A2D0F461A152542240D266F161F630B4A204B48

174F0F29453C4F3E2B053F251F550F33371133722248172C

131833222635150F25134D491B1752422D372C262A5B3279

5F2170324C331B5A

56655E1418322A3B4B1C372020371C1A2F4465645B1B2A12

3F105A10272E2635191543423904173E0E2221352C281156

3A3A1E0C35323C39246422251C1017073D4E3C25241B2D41

2B2B0E3B443E430A4B33490B1C4052292526292E5C0E3133

0F360F28163134315128562A3C1A17634E215C3609481B56

94502A612A314B6E

774347495F104D1451490C532132324061824F8428191250

25432F6221393A2D3A3229492524291815322426492F101F

214D32145B36302F15151A20151B543E0821491D3E292D16

0C28522A21452D361D203410230634292E16184162573E44

4B0E46445006322D5A204D2606163D14131610242D1B3824

2E6D6E122323163A

4A4D1574064D452C633C0E5154381A17233058565D2E1A38

6607713C724435514A2F22252325220D1922883743271A4C

1E5F294E4109311313340F24162A262F472D1B321F421344

1D34205D2A4D37333B062D0E1813200B2D27380B2D1A4717

17225148343629471730322F5A4A2237371C50463537301A

4D234D483F383B4D

6019252B29489631300D3917382B134624442C6629341054

0F431E5E73386130134C1C141D0850352919450C14110512

581B3B1A1F302624202B092047114733091C122A50245B51

3C4F2731552F0A1C0A072E2C231210323F0E31183A230916

24432E45376F191844461E3C193A391D17041220311D6154

648053271A30792B

593B686B121922351633603B3C20215F4E145B187015503A

3E30455E5283193902153225161836164139393526482739

1D084335135510161E0C08030C2E223B2E2B365532532058

2F3D3D502A1D15271E23381B36113A3F5B321F2E25282437

1F18243D5E0C491A3B0F5F955153384E4B402E073360422B

2A40264839223029

6D6F504F381C2932224764422D2D3F2C1A2E43232C3B144A

2D30460B31261845413C7917371E2330191214172418252A

2160372D4123182E2033580B38372B102A27350C3951444E

4F4114393E5027221617244F4433352B32172028142E3839

1F4011445048194470025E7B70190D0826280B212C1D142D

15464A0B2C3C4D15

54215A9C41453515265243543F1F313D1F2B0A133E533641

4C3C3F4A0D13424630583B5A123F36183F3B0E3A14421D35

340B313E342E1A11163A1C381D32212B2B311D66176B214B

442F355412130C2736394B254B073E356E22222C0F09353B

24383D1A6127342E6F364A1E24331C20183A090B255B3245

2C294A59486A1810

544D64377E5E2928283A374D2F3B1A5D663016161A2E202E

382635132E561E42125F0E151B28353A0A0820113A2F104E

1456152C2E0D164A2B2B410E33172725143A1F211F432741

3436131E2634371A1E1B1F2934094113631B222D241C1C0F

1A151042365A191754594320142B274349191A743C3B1633

332E133440694E46

8E6154333545343C473512272E322E253923124949222108

69186F3B322C3E1B43390A54172825202D40321236510B66

3A4D08321B263707102F3C4A306D1252275230200A5E3430

254142563D362337574011251826155E0F51295727612B23

191030271D29462915342A4510260D123A10375D25225D6D

2315515E400B1D4C

6AEA47372C231C1A2B292A1D122B2E3F19121B153C152275

1F492476276420200841152F253B0C1F061714334B1C1D3F

2B4C212B300A36351607224026152A1B19561C221F343A41

0F0E353B3E76283C1A4E10350E1D294857202D102162502C

3E4348241F2B1F3A34355A6D20231E379572264937273514

3169321E2E0E122C

3C10545334395A242059427E4C3B380A3353104F23172630

2D32664534063D1A4D360E0F11221A261B530F131140461C

0B4744332B0B4A0D3B3036492C45176E053304550C451F18

121B13363D0D0E0F190A171665432E2F632C37283A604337

31123B1E2C1D3A284A0A1564136B32224C4213452E591F09

3F1F2A3F3C36424A

3B19312E5582592B533712221234095739283B5E1A611A89

133E10510D220D201A33337917481E163437060E26243043

1C5C1339121D2C2B221B31322B2E187D267D182E2B32311B

222B2C1D1239135C1C433024260E063734161E4817793333

1A200D220D51103E13891A611A5E3B283957093412221237

532B5982552E3119

3C4A42363C3F2A1F3F091F592E4513424C22326B1364150A

4A283A1D2C1E3B12313743603A28372C632F2E436516170A

190F0E0D3D36131B12181F450C550433056E17452C493630

3B0D4A0B2B3344470B1C464011130F531B261A22110F0E36

4D1A3D06344566322D302617234F1053330A383B4C7E4259

20245A3934535410

6A2C120E2E1E3269311435273749267295371E23206D5A35

343A1F2B1F2448433E2C506221102D205748291D0E35104E

1A3C28763E3B350E0F413A341F221C56191B2A1526402207

1635360A302B214C2B3F1D1C4B331417061F0C3B252F1541

08202064277624491F7522153C151B12193F2E2B121D2A29

2B1A1C232C3747EA

8E4C1D0B405E5115236D5D22255D37103A120D2610452A34

152946291D27301019232B61275729510F5E152618251140

573723363D5642412530345E0A2030522752126D304A3C2F

100737261B32084D3A660B51361232402D20252817540A39

431B3E2C323B6F18690821224949122339252E322E271235

473C344535335461

54464E694034132E3333163B3C741A194943272B14204359

5417195A364210151A0F1C1C242D221B6313410934291F1B

1E1A3734261E1336344127431F211F3A14252717330E412B

2B4A160D2E2C1556144E102F3A1120080A3A35281B150E5F

12421E562E133526382E202E1A161630665D1A3B2F4D373A

2828295E7E37644D

5410186A48594A292C45325B250B093A18201C33241E4A36

6F2E3427611A3D38243B35090F2C22226E353E074B254B39

36270C131254352F444B216B17661D312B2B21321D381C3A

16111A2E343E310B34351D42143A0E3B3F18363F125A3B58

304642130D4A3F3C4C4136533E130A2B1F3D311F3F544352

26153545419C5A21

6D154D3C2C0B4A46152D141D2C210B2826080D19707B5E02

70441948504411401F39382E14282017322B3533444F2417

162227503E3914414F4E4451390C35272A102B37380B5833

202E1823412D3760212A2518241714121930231E3717793C

41451826310B46302D4A143B2C23432E1A2C3F2D2D426447

2232291C384F506F

59293022394826402A2B426033072E404B4E385351955F0F

3B1A490C5E3D24181F372428252E1F325B3F3A11361B3823

1E27151D2A503D3D2F5820533255362B2E3B222E0C03080C

1E161055133543081D392748263539394116361816253215

02391983525E45303E3A501570185B144E5F21203C3B6033

16352219126B683B

602B79301A2753806454611D31201204171D393A193C1E46

4418196F37452E43241609233A18310E3F321012232C2E07

0A1C0A2F5531274F3C515B24502A121C093347114720092B

202426301F1A3B1B58120511140C4519293550081D141C4C

13306138735E1E430F54103429662C442446132B3817390D

30319648292B2519

4A4D3B383F484D234D1A30373546501C3737224A5A2F3230

17472936344851221717471A2D0B38272D0B2013180E2D06

3B33374D2A5D20341D4413421F321B2D472F262A16240F34

13133109414E295F1E4C1A2743378822190D22252325222F

4A513544723C710766381A2E5D56583023171A3854510E3C

632C454D0674154D

773A162323126E6D2E24381B2D24101613143D1606264D20

5A2D32065044460E4B443E57624118162E29340623103420

1D362D45212A52280C162D293E1D4921083E541B15201A15

152F30365B14324D211F102F492624321518292425492932

3A2D3A3921622F432550121928844F826140323221530C49

51144D105F494743

566E4B312A612A5094561B4809365C214E63171A3C2A5628

5131343116280F360F33310E5C2E2926252952401C0B4933

4B0A433E443B0E2B2B412D1B24253C4E3D0717101C252264

24393C32350C1E3A3A5611282C3521220E3E170439424315

1935262E27105A103F122A1B5B6465442F1A1C372020371C

4B3B2A3218145E65

615A1B334C3270215F79325B2A262C372D4252171B494D13

250F153526223318132C17482272331137330F551F253F05

2B3E4F3C45290F4F17484B204A0B631F166F260D24422515

1A460F2D2A36383D210D0F217B282D27154B5B1954363B3F

58341A3D0A4332524F40106D944A391D5330421E27404203

47413710235D5711

72064D23455735656F20123545497B2E4E42234C462D2947

241313041B4E2E696D36331F3C1F262D1F202A4B28056C0B

4E2F3C46385430211D133C0B4824002725290D4A1B073122

4B3729180A1525264C3F1D35363F4C2364205F1A35402627

232347557A393F3457352D4421741140464F402D552F2B17

37956F918F401770

AA581F5F7D371C475E4B4047586B12201F3742422A1A6F4B

371B0E17220B34112614282944303323254B1F3854362945

166B563A5E1D2B32191D2F230F1C2D32202D132920231918

3A3E33472C3D3409142B28582E1740331C61273237443D1B

3D1F282D231D313A5442624B1519113E230D4D1846272F10

311C1E3232071352

B65D52492E45715A123D620C2C304A4A906319132B598639

24181E49447251414523542958610A203E38161832476149

7015230B370809360A29082118310D61283F1F5A203A200C

1A2B1A280D1D1A100E3837133A150A11400C3D3E224F3E42

2B06261C2A13051E306033232535381B2A41404F4E250D12

351D382A2710333F

55262167825F5A332F9356351A3C522D3254231D63443C54

173A172A3E102F393435423F1F1F183913102935203F1809

0D72575A5347152A1E26185B2D061D211F3B1233131B2F30

39362411211E11312B542F2552312F5624404C072936310D

331619215E291831300A2E3F4C21393714334B2540363433

534926054E223E5A

3D534209745F192F2B25084D6F4E820F1D0E31341517152A

68183244163A2A544B812F31162434331B52465C1E3B4C23

5F26144E1A2B283A333B1531442B1911531B384529344426

0F2B2B3E071E653D351C173A50195933461D522E3B34444D

1424342B1C27082C1B201E40153D4849451A0F19014B2832

44155E4229657C46

811F2883221829843B3E6D3F29093D082F19464D3D33190D

1F26222F22242F364F352645221E3C67442B533F15503D38

2F5A46424216272322144D443006583E1327390B1732400F

1219102B1819392359204A4A2945563C2917432645440D15

23394633322A15503B2F1335316F26181D1F2B985D57271C

53772634393C4877

73CA8560623D1C393A121D283B3F39291B472E262C073316

33424459483E2A2F352E31082B3C2E5435344438233C2B38

0A44423A3B694A0E53182D19091F02237A52392D272F1219

24461D23181817392271267B1D2E7513334F063A3A48302E

1B342A30693E1E326B1D1432228B326C2C6D5A2E25504859

55575E791B191910

6C7846615156160B401E5C61556119283E23164F202E1338

336C4A580D41353C151A38304E5215210C37552B495D3E40

1D411329263F303B2C0B1632501837222334571B31043A1F

233429103E26095435181F293B48561D4B2F34520D273918

4A22471D8B412F32334442656A10382A5010273D2C1B3F4C

75793470810E4D4D

362515464181A260758752374C3E2C0E3A5B344B532A3E21

203D09173D414B4635395068546FAD5A5454613C2E25393B

382625592B671038466A631340271D3A2C3F3416480F5818

3B3B202836103332273A432E082F691101392B332E172A10

102A4D2F5B63242E390B29453B520C1E0B41377C651A1945

0A152779535A607D

A519B49C172C6A863EA3956340504C461E2B43295152230E

3D42203F292E2D5A265459368E2C395607595453673D0D6C

3B4616362A3B291E2F2D3B3A31100F4B870A5A112524304C

11221614332C06382D426A1F7B702D604B394F3E3D390E10

45172608512C2D4713643C934D459D76451C41404168495F

2D872B43654F4954

696795776E12152C0943220756461A5C4F194E1A20154A4F

60730A0E555449634C524F713D388A2D62454B7B4C6E346F

7D3130203E434E4E3A2350165B2758222F2D29240C051C20

2B231519311131181C2837132B3438153A2E57531E360F58

0D21322917454B2A252B361254634D273F6F415739953B4C

8A40723C3F3B4174

6C40764993923983A6578C2E5B19431B4210590941381E3D

253E5F3832174B493D5F1121677D69506D205715185B4652

26230A112B2D222F435F155228264D2827334246253E1539

2535181C1532172358395C4A124644612C382F38183D554A

3619210740546128494556492873AA1C2A4F785823299D72

1A6C34231E29344F

536C55475E467333274C27466A682C583344462F334F405B

563015583A5D1318165E576F2664412B2B211425283E3C72

2A234D10112827480F1E542045335011452D2749271E3610

211A233D1D4F413621185343422E36223A217A333027396A

2A372A192C855C6F36523D39326F39794CA2980E37376131

755E3A114E1D4437

65725C225D70977048301E0E5A3A29142215333D47412C62

24458449604A41433E362E2A095436179063932014423A46

44681B0D0322404C3D263A3D12042412201C2C380F3F3C1A

313F123B1B51672D3D26620A3E48194D37604A28182A0128

314E1E23662775474858607D554341453C7B176A59674F87

364F1E6170569942

621066D1E3CB93CFC22E8DD8471A2212451572513F243C6C

554B5D57325E5874742F725F256917633D753D315E384169

282749333D474641202A5275335F18302D06251C28266827

3D4B143E14333D442E463F60423133643934304115282B24

1256684A7A310B55853D9637384736265078825D55DAA90F

3B2A4B278949600E

785DC2574C7F5067467AAE834B3C0F5426234D17444C3B37

514B60201B212F7A3E2E206156C85C725A776C5B2553404F

2F0F040838112A51405C211945204A300D2E271607272E37

1C43143B311830223136383F0F3E3A79264E3A2521302015

1F3A0F4BBF40452D058D303E5C34A720CA6E8A547677538B

836D690B35281A5B

6C08415B374D6B4272578A65144339217C31573B538B1C4D

306B449424556D6F69897A802DA922231514581D652B1A48

373548553C1E691B0836122F1B0F26160D1027321E2D1642

1C617021130815133B191F552B7C6812744B2D394E283841

291906334C1E5F5252127460563021715C357556514D2437

341F1C0A36248BD2

FF632A33AA8670315A53693E6C7D352847412C210C363207

23775E81766F3E560331265350604E742F6D5F185F7A835B

436033593A374A4A403D0C42305E4110202237294F255A17

36322B1837493F15410824281C423B4A2A1B2330483C1727

4159571D2A0970107A4E15782497D98B52895E8D28367968

0D3F938A2A6454BC

CEE1AEAFC89D8EB2818246523499715C34275F4D393F3B2D

48070A554B47B34F918A698E5E377E6819BF224D4030561B

385C401C264E203E1F1C305117251A2A0152133C532B5C11

3F48234B264A4F3906731D4E420917205C1F2F2E04322E38

113E37174E691054160F2D3D5F406114211E244B437D3771

52636342FF9C5273

482C1B65A683425C786D9EA457A83D572A412A315B395734

38677B9149628A5F501C50363756482E0A4B425251294D52

572F0F29252E482D13340E501928351E6F4B4C4E162A4C26

4C3A1E4716246548317816430E284B444D2B4A1553293C3A

5A3D25151C55561A2644A2CA1A532016392E27344B0E6F52

3F2E5F469250746F

823C9064791E4A42695161B54C20911872324D261A687060

982C4523432F2B3A663749264C5A643510BF5C4B81103C2D

4F372D3E205011443C397D091C5B3E4721271F14530D5A10

1131111C271B5B701F23342A172F0B1A19243256576D2270

2F215B782954497231306729413B917D68974328505A6392

7B8444783F3B7BE7

FF8A368A8052211C272ADC8D62938F2F31180E175B451B47

24311238468F2945201835920C67713746793A7E3224353C

18093E310E37156816133357111B854218172F38151D0843

1D66143D3F235A110E022B0C271D3B16011A194142411924

463E6C216407315874244A59167C652984639F47AE1E8C92

819FC1BB1E1E8E5C

6DD36A647BAF62BC48635C2A24096F3F3B7D7AA14440251B

5B52683A2C321B594214AA2B968312553558324C221A0E1E

3738582B163F38772B2C217C4F74256E042F91363B131622

172A1C423524381E42731C5A2338293C20627146336C3E3D

242F344C6C4546715C48493F5E3C6891418C839FEB5D6673

45B94C7D4C53494E

AD8EE9C478B3687CE9FF7040834A5A4936286D40605E0B86

615AA44829783877076C7A377F3B6F27531B183B284A211F

52419F3476252046164B1B367A1F6352221F52371B0C2545

2E432C5B3341265D101C38802538271C1D2A2E681534365C

92446D7A74578128412868593C01383C986347756B662F40

FFFF30C1AC534CCD

77705C69372284475880AFC3BC4A12522E5E3DBB5D6C5E15

4559314F35373F19294539386B3239264E083629192F2927

2B4A2A2D53341C386A2A3B6C2A416A163348711922284734

2A19562E4F41371031161A3033183D6533254726394D493E

2D8B8D1B695F1E610B4C40665A15216EAC894A30937A6E69

A557CCB16C3632B1

E83AA0B98E1B45357C83564F277C1384716349493E91425A

894FAB7E305B63566B41584E2D52461C55113E2138613772

6E1F2042166C283C286F24195B381D3D0613292E111E3016

401D254A772E132A283D3A1F1C42503A25521B243F403B30

497E12746A1A7F2D4B4F4F414543272D497DAE55E39AD8B5

268E553941622587

88E4648A81782158675A3D7C3C2B8B85AFE3998FAB6FA64D

4D715B694173D65791385F8B258444272B4513405A4C5459

424A1629324B7D1C66276737364547110045526B337B433E

4026481F2D523E16184A53122F5E2A4027822B41422F1039

1432586C5F2C782B3D88092C492268BE689E5D9DC06EBF1C

0E6951F989732D38

5331D6C1B64381803F4F094C6CA9B15C5B36CC8B4B574F63

4B5F36875B5E1D873C164D19482C51273E5B237D503D6940

161B30673A7C27553069413F244B1C4B0E0D1F065167281F

7A7329852C210E3139273A5F32453C1B2B24415820252D3F

5C627739604375115D21243A6A2B6B3A6252819F48751B7D

9359D78711587223

FFCF81A5FFEF65BEC35218444D9A81767F8793988D60477B

1A8E34406D5B8A17434A12473D143745636C38614C1E1A26

4527692A51190E5141120C197A1B1B46292A35335F4E6B1F

334062560F62363214322E4C3F2C28514018384E4D414443

0547273D71680E7148102BCEC6247B526985A40C6D38BD42

A8FAFF436D889FDD

88899668706A415294886BC0803C6619835893AD2BDC9D61

95ABA0CE208C466F4114460B3E657D1E439F40347D6F3A93

0C440D2131610455494024257F403B392E26192444281B2E

2E413B493C6E1321561F44311F2F47671C2711224810332B

688B1E437839A14E44574E95284462BA18D68824C7FF6DD4

CD90D1669FA9FFD9

A169A5D1EDBD514DAB776E409EE0FF855387AF572F4EA036

637F48194906503B682D734D60179B1DA812545B2135361B

377C52513B341A4F64333F1B29233B22314954221F16112B

395A2C20493E4053312C1E0E0D562A404D2D1F10473B2338

4111691315453C22A6813ED262305C91407B6F438B6AC1AB

30AA503986FF4170

BB3CFFFF7B8F9C3D7927EEFFFF7B33954A6C8FDF0E9A6AC5

63B925A34816277921842A6187114B61468949394889335C

21074F1D20342930368042255E4A3319112E371444412028

4D31435B3E3D44260F451B5E4B3D796A0D53143D5A88429A

2E0F3E29AF3267766B6689403E64A982A39B3F1E966118A8

EF3283B5A7564691

FF88F6FAE4D6FF87FFFF72D53F8E95FFFFA8B3580F72244B

68749C3321477E8F7D602F9816576051875D6C3D75664342

4115312712132C3D854E323526131424352A550E182C6417

67285D339060472433054B4D33503B4510283C0D306E330D

2B943A556E463E034EAEB960968577B1E49DF98D965A810B

7D90FF932A81D6FF

FFFFFF9550B077FB4E7DC5C04DABF9D675BC367D4BAC627F

1F773C4338439DA36F056C562D964B50375F2E0F225B3333

043D2545464A3957360B35712A320E152E864C423A78442A

2D2F57102E843226675A4E3C3B2E23413630099155953087

896C3E304D820E7D632BFF4E86935AC359FF7F28CDCF88EC

85606E37FFA3A358

5EB253FFFF7EB9A947E5B5FFFFBE50E2E7FDD45953445227

2C5210157A18854034605C1555568A303F216220417A6328

3C825859A02F2D236C413B452D693C34133E33322F492047

1430131232392040552C0E262C114049382A10822D6A5713

A14F6F4A9455783F41AD6A74F23D46B2755C727917EBBFFF

17FDE4FF32C13514

85EFFF86ACFFFFFFFFDCFFB835A13581FF28F754864FA55E

911DAC27483D31471571124539257E7F625B2A205A3E1792

476A464F4734521631266F2D26203E0B3C0A3E332F332B34

49252F356C251338551233433D165A3A4338254E6145186D

2A4D5648706D3632F8BD64FF5BA65053A2E5BE369935BA61

7AE5FFD597C5FF76

FFFFFFFFFF9ECC8035FF87B8FFFFFFDA6F80727CAA15445C

B0FF8368EE93694B78312784528A47288317476F66581E66

211F516833254A5E75414C20341F52546512394817452729

413F321838303D230E154B3D1E465B436477136B86747B48

9B54A587782F1EB8C15D2B4D695551A66BFFBE81769C889A

FFFFFFFE60FFFFFF

FFFFFF9679FFFFFFDDFFF4FFFF97FF52C48378619731D33B

95E36CE82D863B373313391D604247345D2F154E23646C7D

3C2D3C52484D4D1B483A4A0E564015374438141E2E480B10

273039394D32352F374C424826131D6047824F6657B7554A

96409E3C6221BF55748095C5B95DD25840816E64FFCE9344

6832FFFF93FFB4FF

D7FFB3B0FFFFFF82679BFFBBA032B2F7FF4E3F4728C5FBE9

FF5D6970B92FD941A22A9647599582188C5D645430435A2A

1E10633B252C273444463D204B40513D443F5C303A49500F

21302E2227334A0731495E5A2359304D4E3F3E335C21A710

35335117B33F36A35632FF47B4FF66839DABB96922BED6F4

FF87FFFFFFFFFFFF

0CFF384EFFA1FFFFFFFFC465C143DE744BE77FE297FF69CC

485FCC1A7024595C62394A7C813A7760598763104B232E64

2F3C3E734E2523301856653F50296C321C444E1719342328

2307290E0F5623321A2E0D1B75345A352340463220541A3E

B025AAC5595C9A456B5D64D556DF4769C5A911E1FF54FF7A

F7FFFF8AAD7776C5

FFFFFFFFFF87C766FFD7DCFFFF7AFFFFFFB553FF979CFF36

79C15052810E94402825C68888DA688A780B7E614541393C

492C496A273C347B3C475F0B16542E1F156136331366051C

492E424943271E2D6182122C5C5269554804485A6A625438

CB1C109261604BEE60D841A21E8EFF47A5DC6AFF89CBEE91

77FFB4FF84A3FFFF

FFFFFFFFFFFFFFFFC09A769524FFF0FFCB1EFF6D97FFDB5B

CADE5C8195154A285C38545F5462694D276956204E3A3D55

634534103154142E2817290731152F2A2D07730C0A49572C

186719433822244E5D9C142D09355E423324192C2E76AB37

7064732B0E558729C587FFFBB0C6E4FF7EFF6D9476FF636F

FF973EFFEAFFFFFF

FFFFFFFFFFFF99FFFFFF3426FFA1FFFFCDFFFFD897FFA054

851D5146566C284C3E40A16872357C5F3C851B555A216A44

09544C104A60185415273E4F5D5B5939265F8B1B3A2D5436

4A43215D1714317749253A2B384830395171296026195F43

084630603B3A3DC45A5EE6E79934FFB63A6CFFFF1BFDEFFF

FFFFFFFFFFA8F4FF

9B36FFFFFFFFFF9D3DFFFFFFC9FFA0FDFADD7999FFCDFFFC

A0651BB61D5C29596348B0462A28728115BF578341302E6F

39192B0F74271C3849262A471F5D355720886129252B1A36

7B0218443E4814226129411A33253B2828644C39585C3046

55641798B9B04F575DFF3ACCB1FFFFFFD9D0FFFFDCFFFFFF

FFFFFFFFFF81FFA1

FFFFFFD7FFFFFFFF2E66FFFBFFFFFFFFFFFFFAFFFF9AFFFF

347E7F71706144308B1A5B5ACC26BF806B27236F6A63455C

677718336558171C6A0F402F263543661C3E400511293039

3D2511222C0B240B3140285426482A507D503224602E0560

5D153D3A36E719127EFFC92567FFFFEDFFFF71FF81FFFFFF

FFFFFFFF81FFFFFF

FFFFFF9DFF9BFFFFFFFFFFFFFF63B4FFD7959F5216FF1236

AE4A73B935755B4FB3268D6E7555219B7E3C776594374124

345B14193F301D352E2A49352E4729414D152C2C364B2633

0939263920273B1C50402E451B516E62117B2E2564606018

413A4A9B4DCC6350C060FF4FEDD2F5FFFF8FFFA5FFFFFFFF

FFFFFF75FFFFFFFF

FFFFFFFFB0FFFFFFE5FFFF33DFFFFF672DFFFFFF49FFFF7E

FB60FFA770D1B9D9737E353D5B5171510A8D3D4290344643

1E492A29372D106F284F3C6F3C5A3A1B173A351E32492858

0F26173D0E1B452F405D4F710D50631E67AD0E1948A33633

68288C7C7A809888949ED68790FFABFFFFFFE9FFFFFFFFD1

FFFFFFFFFFFFFFFF

FFFFFF95FFFFFF4BFFFFFFFFFFFFFFFF66FF65ECD47D20FF

FB9580B0E7C573A632142078888A261B46524D1341425157

342D292C36242E326451483038195231041F2E28183F2C16

363C0F431A3A2B543B4507412C1246637D1B531530831E57

506DFF7B5C46198089946363FF5CFFA354FFFFABFFFFFFFF

FF328BFF8FFFFFFF

FFFFFFFFFAFFFFD5FFFFFFEEFFFFB5FF8FFFFFFF43FF9BFF

AC5CA2D58C15ECCC265550268434453B214D4B3A6D0C867B

2D05701843284F311C154D2A2834512D2A402D3C1C3F2B55

131540410B56241D1231212022502B4D5E1E3E240857329E

3445A259755F4E1A49FFA47EFFDBC8EBEE5DFFB9FFAAFFFF

FFFFFF7AFFFFFFFF

FFFFFFFFFFFFFF64FFFFFFFFFFFFFF67FFFFFFFFFFF1FA39

80425EF3365A4A4EAB4946588D3620611E61276F474B3853

150E8B474B360F2E31280C35291114212C302239380F2A68

3827569D3E18471A2B063B163432636D201C6F44AC5A4D78

25AA55514D7B897537FFD0FF30C73CD49CFFFFEBFFFF18FF

FFFFFFFFFFFFFFFF

FFFFFFFFFFFFFFFFFFFFFFCDFFFF5CFFFF4AFFFFF3637BF9

C83D54C31ACE5568739A7C6F5A65764C6F4E3E3E3F743964

5E5B135C2C23270F291D0A32254C3A2D2740231D2461314A

1F136158283C483F28824A2829501678583B5C5BD8301823

0FE11A5BE19EFF9E983AD987ECF1B25952FFFFFFFFFFACFF

FFFFFFFFFFFFFFFF

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.678571 0.00744048 0.97619 0.30506 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.00751202 0.0192308 0.00751202 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

128 string

128 128 8 [128 0 0 128 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

7FF603C133AE31852739D538978251B1DDC5153B413E1796

997AD321ADF85D28F5A6835F55FEBBD6A185E83DCC0A61FC

43D695AF319A169D09A05AA55B1C59B67F49A6E3A45AA55F

F662E965CE506929BC039DF533C2177A5E294401AAA07C59

0AD7A20752DE2C856669E8C1BEC4EA3A224EAE7D68C72AC6

D87ACE51CC3EFC09

EC349776A262D3196BE46CC69A3F15225E5B50A5AF91E688

F8E83EAE388A19A25524D7890ABADC68623491BB4F71E79D

D97A1918D73DA6E497730D0BA87850E52CB3542E7AFEEFE1

5957B4544DD057BD3CBD0D5A2D7F899F101EC9B1703FE60E

386BF28BFE8854FAC1F1FBAE3B4A52F0A6D8A338EF9CC968

7C1059F248B6816D

F88A6CE51FFF5746E59253532B09AF9DBBA4D90788015B4C

037EB2A5A827A1EF712FDD12913479471BAA01F2B74C4D49

22F652EB88D5871F4206A391F186F24EFE9DC3DA019B687F

12C47AF58462FD9F945266DAB2E0D137C5AC3A7D2EDC5D85

B181D92C9B0201652C617475DAB90EC31C76AD4CAC2A98DB

47ECA1AA0901C05F

DB3DD055ECA0D5D3662B700EAFE5BD0F2E262A8B427DB6C5

A00F3818FEA5333D698D4CB643A40431E10C84756F49B755

04A8DBA8465F26E83CB5A0426E1CB6B2564AEF699B70F905

47A3338BF01382A63FD0EE7F74456D0AB02C8475D088EC67

28E63B913CA874B79FF4980C4938B56D993946CF6AC032DA

D4802786EA751CA1

6B842FCA983B27496F6DFCC0EF6A3F418E8D98C0D8C3411A

631EC74B69EC9E4CD0FDE81CD7C42FD061B27A0F19DFEDF7

7B28CD39D055D4ED8BB011A23B7F0751E2DD7AAB072A8725

9E37A9ED78D110FEC3555C8600A205D27F9FF4117E28931F

3173D996C93414F32A72E87A93F88BEB3EAC2845FEA98764

07FDE3347F84FBAA

43EB9D2575E24C5ECDCDCC2542785EC5A1EB0C154179407E

25BAA7D6A44DFD0851DFEB872D63669EFB520FDD0F6C63ED

95CC9719E00BDAADE2553326BDA0890DA4AFF45E48BF3FA9

42EEFB502858A64EA60BAD46D555F1630AAE41D111A17ECE

9D0D700D2454AF6CAE5C0EE543AB554536CEC58E264BFC19

6AB889F01D3C80EF

953FFF8F044394B03AF93D6B8BD1DAC6094639817514B4D6

CA4F232EEF684BA6D45B6EE8A723B909642D956D56D3DF7C

1FA2338935C48D4DFCEED9AD2FD53CFD7C348FD9C732E24D

245F92CAA18418E77DE058FE64088EAEF039C984D7AD3B46

2F96AAB579D0501424E708741B91E995F111DF327448D1C2

AA46316ED4E225ED

30C963E4AA62EF1DD57F4CBCCED0FB3E4E4BA2C0B9162615

4B699A85E8DBD815DE7526D71F51633990A3F70D9512C233

8122056AB666E34447DE57964D7F4AC9E2CF3E048445768A

BD922B46EA010A8226881BC404AE4F4453EABA305B34C5FE

D455DC266172FD5F1AC8AC87123EEFC47B6C63DEE32E513A

A6C8F0BA4C9EC778

E539B5063EC787E53040A5B3FD1A4586C2B1B72E0118D08A

9174EFD64BD51D4A65E1F15A4CC2B8DD412423E4977E35A8

C687EFCF375BFD00BB50CDF46401D360016004A193C65DFD

241AA4DB6CD07781D913F08579691EE1307C51CBD4D2FC65

8296103B75E0E1A79B25510794AA85F9E5065A469DC4B124

F98A6208B32691F1

E654C01FA757DF1457AFDB1ACE46B29EBEC21E3E4C85A50E

3BE12B35C453F98EFC4BCFA3B1E22F6FF05DC65CF66BAF96

09278C7352C253E53FC85731B44B84F4D814B34B0A55EA94

6F7B08B100721615BBB3984018D9E471BCAF0646D64B881E

CD260D90FE3658FA86A22CE5ECD5565B4DBEBE3F34DFED76

25CECA35B875FB6D

0B99C43353D00C14A56D8415307D8FCEB62F2A9FA2A92225

D4CF722F7A4E74CAC3DB49ED696495685BF495D271F2D034

98C0AF57E44E0F6C6636CBC4E50B1E674F704FAF9008C19E

FD2DF02F6C35B0C9A7445B3BC290CB30C339832192F4A18A

4705F2BBB4715E04FE8AAA614BD3CAD72A2A3BACFFF29F79

45FBB676168E1F94

8C3F34CC65BDE94C94E4E03752A8B3022E1B986FD1FC08B0

424E0982BBC565211D62A652C366166FD2AF138741555FC4

1D6F1A567504A0F1EB9044386156C88CF6DEAAFFD9BF4731

76C5519B28DE66993E14E1E75712902373FA23AE51AF25B8

E7D468932911AE92481AD6016436EED1A276F32291420CDC

C14B7B541CC548CE

75C3ECDD713F119BA2FC1C8993F3C35932AE8FB0081C5948

7DBCBAE1DF42FC386FC749CA9A07D30481405E30CCF796C6

5A679AF2BCD247CC6C4A9D98F4DEEB01EA71375966C1C8B6

23342143D9770F0E3A9AA30385BD38DC3289D865015939B9

D8884C5FE8DCE178264847BABFA5442FAC4941E9D09E03DD

8347FEE3A35BC741

4F59E54FBCCF5F44EDF566843AA30EFE9B836E0B0578945A

2CDAB74649DF7F91E681DD943045429EF586AFE44978FE77

DF9202832FA5D66CBCCC19F9D88F5D676EC2EFBCF159602D

91149EFDA536A3A8F03634BF1F9D0164D6688E34C6D2AD1C

482DCCFE814B410CA6C62647D0542183EFB862E0FD66823E

FDFDCE7F2DD255CB

39C4027A9332D6A07703478EDE3E2A7C5399F3D97C600BE7

CE833CA5F6C679E6D0FB415F3CDD97B0670C292D50DC8529

7614A336B95D10E654E2836B75C5BCD70A38B760968757C9

1DEDA0B45E184C33E6AED3571A53FA66A00364F04B0BB29D

7F6C3C0A6DBA5D2B0690947DEFE59A6B2E078C3BF0AA3F0A

C3712FB921BA43B3

50C86F14E4CD5198E2326FD3501AAD45BAE4863955D2BDF0

A831B44E78AAF6FD53476FEED19A403A26B2D15CF95BF689

58A02DD1E54CAF5E36DECFA85B2C1BF492EC74B423060575

D7773F4E2ABCEEAEA04D7932BDE49B1537EC15A49B353160

CDE15B9A1240A6A5230B83064616A2B237ECC96639CCD478

D2C230C854E68BF1

CA980F79ACEE74FE1C588E9000F83CB5A915135537C0DA7B

29B959C0C92F2C780497A5FB8A2C050099227BEDA6DE7409

12D7BF5F47D248EDAFA43E27E7C664FB1B8FA75F1C34BA6B

893BE0FE1D57C06B84FED8B7563C65BEC2591FF292A4AE26

791EA96BB0FD0F357346DBC5A879F34670373BCB2DE18435

049753F8A5FB882F

CCF0F3A5EE4D02B1AE3BA4ED355B878D032680FAA73FD123

8B62C4A62103993B7BCEF9D613506ABB8E9516BFFA741705

B146736EE7B0ABDFED48B2474183E6BB996137FBA3C15FED

333B50BDA4AF3AFF43B5399CD0633C281394A61C1BB648B1

74D40FD877504ABCC4CD244D666B34D0B53A06D67D1DD78D

2D23CF3D960F6E37

A34C448E08749BE7057DB60A57FA7CE2FA6A1BA5C3F647D8

D1AF7C228A5A2F94E9FA015E5EC3AB57FC0FEDA0631448AC

7BC435E4D2D24345542373C4CF12B034BF46E6B02362D123

C7B7B139133859A149BDED3AB0A7D23EE0CBAA5709BEED33

3078AA1EFF6524F75C725EE8E4BB4646BE7107B64E60F757

A5D07023842A960A

77F25CDCA7039219692FEC4FED79C75A34C192670530D479

717544FBF58388FD9AC29572EFE8F607B878D43E3880D915

033DD25C6F47D6B1BE8D012267406BAB19BF94FCC3E5660F

5EE59B239AF23ACADD77980941F2A7A6561BFEB1775698BE

C82240F1C7DA964AE39823382C9E7B00FD98541526A90BC8

50FC6DEEB734B824

6F05FF38A944C1971EA911CB6A91FF158538CDE662136398

DA14019E6CE4CDB6FE506FF5BA2D4B80F2CF5F1FDCD39843

F92C5CA108DBA53C47E85FA35296E4DCB839FE6B62D0099B

FE11227A4BA0C39AF42736AEBB3C35D73B9260E5CEF52D4F

86C3876F7BD61C3D60E6CF6EDBF3825F2FCB4C22B227555A

BA02D151B135B934

1CCB69AB2D7646EC7C72ED297DB428D7D68739FD018357DD

2A85A67608C6FF6A40BCC7A020CE7F178B5400BEEA6E6A1D

37ABDC2ACA4531820F9ECA38D690F9614CB5B21AD1450741

AF6A2FEEDB188255C42A0796AA76165FB9FE345957C08FF2

1E7EE14128647CB3FE248B733021DD771CEE9043F462B3B8

1876A843D76FFA75

B306771FF378F58430B2B557F27DD04E5EC33782C12BC9F7

A5BD5633B0E3C846A1B80F3C2161ABA6FC2ED19084383991

C87150D843864C0AE68AC8396CFD41CCA4214929A2D78E45

F51598985E20D7E74FB37C3EF5DAA049618ABBE83D34069F

881CAD8BCD2E03A8772E14C96E36BFA44DE6CA382C9B2EF0

7C19B235E45FD857

E056D7C94484951287040B8C6DD6FD8F7E27FCB042B7B569

603C9BBA17176598375E03E171BD4D4518AAA0F95229B6C1

94F93460E549CFDCA5056813E6A55972E9B271BD16E15F54

5EB9174499A316B6454E76FA57A592F2121E66B9A05898E6

84E43010AF76A2FD956BDA2FA66100C2712624A2EDEE8134

8C0BD17BEE64B64E

AF68903FF652F92284C5A137BDBD5C2DE95AA020B14B2568

13DFC114B3704696F1DA94256B60E85AD3CA3B65F7B7D07E

3C3FC49BBBF43E9E552522C986A0280A0128E77CEF48AED9

9E63CE180772AA6EC5FDBFDA4927F4968ECEE475123337E0

C4930EDD1F844E2BE19B3C1BC9A72EC85AC8D4781C7154D5

0E80FAB04B9511E9

C4562EF23BB83EA00C672DC081141B9C6BE34C3735AE72FB

7299A54A103A97DB36E7496E92FDA0F265AE9D0D94694719

4FB29DF96B835039ECE9BB6D13158AB69A781CD98DAD4DB7

1DD476BBD11552C4422344A0A4DCFD012584553AA7AAB93B

102D9034E1BDFA61D0F86BCA12836E01A56428E734BD6911

B14CFB7415AFE051

B647F2A62EC17B2678D94290EDB7671ABD2455C06CCCFD4B

966C08C842A3FDDA29636053BDE8E37E366323B1B83424BD

B0AD3B4E098FE503926A81FFF08709C40E5E8DA420A1D46F

F0FDF28240307BF7C98A0D1BFA764C9D8DE8ADDAFF203C69

9BD7FA7039EB834C18BACC6704F8C45FD120ADA46ADB762F

B71E64E7D0550050

501BBF59B64AEA966A05C7A248FF2A9FE3585666BD014559

79C1D91D866FC439E0668FD8041331758FF684C411E09584

60E8EC37956AB91C2D4C0C03BC4C9221FDEAA938BE18DE45

7D7AE616C7AC0D426355C6B3938ADB740E0A4F8094FFD066

3A64E1D0692821B879F7CA3C31B98F3A309765CC53039A22

AB5DDB602478BDAE

209DD0065ACD6D47CB5158299F0FC3A440B2ECDC72188CC1

BFEF27708FE92AB66CC40810D76DCF5C16C9E741F152A586

EE1EC2AA830A56259BBBE485449C28E173B419DE66A6F5F2

36CD3B123CAE9315FDE79456170F875E97C2F45E3E59B2DF

6430149E7A40E0A15622AEAD9D2830D8DA8C12F99B47018E

FF6425973AC9208C

280067F89831E9A1170D61A0DA5D5DE3A6208561EB911C7C

C50E7A83F58B10758E2ECC760C1A77E79526EC8536BB9012

BD80338627B335E0A48DA0614D11CD6B2565C507E265A1EC

D665CFB1473E1AB26B3E16CA8CC9E32A586087C9C8383AB4

AA8C45EDE7773CF29B111AB0470BA668E6CC5957B51EF83E

3DA623CF36B543A1

FEB57541F9BB52087DD983D0381CB05DF5915DD6912999AD

26845AC7D6DE5038CF981A187AB727E186957215882F0C82

7B109007EF1D8274E41C96E5A584260223D05F9000DC808E

5516397582B2DD655EBA1533216287C5CC094143539CED1A

329E18149B9DCC05378417C965AEC3E532DA62FBB234A428

C6550A832FAF0861

C967F599F34314A1D55138E4A0F085E8476CBD31072B7FC2

DE35EAA2042D99B18F0E76A2046EFB7FFB5528A82CE3F87F

19951FCC6DA1D2E7973D4B0ABE168E610FEFE76585CC1865

97B28A01CA47023B6646BEA9BEF12850F0D1AAC620197964

ECB88966EE7D4424C77827F7894CDD9C3A44BF1AAF56EE70

0C9F3897D7843CCB

BA51BA40198CC1903A28B123157E910E49D513DCBA6FE510

1AA477D5526346D8FFA54E035D00B21AC24878E6F7118C6C

D53BD1A53F59E751E8D88179F7F91B7F87D1E246E9B2723A

EAED46928C0E64BBE0C547454C9FD3E8189D5C5A07CE9D33

2EE46C5501E89C4C31E4A142B02C5276C3EA6745E6A51ECD

4BAC77E760EE3710

82380AF288CE164AC35707C4356AD9EE11BA9A234DDDAB39

68921A024FA2DF86E852CA47C9C2C6414BB4C17A11696BD1

65D64B35BEFBC19E5369F3FC648C60D6124DCAFB603695BB

D38CE41715BE55649219D6CD38254E8A1B1CD5B76B27EF9D

6624E0BE3B708BCA00984B2ED57FF6DF5635D5A50E67FB92

46D94DDD50DF6CDD

40E19A6D2604870725F187FD2678D6116883E53C26AA17FB

41BAB6DA5177AA0D61538DE069DA01722C8D01E6BB6BFD97

37DC78DC83A1BF2A3D61ACC0F56B52E8F03B449BBCEE269E

0A1F697A93B3F1EAFF2D518FA2030EDEB95C46F884ACCFF3

6A2AC3986FF7E46628D1B3DB815C34CA65DF975B0EB63EF7

B2FD61E98A1B2BA7

1F9F0656BB5751C74BB4833552DFBD3460D5115377BD0F7D

8FAC2E4A23BDF8E437C736A0D12C3552BC3BD8405F99C523

0B7DB7B813953ED6C07547563FE2932DB3E1FCF86A33B35A

1FA4CBCE221B55807CA40AFBF3C16458557C21C6076C39FC

A8973CEFB155E3B561E65F4ED1C45827BB45E601BC6ED198

4A079A384BEBC716

20A8343D788BF978F463F0ECA0661749A5E61F819EFBF75E

C4ECFE26AD4DC14497B5E14F0CB93BBC5BE1536698CF05D6

7B5FA727F940AC77E406C1479904BB38D7927640EBAC1ED6

5D467489CE30E507EB64AFF9DF677101F8919E3ADDE55F43

AE5CFDE89DCF3FB74705CA932A4CEE98A5513EA120A33BF0

72DB77FF96D7549F

EAF07C35EA964CEFB42DB14A21B0DB69F3E41F78B9F248DA

9DF8795B59E11290042B86D8BA4AA39DF62A529C91EC5950

85CB2D4A9FCDD507898C2DDBA69A926B18FC65D8045A7BD8

93ECF0124E53A868E6F095474AD29A9F31ECDF345AA98A45

01D45D27B882FFEC8A6B07C90BBE68FE0FE22E9054EC744C

A01F9426AA24A536

9232FF9F9116729BB53D18EC89D96F41A5D35C77D5109275

020757CED67AC51DA3708034FF9E55E905724DA20A3131A1

910BE85B6BBBB45432C4BF903831FB964487AE9D38A426FB

149955BCBEA3A1F64837789C8E0EDB294879CC9D2E02D74D

43DA8A47E3AE6927E6FCB16B56F2A0E04397E5EE69707931

0048C747D133830F

9E89567101947BEE219EA25CAD253793D81D369FFE573CC7

B130BF8F1C0127735DF3AB993C35D14362BD71C2F81D95B5

D62450C7A6283FCFDE811ED68844F8DA9C14EF374A85B903

E75ACB6DAB1D04A855950310983E97B88DE6E581521BE88D

3F76E4913EEF27F2A97735DD8A42D444DC7100AB35D919C3

6A48DD8D754B14E7

6E1EE6A1F77D1EA0158A0E086AB11EC928D879EFC3368AD3

10816C20D87775CACE992D2279B89A14356FC7034E6982E7

F646AE97FD4DFA9B93DB7B3DF6AF730979FE83342DCFC639

8EF23EEFCA8F216F6661E0D31E513EDC948516F778E1F57F

7913BE0C042C927B3CF78CBE191174E7E6A25440C0217A25

C85CB644F3EE85F0

68E45E880524B35427C5E18B1129869EE45528981106A758

035CE9BD574050B86437E3B73AB5422BC32FF4901F56A1DA

1E827B09D48D9304196177E735B7E24B3655EEAE79E9E146

65C3CE4C4E8B882ACBF7325584920324C50F48A8C37825D9

A91C1DA46E36AB27C775196F9AAFFA1E4AA214026105AA04

950DA086BE469E15

42BECB23A57363F27B8B044BD5C758D21346ACD6137DE1F4

8E55A9662BB4B79BF6C9415F9E19F38B6ED79A287CC4E736

55A711DF33AB5CA242F589A001FD3C2AB9406A1DCA185161

B47A279DE4053422719D9147F8E6A43346AC4561C61C54EB

EE85531590F7CB9722FBAF2B8615B2920E0B900E9D0FBA45

DA7EF066AF3CCA0B

F29F38BD64FA566A57E94CF6962579E4D4A584112654CBA8

48B1170197B42E6F7E1B57CAD9F9776BA2D30EAEFEBCF157

7899E5333CBADF157976EE226A21D57AFBB42E148AF63AA7

DC0B8E3D64CF93A2141A7F3EBFE0558109FF943E04D28943

F23EA0B0097D4D3C3E7687C4D327126CA9CE0D6DB240178C

1E960C991AA75B70

C90B66A00EAA65F67BCE496C20DDB3AF652CDDAA6ACCEA49

E25DA2A12CACAF082B17C190B24A4EA3E0028C46BB545FE5

8F1D15E07D7A2CCBBF2A58B3DB467E0EEC944E8FEC4EAFB8

B21D29B0C63AFF856C01FF984825E0855C066FBE272E7379

D0B1181E5444C58803C60D355E91F8CE49CE62E88329C179

E4C61643D060F55F

C11D5C9F9433C6834AFD4ED915A4740F099B980F8C902587

43C9F30BAB2A2BB4E67F86022D9BCDDA1B4852A5BEF61E72

0BD6346DA8029839E07FE2AB341ABCA6229AE069A8B9AF15

2A5769B4983BEEFDFA644EBEBD40DDAD7E2FE8AA595ACFDC

4052C219958206D93A954152EA4365D2DF068847E288AD45

1367F17EF593D83C

AF3CEF6AE87CB022C38A2F8CB52BB9BA2479278828F5F118

8FC10C6C448EB40C51495BA915569752D44DFDC01D843F05

BE973337C5D1D44B2C9B7B049D81168DA02BB42410327CCA

C579E22EFD3F66B39A6AF0E96D4163DFE475ED246544CFAE

0C775482E6F1279A2AFCB46CDEAF08A053AB402FC89826AF

66DD51C7DF6238E7

741984F0884DC97F67017B06A98A1DC99121DD238E885CB2

E3534F29C8D3336759B0044772C0F7E14E3B9F38DB467C97

220A8FA7123FE5A477380BEA4C81E8E05DC2EBC36DD6D324

2D999DEC1E836D4FE4C75620F5A356ECEA3683D6DCCFAA2E

62B0DB21B8BB3A2E8001F0B9116159F80F15C063EC5BD653

027C42A53AA705C5

87FF529FFFC56048D12CB99D355BDA575CB54A1192E31409

64BED53084DD9D0D5BBEE2157747830A42B7C6123268C1B8

34522740C3D05E67E7B7BA48C57557EEB27338B8EE66DBE3

6FB8C04E1AB6A216AD42AA6F0DA0E308658BBC5E2959BEA0

4AE2B0D8425748D27526CC8224E081D85C26A851076722C0

41AE3FC628BC5480

2DCAC6834B90DC2487DD5B4DFC6DA308234ECE9E2BDD9747

93092C9323E34177C5108476E9CF127B7002DC279451B800

2361A5FAB4CA79E32AC3784BB5D65C2648A8B93216D2F271

B51CBBC779EDEA1740BD9D32E7CCE05D2DACE1F48A9D234C

96E22261D5C6850EE1B744DA6BB434059A2CFA37C202AD33

0275057CDB83FD7D

FA8238AF19702D25CA61CF23880215A4A3947AEAC06218C5

97023388CBCB3389A4E535F49829E974AEEE033445B0FE49

4079C5A21C5A0F90C225289F04BB1F8686F8214A6B9BF2A3

8A04EDB660F7F8916B25DEAC5DEDD767C3C926772DC103D5

59CEBCA6D71F860D7A31B04C22BAB0301F89D39A28AA2DAD

2BC045D63AC5597F

DD5DCBD23CB50688126A6175FFD4AC662BD82345DDCB965C

00B33F61C624A04C3D18D57E9C464BFED064469F73E84808

8A6A100EF019A4045A40BB4F991C0E599AE9748588F6FE1F

747232D9AC62054A95830437A9489219A4F30812B25247AB

AD2819953D2F693FCF8EFFDF84134947B19C2BBF47E2B965

6CE96AD48A6D3689

BA7AAC2998695D15AFC420C98A8028FF900402C47D09E458

C63BC9A64D3F8F02D673399E133DB4F8374A7F6EF7D93DCA

7AC4062B529484BD1B1238BA2E6059B7CD0C3DC0CDFB6FFB

D3903F4EB2F74CE7E0FC4CB583F181C23C11936209D71843

C3D054C4A307DE6AE6556D0660ECAA3DEE95D36438915B0A

AFDD57E14BDDE13E

93392BF98CD8F8942EFE8F0F387A07B0E6AC623BD8F25F93

E21475D700107C80F6699122DC8C607C72E60EBB891A9567

D7057775CB99F2442E8DDD28792AD048FD5690AAFACC4E6C

EED62F24E3916B94D18633CCFC892B81E63D86EFBA4EA420

E863BBD93A5DD14FBF3D0AD29020DC8F046A36A902ED4DCB

61E876048AB645CB

2BF2AEC3810A4ACDED6530C6510C5FDE7117EE981A3029B3

305B56EFF56BA5F44513FDA84D49CC03128A0D027D49F1E7

C8EA5C557CF871138799100B27A27E096804A3B3161C9C21

F4F3A44D2ECE832E0B098268E94EF2B1479A9F9F3B035F8E

FA7869D00DDA8C711DAFA37B662C1667AFF174CD90BF6034

D81199477403479A

6BAC893D9116E5A35FCEC86721C48FBAE2B56912C24952A6

1FC4C4791C7AE1A737D57005739F2CA201E981FA1040D6A6

515117B508852592B7CC379039FEE311639EF0D12957D0AD

3705D574520AD2A03877A2FF075975F0A8440DD63B53B4B2

0CE6D9567436CDCB4D781D2AD869FFAA28D489F9532802D3

9CD75EF167E72DD7

352218E9B4D2772AC832175CD373EE65051ED693E96443DA

2E6F39F48A68FB16A47CE0D12331C84F3B98007CA6765EED

015A975120CEA555B10BD82C92981C9F6290C41F6F4EEBC2

794319DBA742DA474E318C0AF28FF8FD77580CC0C14B22F7

22725AE9ED8B222442D4A56B491FBF8A007C2A15B2159824

B33EB954E90896A8

14A3B847AD890BED953BA412811ACC1FB79095312014A717

62B1A4331CB18E2571BC70F5069246BC9CEA9F360CBF7329

8E03BAC3592BADA7579E4FEFB852DD46C76B1B06739AA318

0CA242B23A11ECD08535E3BC68A58148EBBA5C0C7D6F1CE3

6FE289EF6B12065EB5527307C38848E85ADA55648D0EB468

F94ABD149DE7377F

ED6B14D1730C70CD39D469FD8109A81C744004E0936CF1F5

549A1294A3EA0D5D7D1DE49C784909B93932A36A7198FFF1

F383231767B537B909FD776EE3136E05BFE25F7EE6932B1D

906DB5E3F97D35089BB2A7442BE2A4EC800EA748F3CCBE46

52D29D3204B26BA742A8E59F3AF8E1C746A56A001BAA6BFA

9452CB7F8BE55D0B

C536BD65F013C420946A10B9367616A30A9D7CB234D69B22

6BFFDD7A63A13AECC4B44F3D12C56801A844FDCF492BE797

622BCA0EC871C095C032138EE116908419ED9A628CF89764

05CBAF3272FA81ACF73807BF91EFEA6720B2609A609110B7

6D19DD52985B0A2AC4A657230EA2FBB483093EB7B051D354

F37CCE32C451C814

8B7E270CCD5FC88424EE981795E1515EE064E326CE6A1144

ABB7048B50FB63916B2AB6D599A9EC2DA709454BC1BC5438

DDDA4E4F97A6E909726DA83022D7C36A3614A5A736DC276B

9FE02C1E3ABAB927857D0C72A50E22149D5BF8C71611976C

8EB1D6652AE5A0CE7925D96BA9B1502AA227DA4DDF92D334

E4AB1547830CAF05

6521E99E8A13A03FC828D379FD6CFFA840C532B740BB329C

BA485715D1BC6F3DE608397A21027C56EF98F492511633A2

3BBE1F721AEE69C2707CFCD53C6D42E2A641CBB40A3EBCA3

1329D763A9AF2E37067B4EC8AD292A760EFB7D42E67616EE

A21830C2B8BB555DAFDEEE7A47030BD735FA7FD2584BFC8A

2849026BC04D94E0

46C74C5CEA7105F163ACCE7C64F7ED73C3044403A41BCC56

480104A8742DF8BF7C5DC2DBAA17CE7841719A33D97F72FB

AB470E64D781E54788A2F35CA083FFCF4169D6F59C103EBD

B06539C9630DD569A8C26933C63E59ED9C333C049BEF842A

C44CD482591F46C3CE5074EF62AB2D3CAD1AAA64DF4816A7

ED9243F1E4714538

3BFF159C36EE8E0A9734AB2BBA9435CE1D9FC25AEAA8FEF6

CFA9602DBF81A422E8923A660A0E738D9B0959CB805BCC8A

23FC77A415D0556ACBC56003549EC712918AB6049C72F902

F84571A5E5B4307646DA67AC028CA4AB2259CDA637AA393E

DABE4BC8E4B5763A035AD57B5DFB81BD338EA00628A1B4A1

60FE128BF42EB9B9

FFB17F87EE740776F893D2C35444ABC7340F64C15D033F8B

0A3916C64264146182662BD9618112E527B1EF9F71CB4AFE

A54FDCCF4101D47F28E5686DEED4E059FFA61F2B1192971A

D7802BFEBE3023B05A01B5348E60104ED81AED7E9E26D499

7D9EEB9BBD39E9C6F574C0FCA23E9BF0CB3854BBAB3C2D6C

0789F88B1178804E

C44646D10B74ED019F5E4B5ED7F95F71CC427E04A2842AA5

FCC5894A1B37B44125C1C655C85832A6DD545B73FD539825

B989CF4B1A5A8EBA07FD068D63FB49756EED3861ABFC9F3A

3495AA2FEA5B8803DC7533A47F34A6F664728CF1F599C56D

17DD5B7E40D29F563009015715A53D60E231CA6B45D454CB

68F57111C963EA00

B9C7BA8E1B0EBC6D1258E9B7209B55E552C3D2549D108BAF

313CB9E0A67D2BB33BD57B1064FBC3CC6312A6C139CC963D

57962AF29C36C69A4F42C1EE630A2996BE30007C5FA30C5D

77B81A7E289BF1B854048D8026CC658EBE8731E855243DA2

834007D28B57FBFEB7A933E45BFCBBFB3C8C12089B833153

9C0EFA8E15A3B338

9A1F6BB23F94FDB6D77503B4A72D8005CA28F4FCB8851121

50A2AA44473DCFE75D11E98919BD8204F189D5D65237B184

F9C8D150569C28D6EC5C43C1F54B34BE591DBD92C32A0383

8F3D9611E58DE041C45DCCE9AE6D0B6710A983FDDE85C6F7

19C290432EE9A8B74563CD44BF48CD3ABF57009302862CD7

37C05FEC756016DE

74FA50F37CB8EA541BCB2C6D20B225D85DD5AF4E569426DA

86315F1AD59A294E719368EEE93807A462EBDDF15A8DF382

7AD84645C5E1D31F6094D823C9585AEBC9953C28DDCF5792

8DF6165968B0B12522C7AB433EB4BAF658D21356662A49D5

946E9C04AF74FB4854BBEE9531D91C9B1FA1AE1E6AE86711

DB7B37A032F3D881

3AEB37AE3BCD31830CAB2CAE4F48C1F67C4B045DF1DCA859

3BD5F5A467AD22E69248EF6E9F659F4DDF9815106E40F8C7

08537E058DCD5034FA9B6807739D6512E67B6FE91E71ECCD

3F6A3F8E37F135D49D6818D4B63002BB57FE973AEDC2B04B

3B13C55E9C85220094DD6429CB4D8362F55CE989C946EF95

6BDF3BEC0F9A42C9

12F4A21A748034AD6B059455E4FF955AB9381E07C5601A57

BD58944DFBCD622DADB941330CB758F17F135B1DD4BB584D

64F7CA82061C4A926FE2D46C1981A01D40FA91EC1C918802

F646C84A98E8DC7C0C0E00678E955CCDC646F6B687631BE2

82A2F2155C6BED65AB0A0E936C1FFBBF8BE357F67E02962B

C6328FF38C2EEB94

EB80C81862EB42B506974BF1729BAA25A517B7773CF88CAD

4AA1F9ED9410761D901CE39082F3A34514B77E5A97431CCA

7A2F13EEC54DBD5DF3E75C658CF9E49438B922AD4710B061

A85852D4A63C45FC71D68C40F3C960156343B96DF90A8F43

8EDA714EE3CC5B4E9DE858EBDFCE6A6F48E033E57EED5BC4

6A12F47652B8475C

CA5769F716AB46C14CDB67EA4DEAD583FF7540E0B6945A2B

BDDBDD741216A58DDD08DDB43E3FF3A7880207700DF573CE

B1B825BD5824E6BC863D14B190E03B6F9D60E3676DD327F4

4EAA5A31DFAE68A5FE12A1895983FF67C4B037CEDC2E1F83

5BE90497750BC690D125BC9B166C29E1FA9A118C2CA3E8CD

37D5882D4B16E7DD

9428D218980EA128632CFDD7AC06762BD755009627D5E287

B23432C98BA92619F34D4BACC429F2BB570F8AA6F8005D88

C75F2DF5AD8B2AFAC8522FA8D62E0F619CEE1C01C66FC833

486DDA7AF74AE8AEAE5929BFEF057E16FE5DD3608CFA8F2A

C8581E85E3863B3BE059ADB63DED964A1D45703BDE983731

A05C1AE96EC27653

D465B8FC8BB866EE27CB9F406F328B0E5098E9D399845C50

E28E7325F22F96870571A0FCC4606065B84E0DB116977DF6

F4D17C31D1B25B0C0BDE63E3E94C5CFB97F6815DD8F4EF66

78EC8E0783AAA31537180EB682FDF275EDFC33B6B25702EC

BA0B5A940A10A9A4CF4CD6CFE56711E88E21A0F3AD39CF9A

1232B5F57E3C510D

6C34BA4975FB89179E34B212FD56C995FB7023DF6F2DF5C2

40B02EA2C526449C17DF5BB1451079C2197ED4760333CC79

2E6B946E1CDBD0291093B13305556FA902B72FD586D72272

D1BB0D66348A88FA28986AE57644F1198D839F7323DD6E96

097F83EFFF288AEB1D6CA00D27C49D53194FF885C7F07001

D16B07277306D4C6

45C11E22B41EA82250F5A46EC79B2C6A11C255139FF992AA

199521F85C3BAB2F3CBCE728F69D6CEEC33D7E0E7C4AB303

1F18B3084DB1C06F2C049004323FC2F33248A69FD145C7ED

E4427B6BADD4F93B8535C226089180B5C8074BC2EC61C68C

29FD70C0B25936C439A71BF6823BFDFB6F00D77F7536DF3B

50EAA29667D65385

2276C992752B9516939A461DB840D4634EB8B6EC7B200071

30C096D0C26AE6D75254B8AD4DEDF70C5BE66DB756C8FB7C

6AB5FA9D5326CD8D8BE00109777A8B1665A6F1E366B044BF

A5FB5BE60FF1EF9575F7B7178C60B99B2F01B4B963812AE7

C2B35FDB399EC04CFFA3693422BADC27D499532B008A9E95

ED77F94AC32D34A2

0580A63AC529BA3FD452D255D7652C76E0CF4F44DDB34FCE

85F279E028594331A62AFC3ED288D9363C982812A25321DA

946E07089F4912FB755C0D6494B5DE077979E044FB60D7DA

3D6FF0A5E35D3A86BFB6014FBACBFC11518B16D6670BCA1A

5B76CC343477CCFD683AE79D3F15856B5C5BEAFD77DC309E

35DAD28FE650C77D

D282027C2483FA8AFDCC52FD3DC805D365FACB4B9425BB48

1EF17A392A9EDD1D69B3DC62750B1E53D2A21F3318CD6242

BFE81512863844E34A8E0D2DE9CD4657B7D9A3294AB4873C

D51C86354B055A9EDCFF47AE6BD823FD8F84ED3016897BEF

3A88BE1CDC6CD3F66CB86822D46131B1DCF75C9203B2A422

78DB236FB47C3935

787FAB43D739C051BE3FDD98F8AE57D9A3277E1FDB7D33D9

8A2DB7A8BD274F1DB55F41A6D6A143749AF71C5FF29055BD

52E95D49E5B13F47901C24991147C78C4D11A88A3AB74548

1898A12F3CBFD8ADCB473E97CDED3948BDF57CB888EA1D41

A4F262227BCF2A419BF6EB1C6DEEB54AA3A825A4CA6246D3

2EB79F3A0060AD00

8B3AFA58C55ABD83FDAC29A4139C3FEAF007A69EEE460FFE

7FD1C54447DE244F9DD1553023297CC91513A95C0ADFA938

1BB0927CE1136266D2DB2C29923C143DA21E177EB315F4C7

885B1AC0ED5870F5DD6883B924C760C4B11E083F8DB8FB4F

A698CC2C37D6B0AC1C4DA37771DC22DE6E36E27556F984FE

988036B2770F7BE6

5018C79D2038AE229950D96637D0BF54AC5FF75021934B03

D565D80E197DAB88F35130BB9ADB128A1B209CBE92160F95

654C99C002D11D863A3583CDEFDB4BD45F72E97E62FB8464

D3B42B2E3AC8CC6841FAC07BE23F02B22BAD68A9EA56A4B6

AEF34B71BB93F33E70E70E0AD777D886DB4546D44A73D075

3CDD4F83179510C3

3EC3276C0A810E98ECBA52771DB877F9202D9ABC15ADBE6A

C526F97D6AE63DADBF2330A5A65517D0815222BF4241B19B

050211C4674B96A8D5EA504657961F65DD5943E5CB541D80

1FC667FD5792CB29F48DE109415AADB7E4253264D2FD7980

194BD4D554F40C36BC78DA6F73F06764F6F08B5BEA26B102

B57C39CC6B60A3E2

36A00A9F2FBBE9391B863ED67C179D31B631076EA1CAF239

FC773ABBABE1E74E2F868CD1D84190F9A37A1FDAB76700FE

937A00C5394FD6E24D4750B11370B16B13F181B9244CA7D5

4034D385821FEAE2701AA0AB44B973FD1F5CB1B54D6F3EE8

D4F75053D35E5DA21DB61533955522D39A504C22DF93B631

84099A55F15F99F4

0D8FA458E566F369E173E8BF4D92F2315693EDD82C3B7889

C1C3B282F64F5FC10DBC762DFBC16B00F67EAA1F40C180E5

EB5D6C309BC271F42358C50975EBD14B04852ADE95DD1189

86EA2045C3CC1A6687A80E430151F12C5D9488062635A8E4

8190D14B68FEE84EB75734ABD9EE7B5A2B1B86DA6909B316

A895A9059B42C760

BDF435C350990F8125BA45F062F16FF4F16D4DEA79D45004

DD6834086FEAAC7A1114ABE3399EBA53B9CC5B1907B86E62

8EDDCBFA1B62D8854B9EAEE735E295BF46D5C302FE5F760A

BD5DA354CC20EE58AAC9183B83D7642891740CE661A0BE36

0964484BD49956AA710B1E82EC2953B9EC2DA7382AB4FB74

840D9C8C5ADC3441

97EA61B941795FF26AFB55FA9EFDEB5DB5E105506590E68A

38D854C9915BE2E35626DA873C57B7F03ADAFC6D7BAACD08

34D57774B1B3313C9AB91E16865111AAC9B41D48CA18889E

E6FB6C722BF6847DE1255EA9E06F0BD03CD4BD4AC5481CC8

9B47AFBFA84216A3FCA758F9EE67D7AA1B6179D6EE741E3A

D8AB4CDBFA77A11B

910F7A110CBB49A337DA85DE3FBFAB5D19188BEEE6417308

C3846DD3FBF341EC86800A1E8708E97A6B23C1AEE12C1F9E

9990DE703510C10D71C63930D2CB7C0186F68C5009C28424

6C6405B2026851B909187D96B1FC3890CAEB654786DDD266

31358A8827DF937EEF2C75C93C108627D736E14E95F7F175

EA5FE182085E19E1

6118EBB48A7222B7953CE626CA54FF8E23BB2BBD7522CA88

560DD810C16E1B89C07217E4AD7E1A19724767C167EFFC6A

AA57FBE2549234A518FC467AB5C810EB632507BB7729E17E

2130C0D75938AFDB294A6AE2073D8E429DBC2ECAC366540C

A28CD8FEE37040CF4E38C3A80160C9E2276CC8DA52A35D61

DE11846BFE8EA976

6DF07CCC2EB838B7FFCE868F96111A68BC1F5F0DA9944E03

19D896511CB87525BCB228FDD1623386B7D624F1716387C8

B7095E5C4143AA66EB04D95BC7625178BB6904CEC76F403B

CDAB4B4494A417F46E5ECECEF55DB28DFA16AA6100CB7F8F

5CE23A852931A8F8FD8A6DEF2A88A32C5ABE90267613E7C2

4A648DE96E6000CD

15C95ADB55D96BE05FB38B13AB6FD11DF0019741F436F894

7513007D47D8A22BFEBA7556A5CB2013CE60652DB5B86A0F

199757ACB1ED0F136C2784A5FB279A03E7946D655924D273

76F82A3260B5D2347AAFA6136E63ADD509625CB5452779D4

FA6FED1EA6A486076225B70D4687E01B0C96244FDEB54ED2

4B10B36915CA830F

DF60AB28690088248D0FC45CDF5EC1AE5A6711B3D56C35FA

B848C030621702A351BCA01A22C5616E07FE8E982006509B

14F81ACF31768BB9A229E15314BF896D28C744FB66B83EF9

1B8853BF06D858A08429FA306799AC1EA443C446F3B01E4A

68BB3EB252D901133BA10804617EE0195AB6E8995F130F9C

0B87067487C2CB57

E0E93814B4C765F8B5672E9143FE19BA44D8A73B2EB1A019

9E4A1CAA4E10C3685703C693F839DE83AAA79B3E0C04F55B

837FAAE4DD31345BE0A54CCC9507031E4CD26C1DC0A9B88A

3F29C16AEC474882F4DC3A66A0BF27C443ADCAD32E5FC938

C81B0742DCB5D1537082F04288ACEE2A9FCB421FADCA7C4B

B438AEA844A9F960

BF58D4E475169E024D08C149F1A468209A35CBA37E244C2E

D7991B0890673CD5950C30537B07B9A34621F1FC5D70AED2

00150E4C6C8596E0F561D9114364BBC40F17AD940A3F539E

C2D5405E7C238723C86802944419FE72D38DFE25961F72AC

9EF25588AE254945BE04E855D9C31A7C97EE2987D902780E

DAF878FBD992651E

7D229320AF22B226B96D0498F15A2ACAA92008802AD1B467

FF35748FC4411FDB996210D894482AE2E475B1DAC73229E6

6D9BAA41EAE81B732C446AC99F0435B2ED299F739B030C96

AC613E0441CAB4299A2E9496EE853E4BB4BE393D36B835AD

1779205DB0FDE56D97C65422B2DC6545EE112695CA3BF8A8

3CB5E931770DF5C7

45EFC8119F188853B432E15A19BA98153C89ADD34FBD5E1B

CEB36317FEAA931BD1CC6231F8A5A362E7172C60B3BAB83A

1F449BF1736DB91215C58D4D16B91D2E7880E40608867E27

17AE18A6C05A2EC42A9373EE081987B73DE54DFFA2FCB15A

0027B99CAD2A885BE5EF1A904523EC2AB6F16E81EADC4ED7

C56F3E73E6BF45AE

3634C37B2868C760F38F11A950E540BBC56322B37608D887

38DBBB8211997647139B86E6DF39552E0FAFD70E415641B9

99C4FDB835FE754D689AE7337A9A1810F09E71E941F5B4C2

68182D5E9233E06AE680071CD357D7AA04800491FB5D89F1

704E66D2FB5D15CA213D80D4F8CE4293B8177A0F5F1BC7AE

2A5EEBBC0C660A98

019EF750D07CF5AA39D75BCB4D049D25CD1A3C519A36E87B

C8FA336264EBE761CDE51263ACBCBEF6333A789DDECCEA45

A19A224D7D8AC6E9AA717F23FF6FA02FDCFDD97B5A1A69E3

1B8B7DE210F86FEF847DF3D077EA8D6A791ED84885E7E567

30C7AF212938A57BD95266D66E29A26E0AA24FE3C72F7C26

81F7AD4406BE8A4A

D75EBC4AC930DC59C2C107E14AA8A633199759F4B84FE5EE

640DC3881812BA73554BC5C73736789FA7D51C367335E9C1

944DE5C1B84E309A29135E9A1DF83A9ADA9432EEB29E5F72

5B1FCA4CD879CC7F42ED6F44C97A13D96A1888E5F38933D1

718AEF740A7C85F13A83E36E149E7ADF591CA2A2255F9EF2

E85E16CE670798FF

DF73DF36C568DA9B0071FEB86406ED732527CFD7625251DD

A95E1FBF8561EBCF9B204DA6C1A10B3D68A178F0E8A96B18

02EA6C51C3EDC432C90D0A599921E64B8C1ED763BB7A1B44

64DAA9F57C553DE111795AAD0EBE1836E9A3309228EFF73B

9349D516708FD810403E73E78D23134DBF5B3CF060D6A7AE

34B89232A5F92F62

AF514287DB9F24A254DD65FCAC339A68CFC57046CEC33508

8647DED7962F1E9BC5992F006B7FB0F5F18B24756C4C39AA

9CBDF25338E9198582BA21E741C7561502DE6DB343FCF3B3

D2E346956AC813179F7B6A1FEE3B7B09708ACEECFB277099

1FC63B9079E2263E86A6BAFE4299A9A71C60D500B75D38FA

956915B549A640E4

49AFFFAA2F189BE148D08924955B52DF2EA03B07FB983345

E7B37C14C68F05286496C3DF002552177262B38905E4F275

360884CFBF7D0D020F902B5EDF5B72A1F13BF6780F007E95

6DFC1A70F6B1C4524F42DBCB474EDC9CC9811C1742AC9F9C

D625025CBD37F79369B40233933FAADB42E59848126FBD26

87D9843ED1590DB8

3BAE1F50EA8B04B34EEE9642CB18D79B5AFE917CED359407

2F9E05421ECB6FD2EFC4465558C5AA7BDAFE02235B5FBBDC

BD3BADEA2E44892BE248B2527226E387654975EAEC924416

13C6AF7C9406624DB0E6B8966BF262519A0D5F026D91B618

C92468C5EFB55A668D048D51CAC8B31C9463E4EB7E3FD298

F35FC147C40DD1A9

5016EE6AB44F057FF12AAB8EE3872B37A537D15836E4C364

1ED4B17BE022F16C3B1FC8CCED8A1B3171690BD8B6254002

3A91558DF8E7319C612651B7108318D7FEF5D75F7936DDDA

AA61C10B44643BC0C3812F48089AC4352CA5179F94DA6B25

0E69B98F4CEB3E20EC97DAB44EDF5FA516D2A34242C85E3A

7BDD06AD09C06F97

1FB1499B11842EF473CB7E11125DDBD98E3DFF9E59D02594

6A025D8950EFCF1B7B1967A75F4699E1ED0D6D5AA80589B1

BA49E95C66BBE846A1ABA01EE9428E4D168DA65A19EC97FA

5A2330B61A9FCB066B3E49D6AD065F55E7BAB2428E1EFCA1

C8679AE8E84564C39F964A48BD4F03D8817002299273F4FB

78ED6A7BBB3628A9

4CA827A01BCA4DE6830FD164D3C73519B25B40C99136EBD1

8857FCD1327452E37760F9CBC21744759EB65F250AC1834C

B01828DFA16767EA0ABA71285DD6B6DE5B33BE0293C63775

19F5B379BC27AF8E376EC6C77B6F2ED10359549EDEC3F047

5EB9371C4FCCA9425A0836D43E7DC83CA0B12F820DA84A4D

CF7B0A870CE088F9

E38A059028BC5789E7474C9D0BBC6F11E38822DECF8C74DB

014C839BD6BE1E81E10D703FA8A6CB0146A0E9895569F8D5

3BAA7DE72411D09550BEF8BA2EE54D4AB39E066F29C73561

F07DCEBA35D52354C8E295911541FFAB74E88031DF5F3843

BF950039F789597AD522A87CFE02C6782928D74B82D6128D

8313B989D2549634

90CB46CA4EAE2EFD45A5AAD84DDDB334D0A07D0C24913019

9FC2E3298490783C79B0D20A311A9F6DC428CAC34451C9D8

0B653C5FB485DDEE0164F62F9D9401C647231B69AD5CA017

B8C35A24F75EA3D306BC672C23E0A0300D7FB4D2450A90AF

0149321B9361FEEB25679CEC9D1932C77AEA006E9534EE56

E1683EBB56C700FA

88DB47CB48119203AF37F456D9EAAB6702FF8461D3C7DC67

1CB56925380EBFDD374167A9884E01E4A959580DBEF66788

2235C50D65DC641AA1F0991A3C036B40E65494BF98DDFE72

414E29B890A32DC2FCEA267FC7C12B8747F80917108D6A3D

6502777C0A04BB8A8E862BCFFA986D3ECBA5388612B013D0

96E66DFC5823A30D

5CF569D57BDC8F2F5AA8089FB149F88E41B9B9441B17A18D

A308DB9A00E15587CFCC1241F6A855341FC12D584FC51242

B65EA6C7ECC64E4838DC2E9DDC4F19B940CB4FED303B8CDC

ABBABC2D2D1BCA3B8453B7EB9C5F12F003A8543CA1A1FE05

166BD0A575DD83502E27B8093C5AE495051D8305A8F54982

FA18648BF771BBB3

33C891F069C230DCD17228E28229F9C54A2FCB9499B2DB32

3B43B5AF8827F02B8B4EB749E4E3596BECD7C39C2F63C64A

BC00C5505B42AFC4CC12A03E5C04C89E6644197CBEB84DB7

1220544F18918CB94EFAE88B0540E96A714495AFEC290631

84C466FCDE593B9D74DC2EC058057FD9FC7278A4CA125BC4

514EFDB2115A0C0F

35D077045A07AC68FBCA7B1ED234C4C88FB90C86573A24B9

8CCAF0024F9456E186D9515B6D0DE0A63D419AC3A9482701

7B943FA8E2011FC4769445CBE3A05870E3049B3918D8C15B

5012B72DB8A04028EDF68B21591284DD66FFFAD375045A68

FB87D3D0363FA646D684253FC8AAECEA564AC307FF6F71A7

E3018B115386F067

AF0E7419AB37CF3D2D872B33C6993613C84D5DE9B9F97CF4

DC5A59BFED65A41E329FCECA645BEA13C8EA641B42CD86B2

5F511143D5B1C088288AFAF9DC4B8B136D0BE4D3A4573021

C9A150B31A2ED25FA77609A406A32E4DD9C5BF652E1190B8

AC02095587B14BCE570F422DAAC6791B45BA52E5AF2C90CD

1D67AE321BEB9037

C64CBC45DE46D08E3BF5C0550FC473F8D194651A10826B6F

F9D4A24592F5C39380624DF4B40F9BFB5F9905ACE5A82C51

19CCB3E7A14B5F12E236A878699F48C7F528433A8A947C1D

AB19EFA246C95CEB89D67A23AFD2D6F3984F6822C3A0BE04

2F198639095AC37C3118F49F83260C66AC83D5C12171B8FC

885F29CD6C85FD3B

B034AA2DD280310202C17D99021F9D47107CDEAB2FB8D939

59F3BEB47E0133D2B7E3522D39CB7197299BFE62E040CBC9

0F575CC95A0261EB6ED29FA60E43103D9198A2702706E633

4393295AD07CFD6D20880187B61B50790A61BDBACF6B227E

196E8020B6B94825D3A56B87FAF4917C6401F15CC57B990A

12BB9F3043B01AA6

8ABE38A45C1C01B87C22FC612F16BEB653D0BA5A4045B8B7

D9871E2317A0B3772746C6A6FE9A2776CD23C7427AFC5C65

C5F1F08826BCDECBDC49373E99A6C88E15FE14210B6762B5

9333B82D430D6598A539690833CFA1BF7EFB2CF86535B638

90C703BD201E454382B7A6E3F74F7051CDA63C0C6C76E303

5D64EEC08E22133C

7331B73AE3AB84B43E23F3BD6EDD0C895D2E11C99BFE29E5

B76D51EED66C972B1847DA50AE51DC058CDC6FEDA8181EEB

C1669921D764AE3A89CEB84026005521097337A99EC7BB6F

140E5FFB8AA9E590E23BA0AABE78EC502D90E9993CAD599D

E2DE9A3A447DF6B1BD4FF7032E9067E4D1FD4C57ADC81F1B

6BB316429A33CBC0

F46BE071E9894904BA86600D0053C4D5D528352CB49E5575

01FBA18E4B440DFAB8755E0B6DDE7CC63CCF346F3DC4A4BB

58364FCA93D00FD202613EF76F50B08FB098E1F41A3B34C9

9993F0B11BA8503F67CB2F0D8E2D6A0BA4976A9B9612B624

3C358BB185D08D302BDADD565D60D5D049317082CFEA7B92

5AEBF32FACCC3B66

1992048A47CA3531DA891220CBC04141B2A4A92A131AD35D

7905A7C9016FF2D932E177B429B9F950438E1B26E7BF674C

44EAE98DFF4EF784906B15AAF5B44CEB270B7BB44BCEA837

C01AAC3DAD8C73D8F669509409A339A20F90D01D4E5C30B4

037106AC3BCAD41EC4F15A7AB3C1E13D41614DB931E52450

A8EB20A858E03FAB

1A0E6ED94CF79D7506DB4E3B62B9A5F91A067A556BF8AEDA

64581E1F8AC4EF697D9A032D2B34AE83CF1EE196867A0FEC

267E882F93245BE5DB02A2396C5EFB9FFE9F2CFE9B0B32AF

44FF02A4C83010783957CA81681BDCDBBE22473DB3A50E1E

9AB5E22AB429108B6E752FE7FED1484E3D79BAE5024C5ABF

CF1A7838C1F94AC6

CF873861B3450F3759C5AED11C219C93843B10C1ED785337

E5A0028D9ED923AA2B013ACBA4CF4515ACBBB051FB3BE477

D97DF5FE14B9D46D427589BA7BFBC1301D36B580B269A821

B8BB1C994995FADD7ECC3DED6AF2085C6FC69CAEE028D98A

21EA2724177A6596B4EAD9E9463F5DB4B0C1042F3143B380

2AE2109D551B9C36

6A12DA1D2B91CEB9553D2EB78BCD20EE0E6A166EE48BF718

DBEBAF2F864A5569D0B9C452287B36C60F5171F79B01A71F

8218E77B5E356DA0DBB21DCD382670CB8302C32AD0522611

03B2723BCA76CC5DE083202CA9926AD29BF646DC581791A4

2B59B49710D1DCB035294BEB8A7EC6B9F639252E7494C206

C54F6BBCFB7000C0

BC107FC3E20F764795E603B4D9713A31C9BAAA54BC1AF1A3

519350ABDBF28FF26231815EEE2EBE51F59C0EAA2AB952F4

59B159A7D7AF0411BD56C040B7A10B505BF2765F42D9CCAA

1D5225F41FE668336A129C93F022F0AD0461999CD2781420

AEF702B25B295845DA81BF86BEEAF3145E3AA187BDDA3332

32A1B31D8ADA6214

9455047B80CB1C02F89B785601BAD753C11474076C85178D

D50CEBCB3669268CCEE06CD781EE0B60802DFA5DFF79A3AA

3C01EF2E871256C861DA78D5F85485221DAEF880C45DEE4F

74122BAA2FC632D784081220E6F0854D9E2FD03B28E31702

2FB3611396B438E19CE5BE3C273F677271BEC095103F0392

90B6D8C46735D07B

245EE38A1579D87F2B25CD3F9530B9C666924AC7B6F3670B

60488B57C36EC419D79813772F8A7BD34FF592BA8B80112F

C0597DEC0F74CC5CB8FA068F649610B5A94D49E391BD5F4A

C317D9A0B9572457FBAA48B6908A7BF31ECEFB5BBC49B372

96C2CC5A01E7C7F05F3A4982BD74D5D9D1F0421A50F18FD4

992C2A5F13AA2FC2

07A03FFEF6555E13B82467D553B35289E33CF146258A8B9E

D39AFEFD64D3267E4E7AA223D182C5533AC82E1F4D2599AD

6B60029D7B0A853BED809764FE253C6201B10D790E6E5CF9

BDE0782A7714AD09DDB6B2B3480DFE55E4B886CB6EED22D0

8E105ED8575A4D81FCB3A4FE77F8265B446250F6D4ACAC6D

1AB9A800E01A9375

13927E49B70DA6EF8397366310C75C27590FADB5C451040E

3E05AB7701740D94C7F119C08F4E36E1EF607680D2A5F242

C342A82FB2AB4BA8A61E100185D1AB4CD31AAF8757F4F28C

681B59C228E7E6852662188EB0446ECB9D972345F57628DB

AA5DE675C751C1170777196E505AAFA4A1DDEAC06539931B

94E62C9D5D8968CB

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd


\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{288, 90},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000FQ000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`0027ooE@0027ooE@0027ooE@002Goo0008Ool00`00Oomoo`1AOol00`00Oomoo`06
Ool00`00Oomoo`1AOol00`00Oomoo`06Ool00`00Oomoo`1AOol00`00Oomoo`07Ool000Qoo``00003
1040000000<00003104000@100<00003104000@100<000051040000000040@0700000`@100000005
00000`@100040@0500000`@Q0000000500000`@10000000300001@@10000000010401P0000=oo`00
Ool01goo00<007ooOol01goo049F]GooOom[FUkg<HaW>DHABU9FUFmkDY@LidYB;F/Y:PQ2<F`Q22TZ
=Jd]Jc6<=HdLib3X@Q0Li`aS=JdDYA247>LHaRU:6<HDYA1T9BU64B48=Hd]Ja24;F/@Q2DY46@]Jb48
;F/U:ARV8>Pmkg>LBU9>LeJe<H`HaWooJeY_NgooCW<8Ool00`00Oomoo`06Ool09P00OomkgUlG7<LH
aTHA7>M[FTYB@Q1FeF<H248Q21cWCU=:LV]J48AooaBUNmi2436<OomNmdjCAQ4Li`@Q<H`Q26]JF]HH
aPaSCW<2DY@2;F/015kG9BUFUE:D0Re[01@aS7>lIcTYBQBUG_M>Lg_NHaPmkc6<8@P004ic?Nl48Fmk
105_NaBU0SF]00YS65kgMkdLibU:?Nle[ABUIaTmk`9W>@038@P48@0000Uoo`0027oo0`0000<40@00
00007@0000<40@0000003@0000<48@0000003@0000<48@0000001@0000<40@0000001@0000=oo`00
Ool01goo00<007ooOol02Goo00X]JeKEMke[FQcWCW=oofmk;F]_N`88@P0@JgX]JacW:DX<@bDY5:DU
:ABU8@PLibU:<H`<HbDY;H/248@25:D02RDY48@48@aS248@Q1BU248]Jc6<0QcW00lPj2DY>LhicRe[
=Je>LcW>:DYW>F<H:DYW>Cg_<H`03Goo00<007ooOol01Woo05D007oo6<HicTjCJeX<Hg>L=Je>LacW
48@]JbU:E[E:DT8@NohLieJe@S1BU2U:JeY245kgJgXaS1S6G_LecG>LJeXmk`Q2JeYBU7>L>Lh48E:D
:DYcW5[F:DXmkgooLi`YBU[F9BUWFEkg7>L48Be[?Nm>L`@QIcUF]B48Li`LicF]AS5242U:G_MkgUJe
7>LYBWOMJeXLigNmIcTaS0Q2:FXU:E[F=Jd00009Ool000Qoo`8000031040000000<0000710400000
00040@0010400`0000<40@0000001@0000<40@0010401`0000<40@0000000`0000<40@0000001`00
00@40@0000048@P00005104000@100040@0300002@@100040@00104000@Q00040@0200000goo001o
o`07Ool00`00Oomoo`05Ool03UJeOomooc5/MkeW>GooDYAoo`aS9BTmcbe[9@T26<H01P@Q58D<Hc6<
5:DYBP8@Q003248DQBU:008Q200Q34<YBR4836<HYQBU6:HHaQBU9BT<@aS6:DXQ23W>000mkd8@>JhL
ibTZ48@U2D8@5:DYBQBUMkd<@f]JDYAF]Dic00=oo`03BU9oogoo00=oo`03JeYoogoo009oo`03001o
ogoo00Ioo`05001oob3X:DYg_@02JeX01ABU>LiF]G>L22800QBU01/Q23g_HaQ>LacW36=BU1cW=JdU
:EkGDY@40FnK228icRDYF]H40E:DE[DQ21BULiaJeR48>Lh00U[F02XU:G_NCW<icP00DY@HaW_N249F
UAcWMkdmkbD9125JeT8@?Lm247Nm5:EcW4YBE[DicU:DNmh88RDYF]He[AcWIcTe[AS6Kg/mkaBULk`m
cdjC0009Ool000Qoo`0300040@0000@000051040000000040@0300000`@10000000300001@@10000
000010400`0000<48@0000001`0000<40@0000003@0000<40@0010404@0000<40@0000001@0000=o
o`00Ool01goo00H007ooOomoodXbAS46Ool0:E:DOomooc6<BU8mk`aS;F/mkcF]:DX<HaS6248<Hcg_
9@T8@R48000LiaBU7>LQ20Q26<H<@acW36<DY@006<H<HaS69BTUBAS65:DLaaBU6:H00RU:014M1`Q2
:DXU2A24AS4icPQ26<HicV<HF]Hmkgoo36<mkg>l008aS0Eoo`039BUoogoo009oo`03001oogoo00Io
o`0S001ood8@IcU:DQBU8BPe[G_nMkda[248AS5>Lf]JHaP<Hc6<HaPU:G>l9BUW>G>l36=S61BU<HaF
e@Q2Kg]g_Cg_5:DHiP02IeT0;7NmE[EBU1cW124UBFmk>Nh48ABU58DHaUJe>Li[FWooHaP]Jd8@CY=[
FSg_Nmh8@QBUBU8HaSW>BU8HaPQ25:DicSW^BU96<GNmE[DQ27ooAQ4aS7ooKi/2@Q000eJe001oo`08
Ool000Qoo`@00009104000@100040@00104000@100<000031040000000<000031040000000L00007
1040000000040@0010400`0000D40@00104000@100<000031040000000D000051040000000040@03
00000`@10000000300000`@10000000300001`@100048@00105oo`0000Qoo`03001oogoo00Qoo`0<
BU9oog_NMkeooc6<:DXaS2TZCW<Lib480S6<018DQCg_248e[BU:8@PHaRU:7>LDQAcW48@48AS69BTH
aQRV9BT28@P03aS69BTDYAS646@Li`a3;F/DQB48BU8aS23X?Nl@Q002>Lh03Q24F]H]Jcg?F_HicUJe
249oobU:CW=_Ngoo<H`4Ool01DicOomoogoo000027oo05D007oo8@Q6<@@1BU9JeW_n8>Q6<F]JHaPU
:AcW?Ll8@V]JIcTDQABU=JeBU6]J=Jeg_A24G_LaS1RV=Je[FVmk48ABU4Ha6<I:<RDYMkeF]AS67>Mo
oaS6BU9S61S69BTaS4YBDYA247Nm?Nl]Jgoo125F]G_NHcQ245Je7>LHYTiCF]I[FRU:58EcW3W>36=g
_DYB248HaSW>IeUS62486<I[FW>LMkd00009Ool000Qoo`D000031040000000d000031040000000<0
00031040000000L000031040000002<000031040000000D00003Ool007oo00Moo`04001:LU:D?Nl5
Ool00f]jOomW>@02Ool00e[F7>Moo`02:DX0=e[FCW<aS2U:5:D]JaSV<H`@Q1cW48@<Had7<H`8@RDY
8@P<Hcg_7<LDYAB5;H/@Q2U:;F/<HaBU48@Li`aS>LhDY@aS=JdHYQd7@Q1Nm`a3=LdDYB489BTaS1BU
;F]JePaSDYAoofLiBU8mkg_n009oo`04IcUooacWCW<3Ool00aS6001oo`07Ool04`00OolHiP@17>M6
4G>L8@QBU7oo36=245JeF]H000aS@S1:DWNm009[FP109BTaS7_N;F]S65[F8@P@Q7>L?NlHaV<HAQ5W
>AcWOol002DYNmhaS6]J;F/aS000BU9S67oo36=BU3F]IeTmkfmkMke2436/Li`DYBU:HcQ[FW_n@Q1:
DQcWKg]cW4Yb58D004YB@Q1oo`009@U>Le[F48A6<C6<F]H@Q7_N0009Ool000Qoo`@0000310400000
00L000071040000000040@0010400`0000<40@0000001`0000<40@0000000`0000<40@0010401@00
00L40@00000000@100040@0500001@@10000000010400`0000D40@00000000@100<0000310400000
00<00003105oo`0000Qoo`04001oogooE[D5Ool02A1TOole[E[FOom:LW>L;F]S60027>L0:S6<9BT4
8C6<48@aS3W>:DXHaRDY5:DLibDY6<H8@S5/48@U:AS66:HLidHa48@Libe[<F`LiaBU:DX<HbDY:BXY
BRD9=Jd]JbU:AQ4Licg_>Lhe[@8Q200>5:De[B48:DY245:DOom_NgooIcUooe:DOolLa`Ioo`03001o
ogoo00Ioo`0S001oobe;46AF]Fmk34=F]FmkIcTU:DicHaP<HbTZ@Q08@QcW6:HHaRU:AS5oofLiDYA_
VaS6MkdaK2e[=JeF]@@Q58DicP02:DX05g>LIcTHaU[F@Q1kgPQ2F]H48Be;BU8mk`@Q000icPa3G_M>
Lb48Kg/icUkg00000RDY00Y6<FLi5:E6<AcW;F]64E:DLiag_@8]J`05H_PLiac7Mkdmk`02IcT015[F
?Lle[@002Goo0008Ool300000`@10000000500000`@100048@0900000`@10000000=00000`@10000
000600000`@Q0000000=00000`@Q0000000200000`@10000000500000`@100040@0300000goo001o
o`07Ool0=@00OomoodjC@Q1JeSg_AS5W>D8@=Je[NRDYOol@I1d7JgYg_BDY;H]:DPaSIcTYBSF];F/0
0248=JdYBQBU248aS0aS5:DQ:2488BP<Hc6<248HaPa336<YBPQ2<H`Q23g_6<HDYB4X5:D00QcW018Q
236<124mkc6<AS5241B548A:DP@Q:DXU:Cg_Oom>Lgoo:DX2Ool01SW^Oom[NWoo<Ha64@=oo`03001o
ogoo00Ioo`0l001ooacWIcTaS7Nm9BUcW6mk:DYBU00036=>LfLiOomF]B48125246<H48@<He:D:DXe
S@Q2JeYF]DHA:DXaS0aS>LhYBSW>CW=kgTHa7>L]RfLiAS5_Ne:dKg]NmaS6HaPYBQ24Kg]:DR3XKg]c
W0Q248@icQ240UJe01L@Q7>LIeU:DPQ2E[DQ20aS000aS7NmJeXicQ24AS448F]j9BTmk`aSHaQW>@00
00Uoo`0027oo0P000`@100H000@100040@00104300000`@10000000300002@@100040@00104000@1
00040@0500002@@100000000104000@100040@0500001`@100000000104000@100<00005104000@Q
00040@0300001@@10000000010400`0000D40@00000000@100@00003Ool007oo00Moo`1>00088V<H
?NmF]GooNmhmkbU:Ool8@UJe=JdU:BU:=Hd]JbD9CW<]Jf<H58EF]@aS48@HaR4858D]Jac736<88PaS
58DYBPQ25:DDQABU7<L<HbU:36<HaQBU:DXaS2e[6<HDQBDY8@PLicF=5:DU:@Q2AS4]Jcg_@Q0mkacW
<H`]JaB536=W>BDY=Jeoog>L?NlU:CW>8@QO5f<H0Woo00E>Tgoo7>Moo`0000Qoo`16001oof<HKg/i
cPQ2CW=ooa1TBU9kgRe[F[I6<@@Q36<U:Cg_G_M_Vb487>LicRDYIcT40F]J@Q0Q21S6Oom:DRe[<Hak
gUkg9BUW>BDYBU9kgWNm000icQcW<HaS65[F7<L@Q6mk>Lh8@QcWDY@005kgKg/HaV]J=Hd]JacWJeY6
<Be[Kg]_VaBU9BT2G_L03BD96:HU:G>lJeX006mk8@Qooe:D;F/Q200000Uoo`0027oo3@0000<40@00
00000`0000<40@0000001@0000<40@0000002@0000<40@0000001`0000<40@0000003`0000<40@00
00003@0000=oo`00Ool01goo01@007ooOomoodYBOole[B48IcUoocF]?Nl]JfMIG_M:DT8@:DYNmc6<
0QcW00]:DRU:;F/aS48@8@P@I0Q29BTQ21cW008HaP0>6>HLia24248Q21RV248Q21S68@PYBRDY7>L<
H`8U:@0L7>LHYSg_=Jd@Q2TZ5:D]Jb48<H`<H`Q26<HLid8@Lk`e[DYBIeTHaRf;?NmS62U:BU9oogOM
Kg/2Ool013W^Oomoo`0027oo05D007ooHaPmkdYBJeY>L`008@Q_NacW?Nm:DW_N?NlaS7>LIcTLie:D
HaQcW6Li8@P]JfmkBU8e[@@Q6:I[NT8@>Lh8@QS6G_L48G>LKi/e[CW>G_M[FQcWF]I:DT8@IcUg_E:D
;F/<HaS6LiaWFBe[:DXeSDic<Hag_@@QE]E243F]125JmRe[001:DSg_Mke:LSF]000LigNm8@P48CW>
5:D@Q5[fF]H00009Ool000Qoo`800003124000@100<00009104000@100040@00104000@100L00009
104000@100048@00104000@100D00003104000@Q00L00006104000@100040@@Q100000<40@000000
0`0000<40@0010400`0000D48@00000000@100<000071040000000040Goo000027oo00`004HA>LiS
64YBOolmkc6<6<I>LekgLi`2:DX00be[=HeNm`026<H0>SW>9BTY:QBU36<aS2U:7>LQ22e[36<Q21c7
:DX<@a247<LHYRDY6<HLaaRV8@PLi`PR48@DYCF]5:D8@RU:8@PU:CF]BU8<@be[48@]Jc6<@Q0LibD9
>Lh<@aS68>PDQEJeBU9BU2DY;D]kgWoo@Q1BU1S617oo00AF]GooNmh000Qoo`1E001oodic?NmF]CW>
Ool]JdXb001ooe[F34<8@QcWG_LmkaBU;F]NmaS6>Nh40E:DOolDY@@1BW8@Q7NmKg/icPQ2JeXaS248
9BUg_E:D58Eg_C6<Oom6<EJe36<LacF]7>M_Na1T:DXe[D8@Kg]JeR3XG_MS611TNmiBU5Zf?Nl@Q3F]
Ool88SW>8@QS65:DNmhQ21cWIcTHYT8@7<M:DRU:DYAooaRV00002Goo0008Ool?00000`@10000000O
00000`@10000000O00000goo001oo`07Ool05000;F/8@Ukg6<I_V`aSOomg_@Q2>Lh]Je[F8@QkgS6/
E[DLicg_BU829BT03E:D:DXHYSh?5:DHaR48248DQ@@Q:DX<HacW00<8@P0B9BTQ:1S66<H8@QS6=JdD
YAcW7@L@Q1BUDY@YBT8@48@aS1d70Q2400lQ248`:DX8@S6<6<I240Q234<48ABU:DXQ22UZJeX00W>L
00YNmgooF]HU:E:D?NmoobU:E]D000Qoo`12001oogNmDYAg_@00E[DLie:D6<H]JdHa48A245:D8@P@
Q4HaHaQBU0007>LmkgooJeXYBS6/AS5:DUkg>Lh<HeJe9@Te[G>LD[A_Nb489BTM1g>LF_HaS1S6DYAN
mgNm7>LYBU:DE[Eoob486>I>Lc6<5:D8@U:D36=JeR48>LiWFF]j0RDY015S66Li9BTeSAS6IeTLif]J
?Nm[FTHa48AW>DYB124Li`0000Uoo`0027oo0P0000H40@00124000@10002104200007`a3=Jd]JaS6
9BT<H`Q236<Q22U:<H`YBRe;:DXPj2487>LHaQB57>LU:B4848@001cW9BTe[CW>6<H<HaS600<]J`05
5:D<Ha1T5:DHYP028@P00bU:5:DHaP026<H03QB548@HYPQ2104000@Q00040@00104000@Q00021040
1PPR00040@Q2104000<48@03Ool007oo00Moo`0N001oogoo@Q0DYGoo?Nl88Re[CU=koTicE]DmkdYB
G_MF]@@17>LicRU:BU8DYAc76<H88QBU248LibU:0RDY01DHaRDY<H`Labe[=Jd<@aRV36<]BaS658D8
@QBU6<HYBQcW6:H8@QS624800R48018mcacW<Fa2436<249>Lc6<@O0mkbDY6<I>Lc6/58DicRe[F]H2
Ool02TXb7>LicWooAS5[FW>LNmi6<@0027oo00P007ooNmi_NeJeBU8<HaRV0WNm01hmkbe[HaQ:DP@1
6<HmkcW>9@Uood8@Oom>LdYB>LicW7_NF]HmkacW@Q1[NP@17>LaK3F]JeYFeDXb48@2=Jd01eJeG_M:
DV<HLi`88W>L009>L`0RMmeW>FmkCW<48G_NDY@]JgooF]HYBTicHaP@Q7OMKg]:DW>LBU8LiaBU?Nl0
04ic248DY@@QIcUoocV^F]HLaa240009Ool000Qoo`<00004124000@1000512403000>LhU:AcW36<4
0@Q27>LYBRTZ:DXaK08YBP0<7>LQ21S67>L@Q2U:5:E242e[124Q21BU0PaS0PQ200PHaRU::DXYBQS6
248DYAcW0b4800XLi`Q236<DYB486<H<HaS648@8@P800005124000@100048@0300001@@100040@00
12400`0000@40@@QOol000Qoo`1E001JmTYB:DYBU48@MkeBU36<BU8Q24Yb@Q1BU23X@Q0eSCW>=JeF
]ABU124HYR48;F/LibU:124mkacW<F`<H`Q28@PLibe[8@PU:ABU7@LQ21S6248<HbDY;F/Q23g_6<HD
YA249BT48Be[6<HQ21cW@Q0U2BDYAQ4]Rd8@48@DY@Q2DY@@Q36<<Ja>LfmkBS8U:DYB?NmoogNm?NlL
idXb?NmooacW000027oo058007oo000Lie:DHaQ:DUJe248e[DHa34<HaVLi<H`8@TYBKg/004icKi]J
eWoo>LikgQRV9BUkgVLi48AWFDicNmhDYDic125BU1cWLiaBU2U:Lia[NQcWOolaS6LiCW<8@Q249BUB
U4YbNmhHaUJe7>M[FQcW<HacW7_N5:E245lG>Li[FPaS;F]cW3F]Kg/n3c6<HcP@Q5KE:DX]J`00IcUJ
eP8HaP03001oogoo00Moo`0027oo0P0001048@0036<000PR12440@0022848@Q27>LYBR48248DQ@80
000:36<]Jbe;:DXY:R488>PU:B4848@25:D04c6<;F]240@Q;D/DY@aS248<HaBU6<HDYCF]<H`]JaBU
6:HHaR48008Li`0F8@PDQABU6:HHaQBU36<HaR487<L48@Q200048@00104000@100048@0010421240
0`001240000200000`@1Ool00008Ool03`00AS5[NUJeCW=[FVLiJeYoofLi@Q1[FUkg<H`DY@03:DX0
2djC?NlQ24Ha<J`LabDY48@DQA1T8@P00QS600LU2BU:34<e[BDY7>LHaP025:D05b4836<DYAcW8@Q2
41248@PYBP@16<H88R48BU8Lid7`6<IBU248@O0Li`PR24800R4801A6<FLiDYA:DTicKg]F]DYB@Q0<
Hb3X?Nle[DYB:DXe[CW>BU96<@0027oo00@007oo124@I09kgP0H@Q1JeU[FMme1l2DYHaPHaV<H5:Eo
oe:D;F/HaW>L8@QBU0PR8>PaS5JeOolHaTHa0QcW03EW>CW>Kg/Q22TZ1256<AcW=JdQ26Li48@U:E:D
Kg/Q20a3BU8aS124MkdU:Cg_7>M_NbDY<HaNmgNm6<H48D8@46A6<AS6000mkaBUIcTe[F<HDYAcW1cW
6:HDYG_N36=JeW>L<H`YBP0000Uoo`0027oo0`0000<88P0022800`@Q00X8@P@Q22848C6<:DX]Jb48
48@000848@06<H`e[BTZ:DXU:ASV0QS600H<Ha245:DU:B4848@2248023F=248@I0aS248HaQBU>Lh2
;F/04C6<8@PY:QS648@8@P005:D<@a246<HQ21247>LHaPaS24800`0000@48@00124000848@040004
8@@Q000212401P@100088P00Ool000Qoo`0=000YBQ24:DX8@V]JBU8mkcW>8@Q242U:7>L00SF]0Q24
00h8@SW>;F/Lic6<;F/DYA24:DX@Q1BU7>LQ236<0QcW00X48A24@Q0DYCW^48@aS2U:36<88P8U:@0G
48@Q236/:DX@Q1cW5:D<HacW=JdU:Cg_;F/Pj2E99BT<H`a37>L@I2e[AQ4HaP029BT00be[AS5W>@02
;F/02U:D=Jd48B48?NlQ25[FJeXHaP0027oo00T007oo<H`Q27_NOol@Q6<HCW<00Ukg038HYRe[DYAF
]BDY<H`8@Ukg248e[DYBMke:DQ24<HacW6]JHcPaS5[FIeTLib48BW9NmacWCW<@Q6Li@Q0DY@@Q5:Ec
W7Nm8@Q_Nc6<IcT003W>=JeS65kgKg/@Q4YBAS5cW3W>0QS601IS64YBKg]242TZKg]>L`aSIcTDYFLi
HaPmk`aS:DY[FT8@NohU:DYBMkd000Uoo`0027oo00T000@Q12448@@100040@@Q10400`@Q00d40CW>
<H`aS2e[5:D40@@Q104U:AcW8@PYBP029BT03QBU8@PLiaRV248Q22DY46@000PR9BT8@P@Q248236<0
4Q24?NlaS3W>;F/aS12446@<Ha24248U:@aS7>LDYBDY7>LHaP8Li`0448@48@00104212401P002280
00@112440@848@0800040@00104000@QOol000Qoo`0F0016<AcW>Li6<BU:124@I3F]HaP]Je9dG_Le
[BDY125241RV>NhaS3F]6<H224828@P0>d8@5:DDYC6<248YBPaS8@PYBQ249BTQ21cW?NlHaRU:0008
@R487>LaS1BU36=1l1S636<U:Be[:DX]Jb489@TDYBD948A6<AcWBU9[FSW>=Jd]JbDYEYDe[DYBBW9J
eT8@6:HLib3X<H`]JcW^@Q0aS7>L000027oo00@007oo;F]gg@8Li`1?DY@aS1RV@Q0<@dicLi`U:Ac7
E[EoocW>DY@U:AcWKg/LibDY>Liooe:D<HaJ]P@Q=JdQ22U:F]IoocF]:DXLigNm=Jd<@dHaG]LikQ1T
AS5F]E[FJeXicV]J249S62489@U>Lfmk000DQBU:7>MF]Ekg248HYQS6G_MkoV]JNmiW>@Q2>Lh003F=
Li`LacF]248U:Goo249JeRU:00002Goo0008Ool00`0010448@0812402`@10012436<=JdYBQcW6<HL
icW>8@P00RDY00TaS3F]<H`LiaBU7>L@Q1S6<H`00Re[01L40@@Q<F`]Jd8@@S0e[CG=6:HLicg_=JdL
i`Q21248@QS65:DDQB485:DM1aB5008Q200536<U:C6<7>L@Q00300000`@Q10448@02124010Q21248
8P000P@Q00H8@P@Q10448Goo0008Ool08000>LiJeQS6=JeW>E:D<J`mkdYB9BU243F]48@]JacW9BT]
Ra1T<J`<HdHa6:HQ:1cW48@DQAS67>L8@QS636<26<H01B485:D]BaBU6<H00Q2402`ecAS6248Q21BU
7>LDYAcW36<YBQBU9BT@Q1BU36<DY@00:BXHiSF]6<HQ21BU8@PHaRU:6<HQ22e[=JeJmQcW5:DYBRDY
G_MF]Be[8@P@Q1S6;F/e[@0027oo048007oo36<]Je[FMke:DP@1HaPU:GooCW<YBRe;G_L002UZ?Nm[
FQ1T=JdLifmkBS9[FPQ26<I:<W_NHaQ_NdYB;F]c_1S6BU9JePaS9BT005kgBU8@Q7NmDYANm`Q28@Pi
kW>LHaQF]B48<HaS65[F@S0icP@Q:DXmkgooIcTLic6<IeT248@04CW^NmhLiaS6AS4LidYBIcTYBTic
48@]Jf]j48@icUJe00002Goo0008Ool0100010440@Q20`PR00L000@Q12488P@Q228U:@02<H`01CF=
6<HPj0@Q<H`00RU:014U:CW>>Lhmkb486:HYBQcW8@Pe[CW>:DX000a3:DXU:D8@008e[@0758D@Q1BU
?Nle[B48;F/00PQ200<<HaS636<00R4800TLibDY9BTQ21S67>LaS1248@P00P@Q00L000@112448@00
2280000224802@@Q0008@P00124000@QOol00008Ool03000E[EW>BU:E[DHaWoo8@PaS3F]8@PaS0<L
i`0V=JdDYABU@Q0icSg_9@U:DQcW248e[ABU46@DQAcW?NlLi`Q25:DQ22e[5:DHaR48228<HbU:48@Y
BQ1T?Nl<HbDY8@P@Q3W>DY@Q208@Q00C5:DLia1T:DXicSg_7>Le[@@Q7>LmkbDYDY@aS0PR;F/Q23F]
7>L00RDY00U243W>Lk`mke[F?Nmc_4Xb000027oo05D007ooCW<002e[=JdU:BU:;F]>L`Q2DYAJeWNm
>Lh<Hf<HG_LDYCG=MkeJeSF]1248@SF]JeX8@VLi8@PYBU:DMkd<HeJe@Q0]Ja24G_M242D95:EcW5[F
36<aS5JEMmeW>AcW8>QF]@a3Oom:DRU:248]JdicNmhaS2e[F]HaS1S6CW<Q26mk;F/@Q5JeCW<HaV]J
AS5koTic001:<S6<58DLifLiAS400009Ool000Qoo`0400048@@Q000212406000248000@Q00048@00
5:DYJSg_=Ld@I0@Q;F/icRe[:DXaS3F]>Lh]JaS648@YBP8Li`03<Ha243W>0088@P<<H`0K124@Q000
8@PDYCg_=Jdmka248@P<Ha245:DHaQBU8@PHaQcW248@Q2U:7>LYBS6<36<88P0000<48@030008@P00
00@48@0310448@@Q00<00003Ool007oo00Moo`0f001oobe[36<@I5kg@Q16DA1TE[E>Lc6<5:DaS0a3
9BT@Q2U:6<HaS1247>LU2@aS8@PM1`aS000Li`aS124DY@PR;F/@Q1cW248<Hb4836<<@aBU36<Q20aS
248HaPQ2=Jd8@PPR7>L48AcW0QS600HmkcW^9@Tec@@QAU4236<02ABUAS4Li`Q248@<Hb4824888P02
6<H02TYB<Ha[NQBU36<YBSg_7<M2<00027oo03/007ooF]HQ27_N:DX006mk@Q0Li`aS;F]6<Be[AS4D
YEJe58D]Jf<HKg/LifLi36<8@U[F48A244YB34<DY@@Q?Nl8@P00Mkdn3cW>36=cW5:D58D006MI;F/0
06]jAS48@QcW?PmJeS6<<F`8@QS6<HaS66Li008Q200HCW=g_AS6CW<8@TicIcTHaT8@HaPaS5lGLia[
NWooE]EBU124:DX48AS6E[DaS0002Goo0008Ool01@0012488P0012400`PR01848@Q2248U:AcW9BU:
DSW^>Lh8@SF]E[DicRU:?NlaS35/=Jd3:DX02bDY;F/U:Be[<H`Y:P@Q46@@Q2DY36<00P@Q00@DQA1T
58Dmk`924008>LhU:C6<:DXDY@aS8>PLi`8YBP059BTDYBU:7>LU:@02=Jd00c6<24848@0422801`a3
00048@00124000Q200848@0400088Woo0008Ool0=`009BTe[BU:BU8aS1cW:DX48BDY58DHaPQ248@<
He:D8@P<HbU:46@8@R3X;F/Pj2U:34<DYBTZ9BTDYB4836<HaSF=48@U:@aS:BX@Q1BU248Y:SF]48@D
Y@aS124LaaBU9BT@Q0Q26:HYBRDY008YBP0?9BT48BDY6<HLi`aS:DY6<C6<BU8mkacW;F/LiaS6008D
Y@0;:DYF]BU:DW@ikS5/@Q1FU@aS6:H00008Ool0>`00OolYBR4836=O5dYB5:EJePQ2@Q048F]J249N
mcF]248<Hcg_JeXaS6]JOolU:@@1001JeV<H9BUcW0Q2AS5[FQcWDY@LigNm:DY_Ncg_Ool<Hd8@IeUc
W7>lF]HLigNm8@Q6<@@QG_M_NbDY8@QBU7>L36<00Re[01QW>Dic5:EcW2U:Mke>LaS6Li`Q25Je:DXi
cWNm8@QcW0aSIcUF]Cg_<Hag_@Q20009Ool000Qoo`80000324848@@Q00848@80000;36<002U:9BTL
abDY>LhDY@00AS5>L`03<H`3=Jd02Re[9@TicR48:DXQ22e[9BT<H`a30PQ200@@Q0@136<DQ@<@Q00@
9BU243g_?PlHaSg_5:DHaQcW9BT]JbDY7>LU:ABU:FX29BT012e[:FXQ20aS0P0000@88P@Q24800084
8@06104000@100088P@Q0P0000=oo`00Ool01goo024006Li>Li>Lgoo<H`YBSG=?NlQ212436<8@Rf;
<H`DY@Q2:DX8@RDY36<Li`Q25:D001BU48@]J`aS124Y:PaS10400bDY01T@Q1cW248DYBU:248001BU
58D8@QS636<Pj0aS58DLibe[36<]BacW9BUNm`aS?NlaK003AS405E[F8@PYBP@Q9BTLib489BTaS1S6
;F]:DQS68@Q245KECW=S65JeKg/00008Ool06@00OolHaW_N@Q0<@bDY;F/001S6<Jag_E[fCW<U:Fmk
6>He[@aS001>Td8@LiaW>B48009S60089BUJeSg_<J`e[C6<JeXHaP9Nm`03CW<a[7oo008aS00XJeXU
:F<h<H`HaUkgAS5cW0Q2G_LaS4YBJeYW>A24AS4<Hf]JF]HDYGNm=Hd@Q5kg=Je6<@00CW<DYF]JNmi_
NaS6DY@48GooAU5_NbDY:DX2Kg/00`00Oomoo`07Ool000Qoo`<000840@<48@0522848@PR>Lhmk`02
AS401cW>7>L<@c6<9BTeSC6<008icP03=JdikSW>00<icP0J=JdU:CF]9BU:<QS6124@Q36<36<@Q0@Q
5:D8@R4848@mkcF]@Q0HYQc7<J`Pj3W>7>LU:@8]J`04=Jd@Q2488@P2:DX03248;F/Q2000228000@1
24848@Q210400088@P848@05104000Q2Ool00008Ool0?`00=JeWFAB56<H@I1S67>LU:BU:>LhLacW>
48@YBSW>248YBRe[:BXHaPaS5:DLibDY7>LU:CW><J`mkbU:48@Li`a3124@Q3G=46@Q21RV36<DY@@Q
36<88Q1T248Li`aS=JdLibDY6<HU:@aS=Hd<H`a3248@Q1BU@Q16<@02=Jd052e;BU8U2AS646A6<AcW
:DXmka248@P8@THa>LhQ22DY7>LQ20@Q0008Ool0E@00OomBU2U:G_LYBVLiF]I242U:Li`HaV]J248m
kekg@O16<AS69BUNmg>L7>LHaU:D5:DLaekg7>LQ24icHaP88Sg_G_L8@R48JeXmcbU:8@Q:DQRVKi]o
ocF]7<L]Je:DIcT@Q0aS@Q0mk`@QOomS62e[;D/@Q6LI=JdLie:DCW=g_Be;Li`aS7>L:DYWFBe[58DU
2@00G_MWFDic105>LbDYMkd8@P0000Uoo`0027oo00<000Q200000P@Q00L40@@Q248000PR000Q2002
>Lh00dic;F/<H`02:DX01Be[@Q1:DSW>=Jd00S6<00decCW>@Q0e[B48>Lhe[BU:>NhicQ2446@e[@02
6<H020aS5:D@Q1246<HU:Cg_>Nh25:D04@@Q36<@Q1S67>LYBSg_8@PYBQd77>LU:A1T:DY6<ABU1040
0P0000D48@@100048@0000848@0422848@PR124200000goo001oo`07Ool06000>Lh]Ja246<Ha[48@
AS4mkcW>AS4e[A24DY@]JaBUAS4DYB48G_LU:AcW48@<H`8@Q005:BX@Q1cW7>LQ20026<H06ABU36<L
i`Q236<Lia24124@Q0PR5:D@Q24848@]JbU:5:DLi`00248U:B4848@]JcW>008]J`05;D/]RaRV7>LH
aP0248@04Re[:DXLibDY248U:A24:DXLibDYE[DU2C6<@Q0U:F<H;F/000Qoo`13001ooe:D7>LicWoo
>LhaS7NmDY@aS2DYLi`@Q4icOol]Jf<HOolDQBDY8@Q:DW>L9BUNmacW;F]_NcF=IcT40Cg_<H`@Q7oo
E[Dmk`009BU:DUkg6<I:DSW>MkeF]F]J8@PicVLi6<H007NmE[Eooc6<001kgTic7>McW2e[E[D]Jg>l
IcT00R4801040DYB5:Eg_Dic9DUBU0aS7>Mg_Fmk>Li:DV]JCW<000Uoo`0027oo00T000aS12448@a3
12488P0034<00`@Q0R4800<HaPPR>Lh00SF]00e244XbBU8icSW^?Nl]JcF]>Li242e[9BU24002>Lh0
2dHaBU8e[A246<H@Q1BU48@Q20aS6<H00QBU0196<CF]?NlLicF]248<HacW5:D]BbU:;D/]JaRV5:DQ
22U:8@P2@Q001RU:24848@PR00040@848@0:0008@PQ210448@@124848Goo0008Ool03000=HdQ22e[
=Ld@Q1S6AS4aS2e[34<mk`8Q200a:DXaS2e[9BTicSF]48@YBQS6000<HaBU<H`Li`aS9BT48C6<7>Le
[BU:7>L8@QS636<Q20PR6:H@Q0Q20008@QcW5:DU:B48000@I36/9BTLi`a348@aS4Ha7>L48ABU6<H0
0R480RDY019241246:HQ223X6<H@Q0Q27>L]Ja249BTicSG=<F`]JcW>0008Ool07P00OolHaTicBU8i
cTic7>L<HdHaKg/Q26]J;F][FPQ2?Ll002e[IcTmk`aSDY@mkac7CW<]B`00>LiBU08HaP0eBU848Be[
=JeJeRU:HaQ6<AcWOom>Dd8@F[HLie:DOom>LbU:H_QBU7_N9BTmkdic248DYBDYIcU>L`00Kg/Q26mk
8@QJ]SF]LiaoocF]:DYBU6mkCW=g_CF]?NlHaRDYIcUWFAc722800009Ool000Qoo`060008@PQ21240
00Q20P@Q0`Q201@eSA24?NlQ21S6:DXicTHa@Q1BU48@>Nhe[CW^<F`icSF]>LhaS2e[0SF]00i244Ha
AS4mk`a3@Q088R48248@Q0Q25:DHaQ240d8@00P@Q248?NlU:AS65:DQ:2480S6<00i241cW8@P]JbE9
>Li6<AS68@P40@@Q00048@000P@Q00@000Q20008@P848@03001oo`0000Qoo`0L000e[BU:5:D@I1S6
36<ecABU48@mkbDY36=B]1BU:DXQ2124<H`Li`@Q36<LabU:36<HaQcW5:D28@P01BDY;F/]J`Q26<H0
0PaS02D@Q1cW7>LDQB485:D@Q1B548@<@be[6<H@Q1BU124@Q2U:9@T8@Pa336<e[C6/=Jd@Q36<7>LU
:@Q27>L]JaB536<Li`@Q;F/Q200236<012e[AS5BU48@0TYB00<icQcW000027oo05D007oo@Q0icP00
?Nmg_DicCY=F]A24BU8<Hac7Ool]Jf<HF]INmdXb000icRe[E[E:DQS6IcTaS5kgHaP<HdYBJeX@Q6<H
DY@LifLi?Nm[FT8@Noi[NPQ2MkdU:D8@000]JfLiD[@@I5:D:DX000Q27>MNmdHaLi`mk`aSLi`Q23W>
BU9g_ABUDY@mkfmkAS5WFB48=LeF]AS636=O5bDYKg/icRDYLi`00009Ool000Qoo`0300048@@10080
000512488P0022848@02=Jd02Sg_@Q0e[ABU248]Jd8@>LhmkcF]0T8@00TmkcW><H`]Jc6<=Je243g_
;F/00SW>00LmkbU:248HYP@Q8>P8@P0236<07`a37>LDYDYBAS5:DSF]6<HLibe[6<H]JbDY>Lh]JbDY
>LhaS1cW9BTaK2DY:DXecABU48@88P00124000PR0088@P031248@P@Q00848@03229oo`0000Qoo`03
000e[CW>008Li`0;>Li6<BTZBU8Lib48>LhDQBTZ:DXLi`025:D02BDY36<DYA241248@PaS:DXDY@02
7>L05Qc7248Li`aS6<H8@PaS248HYQ2410448ABU6:H@Q1B5;F/YBQB59BTYBQcW0QS600dicQS6:BXm
kbD9<Ha6<AcW>LhYBRTZ9BT]B`0212404C6<9BT8@PaS9BTYBRe[9BTYBQ24124HYPQ2>Li:DSF]0000
27oo04D007ooLia240@1F]H]Bf<HLi`8@QBUCW<]BaBU248002e[001g_Ekg8@QJeSF=LiaNme[F8@QS
61S6AS4]JdjC48A240@QJeY:DP00<HacW1c7Ki/U:BU:MkdmkgNm8@QS66Li:DY6<ABUIcTHaRU:BU8@
Q6<H9BUF]CW^58EB]11TDY@LieJeIcT00SW>00i>Lgoo36=BU000<HaF]@@1125BU5kg9BT8@P002Goo
0008Ool01@0022848@@Q00000`@Q00l000@1:FXaK36<AS4aS1B548@48AcW@Q0mkcF]AS401CW>00h]
Jd8@=JdYBSW>=Je:LTYB248<HcW>7>L48Be[0Q2400LHaPaS5:E244HaBU9240026<H010aS=JdLic6<
0QcW010YBQBU=Jde[AcW8@PYBRDY=Je:DQBU;F/<@`00248000@48@0624800000125oo`0027oo02<0
01S6?Nl]JbU:48@48B4836<aS1cW7@L@I0@Q7>LDY@@Q5:D@Q2e[6<HDY@Q25:DHYQS67>L003F]5:DH
YR485:DHaPQ2008@Q00@7>L<H`@Q9BTHaQBU7>LDYAcW<H`a[1cW124DYA2458D27>L07QBU7>LYBRU:
E[DYBS6<7>LHaRDY7@L<H`@Q48@LiaBU9BTHaQcW228LibDY:DXicRe[@Q0M1`a348@000Qoo`1E001o
odicG_LaS2e;<Jag_BDYBU8@Q7>LDYA24124:DYBU2DY248005[F>Lhmkbe[HcQoocW>DYAWFEJeG_Mk
gSW>CW<HaQcWKg/<@cW>48@a[6]J>NiJeQBUAS5kgU:D1256<C6<IcU>T`Q2?NlPj6mk@Q048DYB7>M[
FT8@NmhLie[F?NlU:AcW>LiS66]J248e[FLi=JeFe@aSAS5:DP@Q36=BU3W>00002Goo0008Ool01@00
12488P0024800PPR0P@Q02L002D9<H`aS3W^>LhHaPaS24848AB5DY@mke:DCW<mkcF]>LhaS3F]@Q0m
kcF]CU=6<E9dBU8@I0Q2:DX<H`PR5:D<@b486<H<HaS6>Lh00THa00I64AcW7>LHaRe;?Nl212401`aS
248Q21BU:DXaS2e[008YBP067>M:<RDY7>L<H`@Q0`0000@48@Q22488@P848@03229oo`0000Qoo`0?
000e[BDY249241c7>LhY:PaS6:HDQ@Q25:DLicF]008Q200I6<HHYTHa36<@Q2DY7>L48BU:6:HU:BU:
9BTDYA246<H48A24248DYAB546@40AS6;F/00Q2400P<HbU:24888QcW6<H@Q0a30R4801XLibDY5:DL
i`@Q34<U:AS636<<@aS68@P]JbDY6<H<@aBU:DX8@R485:DaS2U:<F`Q20PR0RU:00<Q23g_000027oo
04T007oo229>L`Q2<HakgVLi9BT@Q6mkE[DHYVmk=JeW>BDYKi]BU4jCE[D48ARVGaM:DRDY:DY_N`00
8@P]Bbe[BU8<Hg>L?NlHYVLi5:EJeVmk?Nl8@TYB:DYg_BU:F]H@I1BUIaTLidHA=JeoodYB58E2435/
=JeRn1BU>LiW>E[F36<U2F<H105S61c7;F]oo`02IcT02W>L@Q1O5cg_HaP<HfLi<H`]J`002Goo0008
Ool00`0022848@0212405@a3248<@`00228<HcW><H`mkdHa>LhU:A245:D<HbDY>Li243W>@Q0icP02
?Nl01CF];F/aS3F]>Nh00Tic01@DQ@@Q124HiSW>48@<@aBU34<DYA245:DicTYBAS5241S65:D@Q1BU
0aS601/DYA1T48@<@a2446@<HcF=;H/icS6<7>La[2U:12440@00104000Q236<<@`00104007oo0000
27oo00<003g_?Nl00QcW00<@Q2U:36<00Re[00TDY@aS36<@Q1S6248HaRDY34<00QS600THiQ24124Q
212436<DYBe;8@P00RDY00@]JaSV36<DY@<8@P096<H<HaSV248Li`@15:DU:@Q2008@Q08Q200?;F/H
aQcW248Q21BU8@PLia248@PHaRDY6<H@Q1S6008@Q00536<HaRDY9@TDY@0212402ABU=JdLid8@36<@
Q1BU36<00008Ool0=P00OolLicF]LiaJeQ24AS4DYE[F5:ENmcW^5:D@Q7_N249:<P@Q=Je6<@@Q9DT]
Je:D;D]:DV]J9BUS648@8@QNmdiC6<IS66MI9BU:LP00CW<<@dHa5:EJePQ26<IW>CW^Liaoob48E]E>
L`9g_@0;7@M_NfnKMkd@Q248IcT48CW>@Q1g_@025:D047oo=Je_N`00DYAB]1S6HaPDQEJeKg/UBFmk
<HacW0002Goo0008Ool0600024848@Q22288@Pa324840@005:De[C6<;F]:DSg_;F/HaPaS34<40B48
<F`icP8e[@0CBU8icRe;;F]6<CF]BU9>Tf<H124<@aBU6<HicQcW8@Pe[@Q26:H00Q2401/YBTHaAS56
4B487<LHaQ2436<LiaBU8@P48AcW36<DYAS646@48B3X;F/]Ba24>LhYBP@100000P@100T8@P@Q34<4
8@@112488Woo000027oo01H002e;;F/@Q2DY5:DYBQc76<HQ22DY7<LHaQcW9BTHaP@Q6<H<Hc6<48@<
H`8HaP0@5:D48B4858DHYQS648@HaQBU248<H`Q248@LiaS646@224801A1T48@001RV36<00QBU00P<
@bU:;F/icP@Q36<@Q1S60PQ201X<Ha1T8@PHaQc76:H8@QBU36<<@b3X8@P@I1246<HDYB3X36<]JaRV
7<L]Jd8@48@DY@0027oo01`007oo36=g_DHaHcQ24000?NmB]4HaHcP@Q6mkBS9245[FLi`YBQBUJeXa
S2e[000U:EkgOolU:@8Li`0;9BTmka24125F]@Q2LiaBU1cWLk`Y:P02Li`01F<HMkde[F]J48@00Tic
00L@Q48@:DYcW2e[48ABU002Mkd06T8@JeYW>EJe<HaJeQ24G_LLid8@001Nm`Q2;F]kgPa3<Hag_F]J
:DXmkb487>MF]F<H0009Ool000Qoo`0400048@@Q10431240:P@112440ABU:DXQ236<BU96<CF]5:D@
Q0@Q7@L40@aS48@HaSF]@Q0YBS6<>LhU:DYBD[@Q200024848@@136<e[B486<HU:D8@<H`HYQBU;F]6
<@924003BU8DYABU008Li`0E5:DLiacW7>L@Q1BU48@DYA2446@8@Pa35:D40Bf;:DX8@P@100040@00
00848@800004248007oo0008Ool01@00F]HQ20@Q5:D00QS601H8@QB59BTQ21d736<HaQB56<HaS0aS
104DY@aS000DYAcW48@Li`@Q7>L48@88@P056<H88PaS46@@Q00236<09@@Q7>L@Q0aS5:D]RaS62484
8ABU7<L48AcW48@<@b4X<H`HaPaS6<HPj0@Q;F/DYA248@PYBSG=9BT<Ha24@Q0]J`Q236=6<BDY008D
Y@08<H`8@Re[8@PDYBU:;F/000Qoo`1E001oof<h@Q0U:Fmk48A_Nbe[Oole[@@Q9BUW>ABUKg/Q24YB
5:E:DVnK?NmS648@>LiW>@Q2>Lh001BU9DUNma24<HakoU[F>NicW5lG9BUJeRe[48AF]E[F34=WFCW>
36=NmcW^Mkd8@R48CW<HaVLi;F/DYG>LMme>La24BU9_Vc6<HaQ246mkF]I[NSF]6<H40ABU7>MO5eJe
6<HicP00Kg]243g_00002Goo0008Ool01000124000@10`@Q00T000@Q6:HLabe[6:HU:DHa8@P00aS6
0aBU01@8@Pa336<8@Q1T36<@I1cW48@8@P@112488P0048@000aS=Jd]JacW0Sg_00D<@aBU<Fa:DT8@
0096<@079BT@Q1cW8>PLicg??Nl00SW>00le[AS66:H@Q2489BTDYA2446@0011T<H`Q20@122800`00
00L8@P00000000@1Ool00008Ool0A@00>LhecB48AS4icQS636<HYRe;8@PYBR48248@Q1RV6<HLaacW
?NlYBQB548@DYAS636<@Q3F=9BTQ21S646@U:AB5248<HaBU9BT@Q0@Q36<88Q245:D@Q2DY7>L<@a24
6<HLib3X6:H88SF]5:DU:A2446@DYAcW48@HaSV^5:DYBP0034<@Q0025:D03RTZ48@YBQBU9BTQ20Q2
=JdeSBU:9@TU:@@Q0008Ool0E@00OolaK6MI8>P004Ha=JdaS7ooJeXaS6mk48A_NfLi<F`00248<H`D
QBDY8>Q[FT8@8@PU:FLi=He>LgNm9BU6<CF]249g_E:D000Q22DYCW<48Be[Lk`icT8@Nmh@I3W>6<IF
]C6<9BU:DP@16<HU:@aSDY@48@Q2:DXU:EJe5:E:DQS6=Je[FTHaLia242DY8@Q>Lekg9BUJmSF=Lk`e
[DHa>Ji6<@0000Uoo`0027oo00<000@100000P0000h48@00248000Q248@<H`@Q6<HLib4836<@I2e[
0QcW0Q2400TPj12448@8@PaS6<H@Q0Q26<H00PQ200H48@PR00088PQ26<H28@P043h?6:H<Hbe;:FY>
Ld8@AS4mkaS648@Q22UZ>LhmkcW>0Sg_00e243F]8@P]JaBU:BXaS0@Q48@8@PaSAQ4YBP0312401000
12448@@10P@Q00<007oo000027oo01d002f;248]Ja246<HU:@008@P@Q2485:D@I1SVBU848B48:DXH
aP@Q7>LHaRe[7>LYBPaS9BT8@QRV008@Q009124@Q1S67<LDY@Q236<<@b48008@Q00334<<H`@Q008U
:@0F8@PYBP@Q8@PU:B3X000Q20aS:DXHaQcW6<H@Q2485:D8@QS648@HaPQ258D29BT03PQ2:DXDYAcW
48@DYAS6<H`@Q1S69BT<Hbe[0008Ool03000OolikQBUBU8]J`Q2HaP<HdHa?Nmoo`800003?Nl48BU:
009S6012DY@Li`00JeXLidic7>MJeQcW9BTe[F]J7>LikV<H5:DYBT8@G_L8@Ukg5:D]Je[F124LifLi
NoioodHa8@QFeG_NLia_VbDYF]Ig_F<H7>M:DS6<JeX8@V<HIcUS6000Kg]cW2U:000aS5:d7>M:DS6<
6<H]J`@QKg/YBRDYKg/Pj0002Goo0008Ool200001PQ200048ARV8@PLi`88@P0<00088P@Q36<88PaS
6:H<HbDY>LhU:Be[0RDY00`YBQS69BTQ21249BTQ21BU7>L8@Q24124224805P@Q9BT]BbDY36<Q223X
5:DPj4HaBU96<D8@9BTLibDY>LhmkdYBAS564D8@0SW>00hU:AS6;F/mkbe[9BTDQA1T125BU35/=Jd4
8@0010@Q00D88P00229oo`0000Qoo`0i000mkb489BT]JbTZ:DXU:BU:48@HaR48@Q0YBQBU248YBR48
6:H@Q1cW6:HLiaBU48@DQ@aS34<@Q1BU6:H8@Q246<H8@QcW6<H<@`Q248@8@Re;124@Q0aS8@PDY@aS
5:DYBQ246:HHaQ246<HDQ@00008DY@0J36<aS2e[8@PU:B489@T001S6;F/Y:Q2436<Li`a3248DQABU
7>LDYCV^248DQ@Q27>L000Qoo`1E001oog_NHaQ242DYIcTaS1S6:DX88Vmk36=g_@aS6<IJeQS6;F]g
_CF]NmhU2GooE[DU:FLi2496<@009BUggFLiLk`]Bcg_>Lh8@Tic124DYCg_124005:D248@I124NmiB
U1S6IcTHaP@Q@Q0a[2U:E]DU:DicDY@0036<NohmkfLiKg]6<A1TE[Dmkc6<36<aS7_NIcU:DS6<7<L8
@Tic>Lh40Dic00002Goo0008Ool0200012448@@Q000Li`Q2124324802AcW36<@Q0Q248@HaWoo8@PL
i`029BT021S68@PU:ABU8@P]BbU:8@P36<H01`Q212448@0022800124008Li`0348@<HaS6008HaP07
BU92448@@Q0]JaBU7>L00Sg_00a6<D8@?Nm243F]>Lhe[Ac7:DXY:R48<F`26<H01@Q2BS8LibU:1240
0P0000P48@00124000@Q001oo`0027oo00P002DY9BTicP@18@PaS1cW0RU:00d<H`Q26<HYBRe[36<L
i`00>LhecB489DTU:@0348@06@PR36=6<AS65:D<Ha1T5:DY:P@Q6<H8@QS648@<@a249BTDYAS636<8
@R486<H<HaBU008HaP08000HYPQ224848ARV6<HHYP8<H`06248YBR487<LDY@aS0QS600XU:A246<H<
Hb486<HDYBDY48@U:@8Li`039BT007oo00Moo`1E001ooeJe7>M6<G>LCY=W>F<H48AS65kgF]He[ElG
9BUBU124HaPmkcW^DY@HaSW>001>LaBU001cW7oo7>M[FRE9:DYJeP@Q48A:DVLiBU8HiW>L249>LgNm
5:DYBUJe001[FRU:125>LacWCY=oobUZMmeBU0PRJeXYBU[F125cW2e;6<IW>BDY?NlDYF]jOomF]FMI
OolYBP00IeU[FRe[=JecW6]J00002Goo0008Ool200001P@Q00040@@Q:DXU:@8<H`05248<Hb488@PD
Y@02AS403DYB<H`Lid8@<H`8@Q248@PikT8@;F/U2ABU008@Q0036:H@Q0aS008Q20039BTU2ABU008<
H`0Q;F/HaQcW7>LYBTHaAQ56<DHAAS4DYB48=Hde[DHA?Nm64Cg_@Q0e[D8@;F/HaR48:BXYBQ1T5:DH
aP@QF]Ha[2e;00848@0800040@00124000PROol000Qoo`0d000]JacW=Jd8@Q24248LaacW8>P@Q36<
248]JcG=:DXLiaS68@PYBT8@7>L001S6248<H`Q28@PLiac79BTDY@aS8@PHaRe;248@Q0@Q10448A24
5:DHYRU:6<H@Q2e[7>LPj1BU34<258D27>L00`Q28@P]J`0248@061BU6<H@Q1248>P48BDY7>LaS4YB
:DXLibDY8@P48AS68@PDYB489BTLiaS65:D000Qoo`0<001ooe:D8@QF]@@QMkdLie:D@Q0<Ha1T0TYB
04L@Q0Q236<aS5:D6<IJeQ24>LhecG_NBU8U:DicMkdHaV<H>Li:<P00HaP]JeJeDYABM7NmG_M_NbDY
=Jd@I3W>CW<<He:D8@PLi`Q2JeY247>LG_MBU2DYMkd]J`PR=Jd@I3F]Liag_@Q2001JeRU:125S62DY
Lia_Nc6<BS9JeSF]9BUNmdicMkdmk`0000Uoo`0027oo0P000P@Q00<000@Q24800QcW02PQ212458DL
ibU:5:EF]DicE[E2<48@48@<H`@Q36<DYAcW248YBQS6>Lh]Jc6<6<H000Q26<H8@QBU000HYPQ25:D<
Ha246<IBU3g_@Q16<@924005AS4DYAS6;F/mk`02AS4033F]@Q0e[Cg_>Li242e[8@PLic6<;H/U:@8<
H`04124@I2DY;F/212401`0012400000125oo`0000Qoo`07000YBQ24CW<Q21S658D00RU:01LLiaS6
7>LDY@@Q8>PHaR487>LQ20@Q248Q21S67>L8@QcW36<Li`PR7>LQ20aS008HaP0>8>PDY@aS248LiaS6
46@@Q1BU6<HeS@Q248@U:@8HaP0424848ABU6>H29BT05P@Q6<He[A2424848AcW48@Li`aS5:DHaSW>
9BT@I1S636<8@QcW124DQAS60QBU00D]Jb4836<48@0000Qoo`1E001ooaS6<Hag_F<H36<e[@@Q7<Li
cU:DCW<mkaS6JeX@Q3F]Kg/mkdicMkeS62U:7>MS636<E[DQ26Li5:EcW36<5:D48FLiG_M:DQS6AS5_
NdYB@Q1g_DYbAS5kgS6<HcQF]CG=OomF]G_N001NmgNm=Jd<Hc6<BW9:DP@Q=Jd<HbU:;F/48F<HDY@@
Q0PRNoiJeP@QF]IF]F]J:DXmkfLiHaPUB@Q200002Goo0008Ool03@0010448@0024848@PR248Laa1T
124Q236<008Q2009AS4mkcW><H`]Ja245:D@I124008YBP058@P8@RDY9BT]J`0236<010Q25:D@Q0@1
0P@Q00@HaR485:DYBP8@Q00XBU964DHaAQ5244XbAS4HYQS65:DLidic@Q16<D8@AS4a[36<?NleSBU:
8>Pmkd8@?Nm242DY34<40CF=8@P48@0010448@PR00040Goo0008Ool01@00;D/U:AcW?Nl00QBU00HL
ibDY6<H<Hc5/6<H236<00a245:DDY@026<H02bU:8@P8@PQ236<DYAcW124@Q0Q26:H00PQ200/<@aBU
2288@QRV5:D8@QS65:D8@QcW008@Q00758DQ21S634<@Q1cW36<00Q1T00@La`@Q34<aS08@Q00A46@8
8PaS248Q22e[36<YBR4848@HYQB59BT<HcW>7>L<H`036<H012489BTU:@0027oo03P007oo@Q048FLi
HaQ247NmCW=:DW>L;F/eSG>LIcTe[BD9E[D40DHaOom:DSF]F]I[FU:dMkeBU0@Q9BUNmbU:Kg][NRU:
BU9g_@@Q>JhHaQ24HaPe[@Q2DY@HaVmk=JecW1BU7>MNmaBU@Q088SW>0PQ200m>Lg_NIcT8@TicAS5J
eS6<Lia>Lcg_48@e[E:d:DX00QBU00PU:G>LJeXLaeJe34=240PR0P002Goo0008Ool05@0010400000
12440@@Q000DYB3X9BT]Jc6<:DX]JcF];F/YBS6<?NlHiP02;F/03QRV9BT]Jb487>LaS0aS000Lia24
36<48@PR000224802@aS48@DQASV6<I6<DXbBU96<@02BU82AS40724858E6<DYB?Nm>Lc6<AS4Q24Ha
@Q0Q20aS9BTe[DYBCW<icTHa=JdLi`aS5:E242UZ22848@Q20P@Q00<007oo000027oo00H0036/MkdH
aQBU36<25:D02Q1T248HYQcW248<HacW48@icR4X0Q2400XaS0aS1248@QB57>L@Q000248HaP8<H`0]
5:D@Q1BU124La`Q2124LiaB55:D<HbU:48@<HacW7@L88QS68>P@Q1cW9BT8@P@Q46@Q22e[5:D@Q36<
5:DLibDY48@DY@aS6<H]JcF]48@@I4YB>LhQ:1cW008HaP06<J`@I1BU248DY@0027oo05D007ooHaP]
Jg>l105g_EJeIcTaS7_N>Lh00248DY@<HbU:9BT005Je5:ENmcg_HaQ[NPaSIcTQ23G=6<HmkcW>D[@U
:C6<JeYcW2DYCY<]JdicOomW>CF]JeY>L`@QG_LaS1cW<H`88S6/E[Da[1S67>Mg_Dic7>L007Nm@Q1S
62DY@Q0<HbD9IcTYBWNm<H`DYAcW36<aS6mk34=BU4YB8@QcW3G=7>L00009Ool000Qoo`0900040@00
00088P0022840@a3008YBP0<;F/Pj2e[:BXaS1S6124LibU:<H`HYSF]0Sg_00XDYA248@P8@Q247>LU
:A24248<H`848@05104<@`005:D<H`026<H034HaBU96<DHaBS96<D8@AS4U2AS6=Jdmk`92400??Llm
kdHA9BU64Be[=Jdmkd7`AS5>Ld8@BU8]JcF]008<H`0:DY@aK0Q2104000@100048Goo0008Ool04000
8>P8@RU:6<H]Ja24;F/mkbTZ7>L48BU:248@Q1BU0QS600DaS1c7000<HbDY0088@P8@Q00D46@88Pa3
8@PU:@@Q9@THaPPR9BTLiaS69BTDY@aS000LabU:228@I08<H`0:34<Li`Q222848@a3=HdQ21S6<H`2
7>L0636<6<HHaQcW48@<HacW9BT<@c6<=JdHaRTZ8@PU2ABU48@Lia247>LPj2489BT000Qoo`1E001o
ogooCW<LidHa124HaUJeG_M:DVLiDYAS67NmDYAkgVLi<H`DYD8@48Ag_AcW=Jd48CW>CW<48FLi;F]W
>AB5OomBU0Q2;D/e[F<H000]Bf<H2496<EkGCW<icP009@TicW>LF]Hmkb48=JeF]DHaE[D@Q6LiEYEF
]AcWJgYRn6<HF]HicP@1;F/mkbe[@Q1NmdXb000DYE[FDYAoo`Q2NmhHaU[f00002Goo0008Ool01000
10448@PR0P0000T48@Q2124@Q24X8@P]Ja2436<00aS600XYJQBU;F/DQABU:DXmkd8@>NhQ208DY@07
8@P<@`00248000@112400P000PQ200D88QBU48A6<DXb009:DP04AU5:DTHaAS42<H`01ch?>LhicSF]
?Pm244Ha0092408YBP03@Q0mkdYB00=6<@07>Li6<C5/1248@Rf;8@P00P@Q00D000Q2001oo`0000Qo
o`0>000LibDY6<HLiaBU8@P48Be[5:D8@R4848@HaP88@P0D124@Q1cW5:D@I0Q26<HQ21cW48@DYC6<
6:HQ20a3248<H`@Q228HaP88@P0A36<Q20@Q00040CF]8@PDYAc75:D88RDY5:DQ22DY36<U2@022480
5BU:36<<H`Q2124LabDY7>L00248<H`HYQ2436<U:@Q26<H48AcW9BTQ200248@01AcW6<HYBP@Q0000
27oo05<007oo8@Q[FP@QMkd0035/9BU[FW_N>LhQ23g_CY=245:DOom242DY6<HQ2124HaPYBRe[6<I_
NbU:>LhYBTicF]I6<BDY36=6<EkgOom6<C6<9BTicWNm6<IF]G_n7>M:DUJeLk`]J`00Kg/HaU:D6<Ik
gS6<AS5g_DicHaP<Hfmk?NmWFDic5:D48BU:34<Lic6<6<He[B48:DYS>7_N=LeW>C6<008000Uoo`00
27oo10000P@Q01l88P0010448@Q29BT]JbDY:BXLiaS67>LHaRU:CW<YBQ240008@P@Q48@HaQc78@PL
ia24124000@Q00048@0224801ABU2488@QcW58D00TYB00=>DdicCW<00TYB00=243g_9BT00T8@0SF]
01]:<S6<>Ji24248<J`icSg_AS5243F]BU8]JdHa@Q0aS1B5124YBRe[24848@PR00040Goo000027oo
00/004Xb9BT88R48:DX@Q3V^48@DQAS60088@P0>2288@QBU6<HDYB4846@DQ@Q236<HYQB5;F/YBP88
@P0X5:D@Q0Q2:DXDQAS6;F/Q21B56<HaS0@Q6<HDQBU:=JdHaQcW6<H40AcW36<48BDY=Jd48AcW248Q
21BU58D<@be;7>LQ21cW6:HLicW>=Jd248@03RDY248Lia246<HDY@Q28@PPj2487<LYBS6<0008Ool0
8P00Ool@Q5[F8@QooekG>Lh40E:D6:H001BUNmiNmd8@48@YBUJe8@PPj7>L<Fac_4HaG_M247OMAS5[
FQcWE]Eoof<H0RU:034DYF]J<FaO5g_N6<IRn0aSG_MS61BU@Q0Pj4YBLia6<B48HaQW>G>l>JhaS0Q2
@Q1ood8@IaT<Hf<H8@Qg_E:D9@TaS2D9G_MW>AcW;F]:DP005:E_Nekg<H`icS6<Kg/00009Ool000Qo
o`0700048@00124000PR12400PQ201L88P@Q7>LYBSF];F/Laa247>Lmkd8@>LhDYB48248<HaBU248U
:A247>LHaQ2400848@0:00048ABU8@P@Q0a36<H8@QcW6<H2BU8024HaCW=:DU:D@S1:DT8@8@P2>Lh0
1be[@Q12448@?Plmkb48008mk`0@AS52448@>Ni:DRU:AS5243g_5:D002U:=Jd48@@1000212400goo
001oo`07Ool01P00:DXU2C6/8@P8@P8HaP8Li`8<H`0:8@P@Q0Q28@P]J`Q236<HaR48248236<02A24
5:D<Hc6<8@P48ABU36<@I0026<H00`aS248HaP028@P0912436<8@Q2436<HaR485:DU:@Q26:H8@Re;
9BT8@QcW248000@Q6<H<H`Q2<H`8@Q1T:DX8@QS67>L<HaRV248<@c6<;F/Li`8HaP075:D@Q35/?Nla
S2DY000027oo03@007ooNoikgSg_MkdYBVLi5:D@Q5KEJgY[FUJe:DY:DV]j@Q0]J`aSBW8Y:SG==Jeg
_AcW000aS7>lNmi6<G_N>Ni[NR48HaQWFA24BU8@Q6<H;F]c_4YB7>M_NfLiBU9kgPa3<HaJeP8@Q00C
D[@Q25[FNmhYBPQ2:DXDYB4XBU8e[@00>LioobU:G_M:DQS636<00Tic00D@I36/=Jd8@Sg_008HaP03
Mme2400000Uoo`0027oo0`0000@48@@11248@P848@08248@Q000248Q22TZ;F/U:@8HaP0Y7>L<HaBU
;F/U:AS6:DX48B48=Jd8@QB55:D40@0024848Be[E[D]Jb48228]Jb486<I>LdYBDYA>LdXb@Q16<DYB
AS4Q21cW6<HaS48@AQ4mk`02<H`04Cg_>Lhmkd8@>LhaS3g_@Q0YBTHaBS96<AB548@e[Be[10400P00
0PQ200=oo`00Ool01goo01@003V^248Pj1BU9BT8@QRV36<HYP@Q5:D48@PR=LdaS0009@T<HbU:0R48
00D@I1cW248DY@a3008HaP0h7<LU:AB5248DYBU:7>L8@RU:9BTYBQcW7<LDY@Q26<HLibe[7<LDY@aS
8@PLic6<5:D@Q1B534<8@PaS58DHaPaS7>LQ20aS5:D48BDY5:D<@acW58DQ20aS5:DHYQBU=Hd@Q1S6
36<LibU:>Lh000Qoo`1E001oog_N36<icQS6E[D004YBLiaoobe[7>L<Hf<H<H`]JekgBU8U:FLi5:EF
]B487<MJeRe[?Nl<@`aSG_L]JcF=Nmi240009BU:DW>L=Jd<Hdic46AkoTYB36=:DP009BUS64icLi`m
k`@Q000aS4iCIcUW6G_NG]LaS11T@Q1BU0Q2=Jeg_EJe125:DSF]OomNmg>LNmi244YB6:HHaTYBAS4H
aTYB00002Goo0008Ool2000212401PQ21248@PQ21248@P<48@8Q20039@TaS1cW00<DY@036<H]JaBU
008@Q00D000DY@@Q34<<HaBU124<H`00248]RbD9:FXicQBU<F`@Q1RVAU5BU09:DP0L@Q16<Cg_BU8m
kdYB6>HHaTHa?Nm243F];F/e[CG=>Li243W><H`mkdHa?NlU:D8@?Nm:DPaS34<2;F/01`@Q22848@00
249oo`0000Qoo`06000YJQBU48@Lia240QBU00haS1S66:HLibTZ6<HYBRe[248<HbDY;F/Li`Q20Q24
010DQABU6<H]JacW248<HaS646@8@Q1T9BTLiaBU;F/YBP8HaP036:HLiaRV00<48@0U34<48@Q28@P4
8ASV5:D@Q1S66>HQ21S634<@Q0a3000<Hd8@<F`Q223X9BT<@`Q2;F/U:C6<36<Libe[34<HaPaS248e
[AcW000027oo030007oo?Nl<Hc6<8@QJeTiC9BTicTYb58D8@U[F7>MkoUJe9BUkgWNm124@I4HaLia6
<G_NCY<8@U[F;F/Q20aS>NhHaWNmHaQNmbe[Li`aS4HaLia:DUkg48@U:@@Q<H`2:DX035:D7>MkoSW>
AS4Q26<H34<aS5kg=Jd48@96<@05JgXY:VLi;F]>L`02Lk`03Vmk<J`icVmkLi`mkbe[HaP8@WOM:DYJ
eRe[0009Ool000Qoo`0500048@@112440@021240500022848@@100088PQ25:D40A245:DLib482288
@R4836<@Q0aS10426<H01a2424848@@Q24840@@Q008DY@047<LLib486<H27>L04d8@?Nm6<DHaCW=6
<D8@AS4mkdic7>LQ21BU58D]JbU:=HdecD8@0096<@03@Q0icSg_008mk`92400=?Nm6<ABU249242U:
228000PR00048Goo000027oo00<002DY9BT00QcW00XY:RDY36<HaQc7:DX@I1S648@]J`8HaP0?9BTD
YAc79BT@Q0a39BTDY@PR58DHYQ2434<48ARV008Li`049BTaK12446@28@P246@04B486<HDY@aS228L
a`Q26<HQ21BU;F/Y:PaS8@PHaQ2436<00Q2400XDQARV9BTHaRD97>LicS6<36<DY@8]J`0<58D<@acW
:DX8@S6<6:HU:@@Q248Y:P0027oo00H007oo5:D<HdicCY<25:D0AGooE[D48ABU;D/001BUJeY6<E[F
6<IS>5Je36=kgRDYE[DDYG_N:DX8@U:D000]JfLi;F]kgUJe5:EkoRU:DYA[FPPR<Hag_A1THaPicQS6
>Ji[NWoo9BUJ]UJe5:ENm`@1249oof]J<HakoTYBHaP]Jd8@AQ4Lig>L;F]NeacWCU<U:BD97>M_N`02
6<H01Re[36<e[F<H:DX000Uoo`0027oo00<000@Q00000P@Q00<40@@Q12400P@Q0`0000H48@Q22480
01RV5:D27>L212403P006>HDY@@Q34<48@aS124HaRU:CW<Q22DY>Lh2=Jd05SW>BU9NmbU:9BTe[CW>
@Q1BU4icDYA:DSF]AS4icQBU6<H<HaB5<H`mkcW^0THa0Re[00dYBT8@;F/e[DHa>Ni6<DYBCW<48@Q2
<H`e[@0412400`00Ool00008Ool01000:DXe[AS60QBU00]:DRU:9BT48Be[48@aS0Q27>LYBQBU008H
aP0F248DYAS6248HaRe[5:DDQA24:DXLi`@Q8BPU:B488>PLi`PR5:DQ20aS48@27>L01@00248<Ha24
<H`00QcW01DHaPaS7>LYBPQ25:DHaQ242288@QcW8@P<@`aS58DDY@Q2;F/Q21BU36<00S6<00`DY@aS
6<H@Q1S69BTLiaS6248aK36<0008Ool08@00OolHaRDY>Li6<@Q26<IFeGoo:DY:DSF]48@e[ARVGaLQ
21BUDY@@Q4ic248]JeJe248ikPaS?NlicQS6IcTDY@02=Jd0<PaSIcTDYDYB6<H003W>DYAJeQBU@Q1[
FSW>F_H88QS6AS5koQBU<JacW24836=6<Dic>Li_NcF]124mkgNm48A6<@aS=Jd48ABUCW<YBRDY@Q1S
63W>000e[@00>Lh006<H0009Ool000Qoo`800005104000@Q12440@03124210403PPR00048@aS48@Y
BPa35:D@I1245:D@I0Q246@248@02B3X36<DQDHa<HaJeUJe@Q16<@02@Q004b489BTU:DHa>Li:DTYb
CU=BU4icAS5:DSg_CW<HaQBU58DQ22U:008e[@0D=HdicSW>@Q16<D8@BS8YBSF]AS5>Dd8@AS5:DQ24
124e[C6<248000<48@03Ool007oo00Moo`09000aS2e[7<LU:CW>;F/mkbe[008DY@057>LQ22U:36<Y
:P03248081BU48@<H`Q236<@Q3W>248Li`PR;D/@Q2485:DYBQcW5:D88PaS9BT@Q2DY<H`8@SW>124D
QA2434<Q20Q25:D27>L222801Sg_5:DDY@Q2;F/YBP8Li`0>;F/<Hb3X8@PHaRDY248e[BDY7>LYBQS6
48@DQ@<Q2005248DQBU:24800008Ool0B000OomS6124F]IBU124NmiBU6<HCW<e[F<H:DYBU7_nE[D<
Ha24NmhLiaRV8>QcW1BUCW<e[F<H8>P48BDYF]H@Q0aS124U:F<H=Jd40@006<IS67_N9BUFUFMI9@Ug
_B48?NmF]F]J7>M246<H48A:DU[FIcTU:F<H<HaW6ABUOomNmbe[6<HLie:DNmi2409oo`0;000mkcg?
Kg/Lig>lDY@aS6]J@Q000009Ool000Qoo`0500088P@Q00048@0200003`@Q000000001048@P@Q000H
aTic5:D8@Q1T36<HaP027>L04`@Q36<]JdHa=Ldmkc6/=JdmkcW>@Q16<CW>@Q0mkcF]8BQ243g_0096
<@0;@Q1>Le:DBW92436/9BTLic6<:DX]J`02?Nl2AS400cW>?Nlmk`02<H`055:DAU5>Ldic@Q0ikSg_
>Lh]J`Q2229243g_12440@00124007oo0008Ool01`00D[@]Jbe[?Nl<Hc5/008U:@0A:DX8@PaS7>LQ
21BU=JdU:@aS228@Q0@Q248DQA248@PDY@0348@03QS67<LDY@a3:DXLi`aS5:D<Ha1T48@8@QBU48@2
5:D236<01PQ28>PHaQBU6<H48@<DY@0836<HaPaS48@Lib4836<Li`8DY@0>46@HaRU:<H`U:@aS248@
Q0PR248U2ABU6<H<H`8HaP03248YBP0000Qoo`1E001oocg_7>MS65kg7>LYBVMIJeXaS3W>IcTYBVmk
F]IW>D8@>Ni_VbUZ6<IBU7oo7>M6<F]J7>M:DPQ2:DX@Q4YB=Jd004ic249oobe[<Ha:DVmk000mkfmk
Ool]Jfmk=JeggFnK;F]245kg000YBV<h248UB@a3JeX48F<h;F/icQS6>LiW>C6<7>M>Lb48@Q0e[Be[
OolicQS6CW=_NfMILi`U:Cg_00002Goo0008Ool400000`PR10448@0300002@@100048@@136<mkcW>
48@DQ@0236<02@PR34<<HcV^AS5S64YBAS4]J`04?Nl03DYB@Q16<CW>@Q0aS48@BU8mkdHaBU8mkdYB
008mk`03>NhaS2DY008HaP0HDYA>Ld8@@Q1>DdYB@Q0ikSW>?Nle[DicCU=:LU9d@Q0icSg_<H`YBPQ2
104mkcF]10@Q00<40Goo000027oo00X005kG;F/U:ABU>Lh8@R3X124HYP8U:@05<H`<HaBUAQ4Li`02
36<03bD9>LhQ2248;D/]Jc6<48@Q20Q236<Q236<=LdDQ@0412401aBU48@<H`PR5:DQ22e[008@Q009
228DY@aS124<H`Q27>LHaQcW0088@P0F8@PPj124:DXQ21RV48@@I0Q2104HaQc748@LaacW5:DQ22U:
9BT88QS646@25:D00aS68@P00008Ool0E@00Oom243g_58EkoTHaIcTYBQcWIcU[FWooIcU:DQ249BT<
Hcg_7>MBM0aS=Je_Nc6<124@Q6MIDY@HaVLi<HaS67>L249242D9Lia:<QBUMkdQ22e[JgYBU2DYF]HL
ia1T@Q0U:@00DWA_NbDYE[E_NgooBU9g_AS6AS4mkacWAS4<HcF]JeXe[E[F48A[FQS6E]EoodYB105B
U124Kg/DQE[F?NlHaP0000Uoo`0027oo0`0000<40@0000001`0001@48BU:BU8HaPQ21248@P@Q36<a
[5Je@Q0mkdic@Q16<DicAS5243g_0T8@0TYB00I:<SW>?Nlmkd8@BU82AS400d8@AS56<@02@Q0063g_
7>LLie:DBW9>Ld8@BU8icT8@BU96<DicBU8mkdYBAS564DHa<H`a[3W>:FX<H`848@04<J`icP@Q1243
00000goo001oo`07Ool08`007>LYBP@Q>Lh<HaBU48@U:CF]@Q048@PR6<H<@`Q25:D8@QS6248LibU:
9BTDY@a348@HaPaS9@T]JacW9BTaS0Q2:BX00QBU00/HaQcW6<HQ20aS:DX<Hb485:DQ2124008DY@03
124aS1cW008<H`0:9BT<HaS69@TYBQcW6<HU:@Q26<H25:D01`0036<<Hb487>LU:B48008<H`09000@
Q248248Q21BU?NlQ200000Qoo`0H001ooacW;F]S65kg@Q1F]ABU249>LgNm001BU7Nm9@Uood8@HaPQ
26mk:DY>LbU:0QBU01hmk`a3248]JfmkE[D<He[F?NmcW36<=He[NQBUAU48@QcW46@8@U[F249S62e[
36=g_Be[Nmi_Nd8@G_L2HaP035Je124LiekgNoiBU4YB5:E[FU[F36<U:@8icP0=48A_NaS6>LhYBT8@
Oom241S6?Nl48G>L00002Goo0008Ool200001P@100000000104000840@0G12440@@Q104icSF]1240
00@1000<Hb48G_MS65JeCW=BM5:DCU<icSg_AS5:DP02@Q02CW<00dHa@Q0aS0029BT01D8@>Li:DT8@
AS40148@010U:Ac7@Q1BU4icAS5>Lcg_=JdmkcF]?NmBU4YB:DXmk`8icP09=LdicT8@>Lh48@PR6<He
[AS600840@0512440@@QOol00008Ool00`00>LiW>@02<H`0111T7>L8@QBU0QcW00HDYB486<HDYAc7
24828@P00bDY7>LHaP026<H01ABU8>PYBQc78@P00QcW00LHYP@Q8@PLicF]9BTYBP0236<010@Q000m
kbU:0QBU00@8@PaS8@P@I08<H`0Q7>LicQ2446@DY@a36<H48AcW9BTDYA1T5:DHaQcW48@e[@a36<I6
<AS66:He[AS648@U:BU:;F/mka1T36<8@P0000Qoo`04001oof<H=Jd21240@4icG_LYBPaSG_MkoQRV
CW<<@eJe=JeS67oo?NmcW5JeHaPHaU:D:DX<Hd8@:DYNmb48E]D40@00HaPaS4iCDYAg_B48;F/@I3F=
;F/Q26Li;D/mkfLI<H`]JdYB5:EkgW>L124]Je[FLi`HaSF=Oolmk`aS9BU[FW_N125NmcW^0SW>00de
[C6<Nmh]JgNmE]D003g_7>Le[C6<Ki/00009Ool000Qoo`T000091240000000048C6<=Jd8@P@10084
8@03;F]245Je00=JeP08AS5243W>>LhmkdYB?Pm6<@9BU004BU9243G=:DX27>L012DY;F]6<D8@0THa
0T8@01<a[3F=@Q16<E:DE[E6<DicBU8mkc6<?Nle[DXb@Q0icSg_=JdicP02<H`02Cg_6>H8@P@Q7>La
[11T12488P0300000goo001oo`07Ool02`00=Jdmkbf;:DX8@R4836<aS2U:36<00Q240388@Q24248L
icF]9BT48B487>L<@aS6:BXYBQ24124YBQBU;F/Lia1T248DYAcW6<HDY@@Q6<HYBQS648@HaPaS6<HL
i`aS6<HDYB3X124YBPQ248@LibDY36<U:AS6228@Q0aS0RDY014<Hb485:DHaR48<H`48AcW9BT8@QcW
5:DLicW>>NhicSg_008U:@03001oogoo00Ioo`0;001oodicCW<DYGNm6>I241cW?Nl8@P026<H0;P@Q
CW=W>ASVOolLiekgKg/Y:QBUAS5W>B48AS5BU3W^Kg/aS000BU8mkf<H7>M[FW>L8@QJePQ2F]He[G_N
?Nl@Q2DYJeXHaV]J?Pl@Q6nK>Li>LeJeF]Ioo`aS0U[F00DicQcWJeYkgRU:008]J`0A36=JeQS6BU8@
Q6]J9BT@Q6mkF]HHaP@QBW9kgRe[Nmh00009Ool000Qoo`@000031040000000<00005104000@10008
8P029BT312401CW>@Q1>DdYbAS400SF]01HikT8@CW=:<SW>AQ5BU5kgE[D]JacW=Hd]JbDY7>LHaQBU
>Li244Ha@Q1:DP8icP0;8@PY:TYbE[E6<DicBU8aK3F]AQ4mk`02BU801DiCAS4mkbU:>Lh00Sg_00Ha
S0@136<@I1cW<H`312401@PR000007oo000027oo00X005:D36=>L`a3=JdLie:D<H`Q208U:@075:DQ
22U:58D48B4848@00QBU00L]Ja24;F]6<ARV:DX48@02:DX07QcW228Li`aS6<HLiaBU6<HDYAcW6<H8
@T8@1248@QB56<HY:Q2436<HaP@Q7>LQ23F]?NlecC6<9BTYBP8Li`0=248U2A24124DYARV248Pj4YB
9@U>LbD936<00R4800PU:ABUAS4Q23F=9BT]B`0027oo00X007ooNmiS62U:229245kg9@TaS09kgP19
>JhU:Cg_JeX40Fmk7<L48GNm?Nl8@UJeLia>LekgF_IW>@aSG_Le[DXbKg]oo`aSKg]2459dLi`LadYB
HaQ[FV<HOolaS0@Q<FaBU6Li48@]JeJe36<Lifmk5:E:DP@QLia>Lf;h124eSBDYCW<YBSW>125247Nm
:DYJmQRV7>LDYGoo>Lh48Dic;F]_Nb4800002Goo0008Ool300000`@100040@0300009@@100000000
10448D8@>Lh40@00124LicF]<Ja:DT8@9BTmkdYBDYA:DSg_>Li>Le:DE]EBU1247<LU:BU:8@PPj1S6
5:DQ23g_0092408icP06;F/Lic6<DYA6DD8@0Tic01He[Cg_<J`icTHa@Q0icSF];F/mkdIABU96<B48
124001BU;F/Li`PR12440@<00003Ool007oo00Moo`0C000a[3F]>Lhe[@Q2124Q20@Q:DX<Hbe[36<U
:A249BTYBSW>12400RU:01TaS2DY9BTLiaS66:HaS2DY?Nle[AS6?NlDYA248@PY:QcW48@8@Re[:DXH
aQBU48@48@0236<07124248HaQS636<@Q1cW5:DHaPQ27>LYBQ1T6<H]J`@Q6<HDYB489BTDQAS6248a
S2DY7>LicRU:0QcW00M6<AcW7>LLib48>Lh00008Ool0?000Oomc_5kg7@LaS7OMOolYBTicOol]Jfmk
104aS4YB@S0LibU:IcT]Jg>L:DY_Nd8@;F]JeQcWJgXe[E:dIcTHaV]J>LiJeQS67>MJePa3@Q08@U:d
F]H<HfLi249>Lg_n=JdDYG_N?NmcW2e[E[De[FMI7>MNm`8U:@0G36=>Lb48G_LQ20a3NoiBU7_NMke[
FUJe;H][FWNm46@LieJe9BUoocW>36<00009Ool000Qoo`80000F104000@100048@00104000@10004
0@00104U:E:D5:D40@00<Ha245:DBU82=Jd01E:D;F/icSg_>Lh00Tic0UJe00=BU1cW5:D00QS600@Q
21cW6<HDY@8@Q0086:H<HaBU6<HDYDYBE[E2409>L`0FBS8ikS6<?Nle[CW>?Nle[CW>AS5BU3W>;D/]
JcF]7>L40ABU8>Q240PR104200001@@1000007oo000027oo03l002U:=JdU:Be[>LhDQBTZ8@Pe[ABU
;F/Q22DY6<HQ22e[6<H8@QcW;F/<H`Q2;F/@Q3F=5:DHYPQ258DLib3X5:DY:PQ25:DDQ@Q236<@Q248
:DXQ21RV9BTDYAS6248<HaB536<Q21S636<YBR485:D@Q1cW?NlHaQBU=Jd00QBU01@<Hd8@<F`HaR3X
7>LicQcW:BYBU0Q26<HaS3W><H`8@RU:8@PLi`0027oo05D007oo36=JeTHa48ANmacWLiaW>Be;AS5N
maBU?Ll@Q4Ha:DY_N`Q2>Li6<F<H34=cW3g_36<icRDYGaMkgWooE[DYBW>L:DXLae:DOolmke[F249g
_A24124icQBU?NlHaUkg;F/Lifmk5:De[FnK8>PQ24ic5:EW>C6<;D]BU4HaOolicR48:DXLieJe001W
>FnK=Je[NRU:;F/aS0Q2@Q1oodXb>Lh00009Ool000Qoo`0300040@0000P0000;1040000000048C6<
6<H000@Q@Q16<@02DY@023F]@Q0mkcF]@Q16<DYBCW<2BU80:TjCDYAFeEJe=JdLia245:D@Q1B536<@
Q1BU6:HU:DHaBW9:DSg_CW=:LTicAS4mkc6<>Li:DT8@<H`icS6<=JdmkdHa@S0icRDY124000aSBU92
40<0000610400000001oo`0027oo01D0036<249W>G>LBU9S61BUJgXQ2124248<@cG=8@PLicF]9BT]
JaS6<F`00SW>00@ecAB5<J`aS08Li`0D6<HLiad75:DQ:1S68@PU2@aS5:DicQS6248HYP0036<@Q3F]
48@U:@88@P037>LQ2248008Q20056<HaS1cW5:D<@`0248@040Q2=JdU:AS6125244YB7>LQ21c79BTm
kbe[:DYBU1cW0QBU00A2436<124000Qoo`1E001oof<HKg/YBSF]Kg]JeTHaE[De[A1T001>DgOM7<M:
DSW>000mkf]J5:EoocW>:DYW>@aSIcT]JaRVF]He[@aSCU=F]E[F1248@Q24DYAkoTic001:DSF];F/@
Q3W>NmhDYBe[F]HHaSg_DY@8@S6<JeX48Be[F]HDYCW^Oole[A1TDYA2436<58D48BD9Kg/<HdYB:DY_
NbTZIeT8@UKE34=S>0Q200002Goo0008Ool200001@@Q00040@0010400P000P@10`000P@Q00D<@c6<
36<40EJe0096<@0>BU964DYB>JhicTHa>LhmcdicDYA>Le9dD[ABU09F]@05CW<eSBDY48@<H`025:D0
0bDY@Q1>L`02CW<02D8@DYA>LdXbAS51l3g_:DXicP02CW<033g_=Ldmkcg_=Je244Ha=Jd]J`00124]
J`8e[@09124000@100048@00125oo`0000Qoo`0b000mkbe[;F/U:BU:8@Pmkd8@9BT88Re;48@Y:R48
7>LHaRDY<H`@I124?NlLia24:DYW>CW>;F/e[Be[:DXQ21RV10448@Q25:DQ22e[36<Q22DY124HaPQ2
124DYAcW8@P<@`8HaP0Q48@LiacW248Licg_48@Lia246<H8@Q24228U:B489@T001S67>LLae:DIcTe
[Be;>LhYBT8@>Jh48Ac736<]J`0000Qoo`1E001ooc6<5:De[D8@58D88V<HKg/aS5Je=Jd8@V]J=Jeo
oe[FHaPHaPaSDY@YBTic36=S636<105oodYB124YBPa3Nmi[FQS6AS5JmQBU:DX<@dHa>JiS62D9<HaN
mg_nAS4YBP@QJeYBU48@OolHaTic36=BU6<H9BUF]A24<JaNme[FKg/001cWCY<40C6<Li`<HekGBW8a
S0PRCW=240@Q@Q1S62U:00002Goo0008Ool00`001040000<00003@@1125241S648@48AcW@Q16<EKE
DY@mkcW>008e[@04<Ja:DSg_BU82CW<01TYBDYA6DDYBCW=BU0AF]@0?DYA:DSg_BU96DDicBW9244YB
AS4mkdYB@Q0e[Bf;0096<@0==JdLicF]AS4aK2E9>Lh@Q0@Q36<Libe[12400`0000H48@00104007oo
0008Ool04`00OolaS1S6E[De[Be[:DXPj3F]6<H@Q2485:D48AS6124icS5/008icP0@:DX00124:DX]
JcW>5:DaS0Q2?Nm242486<H]JaS69BT27>L00b486<HM1`0248@01QBU9BT]J`Q26<HDY@8Li`0F34<0
012436<Q22DY5:D@Q2DY7>LDYAd7;F/<H`@Q=Jdmk`Q2?Nm:DVmk:DX2AS402ABU>Nh88QcWAS4DYBU:
G_L00008Ool0<`00OolYBW>L>Li>L`00125Nmg_NDY@@Q1S6IcTmka245:E[FPaS124aS6]JBU8HaRU:
125JeRD948AoocF]E[D000a39BTe[DYBKi/]R`Q28@QNmf<H36=F]@@Q7>M>Lf]J8@Pmk`0248@01fLi
001:DPaS>LiWFGoo008@Q00G=Le>LgOMAS4@Q2DYG_L002U:Kg/<Hcg_Mke64F]J?Nl48G_n>Li_NdIA
46@00009Ool000Qoo`800003104000@100<000051040000000040@0212403`00105:DR48124<HacW
DWAJeTiCBW8icTHaCW<aS002>Lh013F]>Li244YB0U:D00MBM4icCW=:DTicBU9>L`02AS4014YBCW=>
LdiC0THa00<aS4HA@Q000T8@00aBU3g_=JdicU9d@Q0mkbU:@Q0mkd8@7>L212403BDYAS4La`@Q1040
00@100040@00125oo`0000Qoo`06001W>FnKF]IS64Xb0T8@00HYBQc7>LhaK1B5<H`27>L051BU1244
8BDY8@PYBTYB=Jd]JacW<J`<Ha24:BXHaRe[7>LQ20aS:DX248@07@aS:DX<@`aS000YBQcW:DX]J`Q2
9BTDQA24:DXLicW>36<Q20@Q48@]JaS6000HaQcW248HaPaS=Jd00PQ2010HYQcW8@PaS12436<U:B48
7>LYBS6<8@QoobU:>Lh000Qoo`04001ooa2448@2F]H0<1BU=Jd40GOM;F]W>A24124DYFMI=JeoocW>
AS4Q26mkCW<8@Vmk9BTDYG>L?Lm[NQS65:Di[Tic8@Qc_11T>LhU2F<hDY@HaU[F5:EBU4ic105:DS6<
7>LQ26Li5:E>L`9:DP0MAQ4U:E[F7>LPj5[F7<L<@cg_;F]oog>LCW=S6124F]HeSB48249:DVLiNmiF
]E[FMkdicPPRHaP00009Ool000Qoo`D000031040000000L0000<104000aS<J`Lia24124icSF]BU9F
]Dic0TYB00DmkbU:=Jdmkc5/008aS09:DP03=JdicSg_009:DP9>L`0;DYA:LTYBCW=6<Cg_=JdU:CW>
<J`Li`02@Q000dHaAQ56<@02@Q001dHa>Nhe[CF]@Q0icPQ200848@03>LheS@0000@00006104000@1
001oo`0027oo018003h?7>LaS3g_9BTe[BE9F]HU:DYB248HaRDY36<e[C6<5:D28@P04AS67>LeSB4X
9BT]JaS6124]JbDY248LibU:5:DPj2DY24800QcW00<48@aS7>L00Q2400d8@RU:;F/48AS6248DYBe[
>Lh@Q1S6248HaP0236<06QS6;F/e[CW>5:D]JcW>:DXQ:1S6<H`DYAcWBU8aS4iC48@YBS6<?Nm243g_
7>Lmkg>L0008Ool0>P00OolHaSg_48AS62e[BS88@RU:LiaNmc6<48@icP@Q@Q0Lie[f@Q1:DRDY2492
47>L7>LYBPQ2E[D88RU:8@Q:DV<HF]HHaSW>9BU:LQS6>Nh<H`@QCW<ecB48NmiS60Q26:I6DAS6<Jac
W00036<YBUJe0P0000i6<Be[@Q0icRDYJeX]J`a348@LifMINohQ24YB0PQ200T]Jf<HE[DaK7>l124a
S4ic00002Goo0008Ool200001`@100040@00104000@100<0000?104000@100040@@QCU<aS248124Y
BRe[BU9>Le:D009>L`07AS4mcd8@AS4aS3W>=Jd00Sg_00haS3F]<H`e[DHaBU9>LdYBAS4mkd8@?Nle
[BU:0Sg_00m243W>>JhecCF]>Li:DSF]>Li243W>=JdeSCg_<H`00P@Q00D<Hd8@@Q040@0000840@07
1240000000040Goo000027oo00`003V^JeXeSCg_<H`U:C6<5:DDQCF]8@P2?Nl07B4858D<HbU:<J`H
YQS6;F/Q25JeBU9242U:7<LHaRTZ36<8@QS6;F/DYB487>LHYQBU?NlU:AB500000QS602PLi`Q248@D
YA1T6<HLi`aS>Lh<HaB57>LPj124>LhHaSF]7>LDQAS6:BXQ22DY;F/U:AcW8>Pa[248AS5BU7Nm=JdQ
25kg?NlY:RDY:DX000Qoo`0c001ooe9d:DY[FW_NE[E[FRe[9BT40A2436<Lidic6<Hmkf<H7<LaS7Nm
<HaW>@Q2<HaNmf;h6<HLidicIcUc_5:DCW<Y:Sg_IaUc_3W>48Aoodic6<Ioofmk;F/<Hg>LAS4mk`Q2
009kgP08@Q1kgVLiMkde[Cg_JeXU:@9cW00F6<IW>A247>MBU6mk:DY[FSF]DY@e[E:DLiaW>Cg_5:Ek
gUJe001Rn2DY0009Ool000Qooa40000=124icTYB48@DYAS68@PicTHa@Q16<DYBCW<00TYB00=:LTic
?Pl00SW>02LaS3h?AS4mkcW>:DX]JbU:?NlaS3g_;F]6<CF]>Li6<CW>AS5:DS6<7>LQ22U:6<HLid8@
?NlicSF];F/Q21BU46@8@QS6=JdQ200010401@0000@40@00Ool000Qoo`0S001F]DHaHaPmkc6<Mkeo
ob48@Q0]Jb4X5:De[C6<125242e[DY@DYCg_>Lh48CW^@Q0LiaBU:DX<HacW9BT@Q2U:CW<HaP0248@0
2PQ29BTHaSg_<H`@Q0aS7>L<HaB50R4801dDYAS648@]J`aS7>L@Q1cW36<@I1BU34<HaRe[AU4e[CW^
;F/mkb48<H`]J`007>M:DS6<>Lhe[ABU009oo`05HaQF]BDYIcT00008Ool06000OolicQc7HaQ_NdYb
>Liooc6<000icQ24IcTaS2U:Kg]F]@aSG_L]RfLiBW8U:@9BU009124e[DicMmeBU3F]001g_BE9009S
600`6<H48Be[BU9cW2DY46A[FUkg>NhQ26]jE[DmkbU:Kg/8@Re[E[ENmac7Li`HaTIAMkekgTYB8BP<
@dHaJgXLib3XLia6<@Q29BT]JgOM;F]BU5JeG_M6DE:DNmhaS0002Goo0008Ool200001@@100000000
10401@0000<40@001040100000PHaQBU8@P48@aS:BXYBU:D0TYB00A244HaAS5BU0=6<@I>L`09@O0i
cS6<9BT]JdHa@Q0HYSV^0096<@0:@Q0icT8@AQ56<D8@?NlLabe[BU82@Q0023F]7<LQ2000228<@be[
9BT300000`@Q0000000400000goo001oo`07Ool05000MkdLiekgAS4U2Cg_@Q0U:ABU2492436<9BTL
ib48;F/YBUJe6<H2;F/03SF];F/DYBU:36<]BacW48@aS1cW=Jd@Q248=Jd25:D02CF]36<]Ja1T000<
@aBU248HaP0236<05AB5>Lh<@aBU8>PLia1T8@PLia2446@Lib486<HU:@Q2>Lh<Hd8@9BTYBP028@P0
3AB59BTmkbe;Lia_Na24BS8Lib4848A6<@0000Qoo`0k001ooe[FE[DHaTicLiaW>DHaBU8]JfmkDY@L
igooBU8U2G>L?Nl8@TYB5:DeSF<HLi`@Q2U:>LhaS4HaLiaggAcW125[FUkg228004YB;F]cW3W>DY@L
ig_N228004YBOol<Hg_NE]DYBRDYKg]W>BU:CW=W>@0236<065JeDYA[FQB5;F/Lig_N=JeJeQc7BU9F
]FmkLi`U:@Q2G_LDYF]j@Q1WFBe[F]H000Uoo`0027oo00H000@100040@00124500000`@100040@05
00003P@QE[D<@`Q2124icS5/?Nm6<DYB@Q16<E:DCW<2BU800dicBW9:DP02BU804THaBU9:DTYB?NlL
icG=BU9242e[>Li6<D8@AS4ecD8@@S1:DP8mk`078@PYBT8@BS8ikRDY:DX00`aS00<U:Cg_12401000
00P40@00000000@1001oo`0027oo01X0048@Lia2<48@48@e[Be[?NlLidHa@Q1cW4YBE[EBU2DY=Ld]
Jad7>LhYBTYB;F/DQD8@0QBU01h8@QcW9BTYBR48248DYBDY?NlaS1BU6<HLab48000Q23F]6<HQ21cW
58DQ21RV7>L<@bDY:DXDYC5/7>L25:D03R485:DLi`Q2;F/e[ABU>LhLi`@Q5:D@Q3F]<H`2CW<02F<H
G_L88S6/Oom241RV6<H00008Ool07`00OomF]BU:Lk`005KEMke:DVLi249>LgooBU9g_AS6000HaP00
8@QS>6]JMkdU2BU:HaQB]6mkOol@Q2e[009Nm`0D7>Mc_1RV@Q0DYB48:DXecG>L@Q0U:CW>Mke6D@a3
HaQF]DYB104U:@9JeP0NBU9ggBU:BW8aS000BU9JeVLi48AS65[F;F]6<@009DUW>EKE36<aS7Nm?Nm[
FTYB<HaNmf<H125F]@002Goo0008Ool400001@@100040@0010400P0000<40@@Q00000P0000L40@00
1040011T>LhDY@0236<03@@Q9BTmkd8@BU9BU4HaBU9244HaBU9>LdYB009>L`07AS5243W>?Nm:DS6<
>Lh00TYB0dHa0Sg_00@mcd8@@Q0e[@9240038@PU:DHa008icP07;F/Lia2448@]JbD9>Lh0100000D4
0@00104000@100800003Ool007oo00Moo`0N001oofLiDYAoocF=HaPYBR48:BY243g_@Q1:DTHa9BTm
kdXb6<Hi[Re[36<Q20Q27>L<@b48<H`Lic6<0PaS00XQ23F]5:D<H`@Q8@P8@PaS?Nl@I08DY@086<Ha
S3F]48@Q236<228Li`8HaP075:DQ21BU:DXQ21cW9BT00R4801H40AB58>Pa[0Q29BTHYVLi58DmkcF]
@Q088SF]G_MBU7oo8@Pi[TicKg/000Qoo`1E001ooe[FCW<8@QBUNmiW>D8@248aK6]j8>Qoobe[IcU:
DSF]<Fa6<G_N36<mkc6<E[DQ24icMkd88Re[1056<Ekg9BTaK36<MkdQ25Je36=g_DHa:BY6<EJE36=g
_G_n58DHaPaSCW<48CF]9BU[FP@Q:DYg_E[F8@P<HgooHaPe[G>L9@TaS5:DBU8U:Ekg105[FSW>5:E:
DW_NOomg_CF]G_LLie:d00002Goo0008Ool01000104000@14@0000@@I6<H7>L00088@P8]J`=24004
?NlicSW>CW<2BU807DYbAS56<Dic?Nm244Ha?NlaS4YB@Q164D8@>Lhe[D8@<J`mkd8@<H`icTHa9BTL
id8@;F/Q22e[00000PaS00DHaTYb48@000@Q00<00003104000@Q00<00003Ool007oo00Moo`0F0012
44Ha<H`icQd7BU9246<H?NleS@aS;F]:DQBUCW<aS5:dDY@<HdHa=Jd28@P00b3X<H`@I0028@P00aS6
>LhLi`0212402A24;H/0024X8@P@Q48@7>LHYP0248@0124836<DYB480QcW0288@Q2436<Q20aS6<Ha
S0aS248U:@@Q5:DaS11T8@PLidic8@PU:DYB8@PaS0Q2JeX@Q6<H=JeW>DHa=He>LgooJeX000Qoo`0f
001ooe:DDY@<HbDYLi`8@VLiJeYS60aS;F/Q24Ha7<MW>DHaNoi[FSW>Li`icWooHcP<Hb48CW=JeQB5
G_M245Je36=_Ne:D<Hag_E[f5:D]Je[FKg/HaUkgBU9S63W>NmiJeUkg5:E6<AcW0V<H01De[F]J000Y
BTicHaQg_C5/F]H<HfLiE[D]J`@QIeTPj6<H7>MF]D8@12400RDY00Hmk`@Q125_Ngoo0009Ool000Qo
o`800003104000@100<000071040000000048@0010401@0000l40@0036=6<@a35:D88PQ28@PmkdHA
;F/]BbDY>Lh00T8@00i6<CW>=Je244YB@Q0mkdYB?Nm6<D8@AS5244HA0SF]0T8@00PmkdHa>NhU:CW>
=HdU:Be[0RDY00@40A1T124e[@9240D000091040000000040@00105oo`0000Qoo`08001NmacWOolm
kdic?NlDY@9oo`0A6<I>DcF]BU848CF]HaQNma249BT8@Sg_48@DYD8@248aS0029BT09QcWAS4Laa24
:DX<Hac75:DLicg_58D]Jac7248HaPQ29@T@Q1BU6<HQ21cW9@T@Q2D936<U:AcW=Jd48@a3;F]6<Dic
6<HLiaBU6<H2=Jd044Ha8@PeSE:dDYA>La24BU8<HgNm6<IJeUJe8@Q:DP0027oo024007ooIcUW>BU:
5:Eooe:DE[DU:Fmk6<IBU3g_58E:DPaSCW=cW1BUBU8Licg_IeT48@aSDYAS61BUHaPYBV<h22800S6<
039JeVmkMkdeSARVCW<006LI48@@I5Je<F`<@f<H;F]oobe[JeX003F]5:EcW1S6229JeV]J125:DP00
9BT<Hc6<OolDQC6<Mke>LaS6HaQg_CF]CU=g_Be[<J`Q22U:IcUkoP002Goo0008Ool500000`@10000
000300001`@100000000104000@100H00004=LeNmc6<48@224802bU:9BTHaQRV=Je6<D8@AQ4e[AcW
=Ld00T8@00]6<D8@@Q0icSF]>Li243G=<H`icT8@008mk`03@Q0mkaS6008icP095:DHaPaS1248@P@Q
36=>La2400<00003104000@100D00004104007oo0008Ool0C@00OomoodYB:DXicRTZ?NmS62DYOom[
FUkg6<HU:C6<@Q0icQcW6<HQ24jC>Lhe[ARVBU8YBQS66:H48Be[6<H001248@PU:AcW6<H48CG=5:D4
8ARV@Q0Q21cW8@PDYAS6:DXHYQS658D]JbTZ7>LHYQd77<L48BU:BU964D8@8>PDYD8@124aS7oo:BY:
DRe[:FYooa24IcT00T8@00H]JacWOomBU2U:0008Ool03P00OomkgV]J?Nm:<QBUE[D005[F8BQ6<E[F
G_L236<054HaDYA[NTicKg]64FLi248M1eJe:DX@Q5kg;F]S60Q2F]HaK6<HMkd29BT07V]jCW=[NPaS
F]IW>BDY6<HLifmkF_INmaBU36<Lid8@F]Ig_Be[Mmd002U:7>MBU7oo34<e[E:DKg]2408DY@0?124L
ifnKBU8<H`@1DY@U:Ch?36<aS7_N=LeJeP0000Uoo`0027oo1P0000<40@0010400`0000<40@000000
0`0002840@00000000@11248@S6<;F/DYA1T8@PPj3F]7>LQ22U:>Lhe[CG=?NlHaSW>AS4mkd8@?Nli
cSF=;F/e[D8@>Lh]J`8e[@<mk`0>=JdLic6<5:DQ23F=124@I0Q2=Je244YB00048@<0000;10400000
00040@00104000@1Ool00008Ool00`00<HaJeP02Ool00ekg8@QcW002Ool012U:Liaoof]J0RU:014D
QBU:248mk`aS8@PHaS5/:DX]JaS68@PaS124?NlaS1cW008]J`096<HDYCF]8@PU2ABU8>P8@R48008H
aP0Q48@U:AS634<HaQ248@PHYP@Q6:H8@RDY7>L8@QBU=Jd8@U:D=JdU:BU:?NlQ23F]>LhPj248?Ll]
Jcg_34=S60a3009oo`8HaP0334<007oo00Moo`0D001oofLiMkde[AS6Kg/icQBU@Q0DYF<H6<IW>Dic
F]HHaQcWF]IF]@8DY@0GAS5JeRDYLi`]JgNmKg]>Lc6<HaQNm`00:DX]Je[FHaP8@QcW<FaS659d8@P<
H`02G_L09U[F48@YBPaSBU9NmbDYMke6<B48=JdicTYBF]HDY@@Q@Q1S67oo;F/LicW>Kg]S62e[@Q1[
NSW>DYAW>Be[HaPU:Goo248]J`PR0009Ool000Qoo`<000051040000000040@0?00002P@100040A24
G_LU:@aS12488PQ20P@Q00<<@`aS8@P00QBU01PaS3W>@Q0mkc6/:DXQ22e[<H`mkcG=:DXU:CW>?Nli
cRE95:DQ22DY248<@b48@Q0224800d8@<H`48@0800000`@Q00040@0300000goo001oo`07Ool00`00
Oomoo`02Ool016Li6<Iooekg0Woo02=[NT8@=LeF]B48;F]ood8@Mke:DRDY?Nl@Q2U:@S0DYD8@9BTe
[Be[36<@Q2E9=Jd@Q2DY>LhQ20aS6<HYBS6<248U:@Q2008DY@0G8@PHaQcW7>L@Q0Q29BT<HbD98@Pa
S0Q2@Q0icRDYBW9BU48@6<H<Hf<H5:DU:@02:DX01CF]OolmkcW>@Q000goo00@]JgooOol000Qoo`1E
001oo`@Q36=B]6Li7>M64ABUHaQ:DPQ29BT]Je[FOomggFmk:FYNmc6<46@HaVLiHcP]Jg>lIcUc_0aS
IcU242e[:DXQ26]JG_M6<D8`Oom[NTHa24848FnKDY@YBQ24CW<YBPaS6:H]Je:D125BU4jC9BU[FUkg
<H`8@THaE[D002U:E[DU:BU:248DYEJe>Nh<He[fLiaF]DYBIcTe[EJe36=c_1cW00002Goo0008Ool2
0002104200001@@100040@0010401@0002H40@00000000@100048@00104000@1>Li6<A24<H`<@`PR
12488PaS24840@PR124]JcW>?Nle[Be;7>LHaRU:=Je243g_8@PPj1BU0SW>0RU:00XaS0aS34<8@Sg?
6<HY:THaBU848@8000031040000000L0000512400000Ool00008Ool01`00OomoodiC?Nmoofmk00Ao
o`0I:DY243g_BU9[FQcWLi`e[ARV@Q0LiaS67>LaS2486<HaK0Q2:DXaS3F]7>LPj2U::BX00RDY01DL
i`Q2:DX<@b487>L<HaS61248@QS67>LU:Ac76:HY:R485:D8@S6<8@P00RU:01QNmbDYCU=>Lb3X48AS
63W>CU=S635/IeTQ248@=HeoodYB<J`HaWooBU9JeWoo0008Ool07@00OolY:R48Kg]W>DXbNmiS60PR
HaQkgTYB<H`8@T8@>LikoU:D8@QkgTYB@Q0U:G_N229>Lbe[CW<00UJe010DY@aSIcUg_DjC<H`8@QcW
>Nhe[BDYIcTDYB48AS5:DP8<H`0TMkdU:F<hMke6<Cg_48A[FW_NCW<a[124CW=Rn1RV36<Libe[HaPH
aPaSDYA240PR<Ha245lG48AJeWoo;F/DYCF]AQ4Li`002Goo0008Ool500000`@Q00048@0300001@@1
0000000012402@0000h40@001240035/@Q0e[@@Q6:H<H`@Q48@<H`@Q0PQ200H48@007>LLi`Q21242
6<H012485:DLabU:0RDY00/Li`Q22488@QBU248@Q0Q2AQ5:DPQ200<000031040000000D000081240
00@100040@00Ool000Qoo`0400048Goo9BT4Ool06c6<G_M_NcW>Li`mkdiC<JaW>Be[IcTe[A24;F/a
S2DY@Q0Lic6<:FXaS0@Q48@DYAS67>LicP0248@01`Q2;D/LibU:=Jd<Hb48008<H`8@Q008124DY@Q2
48@HaQBU228icP8HaP0548@Q2124:DXPj002E[D02f<H;F]:LSF]<Ha[FVmk9BUS65JeKg/00Woo00Mk
gWooAS5F]CW>HaP00008Ool0E@00OomNme:D;F/005[F48AkoQS6249JeVLiG_LLib48F]I_N`aS48A>
Lcg_48AS65:DCW<@Q6Li48@Q27_n;F]S67_N@Q0DQFmkIcTQ:23XBU9W>DHaOol8@P@Q<HaJeQS6G_LQ
20PRBU9BU36/125W>Ekg?NlDYG_N6<IJeTYBHaQNm`aS8@Pn3e[FKi]kgSF]:DYBU0@Q=JecW000<Hag
_DHa48@Li`0000Uoo`0027oo0P0000D40@00000000@100<000051240000000040@0300001@@10004
0@0010400`0001`40@00104000@Q248]JdYB?Nl]J`PR36<Q21S624848@PR248<@`@134<<Ha1T248@
I0Q2124<@`88@P848@038>P@Q1S6008mk`848@0400040@00104500002`@100040@00104000@10004
0Goo000027oo00<007ooOol00goo029NmdicBU8DQGNmOol<HgooBU9_Nbe[Kg/]JdiC248DYBe[;D/Y
BS6<9BTDYBU:48@Lib3X<H`La`Q2;D/8@QBU34<48@8HaP0E5:D48@@Q124YBQRV<H`<HacW58DU:Dic
24848AS68@PHaPaS5:DmkaS6008icP046:HYBTHaHaP2Ool02fLILia247ooBU8icS6<Oom>LgooMkd0
0Woo00<007ooOol01Woo02X007oo=JdicWNm9BT40D8@<H`002U:JeXDYAS6F]I>Lcg?001BU4Ha9@Uk
oUkg;F/88Vmk?NlLif]J=JeS65:D;F/HaVLiBU88@VMI<HakgSW>E[D2BU806W>L36<Lif<hBU9g_A1T
DY@Q236<6<H48ARV125BU3F]CW<8@UkG7>LLaeKEJeY6<ARVJgX2;F/03F]JIcTHaT8@JeXmkdYBMkek
gUJeIcTaS00000Uoo`0027oo2P0000<48@000000200000D40@00000000@100D00004104000Q29BT2
@Q0023F]5:D88Q246:HDYAcW6<H236<040Q236<48@Q2124000Q248@<H`Q27>LDYCF]=Le240@Q3000
00D40@00104000@100<00003Ool007oo00Moo`03001oogoo009oo`04BU9oogoo58D5Ool014iCCW<Y
BPaS0RU:02he[BDY8>Q>LcW>6<HaS1cW36<YBQ24<J`48BDY248]J`aS248DYBDY;F/YJQB5;F/<HacW
:DXHaR4848@<HaS6?Nl@Q1cW6<HU:ASV:DXDYAB536<Q20006<H]J`8Li`0:;F]cW7>L6<IooacW=Jeo
o`aSMkd4Ool00g_NOol00008Ool01@00Oom6DDHa8@P00QS602Y6<@Q2IcUNmb48DYAF]@Q236<]Jcg_
DYAW>CF]Kg/HaSg_F]INmg_N8@Q6<AB5G_Le[B48Mke6<GooNmi243F]E[EkgRDYLk`48Cg_9BUW>AcW
36<2E[D08THaJeYkgRDYBU9>Te:D125WF@aS;F/DY@00=LeF]F<hJeYS67_N>NiJeVmk7>L]Rekg6<H@
Q2DYMkd<Hbe[Kg]F]@002Goo0008Ool400000`@10000000300000`@10000000300000`@100040@03
00001@@100040@0010400P0000@48@0000088P@00008124HYRU:>Li6<Cg_=Je2408icP0D=JdYBQS6
9BT<Ha24248HaR48>LhmkcW>5:D40@@Q104000@100040@<000031040000000D00007104000000004
0Goo000027oo00@007ooOom_N`9oo`035:De[Goo00Qoo`0U@Q0mkcW><H`HaTHa;F]W>ABU?Nle[A24
>LhaS2D9<H`<HaS6;F/<@cF]228HaQ248@P<Hb480008@QS67>L@Q0Q25:DDQ@@Q8@P00QBU00PU:BU:
?NlHaS6<6<HaS35/0QcW00EcW0aS?NmW>A2400Eoo`03@Q1oogoo009oo`04@Q1oogoo0008Ool06000
Oom6<C6<F]H88QcWHaQJ]PaS48A:DQcW249g_CW^7>McW000AS5_NeJe6:HLi`9W>@0@9@UF]Ekg:DXL
ig>LKg/mkgoo249[FSF]?LmNmcg_GaL26<H2F]H09cF]48ANm`aS9BU:DVmk?NlPj7NmNmh]JcW>CW=J
]QBUKg/@Q7Nm48@mkc6<F]Ic_7Nm8@PaK5[FHaPHYQS6F]I246nK248YBQ1T6<H00009Ool000Qoo`L0
00031240000000L000031040000000<000051040000000040@0300001@@Q0000000010400`0001L4
8@001048@QRV9BTe[Be[>Li243g_<H`mkcW^=Je243g_>Lh]J`@Q104000@100D000031040000000<0
00051040000000040@0500000goo001oo`07Ool01000Oomoodic1Woo015JeWooBU9>L`a3248LabDY
>LhHaSW>9BUJeTHa>LhYBTic008mk`08<H`Liad76<H8@PaS5:D@I08DY@0:6<HHYQBU9BT8@QBU6<HD
QAS67>L248@06AcW36<LiaRV36<YBS6<248DYC6<;F/<Had79BU:LVLi<HaS67oo:DYWFG_NOom:<U:D
00Aoo`05>LioogooOol00008Ool0E@00Ool8@Q1T5:EW>E[F7>LDYDHaIcUg_C6/34=_VdHa249_NeJe
6<HU:CF]IcUS62U:?NlHaPQ29DUkgP00DY@n3`aS?NlaK3F]DYAFeFLi6<HicV<h001O5fMI:DX8@UKE
>LiS>3W>;F]_V`aS5:E6DF]JBW8U2F]j36=6<ABU:FY>DfLiKg/HaQBULka6<F<HG_LHiQRV>LiS6000
:DXe[Goo=JeS600000Uoo`0027oo0P0000<40@0000000`0000<40@0000000`0001@40@00124000@1
00040@00104000@100040@00104000@100040@@Q0P0000<40@0000001@0000/40@00104000@10004
0@0010448@@100<0000;104000@Q00040@00104000@100040@0300001@@100040@0010401P0000=o
o`00Ool01goo00@007ooOom>D`Uoo`0>=He[FQ24Oom>Dcg_MkeS65JE6<H@Q48@AS4<H`8U:@0434<Q
22U:6<H25:D06aB55:DeSBU:6<HLibU:000@Q1BU36<DY@aS7>L8@PaS6:HYBRD9104HYPQ2<H`mkbU:
6<I24002:DX01Goo?NlQ20aSAS400S6<00DaK7oo;D]ooeJe00=oo`036<IoodYB009oo`03001oogoo
00Ioo`1E001oobe;?Nm240aS001>Lcg_001NmbU:34<icSF]@Q1:<V]JMkeW>CF]AS5W>CF]Kg]g_@PR
?NlHYRe[?NmBU23X000HaT8@;F]S66mkJeYood8@48AF]GooHaPaK2DY248DYAS6HaQ_Nd8@248@Q7_N
9BUBM6Li7>McW0aS6:IJePQ2F]HLidicLi`Pj1B5=JdicV;hBU88@P00BU9JeVmk<H`Lacg_00002Goo
0008Ool500001@@Q0000000010402@0000<40@0000002@0000<40@000000100000<48@0000001000
00<40@0010401@0000<40@0000006`0000=oo`00Ool01goo00<007ooOol027oo01laS7ooOomoog_n
7>LQ235/6<H]JbDYE[DQ24Ha6<HaS0aS5:De[BDY6<H<@dHa9BTHaPQ26<HDYAS65:D8@P025:D02acW
6<HDYC6<5:DYBR3X8@P<H`007>L00QS601De[A24=JeF]Be[?Nl@Q2U:9DTmkd8@7>MW>GooHaPLidic
Oomc_7oo24801Woo00<007ooOol01Woo018007ooCW=oog_N<F`8@Q24<H`YBUKEAS4Lig_N48A6<Dic
JeX2Ool02FMI?NlU:E:D48A246<H7>MS600248@0=Tic=JdaS4ic?Nm241cW?NlaS7oo7>LaS5[F1248
8SF]Oom_Ncg_>Lh8@P@QKg]FeE[F124YBVnK@Q1S>7Nm48A6<@@QJgX]JbDYNoiJeWoo?Nl@Q2e[<Hak
gVMIE[De[EkgDYA_V`aS>Lh000Uoo`0027oo0P0000@40@00000000840@80000;1040000000040@00
104000@100040@0900001@@Q0000000010401@0000L40@00104000@100040@0700002@@100000000
104000@100040@0500001@@Q00040@0010400P0000X40@0000040@00104000@1Ool000Qoo`03001o
ogoo00Eoo`0KIcUoobe[OolU:GooNmhmkg_n8>PYBPaSIcTe[CW>?Nl]JcF=9BTicQcW8@PicQcW;F/<
@be[008DQ@0U5:D<HaS648@LiaB58@P<HaB56<HU:@Q2<H`DYBDY7>M242DY5:DYBSg_;F/aK6]J6<H@
Q0Q236<]JdicOom:DVmk@Q1kgU[F:DX00goo00=F]GooOol017oo00<007ooOol01Woo01<007ooBU8U
:EkgDYAkgTYB7>L8@VLi58D8@UJeHaPYBPQ27>MF]@02>Lh0<4YBIcT<Hf<H9BTLigNm<H`mke:DMmeS
62486<IJeRDYDY@@Q000AQ5F]BTZ36=JeRU:Nmi6<A1T;F/DYG>LAQ4@Q0aSAS4U2FLiCW<@Q2D9>LhD
YEJe<F`icRU:GaL48@8icP0>:DYJeU:DKg]NmcF=BU8@I7>L6:H]JdHaIcT000Uoo`0027oo00<007oo
Ool0DGoo00<007ooOol01Woo00<007ooOol0DGoo00<007ooOol01Woo00<007ooOol0DGoo00<007oo
Ool01goo0008OomE0008OomE0008OomE0009Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{94.5, 381.5}, {264.5, 175.5}} -> {-1.1324, 1.91768, 
  0.0110605, 0.0110605}, {{102.375, 187.125}, {262.375, 
  177.563}} -> {-164.039, 270.328, 1.5754, 1.5754}, {{195.563, 280.375}, {
  262.375, 177.563}} -> {-310.619, 270.176, 1.57424, 1.57424}, {{288.813, 
  373.563}, {262.375, 177.563}} -> {-457.753, 270.328, 1.5754, 1.5754}}]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["energy compaction",
    FontSlant->"Italic"],
  " property of the DFT is clearly visible. Most of the signal's energy is \
concentrated in relatively small low-frequency zones of the transform domain \
located at the four corners of the DFT magnitude matrix (recall the positions \
of the low-frequency basis images in Section 3). Note that a large majority \
of  the Fourier coefficients have relatively small values and therefore  \
contribute little to the signal's energy. In visualizing the frequency \
response of a sequence, it is common to use a centered DFT domain or \
alternatively plot only one quadrant (due to the symmetry properties of the \
DFT)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        \((\ ListDensityPlot[#, Mesh -> False, FrameTicks -> None, 
                DisplayFunction \[Rule] Identity]\ &\ )\)\ /@
          \ {Abs[RotateRight[\[ScriptCapitalA], {64, 64}]], 
            Abs[SubMatrix[\[ScriptCapitalA], {1, 1}, {64, 64}]]}]]; \)\)], 
  "Input",
  CellLabel->"In[10]:="],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .47619 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.0113379 0.47619 [

[ 0 0 0 0 ]

[ 1 .47619 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .47619 L

0 .47619 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.0113379 0.477324 0.464853 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.00751202 0.0192308 0.00751202 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

128 string

128 128 8 [128 0 0 128 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

267D182E2B32311B222B2C1D1239135C1C433024260E0637

34161E48177933331A200D220D51103E13891A611A5E3B28

3957093412221237532B5982552E31193B19312E5582592B

533712221234095739283B5E1A611A89133E10510D220D20

1A33337917481E163437060E262430431C5C1339121D2C2B

221B31322B2E187D

056E17452C4936303B0D4A0B2B3344470B1C464011130F53

1B261A22110F0E364D1A3D06344566322D302617234F1053

330A383B4C7E425920245A39345354103C4A42363C3F2A1F

3F091F592E4513424C22326B1364150A4A283A1D2C1E3B12

313743603A28372C632F2E436516170A190F0E0D3D36131B

12181F450C550433

191B2A15264022071635360A302B214C2B3F1D1C4B331417

061F0C3B252F154108202064277624491F7522153C151B12

193F2E2B121D2A292B1A1C232C3747EA6A2C120E2E1E3269

311435273749267295371E23206D5A35343A1F2B1F244843

3E2C506221102D205748291D0E35104E1A3C28763E3B350E

0F413A341F221C56

2752126D304A3C2F100737261B32084D3A660B5136123240

2D20252817540A39431B3E2C323B6F186908212249491223

39252E322E271235473C3445353354618E4C1D0B405E5115

236D5D22255D37103A120D2610452A34152946291D273010

19232B61275729510F5E152618251140573723363D564241

2530345E0A203052

14252717330E412B2B4A160D2E2C1556144E102F3A112008

0A3A35281B150E5F12421E562E133526382E202E1A161630

665D1A3B2F4D373A2828295E7E37644D54464E694034132E

3333163B3C741A194943272B142043595417195A36421015

1A0F1C1C242D221B6313410934291F1B1E1A3734261E1336

344127431F211F3A

2B2B21321D381C3A16111A2E343E310B34351D42143A0E3B

3F18363F125A3B58304642130D4A3F3C4C4136533E130A2B

1F3D311F3F54435226153545419C5A215410186A48594A29

2C45325B250B093A18201C33241E4A366F2E3427611A3D38

243B35090F2C22226E353E074B254B3936270C131254352F

444B216B17661D31

2A102B37380B5833202E1823412D3760212A251824171412

1930231E3717793C41451826310B46302D4A143B2C23432E

1A2C3F2D2D4264472232291C384F506F6D154D3C2C0B4A46

152D141D2C210B2826080D19707B5E027044194850441140

1F39382E14282017322B3533444F2417162227503E391441

4F4E4451390C3527

2E3B222E0C03080C1E161055133543081D39274826353939

411636181625321502391983525E45303E3A501570185B14

4E5F21203C3B603316352219126B683B5929302239482640

2A2B426033072E404B4E385351955F0F3B1A490C5E3D2418

1F372428252E1F325B3F3A11361B38231E27151D2A503D3D

2F5820533255362B

093347114720092B202426301F1A3B1B58120511140C4519

293550081D141C4C13306138735E1E430F54103429662C44

2446132B3817390D30319648292B2519602B79301A275380

6454611D31201204171D393A193C1E464418196F37452E43

241609233A18310E3F321012232C2E070A1C0A2F5531274F

3C515B24502A121C

472F262A16240F3413133109414E295F1E4C1A2743378822

190D22252325222F4A513544723C710766381A2E5D565830

23171A3854510E3C632C454D0674154D4A4D3B383F484D23

4D1A30373546501C3737224A5A2F32301747293634485122

1717471A2D0B38272D0B2013180E2D063B33374D2A5D2034

1D4413421F321B2D

083E541B15201A15152F30365B14324D211F102F49262432

15182924254929323A2D3A3921622F432550121928844F82

6140323221530C4951144D105F494743773A162323126E6D

2E24381B2D24101613143D1606264D205A2D32065044460E

4B443E57624118162E293406231034201D362D45212A5228

0C162D293E1D4921

3D0717101C25226424393C32350C1E3A3A5611282C352122

0E3E1704394243151935262E27105A103F122A1B5B646544

2F1A1C372020371C4B3B2A3218145E65566E4B312A612A50

94561B4809365C214E63171A3C2A56285131343116280F36

0F33310E5C2E2926252952401C0B49334B0A433E443B0E2B

2B412D1B24253C4E

166F260D244225151A460F2D2A36383D210D0F217B282D27

154B5B1954363B3F58341A3D0A4332524F40106D944A391D

5330421E2740420347413710235D5711615A1B334C327021

5F79325B2A262C372D4252171B494D13250F153526223318

132C17482272331137330F551F253F052B3E4F3C45290F4F

17484B204A0B631F

25290D4A1B0731224B3729180A1525264C3F1D35363F4C23

64205F1A35402627232347557A393F3457352D4421741140

464F402D552F2B1737956F918F40177072064D2345573565

6F20123545497B2E4E42234C462D2947241313041B4E2E69

6D36331F3C1F262D1F202A4B28056C0B4E2F3C4638543021

1D133C0B48240027

202D1329202319183A3E33472C3D3409142B28582E174033

1C61273237443D1B3D1F282D231D313A5442624B1519113E

230D4D1846272F10311C1E3232071352AA581F5F7D371C47

5E4B4047586B12201F3742422A1A6F4B371B0E17220B3411

2614282944303323254B1F3854362945166B563A5E1D2B32

191D2F230F1C2D32

283F1F5A203A200C1A2B1A280D1D1A100E3837133A150A11

400C3D3E224F3E422B06261C2A13051E306033232535381B

2A41404F4E250D12351D382A2710333FB65D52492E45715A

123D620C2C304A4A906319132B59863924181E4944725141

4523542958610A203E381618324761497015230B37080936

0A29082118310D61

1F3B1233131B2F3039362411211E11312B542F2552312F56

24404C072936310D331619215E291831300A2E3F4C213937

14334B2540363433534926054E223E5A55262167825F5A33

2F9356351A3C522D3254231D63443C54173A172A3E102F39

3435423F1F1F183913102935203F18090D72575A5347152A

1E26185B2D061D21

531B3845293444260F2B2B3E071E653D351C173A50195933

461D522E3B34444D1424342B1C27082C1B201E40153D4849

451A0F19014B283244155E4229657C463D534209745F192F

2B25084D6F4E820F1D0E31341517152A68183244163A2A54

4B812F31162434331B52465C1E3B4C235F26144E1A2B283A

333B1531442B1911

1327390B1732400F1219102B1819392359204A4A2945563C

2917432645440D1523394633322A15503B2F1335316F2618

1D1F2B985D57271C53772634393C4877811F288322182984

3B3E6D3F29093D082F19464D3D33190D1F26222F22242F36

4F352645221E3C67442B533F15503D382F5A464242162723

22144D443006583E

7A52392D272F121924461D23181817392271267B1D2E7513

334F063A3A48302E1B342A30693E1E326B1D1432228B326C

2C6D5A2E2550485955575E791B19191073CA8560623D1C39

3A121D283B3F39291B472E262C07331633424459483E2A2F

352E31082B3C2E5435344438233C2B380A44423A3B694A0E

53182D19091F0223

2334571B31043A1F233429103E26095435181F293B48561D

4B2F34520D2739184A22471D8B412F32334442656A10382A

5010273D2C1B3F4C75793470810E4D4D6C7846615156160B

401E5C61556119283E23164F202E1338336C4A580D41353C

151A38304E5215210C37552B495D3E401D411329263F303B

2C0B163250183722

2C3F3416480F58183B3B202836103332273A432E082F6911

01392B332E172A10102A4D2F5B63242E390B29453B520C1E

0B41377C651A19450A152779535A607D362515464181A260

758752374C3E2C0E3A5B344B532A3E21203D09173D414B46

35395068546FAD5A5454613C2E25393B382625592B671038

466A631340271D3A

870A5A112524304C11221614332C06382D426A1F7B702D60

4B394F3E3D390E1045172608512C2D4713643C934D459D76

451C41404168495F2D872B43654F4954A519B49C172C6A86

3EA3956340504C461E2B43295152230E3D42203F292E2D5A

265459368E2C395607595453673D0D6C3B4616362A3B291E

2F2D3B3A31100F4B

2F2D29240C051C202B231519311131181C2837132B343815

3A2E57531E360F580D21322917454B2A252B361254634D27

3F6F415739953B4C8A40723C3F3B4174696795776E12152C

0943220756461A5C4F194E1A20154A4F60730A0E55544963

4C524F713D388A2D62454B7B4C6E346F7D3130203E434E4E

3A2350165B275822

27334246253E15392535181C1532172358395C4A12464461

2C382F38183D554A3619210740546128494556492873AA1C

2A4F785823299D721A6C34231E29344F6C40764993923983

A6578C2E5B19431B4210590941381E3D253E5F3832174B49

3D5F1121677D69506D205715185B465226230A112B2D222F

435F155228264D28

452D2749271E3610211A233D1D4F413621185343422E3622

3A217A333027396A2A372A192C855C6F36523D39326F3979

4CA2980E37376131755E3A114E1D4437536C55475E467333

274C27466A682C583344462F334F405B563015583A5D1318

165E576F2664412B2B211425283E3C722A234D1011282748

0F1E542045335011

201C2C380F3F3C1A313F123B1B51672D3D26620A3E48194D

37604A28182A0128314E1E23662775474858607D55434145

3C7B176A59674F87364F1E617056994265725C225D709770

48301E0E5A3A29142215333D47412C6224458449604A4143

3E362E2A095436179063932014423A4644681B0D0322404C

3D263A3D12042412

2D06251C282668273D4B143E14333D442E463F6042313364

3934304115282B241256684A7A310B55853D963738473626

5078825D55DAA90F3B2A4B278949600E621066D1E3CB93CF

C22E8DD8471A2212451572513F243C6C554B5D57325E5874

742F725F256917633D753D315E384169282749333D474641

202A5275335F1830

0D2E271607272E371C43143B311830223136383F0F3E3A79

264E3A25213020151F3A0F4BBF40452D058D303E5C34A720

CA6E8A547677538B836D690B35281A5B785DC2574C7F5067

467AAE834B3C0F5426234D17444C3B37514B60201B212F7A

3E2E206156C85C725A776C5B2553404F2F0F040838112A51

405C211945204A30

0D1027321E2D16421C617021130815133B191F552B7C6812

744B2D394E283841291906334C1E5F525212746056302171

5C357556514D2437341F1C0A36248BD26C08415B374D6B42

72578A65144339217C31573B538B1C4D306B449424556D6F

69897A802DA922231514581D652B1A48373548553C1E691B

0836122F1B0F2616

202237294F255A1736322B1837493F15410824281C423B4A

2A1B2330483C17274159571D2A0970107A4E15782497D98B

52895E8D283679680D3F938A2A6454BCFF632A33AA867031

5A53693E6C7D352847412C210C36320723775E81766F3E56

0331265350604E742F6D5F185F7A835B436033593A374A4A

403D0C42305E4110

0152133C532B5C113F48234B264A4F3906731D4E42091720

5C1F2F2E04322E38113E37174E691054160F2D3D5F406114

211E244B437D377152636342FF9C5273CEE1AEAFC89D8EB2

818246523499715C34275F4D393F3B2D48070A554B47B34F

918A698E5E377E6819BF224D4030561B385C401C264E203E

1F1C305117251A2A

6F4B4C4E162A4C264C3A1E4716246548317816430E284B44

4D2B4A1553293C3A5A3D25151C55561A2644A2CA1A532016

392E27344B0E6F523F2E5F469250746F482C1B65A683425C

786D9EA457A83D572A412A315B39573438677B9149628A5F

501C50363756482E0A4B425251294D52572F0F29252E482D

13340E501928351E

21271F14530D5A101131111C271B5B701F23342A172F0B1A

19243256576D22702F215B782954497231306729413B917D

68974328505A63927B8444783F3B7BE7823C9064791E4A42

695161B54C20911872324D261A687060982C4523432F2B3A

663749264C5A643510BF5C4B81103C2D4F372D3E20501144

3C397D091C5B3E47

18172F38151D08431D66143D3F235A110E022B0C271D3B16

011A194142411924463E6C216407315874244A59167C6529

84639F47AE1E8C92819FC1BB1E1E8E5CFF8A368A8052211C

272ADC8D62938F2F31180E175B451B4724311238468F2945

201835920C67713746793A7E3224353C18093E310E371568

16133357111B8542

042F91363B131622172A1C423524381E42731C5A2338293C

20627146336C3E3D242F344C6C4546715C48493F5E3C6891

418C839FEB5D667345B94C7D4C53494E6DD36A647BAF62BC

48635C2A24096F3F3B7D7AA14440251B5B52683A2C321B59

4214AA2B968312553558324C221A0E1E3738582B163F3877

2B2C217C4F74256E

221F52371B0C25452E432C5B3341265D101C38802538271C

1D2A2E681534365C92446D7A74578128412868593C01383C

986347756B662F40FFFF30C1AC534CCDAD8EE9C478B3687C

E9FF7040834A5A4936286D40605E0B86615AA44829783877

076C7A377F3B6F27531B183B284A211F52419F3476252046

164B1B367A1F6352

33487119222847342A19562E4F41371031161A3033183D65

33254726394D493E2D8B8D1B695F1E610B4C40665A15216E

AC894A30937A6E69A557CCB16C3632B177705C6937228447

5880AFC3BC4A12522E5E3DBB5D6C5E154559314F35373F19

294539386B3239264E083629192F29272B4A2A2D53341C38

6A2A3B6C2A416A16

0613292E111E3016401D254A772E132A283D3A1F1C42503A

25521B243F403B30497E12746A1A7F2D4B4F4F414543272D

497DAE55E39AD8B5268E553941622587E83AA0B98E1B4535

7C83564F277C1384716349493E91425A894FAB7E305B6356

6B41584E2D52461C55113E21386137726E1F2042166C283C

286F24195B381D3D

0045526B337B433E4026481F2D523E16184A53122F5E2A40

27822B41422F10391432586C5F2C782B3D88092C492268BE

689E5D9DC06EBF1C0E6951F989732D3888E4648A81782158

675A3D7C3C2B8B85AFE3998FAB6FA64D4D715B694173D657

91385F8B258444272B4513405A4C5459424A1629324B7D1C

6627673736454711

0E0D1F065167281F7A7329852C210E3139273A5F32453C1B

2B24415820252D3F5C627739604375115D21243A6A2B6B3A

6252819F48751B7D9359D787115872235331D6C1B6438180

3F4F094C6CA9B15C5B36CC8B4B574F634B5F36875B5E1D87

3C164D19482C51273E5B237D503D6940161B30673A7C2755

3069413F244B1C4B

292A35335F4E6B1F334062560F62363214322E4C3F2C2851

4018384E4D4144430547273D71680E7148102BCEC6247B52

6985A40C6D38BD42A8FAFF436D889FDDFFCF81A5FFEF65BE

C35218444D9A81767F8793988D60477B1A8E34406D5B8A17

434A12473D143745636C38614C1E1A264527692A51190E51

41120C197A1B1B46

2E26192444281B2E2E413B493C6E1321561F44311F2F4767

1C2711224810332B688B1E437839A14E44574E95284462BA

18D68824C7FF6DD4CD90D1669FA9FFD988899668706A4152

94886BC0803C6619835893AD2BDC9D6195ABA0CE208C466F

4114460B3E657D1E439F40347D6F3A930C440D2131610455

494024257F403B39

314954221F16112B395A2C20493E4053312C1E0E0D562A40

4D2D1F10473B23384111691315453C22A6813ED262305C91

407B6F438B6AC1AB30AA503986FF4170A169A5D1EDBD514D

AB776E409EE0FF855387AF572F4EA036637F48194906503B

682D734D60179B1DA812545B2135361B377C52513B341A4F

64333F1B29233B22

112E3714444120284D31435B3E3D44260F451B5E4B3D796A

0D53143D5A88429A2E0F3E29AF3267766B6689403E64A982

A39B3F1E966118A8EF3283B5A7564691BB3CFFFF7B8F9C3D

7927EEFFFF7B33954A6C8FDF0E9A6AC563B925A348162779

21842A6187114B61468949394889335C21074F1D20342930

368042255E4A3319

352A550E182C641767285D339060472433054B4D33503B45

10283C0D306E330D2B943A556E463E034EAEB960968577B1

E49DF98D965A810B7D90FF932A81D6FFFF88F6FAE4D6FF87

FFFF72D53F8E95FFFFA8B3580F72244B68749C3321477E8F

7D602F9816576051875D6C3D756643424115312712132C3D

854E323526131424

2E864C423A78442A2D2F57102E843226675A4E3C3B2E2341

3630099155953087896C3E304D820E7D632BFF4E86935AC3

59FF7F28CDCF88EC85606E37FFA3A358FFFFFF9550B077FB

4E7DC5C04DABF9D675BC367D4BAC627F1F773C4338439DA3

6F056C562D964B50375F2E0F225B3333043D2545464A3957

360B35712A320E15

133E33322F4920471430131232392040552C0E262C114049

382A10822D6A5713A14F6F4A9455783F41AD6A74F23D46B2

755C727917EBBFFF17FDE4FF32C135145EB253FFFF7EB9A9

47E5B5FFFFBE50E2E7FDD459534452272C5210157A188540

34605C1555568A303F216220417A63283C825859A02F2D23

6C413B452D693C34

3C0A3E332F332B3449252F356C251338551233433D165A3A

4338254E6145186D2A4D5648706D3632F8BD64FF5BA65053

A2E5BE369935BA617AE5FFD597C5FF7685EFFF86ACFFFFFF

FFDCFFB835A13581FF28F754864FA55E911DAC27483D3147

1571124539257E7F625B2A205A3E1792476A464F47345216

31266F2D26203E0B

6512394817452729413F321838303D230E154B3D1E465B43

6477136B86747B489B54A587782F1EB8C15D2B4D695551A6

6BFFBE81769C889AFFFFFFFE60FFFFFFFFFFFFFFFF9ECC80

35FF87B8FFFFFFDA6F80727CAA15445CB0FF8368EE93694B

78312784528A47288317476F66581E66211F516833254A5E

75414C20341F5254

4438141E2E480B10273039394D32352F374C424826131D60

47824F6657B7554A96409E3C6221BF55748095C5B95DD258

40816E64FFCE93446832FFFF93FFB4FFFFFFFF9679FFFFFF

DDFFF4FFFF97FF52C48378619731D33B95E36CE82D863B37

3313391D604247345D2F154E23646C7D3C2D3C52484D4D1B

483A4A0E56401537

443F5C303A49500F21302E2227334A0731495E5A2359304D

4E3F3E335C21A71035335117B33F36A35632FF47B4FF6683

9DABB96922BED6F4FF87FFFFFFFFFFFFD7FFB3B0FFFFFF82

679BFFBBA032B2F7FF4E3F4728C5FBE9FF5D6970B92FD941

A22A9647599582188C5D645430435A2A1E10633B252C2734

44463D204B40513D

1C444E17193423282307290E0F5623321A2E0D1B75345A35

2340463220541A3EB025AAC5595C9A456B5D64D556DF4769

C5A911E1FF54FF7AF7FFFF8AAD7776C50CFF384EFFA1FFFF

FFFFC465C143DE744BE77FE297FF69CC485FCC1A7024595C

62394A7C813A7760598763104B232E642F3C3E734E252330

1856653F50296C32

156136331366051C492E424943271E2D6182122C5C526955

4804485A6A625438CB1C109261604BEE60D841A21E8EFF47

A5DC6AFF89CBEE9177FFB4FF84A3FFFFFFFFFFFFFF87C766

FFD7DCFFFF7AFFFFFFB553FF979CFF3679C15052810E9440

2825C68888DA688A780B7E614541393C492C496A273C347B

3C475F0B16542E1F

2D07730C0A49572C186719433822244E5D9C142D09355E42

3324192C2E76AB377064732B0E558729C587FFFBB0C6E4FF

7EFF6D9476FF636FFF973EFFEAFFFFFFFFFFFFFFFFFFFFFF

C09A769524FFF0FFCB1EFF6D97FFDB5BCADE5C8195154A28

5C38545F5462694D276956204E3A3D55634534103154142E

2817290731152F2A

265F8B1B3A2D54364A43215D1714317749253A2B38483039

5171296026195F43084630603B3A3DC45A5EE6E79934FFB6

3A6CFFFF1BFDEFFFFFFFFFFFFFA8F4FFFFFFFFFFFFFF99FF

FFFF3426FFA1FFFFCDFFFFD897FFA054851D5146566C284C

3E40A16872357C5F3C851B555A216A4409544C104A601854

15273E4F5D5B5939

20886129252B1A367B0218443E4814226129411A33253B28

28644C39585C304655641798B9B04F575DFF3ACCB1FFFFFF

D9D0FFFFDCFFFFFFFFFFFFFFFF81FFA19B36FFFFFFFFFF9D

3DFFFFFFC9FFA0FDFADD7999FFCDFFFCA0651BB61D5C2959

6348B0462A28728115BF578341302E6F39192B0F74271C38

49262A471F5D3557

1C3E4005112930393D2511222C0B240B3140285426482A50

7D503224602E05605D153D3A36E719127EFFC92567FFFFED

FFFF71FF81FFFFFFFFFFFFFF81FFFFFFFFFFFFD7FFFFFFFF

2E66FFFBFFFFFFFFFFFFFAFFFF9AFFFF347E7F7170614430

8B1A5B5ACC26BF806B27236F6A63455C677718336558171C

6A0F402F26354366

4D152C2C364B26330939263920273B1C50402E451B516E62

117B2E2564606018413A4A9B4DCC6350C060FF4FEDD2F5FF

FF8FFFA5FFFFFFFFFFFFFF75FFFFFFFFFFFFFF9DFF9BFFFF

FFFFFFFFFF63B4FFD7959F5216FF1236AE4A73B935755B4F

B3268D6E7555219B7E3C776594374124345B14193F301D35

2E2A49352E472941

173A351E324928580F26173D0E1B452F405D4F710D50631E

67AD0E1948A3363368288C7C7A809888949ED68790FFABFF

FFFFE9FFFFFFFFD1FFFFFFFFFFFFFFFFFFFFFFFFB0FFFFFF

E5FFFF33DFFFFF672DFFFFFF49FFFF7EFB60FFA770D1B9D9

737E353D5B5171510A8D3D42903446431E492A29372D106F

284F3C6F3C5A3A1B

041F2E28183F2C16363C0F431A3A2B543B4507412C124663

7D1B531530831E57506DFF7B5C46198089946363FF5CFFA3

54FFFFABFFFFFFFFFF328BFF8FFFFFFFFFFFFF95FFFFFF4B

FFFFFFFFFFFFFFFF66FF65ECD47D20FFFB9580B0E7C573A6

32142078888A261B46524D1341425157342D292C36242E32

6451483038195231

2A402D3C1C3F2B55131540410B56241D1231212022502B4D

5E1E3E240857329E3445A259755F4E1A49FFA47EFFDBC8EB

EE5DFFB9FFAAFFFFFFFFFF7AFFFFFFFFFFFFFFFFFAFFFFD5

FFFFFFEEFFFFB5FF8FFFFFFF43FF9BFFAC5CA2D58C15ECCC

265550268434453B214D4B3A6D0C867B2D05701843284F31

1C154D2A2834512D

2C302239380F2A683827569D3E18471A2B063B163432636D

201C6F44AC5A4D7825AA55514D7B897537FFD0FF30C73CD4

9CFFFFEBFFFF18FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF64

FFFFFFFFFFFFFF67FFFFFFFFFFF1FA3980425EF3365A4A4E

AB4946588D3620611E61276F474B3853150E8B474B360F2E

31280C3529111421

2740231D2461314A1F136158283C483F28824A2829501678

583B5C5BD83018230FE11A5BE19EFF9E983AD987ECF1B259

52FFFFFFFFFFACFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF

FFFFFFCDFFFF5CFFFF4AFFFFF3637BF9C83D54C31ACE5568

739A7C6F5A65764C6F4E3E3E3F7439645E5B135C2C23270F

291D0A32254C3A2D

3B2F20522E6C2E1B3A4C863D4238655E612258691F4D461D

5C11434D584B932F3CA57DE0A6919885ADCC5F34BCFFD6FF

DBFFAD9AFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF

FFFFFFFFFF9AADFFDBFFD6FFBC345FCCAD859891A6E07DA5

3C2F934B584D43115C1D464D1F695822615E6538423D864C

3A1B2E6C2E52202F

272D3A4C25320A1D290F27232C5C135B5E6439743F3E3E4E

6F4C76655A6F7C9A736855CE1AC3543DC8F97B63F3FFFF4A

FFFF5CFFFFCDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF

FFFFACFFFFFFFFFF5259B2F1EC87D93A989EFF9EE15B1AE1

0F231830D85B5C3B5878165029284A82283F483C28586113

1F4A3161241D2340

2C21141129350C28312E0F364B478B0E1553384B476F2761

1E6120368D584649AB4E4A5A36F35E428039FAF1FFFFFFFF

FF67FFFFFFFFFFFFFF64FFFFFFFFFFFFFFFFFFFFFFFFFFFF

FFFF18FFFFEBFFFF9CD43CC730FFD0FF3775897B4D5155AA

25784D5AAC446F1C206D633234163B062B1A47183E9D5627

38682A0F38392230

2A2D5134282A4D151C314F28431870052D7B860C6D3A4B4D

213B45348426505526CCEC158CD5A25CACFF9BFF43FFFFFF

8FFFB5FFFFEEFFFFFFD5FFFFFAFFFFFFFFFFFFFFFF7AFFFF

FFFFFFAAFFB9FF5DEEEBC8DBFF7EA4FF491A4E5F7559A245

349E325708243E1E5E4D2B5022202131121D24560B414015

13552B3F1C3C2D40

043152193830485164322E24362C292D3457514241134D52

461B268A8878201432A673C5E7B08095FBFF207DD4EC65FF

66FFFFFFFFFFFFFFFF4BFFFFFF95FFFFFFFFFFFF8FFF8B32

FFFFFFFFFFABFFFF54A3FF5CFF636394898019465C7BFF6D

50571E833015531B7D6346122C4107453B542B3A1A430F3C

36162C3F18282E1F

171B3A5A3C6F3C4F286F102D37292A491E43463490423D8D

0A5171515B3D357E73D9B9D170A7FF60FB7EFFFF49FFFFFF

2D67FFFFDF33FFFFE5FFFFFFB0FFFFFFFFFFFFFFFFFFFFFF

FFD1FFFFFFFFE9FFFFFFABFF9087D69E948898807A7C8C28

683336A348190EAD671E63500D714F5D402F451B0E3D1726

0F582849321E353A

4D4129472E35492A2E351D303F19145B342441379465773C

7E9B2155756E8D26B34F5B7535B9734AAE3612FF16529F95

D7FFB463FFFFFFFFFFFFFF9BFF9DFFFFFFFFFFFFFF75FFFF

FFFFFFFFFFA5FF8FFFFFF5D2ED4FFF60C05063CC4D9B4A3A

4118606064252E7B11626E511B452E40501C3B2720392639

0933264B362C2C15

1C664335262F400F6A1C175865331877675C45636A6F2327

6B80BF26CC5A5B1A8B30446170717F7E34FFFF9AFFFFFAFF

FFFFFFFFFFFBFF662EFFFFFFFFD7FFFFFFFFFFFF81FFFFFF

FFFFFFFF81FF71FFFFEDFFFF6725C9FF7E1219E7363A3D15

5D60052E602432507D502A4826542840310B240B2C221125

3D3930291105403E

2057355D1F472A2649381C27740F2B19396F2E30418357BF

158172282A46B0486359295C1DB61B65A0FCFFCDFF9979DD

FAFDA0FFC9FFFFFF3D9DFFFFFFFFFF369BA1FF81FFFFFFFF

FFFFFFFFDCFFFFD0D9FFFFFFB1CC3AFF5D574FB0B9981764

5546305C58394C6428283B25331A4129612214483E441802

7B361A2B25296188

2639595B5D4F3E27155418604A104C5409446A215A551B85

3C5F7C357268A1403E4C286C5646511D8554A0FF97D8FFFF

CDFFFFA1FF2634FFFFFF99FFFFFFFFFFFFFFF4A8FFFFFFFF

FFFFEFFD1BFFFF6C3AB6FF3499E7E65E5AC43D3A3B603046

08435F192660297151393048382B3A2549773114175D2143

4A36542D3A1B8B5F

2D2A2F1531072917282E14543110344563553D3A4E205669

274D6962545F54385C284A1595815CDECA5BDBFF976DFF1E

CBFFF0FF2495769AC0FFFFFFFFFFFFFFFFFFFFFFEAFF3E97

FF6F63FF76946DFF7EFFE4C6B0FBFF87C52987550E2B7364

7037AB762E2C192433425E35092D149C5D4E242238431967

182C57490A0C7307

151F2E54160B5F473C7B343C276A492C493C394145617E0B

788A68DA8888C6252840940E815250C17936FF9C97FF53B5

FFFFFF7AFFFFDCD7FF66C787FFFFFFFFFFFFFFA384FFB4FF

7791EECB89FF6ADCA547FF8E1EA241D860EE4B606192101C

CB3854626A5A4804485569525C2C1282612D1E274349422E

491C056613333661

1C326C29503F6556183023254E733E3C2F642E234B106387

5960773A817C4A39625C5924701ACC5F48CC69FF97E27FE7

4B74DE43C165C4FFFFFFFFA1FF4E38FF0CC57677AD8AFFFF

F77AFF54FFE111A9C56947DF56D5645D6B459A5C59C5AA25

B03E1A542032464023355A34751B0D2E1A3223560F0E2907

2328233419174E44

443D51404B203D464434272C253B63101E2A5A433054645D

8C1882955947962AA241D92FB970695DFFE9FBC528473F4E

FFF7B232A0BBFF9B6782FFFFFFB0B3FFD7FFFFFFFFFFFF87

FFF4D6BE2269B9AB9D8366FFB447FF3256A3363FB3175133

3510A7215C333E3F4E4D3059235A5E4931074A3327222E30

210F50493A305C3F

44371540560E4A3A481B4D4D48523C2D3C7D6C64234E152F

5D344742601D391333373B862DE86CE3953BD33197617883

C452FF97FFFFF4FFDDFFFFFF7996FFFFFFFFB4FF93FFFF32

684493CEFF646E814058D25DB9C595807455BF21623C9E40

964A55B757664F8247601D132648424C372F35324D393930

27100B482E1E1438

6554521F34204C41755E4A253368511F21661E58666F4717

8328478A52842731784B6993EE6883FFB05C4415AA7C7280

6FDAFFFFFFB887FF3580CC9EFFFFFFFFFFFFFFFF60FEFFFF

FF9A889C7681BEFF6BA65155694D2B5DC1B81E2F7887A554

9B487B74866B137764435B461E3D4B150E233D303818323F

4129274517483912

3C0B3E20262D6F2631165234474F466A4792173E5A202A5B

627F7E25394512711547313D4827AC1D915EA54F8654F728

FF8135A135B8FFDCFFFFFFFFAC86FFEF8576FFC597D5FFE5

7A61BA359936BEE5A25350A65BFF64BDF832366D7048564D

2A6D1845614E2538433A5A163D433312553813256C352F25

49342B332F333E0A

13343C692D453B416C232D2FA05958823C28637A41206221

3F308A5655155C60344085187A1510522C2752445359D4FD

E7E250BEFFFFB5E547A9B97EFFFF53B25E1435C132FFE4FD

17FFBFEB1779725C75B2463DF2746AAD413F7855944A6F4F

A113576A2D82102A384940112C260E2C5540203932121330

144720492F32333E

2E150E322A71350B3657394A4645253D0433335B220F2E5F

37504B962D566C056FA39D4338433C771F7F62AC4B7D36BC

75D6F9AB4DC0C57D4EFB77B05095FFFFFF58A3A3FF376E60

85EC88CFCD287FFF59C35A93864EFF2B637D0E824D303E6C

89873095559109303641232E3B3C4E5A672632842E10572F

2D2A44783A424C86

352414132635324E853D2C131227311541424366753D6C5D

8751605716982F607D8F7E4721339C74684B24720F58B3A8

FFFF958E3FD572FFFF87FFD6E4FAF688FFFFD6812A93FF90

7D0B815A968DF99DE4B177859660B9AE4E033E466E553A94

2B0D336E300D3C2810453B50334D4B053324476090335D28

6717642C180E552A

1119334A5E25428036302934201D4F07215C338948394989

46614B1187612A842179271648A325B963C56A9A0EDF8F6C

4A95337BFFFFEE27793D9C8F7BFFFF3CBB914656A7B58332

EFA81861961E3F9BA382A9643E4089666B766732AF293E0F

2E9A42885A3D14530D6A793D4B5E1B450F26443D3E5B4331

4D2820414414372E

31223B23291B3F33644F1A343B51527C371B3635215B5412

A81D9B17604D732D683B50064919487F6336A04E2F57AF87

5385FFE09E406E77AB4D51BDEDD1A569A17041FF863950AA

30ABC16A8B436F7B40915C3062D23E81A6223C4515136911

4138233B47101F2D4D402A560D0E1E2C3153403E49202C5A

392B11161F225449

2E393B407F2524404955046131210D440C933A6F7D34409F

431E7D653E0B4614416F468C20CEA0AB95619DDC2BAD9358

8319663C80C06B889452416A7068968988D9FFA99F66D190

CDD46DFFC72488D618BA624428954E57444EA13978431E8B

682B3310482211271C67472F1F31441F5621136E3C493B41

2E2E1B2844241926

29461B1B7A190C1241510E19512A692745261A1E4C61386C

634537143D47124A43178A5B6D40348E1A7B47608D989387

7F76819A4D441852C3BE65EFFFA581CFFFDD9F886D43FFFA

A842BD386D0CA48569527B24C6CE2B1048710E68713D2747

054344414D4E38184051282C3F4C2E32143236620F566240

331F6B4E5F33352A

0E4B1C4B243F41693055277C3A67301B1640693D507D235B

3E27512C48194D163C871D5E5B87365F4B634F574B8BCC36

5B5CB1A96C4C094F3F808143B6C1D631532372581187D759

937D1B75489F8152623A6B2B6A3A24215D11754360397762

5C3F2D25205841242B1B3C45325F3A2739310E212C852973

7A1F286751061F0D

0011474536376727661C7D4B3229164A4259544C5A401345

2B274484258B5F389157D67341695B714D4DA66FAB8F99E3

AF858B2B3C7C3D5A67582178818A64E488382D7389F95169

0E1CBF6EC09D5D9E68BE6822492C09883D2B782C5F6C5832

1439102F42412B8227402A5E2F12534A18163E522D1F4826

403E437B336B5245

063D1D385B19246F283C286C1642201F6E72376138213E11

551C46522D4E58416B56635B307EAB4F895A42913E494963

7184137C274F56837C35451B8EB9A03AE88725624139558E

26B5D89AE355AE7D492D274345414F4F4B2D7F1A6A74127E

49303B403F241B52253A50421C1F3A3D282A132E774A251D

4016301E112E2913

33166A412A6C3B2A6A381C34532D2A4A2B27292F19293608

4E2639326B38394529193F37354F315945155E6C5DBB3D5E

2E52124ABCC3AF805847842237695C7077B132366CB1CC57

A5696E7A93304A89AC6E21155A66404C0B611E5F691B8D8B

2D3E494D3926472533653D1833301A16311037414F2E5619

2A34472822197148

2252631F7A361B4B1646202576349F41521F214A283B181B

53276F3B7F377A6C077738782948A45A61860B5E60406D28

36495A4A834070FFE97C68B378C4E98EADCD4C53ACC130FF

FF402F666B754763983C38013C59682841288157747A6D44

925C363415682E2A1D1C27382580381C105D2641335B2C43

2E45250C1B37521F

046E25744F7C212C2B77383F162B5838371E0E1A224C3258

35551283962BAA1442591B322C3A68525B1B254044A17A7D

3B3F6F09242A5C6348BC62AF7B646AD36D4E49534C7D4CB9

4573665DEB9F838C4191683C5E3F49485C7146456C4C342F

243D3E6C33467162203C2938235A1C73421E382435421C2A

172216133B36912F

1842851B11573313166815370E313E09183C3524327E3A79

463771670C9235182045298F4638123124471B455B170E18

312F8F93628DDC2A271C2152808A368AFF5C8E1E1EBBC19F

81928C1EAE479F638429657C16594A247458310764216C3E

462419414241191A01163B1D270C2B020E115A233F3D1466

1D43081D15382F17

21473E5B1C097D393C441150203E2D374F2D3C10814B5CBF

1035645A4C264937663A2B2F4323452C986070681A264D32

721891204CB5615169424A1E7964903C82E77B3B3F784484

7B92635A50284397687D913B412967303172495429785B21

2F70226D57563224191A0B2F172A34231F705B1B271C1131

11105A0D53141F27

6F1E352819500E34132D482E25290F2F57524D295152424B

0A2E48563736501C505F8A6249917B67383457395B312A41

2A573DA857A49E6D785C4283A6651B2C486F745092465F2E

3F526F0E4B34272E391620531ACAA244261A56551C15253D

5A3A3C2953154A2B4D444B280E4316783148652416471E3A

4C264C2A164E4C4B

012A1A251751301C1F3E204E261C405C381B5630404D22BF

19687E375E8E698A914FB3474B550A07482D3B3F394D5F27

345C71993452468281B28E9DC8AFAEE1CE73529CFF426363

5271377D434B241E211461405F3D2D0F165410694E17373E

11382E32042E2F1F5C201709424E1D7306394F4A264B2348

3F115C2B533C1352

2010415E30420C3D404A4A373A593360435B837A5F185F6D

2F744E605053263103563E6F76815E77230732360C212C41

4728357D6C3E69535A317086AA332A63FFBC54642A8A933F

0D687936288D5E89528BD9972478154E7A1070092A1D5759

4127173C4830231B2A4A3B421C28240841153F4937182B32

36175A254F293722

0D16260F1B2F1236081B691E3C55483537481A2B651D5814

152322A92D807A89696F6D552494446B304D1C8B533B5731

7C21394314658A5772426B4D375B41086CD28B24360A1C1F

3437244D515675355C7121305660741252525F1E4C330619

294138284E392D4B7412687C2B551F193B13150813217061

1C42162D1E322710

0D304A204519215C40512A113808040F2F4F4053255B6C77

5A725CC85661202E3E7A2F211B20604B51373B4C44174D23

26540F3C4B83AE7A4667507F4C57C25D785B1A28350B696D

838B537776548A6ECA20A7345C3E308D052D4540BF4B0F3A

1F15203021253A4E26793A3E0F3F383631223018313B1443

1C372E270716272E

2D30185F3375522A204146473D334927286941385E313D75

3D631769255F722F7474585E32575D4B556C3C243F517215

4512221A47D88D2EC2CF93CBE3D16610620E604989274B2A

3B0FA9DA555D8278502636473837963D85550B317A4A6856

12242B28154130343964333142603F462E443D33143E144B

3D276826281C2506

20122404123D3A263D4C4022030D1B6844463A4214209363

90173654092A2E363E43414A6049844524622C41473D3315

2214293A5A0E1E30487097705D225C726542995670611E4F

36874F67596A177B3C454143557D60584847752766231E4E

3128012A18284A60374D19483E0A62263D2D67511B3B123F

311A3C3F0F382C1C

451150334520541E0F48272811104D232A723C3E28251421

2B2B4164266F575E1618135D3A581530565B404F332F4644

33582C686A46274C273373465E47556C5337441D4E113A5E

75316137370E98A24C79396F32393D52366F5C852C192A37

2A6A392730337A213A22362E424353182136414F1D3D231A

2110361E2749272D

27284D262852155F432F222D2B110A232652465B18155720

6D50697D6721115F3D494B1732385F3E253D1E3841095910

421B43195B2E8C57A6833992934976406C4F34291E23346C

1A729D292358784F2A1CAA73284956454928615440072119

364A553D18382F382C614446124A5C3958231732151C1835

2539153E25464233

2F2258275B1650233A4E4E433E2030317D6F346E4C7B4B45

622D8A383D714F524C634954550E0A73604F4A15201A4E19

4F5C1A4656072243092C15126E7795676974413B3F3C7240

8A4C3B953957416F3F274D635412362B252A4B4517293221

0D580F361E53572E3A1538342B1337281C18311131191523

2B201C050C24292D

874B0F10313A3B2D2F1E293B2A3616463B6C0D3D67535459

0756392C8E365954265A2D2E293F20423D0E23525129432B

1E464C50406395A33E866A2C179CB419A554494F65432B87

2D5F49684140411C45769D454D933C6413472D2C51082617

45100E393D3E4F394B602D707B1F6A422D38062C33141622

114C302425115A0A

2C3A1D274013636A463810672B592526383B39252E3C6154

545AAD6F5468503935464B413D17093D20213E2A534B345B

3A0E2C3E4C3752877560A28141461525367D605A53792715

0A45191A657C37410B1E0C523B45290B392E24635B2F4D2A

10102A172E332B390111692F082E433A273233103628203B

3B18580F4816343F

232237185032160B2C3B303F262913411D403E5D492B5537

0C2115524E30381A153C35410D584A6C3338132E204F1623

3E28196155615C1E400B1656516146786C4D4D0E81703479

754C3F1B2C3D2710502A38106A65424433322F418B1D4722

4A1839270D52342F4B1D56483B291F18355409263E102934

231F3A04311B5734

7A23021F09192D18530E4A693B3A42440A382B3C23384434

35542E3C2B08312E352F2A3E48594442331633072C262E47

1B29393F3B281D123A391C3D626085CA731019191B795E57

55594850252E5A6D2C6C328B2232141D6B321E3E69302A34

1B2E30483A3A064F3313752E1D7B26712239171818231D46

2419122F272D3952

133E580630444D14222327164242465A2F383D50153F532B

44673C1E224526354F362F24222F22261F0D19333D4D4619

2F083D09293F6D3E3B8429182283281F8177483C39342677

531C27575D982B1F1D18266F3135132F3B50152A32334639

23150D4445264317293C5645294A4A2059233919182B1019

120F4032170B3927

5311192B4431153B333A282B1A4E14265F234C3B1E5C4652

1B33342416312F814B542A3A16443218682A15171534310E

1D0F824E6F4D08252B2F195F740942533D467C6529425E15

4432284B01190F1A4549483D15401E201B2C08271C2B3424

144D44343B2E521D46335919503A171C353D651E073E2B2B

0F2644342945381B

1F211D062D5B18261E2A1547535A57720D09183F20352910

1339181F1F3F423534392F103E2A173A17543C44631D2354

322D523C1A3556932F335A5F82672126555A3E224E052649

5333343640254B33143739214C3F2E0A303118295E211916

330D313629074C4024562F3152252F542B31111E21112436

39302F1B1333123B

28610D31182108290A360908370B23157049614732181638

3E200A61582954234541517244491E18243986592B131963

904A4A302C0C623D125A71452E49525DB63F3310272A381D

35120D254E4F40412A1B383525233360301E05132A1C2606

2B423E4F223E3D0C40110A153A1337380E101A1D0D281A2B

1A0C203A205A1F3F

20322D1C0F232F1D19322B1D5E3A566B1645293654381F4B

25233330442928142611340B22170E1B374B6F1A2A424237

1F20126B5847404B5E471C377D5F1F58AA52130732321E1C

31102F2746184D0D233E1119154B6242543A311D232D281F

3D1B3D44373227611C3340172E58282B1409343D2C47333E

3A1819232029132D

25270024480B3C131D21305438463C2F4E0B6C05284B2A20

1F2D261F3C1F33366D692E4E1B0413132447292D464C2342

4E2E7B49453512206F65355745234D06727017408F916F95

37172B2F552D404F4640117421442D3557343F397A554723

23272640351A5F2064234C3F36351D3F4C2625150A182937

4B2231071B4A0D29

161F630B4A204B48174F0F29453C4F3E2B053F251F550F33

371133722248172C131833222635150F25134D491B175242

2D372C262A5B32795F2170324C331B5A6111575D23103741

47034240271E4230531D394A946D10404F5232430A3D1A34

583F3B3654195B4B15272D287B210F0D213D38362A2D0F46

1A152542240D266F

3D4E3C25241B2D412B2B0E3B443E430A4B33490B1C405229

2526292E5C0E31330F360F28163134315128562A3C1A1763

4E215C3609481B5694502A612A314B6E56655E1418322A3B

4B1C372020371C1A2F4465645B1B2A123F105A10272E2635

191543423904173E0E2221352C2811563A3A1E0C35323C39

246422251C101707

0821491D3E292D160C28522A21452D361D20341023063429

2E16184162573E444B0E46445006322D5A204D2606163D14

131610242D1B38242E6D6E122323163A774347495F104D14

51490C532132324061824F842819125025432F6221393A2D

3A3229492524291815322426492F101F214D32145B36302F

15151A20151B543E

472D1B321F4213441D34205D2A4D37333B062D0E1813200B

2D27380B2D1A471717225148343629471730322F5A4A2237

371C50463537301A4D234D483F383B4D4A4D1574064D452C

633C0E5154381A17233058565D2E1A386607713C72443551

4A2F22252325220D1922883743271A4C1E5F294E41093113

13340F24162A262F

091C122A50245B513C4F2731552F0A1C0A072E2C23121032

3F0E31183A23091624432E45376F191844461E3C193A391D

17041220311D6154648053271A30792B6019252B29489631

300D3917382B134624442C66293410540F431E5E73386130

134C1C141D0850352919450C14110512581B3B1A1F302624

202B092047114733

2E2B3655325320582F3D3D502A1D15271E23381B36113A3F

5B321F2E252824371F18243D5E0C491A3B0F5F955153384E

4B402E073360422B2A40264839223029593B686B12192235

1633603B3C20215F4E145B187015503A3E30455E52831939

021532251618361641393935264827391D08433513551016

1E0C08030C2E223B

2A27350C3951444E4F4114393E5027221617244F4433352B

32172028142E38391F4011445048194470025E7B70190D08

26280B212C1D142D15464A0B2C3C4D156D6F504F381C2932

224764422D2D3F2C1A2E43232C3B144A2D30460B31261845

413C7917371E2330191214172418252A2160372D4123182E

2033580B38372B10

2B311D66176B214B442F355412130C2736394B254B073E35

6E22222C0F09353B24383D1A6127342E6F364A1E24331C20

183A090B255B32452C294A59486A181054215A9C41453515

265243543F1F313D1F2B0A133E5336414C3C3F4A0D134246

30583B5A123F36183F3B0E3A14421D35340B313E342E1A11

163A1C381D32212B

143A1F211F4327413436131E2634371A1E1B1F2934094113

631B222D241C1C0F1A151042365A191754594320142B2743

49191A743C3B1633332E133440694E46544D64377E5E2928

283A374D2F3B1A5D663016161A2E202E382635132E561E42

125F0E151B28353A0A0820113A2F104E1456152C2E0D164A

2B2B410E33172725

275230200A5E3430254142563D362337574011251826155E

0F51295727612B23191030271D29462915342A4510260D12

3A10375D25225D6D2315515E400B1D4C8E6154333545343C

473512272E322E25392312494922210869186F3B322C3E1B

43390A54172825202D40321236510B663A4D08321B263707

102F3C4A306D1252

19561C221F343A410F0E353B3E76283C1A4E10350E1D2948

57202D102162502C3E4348241F2B1F3A34355A6D20231E37

95722649372735143169321E2E0E122C6AEA47372C231C1A

2B292A1D122B2E3F19121B153C1522751F49247627642020

0841152F253B0C1F061714334B1C1D3F2B4C212B300A3635

1607224026152A1B

053304550C451F18121B13363D0D0E0F190A171665432E2F

632C37283A60433731123B1E2C1D3A284A0A1564136B3222

4C4213452E591F093F1F2A3F3C36424A3C10545334395A24

2059427E4C3B380A3353104F231726302D32664534063D1A

4D360E0F11221A261B530F131140461C0B4744332B0B4A0D

3B3036492C45176E

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.0113379 0.97619 0.464853 MathSubStart

%% DensityGraphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0192308 0.015024 0.0192308 0.015024 [

[ 0 0 -0.125 0 ]

[ 0 0 -0.125 0 ]

[ 0 1 .125 0 ]

[ 1 0 .125 0 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

[ ] 0 setdash

0 0 m

1 0 L

s

0 0 m

0 1 L

s

0 1 m

1 1 L

s

1 0 m

1 1 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

% Start of gray image

p

.01923 .01923 translate

.96154 .96154 scale

64 string

64 64 8 [64 0 0 64 0 0] {

\tcurrentfile

\t1 index

\treadhexstring

\tpop

}  Mimage

FFFFFFFFFFFFFFFFFFFFFFFFFF9BAFFFDDFFD8FFBD3460CE

AE869A92A7E27EA63C2F944C584D44115D1D464D1F6A5822

625E6638433D874D3A1B2E6D2E53212F

FFFFFFFFFFFFFFFFFFFFADFFFFFFFFFF535AB3F3EE88DB3A

9AA0FFA0E35C1BE30F231830DA5C5C3B5879165129284A83

2840483C285861131F4A3161241E2341

FFFFFFFFFFFFFFFFFFFF19FFFFEDFFFF9DD53CC930FFD2FF

37768B7C4D5156AB25794E5BAD456F1C216E643334163B06

2B1A47183F9E572738692A1039392230

FFFFFFFFFF7BFFFFFFFFFFABFFBAFF5EF0EDCADDFF7FA5FF

491A4E607659A34634A0325808243F1E5F4D2B5122202232

121E25560B42411513562B3F1C3D2D41

FFFFFFFF90FF8C32FFFFFFFFFFACFFFF55A5FF5DFF646495

8B8119465D7CFF6E50581E843116541B7E6446122C410746

3C552C3B1A430F3D37162D4018282E20

FFFFFFFFFFFFFFFFFFD3FFFFFFFFEBFFFFFFADFF9188D89F

958999817B7D8D28693337A549190EAF681F64510E724F5D

4030451C0F3E17270F592849321F363B

FFFFFFFFFF76FFFFFFFFFFFFFFA6FF91FFFFF7D4EF50FF61

C25164CD4E9C4A3A4118616165262E7C11636F521B452F41

511D3B27203A273A0933264B362D2D15

FFFFFFFF82FFFFFFFFFFFFFF82FF72FFFFEFFFFF6826CBFF

801319E9363B3E155E61052E612533517E512B4926542841

310B240C2C2311253E3A30291205413E

9DA3FF82FFFFFFFFFFFFFFFFDEFFFFD2DBFFFFFFB2CD3AFF

5E5850B1BB9917645547315D593A4D6528293C25341A4129

612214483E4518027C361A2C252A6289

FFFFF6AAFFFFFFFFFFFFF1FF1BFFFF6D3BB7FF359BE9E85F

5BC63E3A3C613046084360192761297252393149382B3A26

4A783114175E21444A36552E3B1B8C60

FFFFFFFFECFF3E98FF7064FF77956EFF7FFFE6C7B1FDFF88

C62988560F2B74647138AC772E2C192433435E35092E149D

5E4F242238441A67192C574A0A0C7408

FFFFFFA485FFB6FF7892F0CD8AFF6BDDA647FF8F1EA442D9

60F04C616293111CCD3855636B5B480449566A525C2C1383

622E1E274349432F4A1C056713333662

0CC77778AE8BFFFFF97BFF55FFE311AAC76A48E157D7655E

6C469C5D59C6AC25B23E1B542032464023365B35761C0D2E

1B3323570F0E2A072428233419174E45

D9FFFFFFFFFFFF88FFF6D8BF236ABBAD9E8467FFB647FF32

57A53740B51851343510A8225D333F3F4F4E305A235B5F49

31074A3327222F30210F51493A315D40

FFFFB6FF94FFFF33694494D0FF656F824159D45EBBC79781

7556C121623C9F40974B56B958674F8348611D142648434D

372F35334E393A3127100B492E1E1439

FFFFFFFF61FFFFFFFF9B8A9E7782C0FF6CA752556A4E2B5E

C3B91E2F7988A6559C487C75886C137865445C471E3D4C16

0F243D313918333F4129274517493912

8677FFC699D7FFE77B62BC369A36BFE6A35451A85BFF65BE

FA32366E7149574E2A6E1946614F2538443B5B173D443412

553814256D362F254A342C332F343E0A

5F1436C332FFE6FF17FFC1ED177A735D76B4463EF4756BAE

42407956954B6F50A313586B2D83102B384940112C260E2C

5640203A33131331144820492F33343F

FF59A5A4FF376F6187EE89D1CF2880FF5AC55A95874FFF2B

647E0E834E313E6D8A883196569209313642232E3C3D4E5B

682733852F1058302D2B45793A424D87

FFFFD8822A94FF927F0B825A978EFB9EE6B278869761BBB0

4E033E476F553A952B0D336F310D3C2810463B51334D4B05

3424486091335E286818652C180E562A

BD924757A8B68433F1AA1862971E3F9CA483AB643F418A67

6C776832B1293F0F2F9B43895B3E14540D6B7A3E4B5F1C46

0F27443E3E5C43324E2920414514372E

A27142FF873951AB30ACC36B8C44707C40935D3063D43E82

A8233C4515136A114238233B48101F2D4D402A570D0E1E2C

3254413F49202C5B392C11161F225549

8ADBFFAAA067D291CFD66DFFC92489D818BC634528974F57

454FA23979431E8C692B3410492212281C6847301F31441F

5721136F3C4A3B422E2E1B2845241A27

FFDFA0896E44FFFCA943BF396E0DA6866A537C24C7D02B10

49720E69723E2748054344424D4F39194152282D404C2E32

143336630F576340341F6C4F6033352A

542372591188D95A957E1B7649A08252623A6C2C6B3A2421

5D117644613A78625D3F2E25205942242B1B3C4633603A28

39310E212C862A747B1F286751061F0D

89392E748AFB516A0E1DC06FC29E5D9F69BF69224A2D0989

3D2C792C606D5932143A102F43422B8328402B5F2F12544B

19173F532E1F4826413E437C336C5245

EA8826634239569026B6DA9BE556B07E4A2E274445424F50

4C2D801A6B75127F4A303B413F241B53263A51431C1F3B3E

282A132E784B251D4117311E112E2913

78B332366DB3CD58A66A6F7B94304B8AAD6F21155A67404D

0B621E606A1B8E8C2D3E494E3926472633653E1834311A17

32103742502F56192A35482822197249

AFCF4C54AEC230FFFF4030676C764764993C39013C5A6928

41288258757B6E44935C373515682F2B1D1C28382581381C

115E2641335C2D432E46250D1C38531F

6E4F49544D7E4DBA4574675DEDA0848D4292693C5F3F4A48

5C7247466D4D352F243D3F6D34477263203D2938235B1C74

421E382435431C2A182216143B369230

FF5D901E1EBDC2A082938D1EB048A0648529667D165A4A24

7559310765216D3E472419414341191A01173C1E280C2B02

0F115B243F3D14671D43081E15393018

83E97C3B3F7944857C93645B51284498697E923C422A6831

3173495529795C213071226E57563325191A0B2F182A3524

20715C1B271C123111105B0D54151F28

497075519346602E3F52700E4C35282E391620531BCBA345

271A57561C15263E5A3A3D2953154B2B4D444C280E441679

3249662416481E3B4D264D2B164F4D4C

CF74539DFF4364645372377E444C251E211462415F3E2D0F

1755116A4F17373F11382E32052E2F205C211709424F1D73

06394F4B264C234840115D2C543D1352

FFBE55652A8B94400D697A37288E5F8A528CDA982479154E

7B1071092B1D585A4228173C4930231B2A4A3B431D292408

42153F4A38182B3237185B2650293822

6DD48C25370A1C1F3437254D525776365C71213157607512

5353601E4C3406192A4238284F392E4C7512697D2B562019

3B131508132171621D43162D1E322810

795C1A28350B6A6E848D547877558B6FCB21A9345D3E318E

052D4640C14B103A2015203021263A4F277A3A3F0F403936

31233018313B14431C372F270716272E

630E61498A284C2A3B10AADC555E8379512636483838983D

86560B317B4B695712252C28154231353A65333143613F47

2F443E33143F144B3E276926281D2506

66429A5771621E50368850685A6A177C3C464243567E6159

4948762867241E4F3128012A18294B61384E19483E0B6327

3E2E68511C3C123F311B3C400F392C1C

5438451D4E113A5F76316237370E99A34D7A3A7032393D52

36705C862D1A2A372A6B3A2831337B213A23372E43435418

223741501D3E231A2110371F284A272D

6D5035291E23346C1A739F2A2358794F2A1CAC74284A5645

4A28625440072219364A553D183830392D624447124A5C3A

59231732151C1835263A153F25464334

6A75423B403C72408B4D3C97395841703F284E645512362C

252A4B45182933210D590F371F54582F3A1539352B133729

1C193211311915232B201C050C25292E

A7554A5066442C882E604A694141411D46779E454D943C65

13472D2C5208261746100E3A3D3E4F3A4B612D717C1F6B43

2D39062D33141623114C302425115A0A

367E605B547A27150A46191A657D38420B1F0C523B46290B

3A2F24645C2F4E2A10102A172F332B3901116A2F082F443B

273333103628213C3C18580F4916353F

6D4D4E0E8271347A764C401B2C3D2810512A38106B664244

33322F428C1E47224A193A270D52342F4C1E57493C291F18

355509263F102A3523203A04311B5835

74101A1A1B7A5F5856594850262E5B6E2C6C338C2233141D

6C321E3E6A312B351B2E30493A3A064F3413762E1D7C2672

233A171818231D4625191230272E3952

8278493D3A342678541C27585E992C1F1D1927703236132F

3B51152B3334473A24150D45452644182A3C5746294B4B20

5A233919192B101A12104032170B3A27

3D477D6629435F154532294C01190F1A4649493D16401E21

1B2C08271C2C3424144E44343C2E531D47335A19513A171C

353E661F073F2B2B102644352A46391B

565B3E234F0526495333343740254C34143739214C3F2F0A

313218295F211916340D32372A074D4024572F3153263055

2B31111F2111243739312F1C1333133C

B73F3311272A391D36120D254F5041412A1B393525233361

301E05132B1C26062B433F50233F3D0C40110A163A133839

0E101A1D0D281A2C1A0C203B215B2040

AB53130732321E1C32102F2847184E0D233F111A154B6242

543A321D242D291F3E1B3D44383227611C3340182E59282C

1409343E2C47343E3B181923202A132D

7371184090936F9638172C2F552D41504640117522452E36

5835403A7B55482323272641351A602165244D4036361D40

4D2625160A1929374C2231071C4A0D29

6211585E2310374248034241271E4230541D394A956E1041

4F5332440A3E1A34583F3C3655195C4C16272D287C210F0E

213D38362B2E0F461A152542240E2670

57665F1419332A3B4C1D372021381C1B304566655C1B2A12

40115B10272F2635191544423904173F0E2222352C281256

3A3B1E0C36323C39256522251C101807

7843484A60104E14524A0C54223232406283508528191351

25443063223A3B2D3B33294A25242A18153225264A301020

214E33145C37312F15151A21161C543E

4B4D1575064E462D643C0E5254381A17233059575E2F1A38

6707723C734535524B3022262325230D19228A3844281A4C

1E602A4E4209321413350F24162A2630

6119262B29489732310D3917382B144724452C672A341054

0F441E5F74396231134D1C151E0851362919460C15110512

591B3B1A1F312624202B092048114834

5A3B696C121922351633603C3C21215F4E145C187115513B

3F31465F5384193902153226161937164239393526492739

1E084435135610161F0C08030C2E223C

6E705050391C2933224765432D2D3F2C1A2F44232C3B144B

2D30470B31271846423D7A18371E23311A1215172418262A

2160382D4223192E2133580C38372B10

55215B9D42453515265243553F1F323D1F2C0B133F543641

4C3D3F4A0E14434730593C5A12403718403C0E3B15431D35

340B323E352F1A11163A1C381D33212B

554D65387F5F2928283A374D303B1A5E663016161B2F202E

392635132E571E4312600E161B28363A0A0820113B2F104F

1457162C2E0E164B2B2B420E34172726

8F6155343646353C473612272E322E253923134949222108

6919703B322D3E1B433A0A54172926202E40321236510B67

3B4D08321B27380710303D4A306E1252

6AEC47382C231C1A2B292B1D132B2E4019121B153D152376

1F4A2577276521200942152F253C0C1F061714334B1C1E3F

2B4C212B300A36361708224127152B1B

3C105454343A5B24205A437F4D3B380B3353104F23172730

2E33664634063E1B4E360F1011221A271B540F131141471D

0C4745342C0B4A0D3B3136492C45176F

pop

P

% End of image

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd


\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{288, 137.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000RA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0007Oon2000=Oon20008Ool000Moo`03001oogoo07ioo`03001oogoo
00]oo`03001oogoo07ioo`03001oogoo00Ioo`001goo00<007ooOol0OWoo00<007ooOol02goo00<0
07ooOol0OWoo00<007ooOol01Woo0007Ool01@00OolDQCg_36<00QBU0QS6010<Ha245:DDY@aS248H
iPQ2;F/<Hb486<H@Q1B512440@8HaP05248@I24836<ikP026<H236<0?@PR48@88RE9248Li`Q2@Q0<
Hbf;36<]JaBU6>H]J`@Q6<H8@Q24248LibU:5:DYJT8@:DXHYQS636<Li`aS6<HHYRU:@Q0YJQBU:DXL
i`Q248@8@QS6124]JaSV5:DLic5/36<aS0aSAS48@R3X124YBP@Q48@48A24008HaP05>Nh<Hb4846@8
@P026<H030@1124DQA246<HQ20aS;F/8@QSV248<H`8DY@0448@<HaS66<H25:D010aS?Nmoo`003Goo
00<007ooOol067oo00A>LdYbE[EF]@9oo`9_N`9oo`04JgY[FWooOol2G_L26<H0136<;F]W>FLi0UJe
0T8@00A>LdYbBU96D@9BU004Lia_Vcg_?Nl2DY@27>L011S65:E:DTYB0RDY00D]JbU:9BTU:B480088
@P8]J`0436<@I2489@T29BT01PaS48@a[3F]:DX]J`8@Q08aS006;F/aK36<=HdHaQcW0R480QcW00A2
44HA9BTU:@8Li`8<H`065:DHYSF]=JdDYARV0RU:0Q2400@DYAS6Ool000Qoo`001goo00P007oo000i
cPa39@TDYBDY0QS600XLi`PR9BT88QBU7<LQ22DY124@I08Q2008248<@`PR:DX<HaBU36<@Q088@P0?
124LibDY36<Li`@Q6<HU2C6<6<HDYAS648@<Ha24008YBP087<L48AcW7>LY:Sg_8@P]J`8@Q00i;F/L
iac7:DX]B`Q28>PU:B486<HPj1cW5:D@I248124@Q2e[6<HQ20a38@PY:Q246<He[@a3<H`<@`@Q9BTD
YAcW36<HYPaS7>L8@QcW8@PaS1cW5:DHaQRV<H`HaQBU8@PaS0aS34<48@aS24848@PR008Li`0<248@
I0Q236<@I2D9124]B`007<Moo`003Goo00<007ooOol067oo0Tic00AF]E[FOomoo`9_N`9oo`04JeY_
NgooOol2G_L011S67<LaS36<0VLi00AF]EZf@Q164@9>L`9:DP0<DYAF]FnKLi`mkd8@DYAFUAcW8>PH
YQS60TYB00LU:BTZ;F/]JbDY:BXQ200224802S5/;F/@I0aS9BTQ22TZ9BT@Q11T0SF]0Re[0Q240c6<
00<]JcF]<H`00QcW0R4800HPj1cWAS5242TZ9BT27>L0211T36<HaQBU>Jhe[AS65:D2:DX248@011S6
6:Ioo`0027oo0007Ool06000Ool<H`aS5:D8@QB57>L@Q00034<HaQc7124HaQBU48@U:ABU7>L@I0aS
9BTHaP88@P0E104<H`@Q7>LDQABU34<M1`@Q36<@Q36<5:DicQ248BP@Q3W>48@8@QcW0088@P0636<Q
21BU5:D8@Q1T0aBU0PaS01`@Q1BU7>LQ27Nm<J`DY@Q2228DYA1T6<He[AS6248HaQBU6<HU:A24>Li:
DQcW36<@Q0aS=Jd]J`8HaP057>L<HaBU36<@Q0028@P06aBU:DXaS124124HYPaS;F/Q21BU36<88QS6
248U:@aS7>LDYCW>8>PLiaS61248@Qd77>LHaP0248@010aS:DYoo`003Goo00<007ooOol04goo0UJe
2Goo0RU:0Re[00AJeUKENmigg@9g_@04AS5246mkJgX27>L014icBW9BU4ic0Woo00ABU4icLia_V`8]
J`8<H`04Lia_V`Q2124248@01PaS248HaQBUKg][NP<]J`8Li`08:DX]JcW^?Nl8@Pa39DTYBP8DY@04
48@DYBDY9BT2@Q000a245:DLi`028@P02BDY7>LLia245:DYBRe[;H/aS002248010aS48@U:BDY0QS6
00H]Rc6<48@@Q0aS46@248@011d78@Qoo`0027oo0007Ool06`00OolDQBU:248i[QS69BTLiaS62484
8AS65:D<HaS6124Y:QcW=Jd48BU:6<H8@QS68@PDY@0248@03aBU34<]B`@Q7>LQ211T7>LHYQS67>Le
[@aS=Jd48@0248@29BT00a247>L@Q0036<H0?AB5248HaRDY7>LLab487<LHaRe;<Ha:<RDY46@48B48
;F/YBPQ258De[C5/48@DQBe[7>L8@QcW24888Q24248Q21BU6<H<@aBU9BTDYA1T58DHaPQ258DDYC6<
58D]JaBU:DX88S6<248DY@aS58D8@R48:DXLia24008Li`04;F/Q224848@26<H01c6<124@Q1S6:DYo
o`0000eoo`03001oogoo01=oo`9F]@Uoo`8YBP8]J`9JeP9kgP9g_@04@Q16<FmkKg/27>L3CW<01E:D
OomoodicDY@00W>L00@]Jc5/36<@I09cW0042288@Q2458D236<26<H01F]jKg/]Jc5/;F/00QcW0Re[
0Sg_00@<H`Q2:DXYBP@DY@8U:@92408DY@8Q208U:@048>PLiaBU5:D2;F/2<H`010a3248@Q11T0RDY
0QS60S6<00HDQA2448@<HaB548@28@P00goo001oo`07Ool000Moo`09001oo`Q248@DY@Q26<H48B48
008DY@0_9BT<@`@Q6:HDY@a3:DX8@RDY248DYAcW248@Q000124LiaS648@<H`Q2228]J`Q28@P@I2U:
6:H8@QS648@LiaBU48@DY@aS248HaS6<;F/<HacW5:DU:AS67>L@Q0025:D03C5/?NlLic6<9BTYBRD9
9BTe[AcW6<H8@QRV008HaP04248LiacW>Lh236<02B4X8@P@Q1BU248@Q248;F/YBP0236<01Re[6<HQ
20@Q34<48@8<H`0C48@DYA2436<aS0Q28@P48AS65:D@Q0aS46@<HacW6<HDQ@aS24800QS600<M1aBU
8@P00a2400<Ligoo00003Goo00<007ooOol04goo0PaS0goo0WNm17oo0Tic0V]J0QcW00AW>F<H6<HD
Y@9oo`06JeYWFGooOolLiaS60SW>0THa0Sg_0RDY00`YBRE9;D/YBUJeD[@DQA24?NlikRTZ9BT2;F/2
E[D28@P00cW>36<<H`0248@2=Jd2<H`46<H01PQ234<LiacW00040@8DY@8<H`068@PU:@Q236<Lib48
0Tic00PYBRe[48@DYAS67>La[3F]0QBU00H48@Q26>HLiaSV7>L248@011BU6<Ioo`0027oo0007Ool0
2P00OolDYARV48@HaPaS7>L<HacW0PQ200d<HaS66<HQ21S6228HaQc736<Q20Q27>L48@027>L08@aS
6<HQ20Q2;F/Libe[6<HU:B4834<48BDY7>LPj2DY8@PHaRU:7>L<@aBU48@LiaS646@Q22U:8@PYBQBU
248La`028@P044ic;F/@Q2e;248<HcF]9BT]JbDY5:DHYR486<H]JaB50P@Q010Li`aS48@@I1S658D<
HbDY6<HicQBU7<LDQC6<36<Pj08Li`046<H48@PR6:H248@03SF]7<LLi`@Q9BTDQBDY7>LHaQBU124<
@`Q2;D/26<H02R489BT@Q3F]34<e[@aS6<Ioo`003Goo00<007ooOol04goo0PaS0goo0WNm17oo0Tic
0V]J00@Lib3XHcQW>@8HaP9oo`08IeU[FWooOolHaQcW>Lhmk`96<@8mk`039BTY:RU:008YBP05;F]F
]EJe48@DQ@02?Nl012DY:DX]Jbe[0UJe00DQ22D9=Jd@I0aS008@Q00:>Lhe[CF=<H`LaaS67<LHaPaS
24827>L010@Q000HYQBU0PaS00`U:B4836<<Hb487>MBM4ic;F/YBQBU58D27>L2=Jd25:D224847>L2
48@26<H00goo001oo`07Ool000Moo`0G001ooaBU124DYAS67>L48Be[6<H@Q1BU36<@Q2485:DLibe[
48@DYAB5248@Q003248020aS5:D@Q0aS7>L8@Sg_7>L28@P0;PaS48@HaP@Q9@TDYARV9BT8@QcW5:D@
Q1RV36<DYAcW6:HDYB48<H`U:A246<HDY@aS6<HYBRDY>Lhe[@a39BTLiaBU124U:BD9248HYPQ246@D
YA24124DYA240P@Q00P<HcF]?Nl]J`00=JdQ20aS0RDY00LQ20Q28@PHiQcW5:D8@P0248@00`Q26<HD
Y@026<H05R489BT@Q0Q234<@Q1BU9BTPj1SV248M1bU:9BTQ22E97>L48AS648Aoo`003Goo00<007oo
Ool02Goo0Sg_2Woo00EB]5JeOomNme[f009oo`03<F`]JgOM00=g_@04IcUS>6mkKg/2Ool0148@?NmB
U5:D0Woo00PU:B4X36<<HbTZ9BTaS2e[0SW>00H]JbUZDYA>TbD98@P26<H025:DCW<HaQS6;F/YBP@Q
000248@01B4836<@I2e[<H`00RDY0QBU00DUBBU:48@@Q0aS00<@Q08HaP88@P0636<@I12458DYBRe;
0P@Q0R4800@M1b48248<@`88@P06:DX]BaBU5:DLib480PaS0QcW00HDYARV7@LQ27oo0008Ool000Mo
o`0:001ooaBU7>L@Q1S612440@@Q228236<030Q2;D/8@Qc78@P48@aS7>LDQBDY48@La`8Li`0@8@P<
HaS636<8@QB56<H<@`007>L<Hd8@:DXaS2486<H27>L01bU:34<ec@aS248YBRe[008@Q0098>PLic6<
6<H<HaS648@<H`Q2008e[@097>L]JaBU6<H@Q1cW9BTDYB48008DY@068@PaS1c7104HaR480RDY02lL
ibU::DY:DS6<228Li`aS9BT48C6<7>LDQ@aS7>L@Q1BU48@HaQ1T6<H]Jb487>L8@QS646@LiaB536<D
Y@Q246@DYBU:7>LPj1RV;F/@Q2U:6<H]BaS66:Ioo`0000eoo`03001oogoo00Uoo`8mk`Yoo`9F]@03
OomNmekg009oo`04;F/aS7NmNmh2Mkd2IcT2Kg/2Ool013g_@Q1BU5:D0Woo0RDY0PaS00HU:BU:<H`a
S3W>?Nl2;F/2DY@01R489BTHaQc7CW=BU08HaP8]J`848@0;48@DQAcW48@<Hc6<;F/Y:RDY6:HDY@02
:DX648@26<H22480212436<DQA24;F/YBPPR12448@P040a3248<@`Q2;F/YBQRV5:DQ21cW46@<Hb3X
7>LHYQBU0R4800=oo`00Ool01goo0007Ool02P00Ool48AS69BT8@RDY36<48ABU0Q2400TDQABU48@<
HacW36<]J`Q210400PQ202H48B4836<DYAS6:DX0011T248<HbDY248DYC6<6<HicRe[46@Q20Q2:DX8
@QS65:DaS24848@U2@Q25:DHaPaS6>H88QBU6<I:DRDY0QBU01/@Q0aS;F/DYCW^6<H<HaBU:DY2436<
:DX]Ra1T6<H@Q0Q20008@Q1T6>HLi`aS7>L<HbD98@P00PaS00hicQS68@PDYB4824848A247>L8@QS6
124Q21S60PQ201H@Q1BU6:H000@Q36<48ABU:DXHaQBU9BTLibE9;F/@Q2U:5:D8@PaSOol000eoo`03
001oogoo00Moo`04AS5:DWooOol2AS426<H9Ool2E[D4Ool2:DX2DY@2Ool2;F/2Ool4<H`2BU82AS40
1T8@?Nl<H`aS9@TQ208]J`8mk`9oo`8e[@06:DXU:Be[:DX@I0aS0T8@0QS600<<@`Q2:DX00PaS0Sg_
0S6<00@Q22D92488@P8DY@067@LQ2000124Q22D90QcW0RU:0QBU0QcW0PaS0R4800l48@Q27>LLiaS6
7>L8@Pa35:DHYQcW8@P8@PaS48@00QBU00DHYPaS48Aoo`0000Qoo`001goo02h007oo8@PHaQ245:D8
@QB5228La`Q234<HaP@Q8@PYBQBU<H`<HbTZ36<DYB487>M2412436<88Q2458D@Q1B548@HaRDY:DXH
aRD9>LhPj3W>124aS1cW36<HaP8]J`0@6<HDQ@a336<Libe;:DX8@QcW<H`DYBD99BT48CW>34<39BT2
7>L01R489BTY:Q24:BX<H`8HaP0:7<LQ22U:36<LiaS648@U:Be[6:H26<H03PaS8@PDYAS67<LU:BU:
48@<Hb4836<DY@PR7>L25:D06@PR48@<@`aS248DY@@Q7>LLaaS6:BXDYC5/48@La`aS9@T8@R4846@H
aPaS6:Ioo`0000eoo`03001oogoo00Moo`04BU96<GooOol2AS426<H9Ool2E[D4Ool012U:;D]BU5:D
0Woo00X]Jc5/Oomooc6<=HdaS3F=BU9>D`96<@92408<H`048@PU:Be[<F`2?Nl2Ool013F]>LhYBRU:
0Re[00@<Ha24@Q12408HaP0;248<HbU:46@<Hd8@?NleSC6<9BTQ200224803QRV5:DQ224812440BDY
8@PPj1cW;D/YBQRV5:D27>L236<28@P00`Q2228Pj0027>L01AS636<8@QRV5:D00R480PaS0QBU00HH
aQBU48@@Q7oo0008Ool000Moo`07001oo`@Q7>LYBPaS34<00PaS00<8@Pa35:D00QS600T]J`Q26<HU
:A2436<8@QBU9BT00Q2401HHaPa3248DYA2458DQ:1BU6<HLiaBU7>LHiQ24<H`HaR4858DU:@Q236<D
Y@92400>;H/Q21S66<H@Q2U:124U:BE9248U:@Q2;F/U:@8Q2003>LhLi`Q2008@Q00;248e[CF]5:D@
Q1S636<DYA24124<@`0224802acW34<001B59BT@Q2e[6:HHaP@19BT00R4802888R488>PYBS6<7@L<
H`Q26:HDYAS6000@Q0@Q6<H<Ha1T6<HHYR4848@DYBU:48@48@Q26:HDYB3X36<U:A24Ool000eoo`03
001oogoo015oo`03IeU[FWoo00Ioo`03Mkec_7oo00Eoo`9F]@9oo`06BU96<DHa@Q1[NV]J0Tic0TYB
00E6<D8@CW=:DT8@00Dmk`96<@045:D@Q3F]<J`26<H01QcW6<IBU5:D9BTQ:08<H`07229F]EJe<H`e
[@aS48@00S6<00PUBBU:12488SG=>LhU:BU:0Re[00@Lib485:DHaP8Q208<H`0@1248@QcW8>P8@PaS
48@DY@@Q248YJRe[48@DYB4X9BT26<H010aS48@HaQc70QcW00=oo`00Ool01goo0007Ool02`00OolL
i`@Q34<8@PaS58D@Q3F=48@00QcW0QS600H88PaS7>LLibe[24825:D021c748@@Q0@Q8@P<@`@17>L2
8@P050a336<Laa246<HDQ@Q2;F/8@QcW248DYA1T;F/eSB486<H<Ha1T6<H248@021cW36<U:AcW5:DH
aPaS2482<H`04Re[=JdU:AS65:DaS1BU:DY:DRU:46@U:@@Q6<HaK124:DXaS08<H`0A8>PDYBe[5:DY
BQS67<LHaPaS5:D8@QS67<LHaPQ2;F/HaP025:D02Q245:DYBR4836<88RDY7<LU:@@Q0b4800dLi`@Q
6:HDYB485:D@I12458DLibU:Ool0000=Ool00`00Oomoo`0AOol2JeX7Ool2Mkd6Ool2E[D2Ool2BU80
248@AS5[FVmkCW=BU4YBCU<2AS4014YbCW=2448@0cg_00=1l4HaBS800QBU0SF]00@HaQc76<HLi`9B
U08U:@8<H`09125JeUJe=Jda[12446@eSC6<008YBP0824848CW>>LhYBRDY<F`]J`8Q208HaP0>9@TQ
211T36<8@PPR8@PLi`aS34<DYAB524888P8]J`8DY@8U:@8HaP0448@@I1cW6<H27>L00goo001oo`07
Ool000Moo`0=001oo`a3=JdDQ@@Q48@Q21B5248<Hb4824800QBU014HaQcW7>L@Q0@Q248@Q3g_48@H
YQ2434<U:Be[36<YBQS6008Li`07;F/HaPaS7>L48B486<H00RU:00/Li`Q2=Je:DRDY46@YBQS68@P@
I124008Q200L000Q22486<H8@Q24;F/YBPQ2;H/]J`aS6<HU:AS6=Jd@Q2e[?NlHaRe[5:DDQABU7>LD
YB48:DX236<29BT01@Q248@8@PQ26<H00Q2400dHaPaS5:D<Hb4848@ecAS6248LiaS6248YBP0248@0
5248000DYAcW:DXLib485:D8@RDY36<Q22DY36<U:@@Q<H`<Hgoo000=Ool00`00Oomoo`09Ool2>Lh=
Ool2DY@2Ool00dYBAS5oo`03Ool2Nmh01V]JIeUg_GNm:DXU:@9oo`06<H`]Rf<HGaLYBRE90S6<0VLi
00@Y:RDYCW=>L`8U:@8Li`088@PM1`aS248aS2f;<H`]R`8aS00358D@Q1RV008mk`88@P8aS004=Jdi
cRU::DX236<28@P021BU6<HM1b489DTYBPaS46@27>L011245:D<Ha240QcW00@@Q1BU7>LLi`848@8H
aP0>48@DQBDY9BTHaQc75:DHYQBU6:H8@Pa3Ool000Qoo`001goo02L007oo48@DY@@Q9BT<H`@Q6<H@
Q2DY7>LDY@aS124<@a245:DU:B4836<LaaS68@PU:AB5<H`@Q2e[36<HaR4848@DYA2458DQ22e;?Nl0
0QcW00PLabU:7<LDYBD948@icR480RDY00<Q21BU;D/00QRV00@<@acWBU8icP9:DP0F8@P<HcG=>Lh0
02TZ48@U2BU:7<LaS3W>48@8@QS69@TU:Cg_5:DYBR4858D29BT25:D03B4858D8@Pa3000@I2DY6<He
[AcW6<H@Q1cW008@Q00K6:H@I1245:DU:ABU104e[@PR9BTHaQcW9BTLibe;6<H@Q0aS34<Li`PR9BTD
Q@005:Eoo`0000eoo`03001oogoo00Uoo`03?NlicWoo00aoo`04DYAFUGooOol2BU84Ool01W_NOom[
FV]JMkekgP8YBP9oo`8aS09S608YBP06<H`eSFLiIcTU:BU:0Tic0RDY0QcW0R480PaS1C6<00@eSA24
5:DDY@8mk`88@P8aS00:>Lhe[BU::DX@I0aS9@TQ21S66:H28@P2:DX01Q1T36<LiacW5:DDQ@8@Q08L
i`045:DDQAcW7>L2124011c76<HDYA240RDY00XLiaS66:HDYARV5:D<@`Q2Ool000Qoo`001goo00H0
07oo48@DY@Q25:D248@02`aS248LiacW6<HQ21BU7>LHaP@Q24800QBU00lYBQRV248Q21S636<]RaBU
6<HLib487>L<HacW36<00QBU010@Q0aS6<HLibU:8@PaS2DY34<<Hb3X48@88RDY36<Q208DY@04248H
aPaS36<26<H05@@Q248YBU:d;F/<Hc6<?NlLi`aS9BT]JbDY7>LU:BU:=Jd8@Q2436<Li`028@P02aBU
36<e[BDY6<H<H`@Q36<@Q0@Q6<H00PQ20QBU01@Q21BU6<H@Q1B59BT@Q1S6:DXHaQBU8@P<@cF];D/L
ic5/36<DYAS60PaS00PHaQ24248<HaRV6<Ioo`003Goo00<007ooOol01goo00<n3d8@Ool03Goo00Dn
3gooOolicSG=00Aoo`9g_@Aoo`06=JdaS1B548AW>F<h0Woo00A243g_2488@P8<H`04MkecW1c76<H2
7>L04b3X7>L<@`Q2<F`]Jc6<;H/40@006:HDYC6<;H/DQA246<HUBBU:008mk`089DTYBQBU5:DQ:2DY
48@DQ@8YBP0448@DYAd78@P26<H2124248@212425:D248@22480112458DLib3X0QcW00@DYAS65:DD
Y@88@P0800040Ad78@PLib3XOol000Qoo`001goo038007oo5:DQ211T;F/@Q1cW48@88PaS6:H<HaBU
124@I0aS24848AcW6<H<@acW34<48@Q28@P88QcW8@P@Q2U:7>LQ21BU124@Q11T5:D<@`0048@HaS6<
6<HDQA247<L<HaBU0R4800PU:BU:48@88PQ27<L<HacW0QBU0148@Qc77>MNebe[:DXU:AS68@PicRe[
248Lic6<124HYQS6008U:@0GBU8aS0aS248HYRe[AQ4LiaB536<@Q2DY9@TicRU:8@PDQBU:5:D]Jc6<
124@Q0027>L02`Q236<HaRDY<H`U:CG=34<@Q0PR6<H00P@Q00/Li`@Q5:D48A2436<HaP@Q<Haoo`00
00eoo`03001oogoo00Moo`9240ioo`03@Q1oogoo008icPAoo`03MkekgWoo00=oo`04<J`e[A245:D2
IcT2Ool013g_@Q08@Pa30PaS00=c_7Nm6<H011cW00@Q20Q234<]J`<aS00400040ABU6<H2<H`00a24
58DHaP02:DX01T8@?NlYBRU:6:HDY@8U:@045:D@Q2e;:DX25:D28@P26<H02PPR124DQA2422848ARV
5:DDQA240PQ200<DQA248@P00acW0QS60QBU0PQ200<40@008@P00R4800<Ligoo000027oo0007Ool0
5`00Ool@Q1cW248HaPQ236<HaQBU7>LHaQ24248@Q0aS248HaQBU:DXHaQ24:DX00QS600HYBQ247>LU
:@005:D26<H020@Q6<H8@PaS48@aK1BU36<26<H030@Q6:HLibDY48@Li`Q26<HU:AB57>LLa`8HaP0/
:DXU:A24104U:A247>L]JbU:58D@Q3F]?PlaS2e[6<HDYDYB:DXHaPaS7>LYBQRV6<HYBQ2446@aS248
7>LYBPQ27>L8@QBU7>L8@QBU7>LHaR487>L@Q08<H`0;6>H8@P@Q5:DHaQ247>L<H`@Q228ec@02;F/0
3RU:8@P<@aBU46@@Q0aS;F/HYP0046@@Q7oo000=Ool01P00Oom>LdicCY=BU09oo`03?Pm247oo00mo
o`03Kg]oogoo009oo`04JeYWFFmkJgX6Ool015[FE]EW>FLi0QcW0Woo00<aK2e[;F/00RU:00TU:E[F
E[ENme[fCW=:DPaS24800S6<0RU:00@U:B486<HHaP<]J`04:FXLiacW9BT2<H`011245:DDYABU0QcW
00@@Q1B56<HHaP8<H`067@LQ21BU5:D]Rc6<0Q240PQ200@Q22DY7>LPj08Q2004248<H`000002?Nl0
11S67<L<H`aS0QBU00@@Q1B55:DDY@8aS004@Q16<Goo0008Ool000Moo`18001oobU:46@LibD95:DL
ab485:D88QRV5:DQ20@148@aS23X6<H@I0a37>LYBPaS;F/Lab4846@YBQS67>LLab48:BX8@QB56<HH
YPaS5:D48ARV36<@Q0aS8@P8@R3X9BTU2@aS248<H`009BTDYAS69@T8@S6<8@PDYC6<?NlQ223X:DXQ
20@Q>Lh]J`aS0QRV00T@Q0@Q9BTicRDY@Q088Q1T12400QS60`a302XDYCF]36<HaR4836<LiaBU:DY2
41RV6<H8@QB56<HLa`aS:DXQ235/36<LibDY58D]JaBU248YBPaS6:HDYAcW6<HLi`Q26<HQ21RV36<8
@Woo000=Ool01000Oom>Ldic0U:D0Woo0T8@47oo00=_NgooOol00Woo00AWFF]JKg]_N`Ioo`9JeP9W
>@8Li`9oo`04;F/aS2e[;F/2:DX03UKEF]INmekgBW9>L`a336<aS3F=:DX]Bb489BT26<H012e[<F`]
Jbe[0QcW00<U:CF=<H`011BU00HPj1cW58D@Q1c76<H236<28@P25:D2<H`248@020a3248U:BDY8@PL
ibD98@P236<20002?Nl021cW6<H<H`aS6:HDYAB548@25:D2<H`2AS400goo001oo`07Ool000Moo`0>
001oo`Q248@Li`@Q36<HaR481248@PaS248DY@8<H`047>L@Q2e[36<29BT021BU8@P]BacW5:D8@R48
48@28@P01@PR248@Q1SV9@T00QS600HDY@a39BTLiaBU24826<H01SF]36<<Ha245:E>L`8]J`0948@<
HbU:?Nl@Q1S66>HLib48008mk`8@Q00I@Q0@Q0aS5:E241cW8>Pe[B485:D48AcW124DY@aS8@PU:AcW
6<H<H`PR36<DQA246<H00Q24010DYAc76<HDQB4848@<HacW<H`Q21BU:DXLi`a39BTLi`8HaP06;F/U
2B488@P8@QBU0Q2400T8@RDY8@PHaP00;F/Ligoo00003Goo00<007ooOol00goo0W_N00=B]5JeOol0
2goo00Eg_G_NOomoo`aS00Aoo`8e[@8Li`9JeP9oo`8HaP07CW=:LWNmLiac_7>L<H`00be[0V<H00<P
j1cW7>L00acW00PaS2f;6<HDYBD98@P48@000R4800/aS2e[36<<HaBU48@aS2f;5:DecCW>008YBP08
6>HLiaS66<HQ:2DY6<HLi`8DY@8Li`0648@DQBDY9BTicSg_0QS60`Q200<<Hbe[<F`00Q240R480RDY
00HHaQc7:DXYBQBU6:H27>L236<2AS4012e[<Haoo`0027oo0007Ool03P00OolmkbU:7>LHYQB56<H8
@PaS48@U:@aS58D236<03@a37>L@Q3W>48@mk`aS6<HicPa36<HYBP00008Li`0O9BTHaQS636<LaaBU
6<He[B4836<HaSF]46@8@QS648A6<CF]6:He[Be[5:DDQBU:9BT]Jbe;:DXaS3g_46@00PaS00@8@SW>
IcU64@8aS0077>L@I1cW7>L8@Q1T5:D00acW014DYA1T8@PHaQ246:H40Ac7248Lab489@T]JbDY7>LD
YARV008HaP0@124DYB3X5:D]BaS67<LQ21cW48@Pj1BU7>L48BD98@P27>L03CF]9BT8@RU:36<DY@aS
124@Q00058Eoo`0000eoo`03001oogoo00=oo`9kgP9F]@aoo`05NmiggGooOol@I004Ool01SF]>JhL
iacWF]INm`9oo`0:6<HLadicCW=c_7NmLiag_Be[<H`2;F/016<HIaTLib480acW00<Pj36<<H`00QS6
00@Q22DY12448@8Q208aS08<H`0558DDYC6<<H`DY@02>Lh2:DX27>L26<H29BT27>L01QRV5:DLiacW
5:D@Q08U:@0:?NlikQS66<H<@`Q236<<@c6<;F/248@02RD98@PU:BDY7>LHaRe;:DXHaQBU0QcW00@@
I0aSAS56<@8aS003Ool007oo00Moo`001goo02P007oo48@HaRe[36<HaP007>L<Ha246<HDY@@Q8>P@
Q0@Q:DXHaPQ248@DYAcW8@P]B`aS9BTDYAS6:DX88Q247>L8@RDY48@U:@aSAS4M1`<HaP8Q200B<H`e
[@@Q5:DU:@Q248@LiaBU36<LibDY>LhmkaS6>Lhmk`PR0RDY044e[Cg_8@PaS2E9;D/8@P@Q7>L@I2e[
<H`YBS6<36<DYAcW48@8@RU:36<HYPQ27>LHaSF]9BT]J`@Q8@PHaQcW36<LiaBU:BXYBPa348@48AS6
:DXDYBDY;F/Pj1cW46@M1`Q25:DDQAcW6<HLiaBU124<@aS6:DX8@QcW48Aoo`0000eoo`03001oogoo
00Moo`08Lkag_GooOolLib3XBU9>L`9oo`04=JdicS6<<H`2Ool00cW>BU9:DP02=Jd2Ool0148@?Nmo
ogoo0W>L0V<H00=JeUJeOol00goo00A6<D8@HaQS608DY@06AS5242e;:DX8@P@Q0QBU0SW>0S6<00@i
cSG=7>LHaP9F]@03?NlicQRV00<DY@0336<@Q124008HaP8Q2004;F/aK1S66<H2124011BU6:H8@PQ2
0Tic00@]Jc5/9BTYBP@@Q0046<HLib488@P236<0136<=Jd<H`aS0QBU00@YBRe[9BTU:@@48@8icP04
00048Goo0008Ool000Moo`0:001ooaBU8@PHaPaS9BT8@Re[36<27>L011245:DHaPQ20QS600lDQAcW
8@PHaP@Q6<He[@Q2000LiaBU7<LDY@aS5:D00PQ201<DYBDY6<H]Jc6<48@HaQcW228DYBD97>LYBPaS
228Q21cW?NleS@0236<032481248@QBU?NlYBRe[<H`mkacW48@<@`8Q200B@Q1BU36<?Lm242U:6<HY
:QcW6:H48AcW;F/LabDY:DXDYB480Q2401@Li`@Q34<Pj2489BTQ21cW:DXe[BU:>LiF]Be[:DX]Bc6<
8>PDYAB50acW014DYA24;F/DYCF]248Lib48=JdaS0a38@PDY@aS7>Moo`0000eoo`03001oogoo00Eo
o`9BU006AQ5247ooOomNee[F0Woo00HmkcW^BU9:DW_NMkd2IcT00dHaOomoo`02=Jd2Kg/015:DEYDQ
22DY0Woo00A6<DYB36<@Q09BU08Q2008JgY_Nc6<<Hag_G_N9BTY:P@aS09:DP88@P0436<@I6LiIcT2
7>L012U:;D/aS36<0SF]0Re[00<U:@@100000RDY00@]JbU:=Jde[@8YBP06<F`]JaRV5:D<@`Q20T8@
0S6<00HHaQBU48@<HaBU58D28@P29BT28@P041S66:HU:BDY46@<H`@1000e[C6<34<8@Qc76<HLiaS6
0S6<00=oo`00Ool01goo0007Ool00`00OolHaP025:D00a241240000236<0<QBU48@<@`aS6<H8@QS6
248<Ha247>L8@QBU6<HLi`Q27>LDYBe[:DX@I1S6248YBPPR48@HaQBU36<Q22DY5:DDQABU7<L8@RU:
<H`DYAcW>LhM1be[6>I:DQcW9BU2<248=Ld37>L01ad7>Lha[3F]BU8mkcF]0088@P0<5:D48B4848@4
8BU:9@T<Hbe[9BT<HbDY0PaS00L<@bDY:DX]JcW>12488P02:DX04R4X<H`YBRU:=LdLiaS6AS4DYC6<
8@PU:Cg_9BTe[AS6=Jdmk`8HaP0?36<Pj248:BXU:AcW48@YBPQ2;F/@Q2e[48Aoo`0000eoo`03001o
ogoo00Eoo`9BU092409oo`9JeP9oo`06>LhmkdIABU9g_GOM0VLi00=2<7ooOol00SF]0Vmk0U:D00PU
:B48OomoodXbAS4@I0aS0U:D0R4800I_Nf]J<H`]JgOMMkd29BT0136<;H/aS36<0TYB0PQ20PaS0VLi
00@LiaS6:DXYBP8aS08e[@8]J`099BT000008BPU:BU:;D/a[3F]008YBP8]J`8DY@88@P92408aS006
5:DHYPaS46@@Q1BU0R4800HQ:2DY8@PQ21BU6<H29BT236<01000104aS3F]0PQ20aS600DLac6<<Hao
o`0000Qoo`001goo03`007oo58DLab489BT@Q248248Lia247<L<Ha1T248HaPa358D]JacW;F/U:@Q2
9BTQ236<5:DLiaRV7>L<Hb3X:DXU:AS636<@Q0@Q8@P]Bc6<5:DU:BD9:DXU:ABU>Lh<HaBU9BTmkbe[
58DDYDic>Lh<HcF]7<L248@01aBU7<LU:CF]8@PmkbDY009:DP0H7>M245JE:DY6<ABU;F/<Hb4836<Q
20Q2;F/48B487>L@Q1cW58DLic6<7>LHaPa30RDY01/aS0Q248@aS47`=JdYBSF]48@YBPa336<]Jb48
:DX@Q1B51248@QBU6:H@Q1S68@PaS0Q2:DX00QBU00@U:ABUOol000eoo`0<001oo`PR125W>F<H?Nli
cSg_>NiJ]UJe0THa1Goo00=koSg_?Nl00Woo00<]BbU:Ool00W>L0PQ20UJe00AS66Li=Jde[@8U:@0:
Ki]cW2U:;F][FVmk<H`eSBe[<H`2=Jd01R489BU>Ldic;F/aK08]J`06HaQW6EJeE[D@Q1B50U[F00HL
ib4836<@I2U:;D/248@26<H38@P011B548@LiaS60Re[01HLaaS6?NlicQ1T36<88P@Q6<HDYA1T36<L
aaS658D@Q2e[:DX8@PPR24848@8DY@0412440AB548@25:D011B548@LaaS60`aS00L<@bU:9BTU2B48
Ool00008Ool000Moo`03001oob48008DY@0@8BPDY@aS7<L48A2436<@Q1cW46@U:B486<H@Q0Q2:DX2
8@P01QBU7<L@Q1cW48@mk`8HaP0c48@Lic6/5:DHaQBU36<DYD8@;F/e[Ac7:DXLiaSV6<He[Cg_9BUB
U4YB228HaQcW;H/HaSW><F`Li`Q29BT@I2487>LYBSF]:DXU:Be[9@TicQS648@U:A249@Ta[3F]5:D]
JaS6008Q208HaP0;:DXLibe[:DXHaPQ2;F/Libe[248<H`02;F/013F]58DaS2480QBU00@@Q0Q248@D
Y@8Li`0C=LdDYA249BT48@Q248@DYB48248<HbU:36<Q21S6:DX8@Woo00003Goo00@007oo12448@9S
6004>LhmkcW>?Nl2E[D2AS44Ool017_NOolmkcg_0Woo0RU:00=oog>LKi/00PQ200aF]E:dHaQS63F]
<J`U:B48Lia_Nbe[:DX2JeX2<H`01S5/;F/e[CF]9@TQ209>L`<]J`03:FYS66<H009F]@0658D@Q5[F
E]DPj1cW0PaS0RU:00L@Q0aS6<HHaRD97>LQ200248@011S67<L]Jbe[0QS60SW>0PaS00@48@PR5:DH
YP8<H`8HaP8@Q006:DX]J`@Q24848@PR0QBU00<000@Q48@00Q2400<DYA2448@00QS60PaS00@8@PaS
9BTY:P8Q2003Ool007oo00Moo`001goo02T007oo48@@I1BU7>L88R487>L<HaS68@P8@QcW36<YBS6<
6:HLiaBU<H`48AcW9BT<HbTZ6<HaS2DY5:D<HaBU000DYAS6:DX<HaB5<H`DYCW>008U:@04;F/aS47`
:DX28@P0;R3X?Nl<HcF];F/aS2U:@Q0LibDY48@aS3W>:DY>Lb48=HdicS5/48@aK3G=CW<ecBDY6<H@
Q0@Q;F/LiaBU248@Q0Q27<LLibDY8@PHYS6<58DQ248@9BTaS2DY0R48024LiaBU5:D48Be;6<H<HdHa
<Ha:DQ24248Q21cW9BTQ23F]36<88P0048@Q22TZ7>LDYAcW8>P8@P@148@8@Woo00003Goo00@007oo
Kg][NPaoo`04AS5247ooOol2Nmh01FmkJeYS65kg58D00SF]0Ukg0UJe00I>Le9d@Q12436<=Jd2Ool0
15[FG]LQ22DY0Woo0QS600HYBRe[DYABU1S67>L28@P2F]H236<2:DX011S67<LHaQc70PQ200mBU5Je
48@@Q2e[<F`HaQc77>LQ21cW:DXU:BU:9BT00QS60Re[00HDQA24;F/]Jc6<;F/29BT26<H020@Q104U
:BDY7<LHaQBU58D248@011S66:HHaQS60Q2400@8@PPR:DXYBP8U:@8Li`8HaP06<F`]Jb488@Qoo`00
27oo0007Ool04`00OolHYP0058D<HaBU48@e[A247>LU:@Q27>L8@QS67>LQ21RV008Q2006;F/Q21S6
6<HaS1cW0QS603hM1`a348@DYA24248YBSF]9BTmkaS6124YBT8@7>M:DQS67>LQ21B59BTmkch?;F/Y
BVmkDY@8@QcW5:DU:ABU@Q0U:Be[228aS0Q2<Ha[FVnKIcU:DVLiGaLHYTHaJgXQ20aS48@8@R4834<e
cBU:7>L@Q1cW=JdYBRDY0Re[02DHaS5/:DXicQBU>Lh]JaB5<J`<Hc6<7>LicQcW6<HaK1S68@Pa[1BU
48@U:AS67>LQ22D97@L@Q1BU:DXicQS6;F/<HaBUOol0000=Ool01000Oom[FVmk37oo00A244HaOomo
o`9kgP09JeY[NUkgG_L@Q3F]<JaNme[f009F]@9>L`924004=JdaS7ooOol2F]H012DY8@Qoogoo0QS6
00P]JbU:DYABU1cW6<HQ21cW0U[F00@<H`Q2:DXUB@@HaP0424848EJeDY@248@2;F/26<H02B487>LQ
22DY:DXU:BTZ5:DHaP02;F/248@3;F/00c6<8BPU:@026<H01000124U:BDY0QS600P@Q1BU48@@Q1BU
6<HDYAS60Q2400H48@Q29DTYBR4X9BT27>L26<H2;F/011cW8@Qoo`0027oo0007Ool01`00Ool48AS6
58D<H`@1008DY@0:7>L<Hb48248LiaS636<HaQ246<H27>L04R48228Q21cW?Nl@Q2U:7>LDQA246<H@
Q0a346@Li`PR9BUNm`8Q200A6:H004Xb6<HQ22e[7<L@Q6Li=Je6<BU:?NlicRU:AS524002=Jd0AP@Q
7<LDY@aS;F/mkbe[HaPYBRTZ?NlYBS6<9BTmkeZf@Q0U:AcW248YBQBU48@Y:Pa39@TU:AcW6<HYBRDY
<H`@Q11T48@HaSg_6<H@Q36<:DYW>Be[>Lh]Jcg_=Jd]Ja24:DXQ22U:6:H8@P00124Li`Q25:DYBR48
<F`@Q0aS8@P@Q2DY6<Ioo`003Goo00<007ooOol00goo00ANee[FOomoo`9:DPAoo`067<LHaSF]=JdU
2B480TYB00M[FVLiOolaS3F==JdicP02@Q028@P2;F/2JeX022e[<HaNmekgHaQW>DYBCW<2@Q001SW>
?LlYBRe[GaMS608@Q08aS0047>LPj4icDY@28@P024YBCW<U:BDY:DX]Je[fG_L2;F/00c6<=JdU:@02
@Q029BT2<H`01Q1T36<<@`Q25:D@Q08U:@8Q2003:BXU:AcW008HaP076:HLaaS67<LHaRU:9BT011cW
0QS600HDYAB52488@PPR12429BT01QS65:D@Q0aS34<8@P8Li`03Ool007oo00Moo`001goo02T007oo
22848ABU6<H@I1BU34<Q20aS;H/icQ24248000a3248Li`aS48@YBQBU?Nle[@Q2>LhU:ARV6>HY:Q24
7>LM1aBU36<40AS69BT<Hc6<008YBP0g248icRe[;D/DYCW>;F/HaSW>;D/UBBDY48@LiaS648@<H`@Q
6<H@Q4HaJeXe[@@Q7@L]JaS69BTe[B48=Ld]Jd8`<H`8@R486>H@Q3g_6<HYBQcW:DY6<@aS9BTDYCF]
8@Q:DQ24:DXe[CW>@Q000Sg_01hHYU:D48@@Q0a3248]J`aS<H`DY@aS8@PLiaS69BTYBQcW36<e[@aS
124HaPQ25:D<H`@Q58D8@Woo000=Ool00`00Oomoo`03Ool2F]H2Ool2BU84Ool26<H0136/=JdQ2248
0TYB00=W>FMIOol00S6<00hicSF]@Q0n3b487@L]JbUZJeYWFC5/;F]Nme[f0V<H00A>DdYB@Q0mk`8i
cP04;D/YBV<HG_L248@2<H`27>L2CW<012487>M>DdYB0RDY00T]BbU:G_MJeRe[:DXe[C6<:DX00T8@
00HQ22DY;H/aS0aS46@22480112458DQ22DY0R480RDY00<HaQcW5:D01AS600<U:BTZ6>H00acW0QS6
00@@Q1BU1248@P848@068BPU:ABU6:H<Ha1T0PQ200@HiQcWOol000Qoo`001goo00X007oo48@@Q1S6
5:DU:AB5;F/<H`8HaP1:5:D<HaS69BTLi`a38@P48A245:D<Hb487>LU:ABU46@@Q1S69BTPj0a35:DQ
22e[:DX@I1BU124ec@Q2?NlYBPQ2?Nl@Q4icAS4YBTHa<Ha6<ABU6<Hmkc6/228LidYBAS4DYC6<;D]N
mgoo<H`DYAS6E[E243W>6<H]JbU:=JdLicF]?NlLaaBU9BTQ21RV48@88P8HaP0;104DQCW><Ha243g_
=JdQ22U:6<H@Q002:DX03c6<9BTicQRV>Jh]J`aS;F/mkd8@;F/Q236<6<H]J`027>L29BT02R488>P4
8B486<HaS248249oo`003Goo00<007ooOol01goo0S6<27oo0Tic0THa00=BM4ic?Nl00T8@00ANmf<H
Oomoo`8e[@03DYAF]BU:008YBP09;D/e[CF]9BTYBQBU6:H]Jc6<009S6006F_INm`aS48@HYQS60Sg_
00I244HaDYAFUBU:;D/2CW<29BT2?Nl013W>?Lm244Ha0SF]0188@Sg_>NheSC6<9@TQ235/;F/U:B48
48@<Hb3X7>LY:RDY36<224801@PR58D@Q23X7>L00QS60QcW0PaS00@LaaS68@PLi`8Q20<DY@0558DU
2B4836<<@`029BT27>L224800goo001oo`07Ool000Moo`0:001oo`00:DX8@QcW:DXDYBe[24828@P0
31249BTDQBDY:DXHiP@1>Lh@I2DY8@P48@8<H`09;F/<HaS65:D001S66:HHaPQ2008Li`0E248Y:S6/
248YBPa3124HYQcW<H`Li`Q248@@I1249BTQ23g_6<HicRU:008aS0078@Qoodic:DXicVLiLi`00UJe
01ES64icAS5JeSg_@Q0Q22U:6<I>LcG=;F/HaQBU;F/U:ASV8@PLiaRV8@P00P@Q02HYBRDY9BUFeBU:
@S0e[DHa<F`HaSg_<H`<Hekg48@U:B485:D]B`aS7>L]Jb4836<DQBDY48@Lia2436<HaRE936<@Q0aS
5:Eoo`003Goo00<007ooOol01goo00<]Rc6<Ool01goo00A:LTic@S16<@9>L`05>Li243h?HaQNm`02
Ool2=Jd2DY@4:DX013F]<J`Y:RDY0QBU00haK2e[HaQO5ekgF]H@I0aS6<HDYCg_>Ni6<D8@0U:D0RU:
0Tic00@U:B48?Nlmk`8icP07AS5243F]=Jd8@SW>?Nl00S6<0R480Re[00@Q22DY36<@I08Li`8U:@04
248<@`@Q248248@27>L26<H011SV7>L8@PaS0QS600@Lib487@LQ208DY@0:48@DYB488@P8@PaS8BPU
:ASV7>L224800goo001oo`07Ool000Moo`03001oocF]008U:@0K:DX8@QBU9BTDYBDY7>L<HbDY248D
QC6<9BTHaSg_248Q20@Q5:DU:BD99BTHYRDY34<YBQBU008Li`0@;F/Pj12434<<Hbe;:DX<Ha249@UB
U6Li36<YBPQ27>L25:D0=aS69BT48CW>:DXQ21BU<H`Q24YB:DXicSF]9BTDYA1T<HaFUD8@8@P]Jcg_
=JeBM5:D;F]BU23X:DXDYB485:DHaRe[7>L]JaS67>LaS3g_BU8U:C6<AS4]Ja1T:DXLiaS6;F/U:AS6
124U:B48008YBP0E5:DU:BU::DXHaPPR5:D@Q1S69BTHYPQ27<L48BU:36<DYAS648Aoo`0000eoo`06
001oodHA@Q0mkcW>0Woo00IW6F<HCW=:LVmkJeX2Ool017NmLi`mkcg_0S6<0Ukg00LLiaS6CW<HaQcW
G_MS6002Li`2DY@01RU:;D/YBRU:DYAF]@8]J`9oo`06<H`eSEkgH_QkoWoo0aS600<LicF]>Lh00SW>
0RDY00@YBRe[9BTYBP8DY@06=JdicPaS36<Q22DY0S6<00<U:BU:48@00QcW00@U2B487>LLi`8]J`08
36<<@b3X7>LU2B487<LHaP88@P0;;D/YBQcW7>L<@`Q258D@Q3V^=JdLi`026<H00aRV58D@Q0029BT0
1Ac76<HHYQBU7<L00QS600DHYQc76<HQ21cW00848@03Ool007oo00Moo`001goo00<007oo48@00Q24
00d8@RU:124]J`@Q248HaPQ236<DY@aS;F/e[@0248@01AS65:D<HaBU12400PaS028@Q1S6:DX]JcF]
48@e[AS648@]JcW>5:DYBRDY=LdHaQBU=JdDYB487>Lmkc6<CU<Q21BU9BT]Jc6<BU8mkd8@8@Pmk`8L
i`0G?NmcW3h?7>M6<C6<>Nh@I2DY8@Pa[2U:;H]JeRDY48A6<@aS=LdHaRDY58D<H`02=Jd0:S6<BU8D
YB4848@Q21S65:DLiaS69BT@Q2DY;F/aS1S6249Nmbe[9BU240@Q7>LDYBU:6<HHYQcW48@U:@Q28@PL
iaSV?Nl48@aS;F/Pj248Ool000eoo`06001ood8@@Q0icSg_0Woo0V<H00A:DTicJeY[FP9oo`9cW08m
k`8aS09Nm`056<HLadYb7<LHaP02G_L2Li`00e:DCY<YBP02:DX00bE9E[EBU002;F/2Ool2<H`2G_L0
1WooNohHaQS67<LHaP8e[@08>LhecBDY8BP]JbU::BXU:@8DY@8e[@8<H`099@TQ236<;H/YBRDY58DH
aQcW008Q208Li`8]J`04248<HacW7>L28@P26<H22482:DX01QS67>L8@PQ248@DQ@8e[@066<HLaaBU
6<H@Q1B50RDY0QS60QBU0QS600HDYAS66<HHaQcW8>P212400goo001oo`07Ool000Moo`0K001oo`aS
36<HYQcW248@I0@Q8@P<HcF]248Pj1cW58D]J`Q2124001BU228DQA1T7>L<H`00008<H`<Q200Y36<D
QB488@Pe[A24<H`48AS6;F/icQB59BT]J`Q2?NlDYD8@<HaBU248F[H<HdHaBU9244icHaQNma2436=:
<Re[Oom6<AcWAS5242U:48@<H`025:D00fmkAS4aS002BU80<QRV6<H<H`Q234<]Jb4846@Q21B56<H8
@QcW9BU6<ABU8@P<HaS6BU848CF]>LhLib48?NlLid8@6<HDQAS68>P<H`@Q7>LHaP@Q7>L8@SF]248<
@aS6;F/8@Q1T@Q0Q27oo000=Ool02000OolaS2e[34<8@QcW6<H2HaP26<H2Ool2Li`2Ool01PaS34=o
ogooHaQO5`9g_@0336<mkcg_008icP04;F/aK3W>?Nl2F]H012489BTLib480W_N00HicSg?=Jde[EJe
F[H48@P2?Nl012U:;F]:DTiC0RDY00@e[CW>:DXYBP9BU004248<@be[;F/2=Jd01aBU6:I2448@248H
YQBU008Li`8U:@8Q2088@P0:6:HDYABU48@8@P@Q6:HDYBe[:DX28@P248@27>L01Qc76<H<@`Q234<8
@P8HaP0434<8@RDY9BT248@29BT02QS66:HLaaS67<LHaR487>Moo`0027oo0007Ool0E@00Ool001BU
BU8HaQcW248<@a2436<DY@aS8@PHaQ247>L<Hb48>Lh<Hbe[48@HaQBU7>L@Q36<>LhQ21S6=JdPj1cW
48@DYAS69BTe[B489@TecBe[8@PU:AcW<F`LidYB7@M6<D8@CW=c_2e[<H`icR48G_LU:Cg_9BTYBR4X
:BXe[F]J<J`aS3g_E[DaS5kg8@PaS2e[5:D@Q0@Q=JdQ21cW?NlikU:D008Q200N48@<Hbe[:DXaS1cW
5:DHaPaS;F/8@UJe5:E:DT8@248YBQS6:DXHaRDY48@<H`PR36<LiaS6;F/DY@a30QcW00/icQBU5:D@
Q3g_:DXicQB5=Jeoo`0000eoo`04001oobe[<H`2248011S67<MO5f<H0QS60Woo0W>L0Woo00H8@PaS
OomooekgHaP2Mkd00`Q2?NlikP02>Lh2;F/2>Lh2F]H01RD98@PPj1cWNmigg@8icP8e[@9F]@<Q2005
7>LmkcW^;D/YBP02BU829BT01SW>=JdYBRDYDYA>T`88@P06;F/YBSF]=JdHYQBU0T8@00T8@QBU5:DH
aQcW8BPU:AcW8@P00PQ20QBU00@@Q1B512488P8DY@06:DX]BacW8@P<Ha240QcW0QS610Q20QS60PQ2
00LQ22DY36<@Q24X9BTDY@056<H011cW8@Qoo`0027oo0007Ool06`00Ool@Q124:DXLi`aS228@Q2D9
5:DQ21BU;F/HaR4848@aK0Q246@Lid8@48@LiaB546@<H`025:D073F]248LaaS6<Fa:DRD9=JdmkcW>
;F]241BU8@PDYC6/;F/Li`007>M>Lc6<9BTicSF]<H`HaR480Woo03<HaUlGE[DYBRTZIcUF]DHaMkeS
63g_F]He[Cg_MkeoocW>8@Q242DY;F/U:AcW5:Di[R48<H`]J`PR@Q0aS2e[DY@U:ABU>NhLicW>=Jdm
kacW?NlLicF]5:DYBQ1T36<LiaBU9BT00Q24018YBR48CW<LacW>58D@Q2DY248U:@aS7>Lmka24<H`Y
BWoo000=Ool01000Oomoogoo0Re[15:D0Woo00@LiaS6>Lhe[@8aS004AS5247NmMkd2AS400f]JIeU[
FP025:D013g_@Q1oogoo0Re[0V<H0Re[00I:DTiC@Q16<BDY:DX2Ool021BU6:HaS3F=?Nm240@Q2482
@Q0022DY:DXHaQS67>LQ23F]>Jh2AS40248@AS4HaQS6BU9>DbU:;F/2BU801@@Q6<HHaQcW6<H00R48
00XDQA246<HDYB3X7>LPj1cW:DXU:@8]J`0:=Jda[1BU58DLaaS6AQ5241S66:H22482;F/26<H01QRV
5:DHYQBU9@TQ208mk`8Li`8Q2006:BXU:DHa@Q1oo`0027oo0007Ool01P00OolHaR48>Lh<H`8@Q00G
9BTHaQBU36<]BaBU:DXM1acW124HaPQ236<DYAS6248Lic6<6<H@Q2DY48@Li`029BT05QcW6:I6<DHa
36<e[Be[46@]R`@Q9BTQ236<;F/8@SF]E[E6<BDY6<I:DSg_0SF]00QBU2e[IcUJeSF]7<LHaU[F0SW>
01/]JcF]6<H@Q48@9BTYBT8@E[ES65kg9BT8@RU:5:DaK1cWG_L]JcF];F/<@b48;F/HaRU:6<H00QcW
00d<Hb487>LHaSF]6<HLia24:BX001c75:D<H`025:D00a245:DU:@025:D03RU:6<H<HaS6=JdDYAcW
=JdDYAd7=Jd8@Woo000=Ool01P00Oomoogoo:FX]J`ABU09oo`086<HLicF]>Lh]Rc6<@Q164@9g_@09
@Q16<FLiJeYW>ABU48A243g_009oo`8]J`9S608]J`9:DP04AQ5242U:9BT2Ool25:D2<H`2?Nl01PPR
1252448@:BXU:@8HaP088>PLicF]=Je6<D8`AS52408HaP9:DP05;D/YBTYBAU448@036<H00ac78@PQ
200248@00aBU6:HLi`037>L022DY:BX]Jbe[<H`e[A245:D26<H2@Q002QBU6<H48@Q2:DX]JaBU6<HD
YARV0QBU0R4800@ikSg_7>LLi`8Q208U:@04@Q164Goo0008Ool000Moo`0A001oo`0034<DYAS6248@
Q1S636<Q211T48@U:CW>6<H8@P025:D06R3X7>L@Q0aS8@PYBQcW48@YBPaS58DLib487>LHaRDY@Q08
@SW>=Jd<Hcg_6:HU:BU:9BT38@P08aBU9BTmkeZf:DYcW4icKg]JeQBUAS4]BacW8@PaS1B5@Q1g_AcW
DYAJmTXb36<U2AS6?Nm242e[9BTDYCg_34=243W><H`00RDY01`Q24YB8@P]JdHa9BUF]Cg_6<H]Jc6<
:DXQ22e[:DXDYBU:8@P@I2U:248Lia247>LaS1S6>Lhe[@8@Q00?8@P8@SF]5:DPj1BU>Lh@Q0aS;F/L
i`aS8>Qoo`0000eoo`03001oogoo00=oo`04Kg][FT8@@Q025:D2BU82Ool2BU80148@?Nl88P@Q0T8@
0Re[00=>LdHaBS800Woo00A>Le9dLiacW09JeP06>Nhmkd8@AQ5:DTic0S6<0Ukg00MF]E[F9BTYBP00
104Li`028@P01BDY=JdicRU:;D/00QcW00Y:DTiC5:DHYP@Q228HaQc7=JdicP8HaP0312488QcW008D
Y@88@P049BTQ21cW7>L2:DX00ac76<HY:P039BT01P@1000LaaS658D@Q08U:@8aS09:DP047<LHaS6<
;F/25:D023F]<J`<H`aS=HdaS1RV5:D236<010Q2124]JbU:0QBU00=oo`00Ool01goo0007Ool0A@00
Ool00248:DXe[AS6?NlQ21cW8@P@Q2DY36<HYRU:8>P8@PaS9BTYBPQ26<H]JaBU7>LDYCh?5:DM1b48
5:D8@QSV248HaRe[=JdaS1BU?NlDYAcW@Q048ABU9BT@Q5kg<Ha>Lbe[CW=NmcF]G_L<H`@Q=JdUBGoo
@Q0icQBU7>M247>L<Ha6<@02?Nl04A24;F/aS2e[7>LmkacW5:E6<D8@E[EcW4YBBS9B]3W>DY@00RDY
02PicRe[=JdM1cW>JeX]JaS6<Ha6<AB5@Q0Q21245:DQ20Q27>L]JbDY:DXYJR489BT<@aBU6<HU:Cg_
36<eSA24=JdHaQc78@PU:@Q2Ool000eoo`03001oogoo00=oo`04JeY[NSh?@Q025:D2BU82Ool014IA
BU8mkd8@0P@Q00Dn3d8@;F/]JdYB0096<@04OomkoTicCW<2Li`015[FE]DmkcW>0T8@00Y>DdYB<H`]
RekgF_IJeUJe:BXU:@8000068>PLibDY8@PicSF]0RU:0QcW0TYB0QBU00H88P@Q6<HHaSW>=Jd26<H0
2@PR124Lia245:D48@Q28@PU2@027>L012E9:DXHaQS612DY00@000@16<HHaP8@Q0068@PU:Be[<Ha6
<DYB0QS600P]Jc5/48@DYC6<=Jd8@PaS0S6<0QBU00H8@PaS12488RU:;D/25:D00goo001oo`07Ool0
00Moo`0[001oo`@Q228@I0@Q:DXe[ABU48@mkcW>5:E64ABU48@48AS67>LDYAcW<H`HaRD97>L@I1BU
58DQ22e[48@DQABU8@P]Jc6<>LhLic6<8@PicPQ2;F/00Q2402<LicF]6:HLic6<:DY244ic9BTicQ1T
?Nm:DRe[Kg]240Q2;F/icQ24:DXHaV]JGaMNeb48@Q0mkb489BT48BDY=JeB]5[F008]J`046<IW>DHa
9BT2:DX01C6<9BT]JacW@Q000Re[01/@I48@36<U:@aS9BTHYRU:5:DLibe[48A1l2U:8>Pe[B48248@
I1S6=JdLicg_58D]BaS6=Jd00R4800H@Q2DY36<U:Goo000=Ool01000OomNmekg0TYB00PU:B48;F/Y
BUJeDYANee[F0T8@00@LaaS6Nmigg@9F]@8<H`8aS005CW<<Ha247>LQ2002CW<2DY@2@Q02E[D00c6<
=HdLi`038@P2AS40236<=Jde[CF]>Lhmkc6/=Jd26<H02UKEF]HDYABU7>LQ20PR248HYQS60Tic0R48
0THa0Re[00LLib48248]BbU:22848@02=Jd2?Nl03b487>LU:BDY<H`]Ja1T36<U:B4824888QBU58DU
2@028@P01AcW8@PLic5/;F/00R480QS600@YBRDY5:DDY@8@Q08Q20059@TQ20a3248Li`026<H00aBU
Ool00008Ool000Moo`04001ooaBU5:D26<H04C6<9BTe[@aS6<HLic6<:DX8@S6<7<LHaPQ26<HHYRDY
8@P00QBU00@UBB48248Li`8U:@0K7@LQ2248104Q21BU7>LicS6<228ecBDY124DYFLiHaP@Q2U:<Ja2
45:D124e[AcWG_LQ25:D009oo`0a8@Pe[DHaCW=_NgooIcTmke:DOomg_C6<G_MO5bU:248Q22DYCW<m
kcW>?Nm64DYBCW=6<C6<8@Pmk`aSAS4HaR48=Jd]Jd8`36<U:@Q28@PLi`Q27>LQ236<=JdLibf;9BT0
0PaS00h@Q24848@e[ABU:DX<H`PR9DTQ20Q2124<Hcg_0PaS00<Q27oo00003Goo00`007ooG_MNmdIA
BU8Q22DY:DX]Je:DE[D2F]H2@Q026<H01WNmNmiB]5Je248<H`8aS005BU8@I0aS8@PLi`02CW<2DY@2
@Q0035JeD[@aS36<8@PLib487@M6<D8`=JdaS08e[@04?NlicSF]<H`26<H035[FE[DDYABU8@PLi`Q2
124HaQBUCW=:LP8Q2007AS5242e[;F/Pj1cW24800RU:00P48@PR=Jde[CW^?NlLib3X0RDY00X]Jc6<
36<<Hb489@T48@Q248@DY@8Q20047>LPj1cW8>P2;F/28@P26<H01bDY:BXDYABU36<@Q1d700<Q2088
@P066<HLiaBU6:Ioo`0027oo0007Ool0@@00OolDYABU36<DQB485:D<HaS65:DQ21cW9BTLicW>248@
Q2U:48@Q21S646@HaR48=Jd<HaBU248@Q2DY248HaQRV<Ja6<@aS8@PikQcWCY<YBR48;F/U:DiC5:DU
2Ekg36=[FTHa48AW>Goo>Ji[FVLiAS5[FS6<DYAB]7ooJgX00THa03]>Dc6/>Lhe[B48:DY:DT8@=JeN
md8@7>Le[@aS@Q0]JdYBE[DHYVmkCW<aS4iCE[EBU6Li48A6<BDY=Jd<@b48228LicF=?Nl@Q248DY@Q
21c7?NlicQcWBU848BD9124@Q1S6<H`002e;9BTQ212458Dmkb48008Li`03Ool007oo00aoo`04001o
oe:DDY@2>Lh28@P2Ool014Ha@Q0LiacW0RU:0UJe0QS60UJe0V<H0SF]00E6<B489@TecCW>008mk`8Q
209:DP04;F/aK1S66<H2<H`2JeX041cW8@Q2448@DYAF]A2458DLib3X8@PU2@Q234<8@Pa30SF]0PQ2
0R480QcW00@@Q1B57>LLi`8U:@88@P0546@HYQBU:BXU:@028@P25:D02Re[:DX88P@Q24848A2436<H
YQBU0QS600<]BbU:8@P00R4800<LibDY9BT00Q2400@HYQBU;F/]J`8Li`086:HDY@Q2248<H`Q248@@
I08@Q006;D/YBRDY9BUoo`0027oo0007Ool01@00OolHaR4X:DX00Q240PQ207TDYAcW;F/DY@aS9BTL
ib48:DXHaQBU46@48@PR:DXDYAcW9BTDYA24124U:AcW48@HaR48248e[@Q234<Q21cW48ABU3g_8>QW
FC6<5:E:DQcW?Nle[B48AS4e[EkgE[DDYEJe9BTLid8@OolM1cW>CW<e[E:DJeYg_Ekg9DTU:E:d?Nle
[B48CW=_Vgoo@Q0YBTHAE[D]JaBU:BY>Lac7<Ha2424836<Q:0@19BTLiaBU>LhU:C6<249>L`aSE[D8
@RU:;F/@Q1S67<L<HacW?NlYBRE97>LHaPaS9BTaS1S68@P<HaBU48@Lia24Ool0000=Ool01P00Oom>
Te:D=LdicP8Q209oo`0:@Q164ASV7>LUBBU:D[AF]ABU6<H2E[D01ElGHaPe[CF]AS400R4800HicSF]
?Nlmkb487>L2BU82;F/031S65:DaS36<JeYWFB3X7>M243h?E[EBU08@Q08Li`8Q200634<8@PQ2248e
[C6/0PQ20R4800@LiaS648@@Q08Li`079BTQ20Q2124@Q1BU6:H00RDY00`Lib485:DDYBU:;F/48@PR
12488PaS46@25:D26<H2:DX021d78@PLib488BPU:@aS48@25:D2;F/011SV7>LDYABU0`Q200<<@`aS
48@00Q240RU:00@Q:2DYOol000Qoo`001goo00<007oo24800QS602D<@b488@P@Q1BU9BTHaR48;F/L
ib3X8@PDY@PR9@T<Hc6<9BTPj3g_=Jd48BU:248Pj2e[AS4Q24ic5:D8@QcW5:EF]AS6<H`mk`02=Jd0
5dHa8@PLicF=@Q1BU4ic8@P<HdiC<H`<He:DNmhHaT8@F]IF]BU:9BU:DUkg7>L00Woo00LmkdHaCW<L
icg_58Eg_@02Ool0:Cg_7<M:DRDY=Je:DVmk249>LcF]HaPaS5[f58EBU2DY248DYCg_@Q0DYC6<@Q08
@RDY<H`Q24Ha9BTLibDYAS4HaS5/48@48BDY46@@Q1c75:D00QS600U2424858D]JbDY6<H<Hgoo0000
3Goo00@007ooAS56<@9_N`9oo`9F]@06DYA>LcF]<Ha[FVMI0TYB00I[FVLiJeY[FSV^=Jd2Ool00fLi
48@DQ@02AS4016]JKg/<H`aS0Ukg0S6<00LQ22D95:DDYDYBCW<U:@02:DX01Be[8@PU2BDY:DX00U:D
0QcW0Sg_0R4800@<Ha24AS56<@8e[@045:DHYQS67<L224829BT248@02@Q25:DDYA1T36<e[C6/9BTQ
20026<H02Q2446@HaQS69@TQ212446@]JbU:0Q2400H<@`Q2>Lhe[B3X7>L29BT27>L28@P01QS65:DH
aQBU46@<H`8DY@049@TQ21B548@236<011BU58Eoo`0027oo0007Ool05000OolHaQBU:DX48@aS5:Da
S0Q2=Jd@Q2e[6<I:DRe[9BT@Q1S600029BT0:QS69BTLib48248@Q1cW124HaSF]6<H48ABUBU8LibU:
=JdQ223X000Y:UJeG_L]JdYB@Q1JeVnKCW=kgTHaBU8]Jcg_124mkdYBOom:DQBU@Q1[FP9oo`07AS5k
gWooKi][FWooAQ400Woo00DecF]J7>M6<DYB009oo`0LE[EFeBe[124icQ249BTaS3W>CW<HaQ249BTm
kdXb;F/HaTYB34<YBS6<9DU64Be[=JdLicW><H`38@P00`Q26<H@Q002248011BU7>M242DY0QS600HD
Q@Q2248@Q7oo000=Ool01P00Oom2<4HaJgY_N`9oo`0:D[AF]DicDY@aS3F]IeU[FTHaBU82IcT2JeX2
=Jd2Ool02F<H48@@Q4Ha@Q1[NV]J36<8@P02G_L2<H`28@P021BU48A>DdYB:DXU:Be[:DX28@P022U:
9BUBU4jC7>LHiSg_>Nh28@P01Q1T36=6<DHa=Jda[08DY@8HaP0424848BDY8BP248@00`Q248@DY@02
36<0236<=JdQ22DY5:DHaPaS48@26<H28@P010aS48@YBRe[0Q240PQ200@e[CW>7>LLi`8U:@8Li`8Q
20045:DHYQBU6:H236<011245:DQ22480Q240PaS00@@Q1BUOol000Qoo`001goo00T007oo5:E64BDY
8@PLicg_8@P00QBU00lHaRU:248DYD8@6<HDYC6<;F/U:B3X7>LHaQ248@P00QS600D48DYB:DY>DaS6
0096<@0B=JdLiaS69BU240@Q@O0aS1RVOolYBT8@BU9S62e[Oom241BU0VLi00M6<GNmAQ4aS3W>6<Io
o`02DY@0@Re[OomoogooBU8YBUJe?NmoobU:?NmS65kg:BYF]GooJeXmcekg7>LmkbDYE[DaS3g_48@i
cR3X8@PLib48CW=BU0@1=Jd]JaBUCU<U:BU:6<HaS1BU248@Q2e[6<HLa`008>P@Q2D98@PU:AcW;F/H
aPPR6<HicQBU6<H48@a3Ool000eoo`08001oogooOomcW6mkDYA>L`96<@04>Lhe[BD98@P4Ool01UJe
D[@Q2248HaQNm`8Li`07>Lh48@PRDYAFUD8@AQ400SF]0RU:0Sg_00<@Q1B5HaP00VLi00=[FQBU6:H0
0PQ20RDY0SW>00@48@Q2=Jde[@8icP047>LQ21B55:D29BT00`00104Q20028@P022D98@PQ22DY:BXU
:BU:7>L236<28@P2:DX25:D021RV5:DQ2248:BXU:AS65:D26<H01Pa3248LaaS67>LHaP8aS0042488
8Re[:DX2<H`28@P011c76<H@Q11T0SF]00PYBRDY<H`aS1c76<HLaaS60QBU00=oo`00Ool01goo0007
Ool01000Ool8@QcW0aS600DQ:1248@P8@QBU0088@P0f6<HHiQ247>LYBQBU228@Q1BU248Q224X7>LD
Y@Q2?PlHYS6/;F/8@U:D9BTicRDYBU8YBSg_7>LQ25Je=JdicW_N7>MJeSW>;F/ecCg_249g_EkgOol8
@WooKi]ooaS6HaPHaPQ2;F]JeRU:0Woo00Hmke[FE[DQ27>LF]H2Ool02Ukg9BUcW7>LOomWFBe[:DXQ
22U:0QBU00LYBP@Q34<ikPaS@Q0Q2002;F/07`Q2:DXYBTHa5:DQ2124<H`<Hb48>NhaS1247>Ln3be[
:FYBU1BU6:H@Q3F]7@LLib486:Ha[1cW6<Ioo`0000eoo`04001oogooOol2Kg/014icDYA244Ha0SF]
0R480Woo00AkoWooDYAF]@8Q209Nm`056>HLicF]22848@02DY@2@Q0013F]<J`YBRU:0Sg_0Q240V<H
01QWFFLi5:DDY@Q2124U:B4X>Lhec@PR124e[C6/>LhecB3X7>LDYA249BTQ20@100068@P29BT00bU:
9BTLi`0236<01Ad78@PYBRU:48@00QBU00<HYQcW8@P00RDY00@DYARV6<HHaP88@P<HaP077<LaS36<
1248@RU:;F/00S6<00HLib486<HHaPaS48@2=Jd012DY:DX]Jc6<11S60QBU00=oo`00Ool01goo0007
Ool0:000OolLi`@Q7>LLaaRV7<LDYAc79BTDQARV7<Le[AB5248LibU:248HaR487>L<Hbe[7>LQ21cW
48@YBS6<9@T<HcV^5:DY:RU:9BTecCV^0QS601akgUkg<Haoobe[EYDYBU:DLiaRn1S6CW<HaUkg<H`m
kg>LOom[FTicHaQoocW>AQ5g_Goo@Q1F]@Aoo`0bKg]ooe[F7<M>Tac7@Q1ooaBUOolYBTHA9BUBU2e[
BU8<HeJe58DU:AcW6<HQ23W>248U2AcW58Dmkd8@<H`]JaBU48@]Jb4834=:DR48=JdQ22U:8@PLabU:
36<HaQBU=JdHYP8@Q0047>L88Woo000=Ool01P00Ool]BbU:58D@Q08icP8]J`88@P04AS5246mkJgX2
;F/02diCBU9243g_46@<Hcg_>LhU:DicDY@00T8@0RU:0S6<0QcW0SF]00@DYARV=Jde[@8Li`0648@D
QA2448@]Jc5/0PQ200@icSg_8@PU2@8aS08Li`0<>Nhmkc6<<H`]Jc5/7>LQ21BU6<H@Q1B50Q240Re[
00dQ21B548@HYQBU46@<Hb3X7>LU:B487<LHaP02<H`27>L25:D27>L26<H020Q2124@Q1246:HDYDHA
@Q025:D2>Lh2?Nl01Q2446@DYABU=JdaS08YBP081240012446@88P@QOol000Qoo`001goo00P007oo
<H`8@QcW8@P<Hb480QBU02lQ21cW6<H8@QcW5:DLia242288@RDY7>L@I248;F/Q236<>Lh8@SF]@Q0i
cSg_8@Q>LbU:DYA243g_5:D@I5[FHaP]JaBU9BTe[BU:DY@e[GooG_M243W>CW=244ic00Aoo`03;F]o
ogoo00Ioo`07CW=W>D8@6<Iood8@G_L00goo02i_NcF]@Q0ecCg_D[@<@b48;F]F]Goo@Q0e[GNmBU8a
[2DY6<HDYD8@:DY2<2DY48A240Q29BTe[CF=:DX@I36<48@<HbU:<H`HaQ249BT]JcW>7@LU:@aS6<H<
H`8YBP03Ool007oo00aoo`08001ood8@AS4HiQcW5:DHYP8icP0A@S16<G_nOolUBBU:<J`e[@@Q228<
Ha1TG_MS63F]>LiO5`02CW<2;F/2CW<01SF]<JaNmekg=Jda[08@Q08U:@066:HDY@@Q1256<D8@0QcW
0QBU00HmkcW^5:DDYC6<;F/2=Jd012e[:FXHaQS60PQ20QcW00@8@P@Q6<HDY@@Q20075:E2448@48@D
YAcW8@P00QBU00@]Jc6<5:DHaP88@P8YBP8U:@8<H`04248<HacW8@P2:DX031BU6:H<Ha248@PU:A24
58DM1b487>LPj08Q208mk`8HaP8e[@8YBP8Q2003Ool007oo00Moo`001goo01@007oo8@PQ22e[6<HL
ibDY:DX8@Q246<HDYA2458DLabDY124HaRDY0Re[02D@Q2e[6<HY:RDY8@PLiac7;F/@Q5:D248HaQc7
:DX<He[F8@PHaU:D:DXHaWoo9BUJeWoo@Q1>LeJeG_Le[A24G_M[FW_NOom24006Ool016mkOomJeUJe
0goo00]243F]CW=ooekgDY@HaU[FNmioobDY008Q200]5:ES67ooLkaoobe[=JdecEkg6:I_Nb485:E:
DRDY;F]>Dd8@36=6<C5/<H`]BaS68@P]JaBU36<8@S6<7>L@Q1RV58DLab489BTLia249BTQ22U:8>Qo
o`0000eoo`04001oodHaAS427>L011S65:DicSW>0THa0Woo0RU:0SF]00l8@P@Q46@<Hf<HG_LicSF]
HaQ>Le9d;F/aK4icDY@00SF]00ANmf<H=Jde[@8@Q08U:@045:DHYP@Q1242AS4011cW8>PDYARV0Sg_
00HDYARV<H`aS3F]>Jh2;F/26<H010Q234<LiacW0PQ200<HYQS68@P00b4800<DYD8@@Q000QBU0R48
00HHYQBU<H`]JaS66:H2248012e;:DXU:BDY0`aS00<<@b487>L00RU:00@HaQBU48@@I08U:@035:D@
Q248008Q20037>LQ2248008mk`047<LHaSF]=Jd2:DX012D98@Qoo`0027oo0007Ool02000Ool<Hb48
:BX8@PaS6<H348@06`005:D48@Q2:DX@Q1S636<DY@PR36<icQS6;F/HaQ247>LU2AS648@YBPaS7>MJ
eQ24E[ES6002;F/04Tic8@Pe[Be[<Ha[FRe;Kg/e[F<HE[D8@W>LOolYBWoo?NmkgP9oo`0;AS5F]Cg_
>LiS60@QOolHaRTZOomBU004Ool076<H<HaNmb48Kg/icRDYLi`mkg>LBU9ooc6/IcTQ236<IcT<HcF]
48@YJRe[6>HU:Cg_@Q0Licg_0Re[00a2436<124U:A246:HaS1S67>LPj3W>:BX248@02aBU36<YBS6<
7>LYBQBU=JdHaWoo00003Goo00P007ooLkag_D8@AS4@Q1B50S6<0R4800PHiQcW:DX]BdHaBU8@Q1B5
0U[F00U[NVmkBW9>Lg>L;D/YBU[FE[D00Sg_0RDY00@HYQBU5:D@Q0HQ2003:DXU:BU:00<U:@046:HD
YD8@?Nl236<2=Jd2>Lh224801T8@?NlU:BDY6<HDY@8Li`048@PM1b487>L248@01@aS:DXYBQ2458D0
0QcW00@UBBU:8@PQ20<<H`0648@LiacW7>LPj1240aBU0PQ200@DYARV>Lhmk`8U:@0848@DQ@aS46@M
1b48248<H`8HaP0636<@I0Q2248DYARV0QBU0PQ200=oo`00Ool01goo0007Ool09P00Ool8@S6<6<HL
a`Q2=Jd0011T9BTHaR489BTQ21BU36<HYS6<@Q08@QRV;F/YBSF];D/U:@@19BT]JcF]<H`YBQcWIcT@
I0Q2BU82<H`05bDYMkdaS6mk8@QBU0aSBS8Q25:DKg/e[GooAS5W>GNmBU8mkgooF]Iood8@DY@01goo
00I246Li<Haoof]JKg/2Ool01cg_OomoogooF]HYBWoo009>L`04OolHaSg_GaL2:DX03d8@125:DR48
58ES64Ha@Q1_Nc6/AS4ikPPR?NlaS0028@P051cW8>PU:ARV9BTe[AB58>PHaSg_7>LU:Be[2288@Re;
5:D@Q7oo000=Ool02000Oomg_G>lAS5241BU48@2<H`28@P27>L02Re[:DY:DTHa5:D@Q5kGF]I_Nf]j
0Tic00McW2U:;F]F]E[F?Nm240029BT021BU6<HDQABU8@PU2B489@T28@P02RDY:DXYBRU:9BTY:QBU
6:Hmkd8@0PaS0SF]00HicSg?2488@Sg_@Q029BT26<H27>L28@P01AcW8@P@Q1B536<00RU:00@DYA24
7>LLi`8YBP8Q200446@<Ha2446@27>L00b487>LDY@035:D01Pa3248HaQBU?NlikP8U:@0458D@Q11T
36<28@P01PaS34<HaQS648@<H`88@P086<HDYABU5:D<@`Q2Ool000Qoo`001goo00D007oo6:H003W>
00848@088BP]JaBU36<aS0aS8@PLi`8@Q00]9BT]Jdic248DY@@Q6<HaK2486<H@Q0aS5:DHYSW>E[DH
aSW><H`icQBU228YBTHA5:ES648@OomkoU[FHaQoocg_Oole[DYB>Liooc6<>LioodiC7>Moog>l00]o
o`0TG_M>LcW>BU8@Q7ooMkeoof<h46AoocF]BU9oof]j;F]S>6mk;F]244YB34<U:ABU6<HYBRe[:DXa
S3F]9BTDYC6/;D/<HbTZ0QcW00PYBS6<8@PHaP@Q6<HYBPQ20QBU00T8@QBU000HaPQ26<HDYGoo0000
3Goo00H007oo>LhmkeKEF]H36<H01Ac7=Jde[EKEF]H00VLi00DYBRe[DYABU36/008e[@06>Lhmkcg_
BU8HaQBU0RDY00I6<D8`E[EF]CW>=Jd248@020a3248]Jbe[=JdaS2487>L29BT21242<H`01Q1T36<a
S2e[=Jda[08<H`A6<@0?6:HDYB3X7>LU:B4X:BXU:AcW6>HDQA249BT@Q1B5008HaP8aS0047>LPj0Q2
36<46<H236<020Q236<HaQS61248@QS67>L28@P01RDY:DXDYAS6:DX]B`8<H`8DY@8HaP048@PU:A24
5:D248@236<01SG=>LhQ:2DYOol000Qoo`001goo00h007oo48@aS4Ha46@LiaRV:DXLibDY8@P@Q35/
0Pa301HHaSg_9BTDQAcW6:HLibDY6<HLibU:>LhDYC6<48@<Hbe[8@P48BDY6<HaS0<Li`0:HaP]Jc6<
Liag_DYb7<MJeQcW=Jd2Ool00a1TOomkgP06Ool00e:DNmioo`06Ool024icOomoogoo7<L@Q7ooCY<2
Ool0:fLiOomoof]JCW=ooe:D:DY64@aS:DXQ22e[=JdDYBDY8@Q>TcF]>LhLacg_<H`LidHA36<]Bbe[
48@e[BD9124]BbDY248U:C6<36<]B`Q25:DLibU:00<]J`037>Moo`0000eoo`04001oocg_>Nh2F]H2
6<H011cW6<Hi[SF]0U[F0VLi0Re[00IFUE:D=Jde[CW>=Jd2?Nl00dYB6<HHaP029BT2AS42E[D01SF]
>Lh@Q124248<@`8]J`08<H`e[B488@PU:BTZ12488P8aS00436<@Q36<<H`2=Jd010aS46A6<DXb0THa
00@DYARV7>LQ20<U:@0>:DXLiacW48@DYB485:D@Q1c76<HeSC6<8@PLi`8<H`047<LHaQS66<H336<0
0`a36<HHaP02248011cW6<HQ22480RU:00@HaQRV;F/YBP8<H`8DY@047<LHaRDY9BT25:D248@236<2
>Lh29BT00goo001oo`07Ool000Moo`0N001ooa24@Q0aS1BU58DDY@aS6<Hmk`0036<Q223X8@P8@Q24
<H`DYB4836<HaQ247>L@Q1BU<H`U:ASV0Re[00PHaR48:DXaS0aSBU9NmeJe0RU:00D]Jgoo7>MW>E[F
009oo`05JeYWFGooOom[NP08Ool01D8@OomBU4Yb7<L01Goo00=>LacWOol00Woo00YS67ooCW=oog_n
Kg/ikTicOomW>@9oo`0YCW<aS0aSF]H<Hbe[5:D]Jb48F]HQ21BU48@icSg_34=Nmbe[@Q0Q21BU6:He
[AcW36<DY@@Q>Lh@Q0aS6<HU:A245:DQ2124;F/HaRU:Ool0000=Ool01000OomF]EJe0VLi0RDY0RU:
0UJe00AO5f<H5:DHaPAoo`057>LQ21BU6<HaS002=Jd2>Lh01RDY8@PaS36<CW=:DP<Li`036>H00000
008Li`8]J`0<=Jda[1BU48@Q21d75:D@Q48@?Pl]JbU:0SW>0Sg_0SF]0R480TYB0Re[00TLiaS66<HH
aPa3248e[C6<6<H00QBU00h<Ha1T36<<Ha245:DHaQcW48@DQCg_@Q0HaQcW0PaS0PQ200H]Jc5/48@D
QAd78@P26<H2;F/031BU6:HQ22485:DHYR489@T@Q1B512488P8<H`086<HLibU::DX<Ha24Ool000Qo
o`001goo00<007oo36<00R4800@40@Q25:DHaP8Li`0I58D8@Q245:D88Q24228HaR485:D]Ba249BTD
YBU:?NlYBQS658DaS1S6000aS2e[34<00QcW00/HaWNm36<8@Sg_OomS>1B5<HaoogNm009oo`03>Lio
od8@00Moo`03@Q1oogoo00Aoo`03JeYoogoo009oo`036<HaS7oo00Yoo`06CW=oogoo7<Lmkd8@0SW>
00@aS2D96<H<H`8]J`0NIcTDYEkg@Q0e[ABU48@icSF]<H`Q235/<H`mk`aS7<LaS2e[34<@I3F]248Q
21S648@Lab48=Jeoo`003Goo00`007ooF]IF]F]JIcTY:RDY;D/YBUZfE[D2HaP26<H4Ool28@P26<H0
3CF]<H`e[CW>?NlQ22DY<H`eSDYbCW<Lib3X008Li`8000047>LPj2e[;F/2=Jd25:D28@P25:D2@Q02
;F/023W>?Llmkcg_=JdicR489@T2BU802Re[<F`HaQcW6<HLa`Q234<a[3F]0QRV00DDYA1T36<@I0aS
008DY@8Li`0458D@Q48@@Q027>L0211T36<8@PQ2<H`]JaBU48@28@P01Qc76<HaK2e[6:HDY@8Q200:
6<HDYBDY8@PDQA2422848A1T36<27>L2:DX0112446Aoo`0027oo0007Ool01000OolU:@Q20QBU00PL
abDY58DHaP@Q6>HDQASV0Q24020Li`aS:DXLiaRV8@P<HbE9=JdaS0Q2?NlHYQ24<H`]Jc6<248Q21cW
9BU:LRDYIcTaS2DYHaP]Jgoo9BUg_FMI0Woo00=:<WooDY@01goo00<icWooOol01Goo00=>LgooCW<0
1goo03@aS5[FOom[FTYBCW<YBPQ2Ool8@Qc7E[DU:CW>G_LHaSW>;F/YBQ24AS4e[CW>:DX@Q4Yb?NlL
icg_<Ha:DQS68@P@Q1S6;F/8@PaS8@PDYA1T6<HHYQBU9BTHaQRV8@PDYAd7Ool000eoo`08001oocF]
=JdU:BU:8BPU:@8YBP8U:@8mk`8U:@04F_INmb488@P2>Lh01c6<=Jd]Jbe[MkeBU4ic00924096<@8Q
2004BU96DCF]<J`27>L0136<;F/Q21cW0bDY00TQ22e[;F/icSG=9BTQ22D98@P00SF]0RDY0aS600<D
YA2448@00QcW00@Q21cW=Jde[@8HaP039BTQ23W>008aS00436<@Q1cW7>L25:D011S67>L@Q1240Re[
0PaS0SW>0R4800@<Ha1T6<HLi`8@Q08HaP8Q208<H`8DY@06248<Ha2448@8@Pa30PQ20QcW00PHaQc7
AU5:DQBU6<Ioo`0027oo0007Ool09@00Ool<@acW6<H@Q1S69BTDYBe[228DY@a38>P48A1T8@PHaR48
<F`U:CW>124YBS6<48@aS5Je124<HbDYDY@HaQc7<J`DYDHa008mk`06@Q1:DTHaBU9BM6]J0THa17oo
00=g_GooOol00Woo00=WFGooOol02Woo00EJeWooOomoog>L009oo`066<IcW7ooOolaS1RV0goo01TU
:GooOolmkgoo<Haooe:D>LiWFEkgJgY241S68>P]JbU:>LhYBP@QBS8Lib48AS4La`028@P04PaS9BTD
YABU6<HHYPQ2>LhDYBU:7>LicQcW;F/Lia1TOol000eoo`05001oocW>=JdYBP039BT022e;:DXY:RDY
@Q0mkbTZ9BT2G_L02bD98@PicSW>=JdaS35/;F]g_DicDY@00T8@00A6<DXb8@PQ209:DP8e[@067>LP
j2e[<H`Lib4812DY01d]Jc5/>LhicR489BTQ22DY=Jdi[RDY:BXHaQc76:HHaQ2458DLib3X7>LQ23F]
>JhHaQc78@PU:CW>008aS08@Q0048>PLiaBU5:D27>L01QB548@]Jbe[46@<H`8icP8Q200848@<HacW
7>LDQA247<LHaP8Q200446@<HaBU5:D236<248@010aS248<@`Q20acW00<HaTYBBU800QS600=oo`00
Ool01goo0007Ool08@00Ool000aS6:H@Q0aS7>LDY@Q27<LLi`Q28@P<HacW5:DYBQcW8@P48Ad75:D8
@RD9<H`mk`aS:DX8@QS6@Q0@I002:DX02CF]Oolmkbe[8@P<Hcg_AS5:DP02<H`017oo;F]BU2U:0Woo
00=F]GooOol00goo00@HaTHaOom6<@Ioo`05BU9oogooOolU:@08Ool06c6<OolaS7NmIeTmk`aSOomk
oTYB?NmJeW>LHaPicU:D248@Q3W>AS52<1B536<U2BU:9BT8@P028@P2:DX04QS65:DDYABU7<L@Q1RV
6<HaS2E99BTDYAcW36<YBQS6Ool000eoo`04001oogooOol2;F/01THaBU8<Ha1T36<@I09Nm`06GaMS
64icDY@n3d8@0TYB0THa00L<Ha1TE[DU:B48DYA>L`02<H`2@Q025:D01SF=<H`mkcg_34<8@P8]J`8U
:@8@Q08icP06;F/YJQS66<H48@000S6<0Q240SF]00@Pj1cW9BTQ208@Q08<H`038@PM1b48008Q2004
7@L<H`aS36<2000020Q236<LiacW36<@I1245:D212425:D2000010@Q2488@PQ20Re[0Q2400@Lib48
7>LLi`88@P04<H`e[@aS46@28@P03P00124<Ha1T248<@aSV7>LDYAS6248<Hgoo0008Ool000Moo`0<
001ooaBU8@PDYB3X36<Q21BU;D/8@Pa30R4800H48Be[48@@I0Q26<H348@06BU:5:DY:Re[48@LiaB5
124]JaS6DW@HaRD9DY@]JcW><H`U:@aS9BUooe:D@Q1oofmk009g_@05;F]ooe[fOomF]@05Ool00cg_
Oomoo`09Ool01F]JOomoogooMkd00Woo00=JeWooBU800goo02HQ27ooCW=ooeJe;F]BU6]JAS48@WNm
IcT]BbU:5:E241c78@PLia24:BXU:AcW=Jd88T8@?NlDY@@1=Ld<Hb485:DU:AS636<<@bDY0QBU00DL
abU:6:Ioo`0000eoo`0<001oogooOolaK2e[BU96<A2436<@Q0aS0Ukg0V<H00ABU4ic@Q12409:DP05
BS96<A2436=JeP029BT01TicDY@aS3F=@Q164@8DY@06<H`e[Cg_@O08@PaS0Re[0RDY00@@Q1B5>Lhm
c`8]J`8HaP0410448C6<=Hd248@00cF]>JhLi`028@P00bDY48@DQ@0236<68@P336<200001PaS34<P
j1cW48@<H`8DY@0422848ARV5:D2000010Q22288@PQ20Re[00`DQA248@PLib3X7>L<@`Q2=JdaS11T
36<28@P21240112436<<@`Q20QcW0QS60PaS00=oo`00Ool01goo0007Ool05P00OolDYABU48@HiQcW
124DYC6<7>L@Q2e;CW<Pj0Q29BT<HaBU000Li`Q20QS601XaS3F]48@<HcW>8@QF]Be[9BTicQB5D[@Y
BRE99BTmkdHa>LhLigooIeUooaS6HaQ[FTic0Woo00Ag_GooOol8@Q1oo`03<Haoogoo00Eoo`03=Jeo
ogoo00=oo`0FNmikoQcW?NlQ22e[NmhHaRe[9BTY:R4X9@TYBTHa6<H@Q2f;46@]RaBU=Jd29BT03acW
:DX<@`@QAS4Q22DY6<H8@QBU6<H@Q0@Q6<HDY@0224800a24Ool0000=Ool01P00Oom2448@Liag_@8m
k`<Li`038@PikSg_008Q2092408mk`9:DP8aS08]J`039DTDYA24008Q2004CW=:DSF]<J`2?Nl014YB
AU4LiacW0R480QBU00<e[C6<6<H00aS60SW>00@U:B4X:DXYBP8DY@04?NlikRe[;F/248@011S65:Di
cSG=0Q240SF]00L]JbU:;D/YBQS648@DQ@0436<2124011BU6<H8@PaS0QBU0QS60Q2400@<Ha24=Ldi
cP8]J`8<H`0448@DY@aS36<224826<H224801P@Q248]Jbe[12488P8YBP03248<@`aS008@Q0035:Eo
o`0000Qoo`001goo01D007oo58DQ212446@@Q36<6<HU:A1T34<aS2e[5:DPj2DY8@PDYD8@9BT00QBU
00DYBPQ2?Nl]JacW008]J`0DJeXHaPaS58D88W>L36<]JfnKDWAooe9dBU8Lif]jAS5g_G_N;F/YBPEo
o`03E[Eoogoo019oo`04IcUoogoo<F`2Ool07RDYOomoog_N<H`mkg_nIcTLibe;HaP<HfLi;D/a[4ic
?NlicRe[=HdicRTZ=JdYBQcW8@PLicW>7>LeS@8]J`03248aK1BU008DQ@0;248DYA1T124HaQ24:BXL
iaRVOol0000=Ool01P00Oom2448@Mkec_08mk`8Li`088@PLicg_?NlU2B48AQ52408mk`9:DP05=Hda
S2e[;F/YBP025:D012489@U:DTic0SF]00Hmkd8@BU9:DQcW8>P28@P25:D00c6/=JdHaP036<H2>Lh2
9BT012U:;D/DYABU0Sg_00@]Jc5/48@@Q08HaP8icP8@Q009=JdicRU:;F/YBRe[6<HDQA2400@<H`04
22848AS66:H236<25:D00ac76<HDQ@0348@2>Lh0235/;F/@I0aS5:DDQA1T36<224826<H42482;F/0
20PR124]BbU:34<8@Q2446@25:D00goo001oo`07Ool000Moo`0_001ooacW5:D@Q2U:6:He[ARV36<L
ibDY@Q0Lib486<HaS2e[<H`@Q2e[<J`@Q2DY9@T<Hbe[248Q22DY;F/U:DYB5:DLie:D?Nm_Ne:DAS5>
Ld8@E[EW>C6<6<INm`02Ool016]jOomF]Dic6Goo00e>LeJeOom[NWooJeYooekg6<H]JfLiE[E24002
BU809E:DKi/mke:D5:E:DRDY;F/U:B48248]J`aS9@TU:A24<J`]Ja24<H`]Jc6<6<HQ21cW@Q0U:AcW
36<HYSF]6:HYBQ245:Eoo`0000eoo`05001oob4X9BTe[@03>Lh032E9:DY:DTYB8@PU2Be[<H`DYARV
7>LQ208YBP05=JdicP@Q228U:@026<H02QBU48@HYQBU7>LHiPa3248@Q0aS0RU:0PaS00AW>F<hDYA>
T`8Q20085:D@Q0aS36<]JbU:;D/YBP8<H`0634<8@QB548@Pj1cW0Re[11cW0QBU0RU:00<<@`Q29BT0
0QBU0RDY0R480RDY00@@Q1BU12488P8Q2004248<@cW^?Nl26<H0124X9BTaS3F=0Q2400H8@Pa38@PU
:@aS46@27>L29BT0112458DU:BDY0QBU00@8@Pa39BTYBP@U:@03Ool007oo00Moo`001goo00`007oo
58DHYQcW:BX@Q1S6124@I1BU248258D00aBU<F`8@P02;F/07SF=7>LicQcW8@PLibU:=JdY:SW>=Hd]
JcW>?Nm>LcW>=JdYBVLi36=S62U:8>QS67oo?NlaS7_NOolU:@9oo`04<FaoogooIcTDOol00eJeOomo
o`03Ool022U:;F]JeWOMMke246mk7>L2CW<02WooCW=cW2e[36=_VaB536<HaV]J0Re[00DLibe[?Nl8
@RU:008DY@0D9BU241BU8@PU:B3X5:D]Jc6<34<@I2DY6<HaS12446@@Q248Ool000eoo`08001oobDY
9BTicSG=?LlicP8YBP9:DP089BTQ236<<H`HaQBU8@PLi`8YBP07>Lhec@Q2124Y:QS67<L00aBU00DH
aQcW7>L8@PaS008@Q08YBP0436<@I6LiIcT2DY@012489@TDQABU0PaS00`YBRe[:DX]J`aS46@8@Pa3
48@DYAcW8@P2;F/37>L00b3X5:DDY@02:DX02`Q234<U:ARV5:DY:RDY9@TQ22TZ9BT00QBU00H8@P@Q
9@TQ20aS2482?Nl26<H29BT01SF]<H`DQA2436<8@P8U:@0F48@<HacW7>LY:RDY5:D@Q2TZ9BTHYQBU
36<8@RU:9BTY:RDY:BXU:Goo0008Ool000Moo`04001ooaBU48@224803aBU6<H48A246<HDY@Q26<HU
:B48AS448@a3:DXLi`029BT033F]5:D]Ra1T;H/@Q1S6AS4YBRD98BQF]@8U:@09;F/LagOM<F`Q248@
6>IoogNm00Aoo`03=Jeoogoo00Eoo`03<Haoogoo00ioo`04249oogooMkd2Ool03DicJeXLif<H5:Eo
ofLiOolHaSW>@Q0mkbDY008YBP0;E[DicRDY;F]F]B48>Lh<Ha24=JdaS0026<H05@Q27>L001BU36<U
:@Q28>Q>Lbe;48@Lic6<5:D48AcW6>H@Q1BUOol0000=Ool01000OomW>FLi0SW>0RU:0Tic0Woo0R48
136<0RU:00@ecCW>6<HLi`8mk`078@PU:BDY58D@Q11T36<00Q240PQ20S6<00`Q21d7<H`]Jb3X7>LH
YQBU24848@aS2482:DX224802SF]<J`YBRDY36<8@QcW6<HQ21cW0PQ200@LiaS66:HDY@8HaP071040
01RV5:DHaPaS48@00Re[0Q2400@8@PaS12448@8Q20049BTYBPaS46@2>Lh01P00104HiQcW9BTYBP8U
:@0448@DQBDY9BT248@012489BTLib480PQ20Re[0QBU0RU:0QcW0PQ20RU:00=oo`00Ool01goo0007
Ool01P00OolDYARV:DXLa`8DY@0W9BT<@`aS6<HU:ABU8@P<HcG=104DYCg_@Q088SF]7>LU:BTZ48@L
ib487<M241BU:DX]Ba24IcUg_@a3AS5[FU:D<FaF]GooCW=oob48009oo`03BU9ooe[F009oo`05Mkeo
ogooOom[FP0;Ool00cg_Oomoo`03Ool01EJeOomJmWoo;F/00WNm01UW>FmkOolmke:DOolU:@aS:DX]
Jcg?;F]BU248DW@HaRe[124DQAcW48@]JbTZ5:DYBP0348@01QS6248@I124;F/48@8Q200;34<8@Re;
5:DQ20aS8>PDYB48Ool0000=Ool01000Oom[FVLi0SW>0RU:0Tic0Woo0R4800@eSC6<=HdaS08YBP8i
cP0:7>LHaT8@?NlU2BDY:BX@Q1B536<348@010Q234<aS36<0R4800`]Jc6<7>LQ21BU6:H88PQ234<<
HbU:;D/22482=Jd01BDY:DX<@`aS6<H00QcW00<Q20Q224800QcW00TDYAS66<HHaP00104DYAS66:H0
0Q2400HaK2e[48@@Q0aS34<212428@P012U:9BT@I0aS0SW>00D48@007>LLibU:00<U:@065:D@Q2TZ
9BTDQA240RDY0R480PQ200XaK2e[6:HDYBe;:DXPj1cW34<8@P8YBP03Ool007oo00Moo`001goo00l0
07oo000HaRU:36<LiaBU9BTUBC6<6<HHYQ247<L00aBU00<HaRU::DX00R4801<8@RDY:DXU2@aS58E2
<4Ha>Lh@Q0Q26<IBU3W>HaQcW5Je@Q1:DP02Ool01Q24?Nm[FW>lOolaS0Qoo`059BUoogooOom:DP06
Ool014HaOom6<AS61Goo00QF]GooOolYBU:DOol]Jgoo0S6<02Y:DT8@@Q0<HbD9;F/mkgoo=JdYBQ1T
@Q0HaPQ2:DX<Hcg_<H`U2@Q25:DM1`@Q8@PLibU:5:DLi`aS8@P8@QcW7<L8@QBU7>L<Ha246:H<Hgoo
000=Ool01000Oomoogoo0Ukg0RU:0S6<0QBU0THa0TYB00/Lib4812488S6/=JdikSg_6<HLia240096
<@04<H`]JdHa@S02:DX2AS4016mkJgY>LdYB0Q2400HmkcW^34<8@RTZ9BT2?Nl010Q2124icSG=0P@Q
0QBU00@@I0aS;F/YBP8]J`8Q20045:D@Q0aS24827>L01BDY8BPHaQBU48@00PaS0QBU0RDY0QcW0R48
00@<Ha1T5:DDY@8@Q00800048B488@P8@Pa37>LQ208U:@046<HLi`Q236<25:D36<H00acW248<H`02
;F/0112458DU:BU:0QBU00HHaQcW48@@Q7oo0008Ool000Moo`0?001oo`a346@Libe[7>LicQcW:DXD
YCW>248HYQS6008DY@0K9BT<Hb488@PLadHa8@PLidXb124YBSW>:DX]Jb3X6<I243W>Kg]JmV]J=LeF
]Goo<Haood8@009oo`059BUoogoo6:HaS002Ool01G>L6<IoogooLi`00goo00=JeWooOol02Woo00=W
FGooOol00Woo00eg_GooOomooeJeOom:DT8@JeY>LdYB@Q1>L`03?Nl08dHa5:DLaaS6DY@U:@aS125F
]C6<48@aS2U:124icRDY<F`Q21S68@P@I0@Q8>P<@aBU228]JaBU9BTHaQ246<HLigoo00003Goo00X0
07ooOomoof;hG_L]BbU:=HdaS08DY@96<@9:DP8Q200422848CF]=Jd2?Nl01acW6<HDYDHaBS8]Jc6<
0096<@8YBP96<@06JgY_NdYBCW<@Q1B50Sg_00@8@Pa39BTYBP8mk`88@P8icP848@045:DHYPaS46@4
;F/28@P25:D010a336<Lib3X0RDY0QS600<@Q11T36<00QBU0RDY0QcW0R4800H@I0aS5:DDYAB548@2
12428@P010a3248Q21cW0RDY0QcW0PaS00HHYQBU6<HHaQcW6<H236<2;F/011BU48@YBRU:0QBU0QcW
0Q2400=oo`00Ool01goo0007Ool0=@00OolU:Ad75:DQ21RV6<HU:ABU6:HHaQ1T5:DQ20aS248]JaS6
48@Q21S6BU8aS3g_7>LmkdYb48@YBSW>=Je6<A24F]HU:Be[>LhHaU[F>LhU:EJe6<H8@Woo34<YBTYB
JeYooe[F<H`01goo00=>LgooCW<01goo00<icWooOol01Goo00=BU7ooBS800Woo021kgV]JMkdYBWoo
<HaNmbU:<HaW>BDYCW<U:AcW248aS2e[<H`@Q1RV?Nl8@S6<=JdUB@aS8@PHYQcW:DX<HacW0Q2400PH
iQB56>H48AS658DU:Ac70QBU00<8@Woo00003Goo00H007oo=Jde[FMIJeX2AS40112458DHaQcW0P@Q
0`aS00L@Q1S66<HHaQcW48@DQ@029BT00bU:;F/YBP02>Lh01Qc76<H]Jbe[>Lhec@8@Q08HaP04;F/Y
BS6<;F/2>Lh22484:DX0136<;F/@I0aS0RDY0QS600@40@0036<<H`8DY@8Q20097>LHaQBU48@YBRDY
7>LHiQRV008U:@8icP88@P04<J`e[Cg_?Nl25:D012U:;D/<Ha240PaS0QcW0`Q200<<@`0012400PQ2
0Q2400HecCW><H`aS0aS46@28@P01PQ234<DYARV36<@I08HaP0648@DY@@Q249oo`0027oo0007Ool0
7`00Ool<HcF]8@PLaa246<HQ20Q2=Jd@I0a3;F/aS1c736<mkc6<<F`Q236<=JdicQ245:De[D8@G_LD
YFLi008]J`0:36=6<AS68@PaS3G=>Lhmkd8@6<H2Ool00dicOomoo`08Ool00c6<6<Ioo`03Ool00f]J
Oomoo`04Ool00d8@Oomoo`05Ool00d8@OolicP02Ool02gNmOomoocF]48AW>Goo@Q08@PaSLi`00QcW
01TPj0Q2<H`001S6<H`DQAS6:DXmkbU:5:DU:A24;D/DYB486<H88Q24228DYA24248DQ@027>L011S6
5:D8@P@10R4800=oo`00Ool037oo00@007oo>Jhe[@9[FP96<@0458D@Q1cW6<H21240311T36<@Q11T
7<LHaQcW6<HDQA24:BXU:@8YBP07;F/icSg_6<HLibe[<F`00SW>0Q240QS600HYBRe[<H`aS3W>?Ll2
2484:DX2<H`020aS48@U:BTZ6<HLa`00124236<25:D28@P27>L25:D02BDY:DXLiacW5:DY:RDY?Lli
cP022482=Jd01T7`?NlHYQBU;F/YBP8@Q08<H`8Li`0434<8@Pa32482124010a3248@Q1240SW>0S6<
00X@I0aS8@PQ20aS248HYQBU48@<H`8HaP8DY@88@P03Ool007oo00Moo`001goo03H007oo48@YBQS6
;F/@Q2485:D@Q2DY6<H<Ha24>Lh48ABU36<LicF]6:HDYB48@Q0]Jekg34<mkcW>48@DYB48F]HQ236<
:FXDYBe[46AJePaS<HaBU7_nOomW>GooBU9_Ng_nOom>LgooHaP3Ool00acWCW=oo`04Ool01Ac7BW9B
U7oo@Q0027oo00E[NWooOomWFF]J00=oo`04E[EW>AcWOol2;F/022DYF]IJeTic248aS2486<H2;F/0
7ASV9BTaS1BU48@Lia246<H<Hb485:DaS124248Q223X8@P<H`00?NlHaPaS5:DDQABU<Ha247oo0000
3Goo00@007oo>Nhmk`8]J`8<H`0448@DYAS66<H21240136/=Jde[CF]0T8@0THa0RU:00<icSg_>Lh0
0RU:0THa00@icSF]IcUS>08@Q004E[EBU1S66<H2;F/0123X7>LHaQS60THa00D40@006:HDYBD9008Q
20037>MS65kg008U:@0<24848AcW7>L@Q0aS34<8@Q2436<HaQBU0Q2400TDQA247>LU:BU:48@DYCW^
?Nl00acW00TQ20@Q248Lib486>HLiaS67<L00QS60Q2400@DYAS6248<H`8HaP8Li`88@P8Q208<H`0;
6<HLiaBU6<H@Q1BU00048@Q234<@Q0025:D00aRVOol00008Ool000Moo`04001ooa247>L3;F/0:bU:
7>LDY@Q2;D/<Hc6<9BT8@RDY;D/48BD9=Jd@Q2e[;D/<HdHA7>LaS3g_7<LicSF]CY<Q21cW:BXDYCF]
:DXU:BU:46A242e;CW=oodYBKg]oofLi009oo`04CY=ooa247<L3Ool00dicOomoo`05Ool00g_NDYAo
o`05Ool00g_NOol@I002Ool01SF]7>MJeWoo6<I>L`9cW08]J`06HaPPj1cW7>LaS1S60R48014]J`aS
48@aS1BU>LhYBQcW6<HU:AcW6:HLiaB59BTmkaS6008<@`0=<F`@Q2489BTLibU:6:HLia1TAS4aS7oo
00003Goo00H007oo?Nlmkc5/;F/236<25:D011c76<H88P@Q0SF]00dicSF]@Q1244XbAS4]BbU:?Nli
kSg_:DX]B`02AS4013F]>LiW>FLi0Q2400QB]5Je6<HLabe[<F`Lib480QS600Q6<DXb00040ABU6:HQ
22DY0R4800AO5f<H9BTU:@88@P8Li`8@Q004248<@a2448@26<H348@01QBU7>LYBRDY5:DDQ@8mk`8L
i`048@PLi`Q222828@P37>L36<H011B548@HaQS60PaS0QS60QcW00L<@`Q28@PQ211T36<Li`026<H0
3ARV5:DDQ@@Q104<H`Q25:DDQAS65:Eoo`0000Qoo`001goo00X007oo6:HDYAS6248HaP005:D8@P8D
Y@08248YBQS6124HaR48<H`YBP8Li`0T:BX<Hbe;<J`DYBDY=JdaS2U:;F/YBQS6;F/@Q2DY249:DSg_
;F]_NfLi;F]_NgooCU<e[A1THcQoogNmOol@Q4YB>Li>Lekg2goo015c_7oo7>M>Dgoo>LhaS7oo>Li:
DSF]OolmkgooKi]S65Je009oo`0JAQ5S61BU@Q0YBP@Q5:DicS6<6<IF]CW>6:HDY@aS48@HaR48<F`H
aP@Q5:D8@Tic;F/U:@8@Q0087>LQ20aS<H`<HaBU;F/Q:0848@04>Lh007oo000=Ool03P00OolaS36<
12488Rf;<H`Q:2DY@S16<A245:D29BT25:D27>L02@@Q249B]5JeJgY_NbU:<F`]J`02@Q0043g_>NhY
BRE958D@Q1c76<HU:B487>LHaQcW6<I>LdYB0QcW0T8@00@]BbU:12448@8HaP8mk`8U:@04=Jda[2e[
:DX224800aB548@DY@025:D00a2434<8@P028@P36<H27>L2<H`46<H28@P00bf;<H`Li`028@P00bDY
5:DHaP028@P011cW8>PHaQS60PQ200@Lib482488@P8U:@0B7>LPj1245:Da[3F]48@DQA245:D<Ha1T
48@DQ@00105oo`0027oo0007Ool05@00Ool8@Q245:D]B`Q2228]JbDY7>LmkaS68>PDQCF]9BTHYRDY
8>PLi`028@P0436<?Nl88SW^AS4a[6mk@Q16<F<H58DDYB48BU88@T8@0RU:00QS63g_7>MoodicBU9o
oe[F0goo00TmkgooOom_Nf]JOolaS6Li@Q001goo01QBU48@OomJeWoo?Nm:DWNmIcU6<Goo=Je_Ne:D
8@QoodHa48ABU248JeXaS7Nm9BT2<H`094YB248<HacW:DXaS3F];F/U:@@19BT]BcF]:DX]JaRV2492
436<6:H<HaBU8@PU:B486<HU:A1T000e[@Q27<LHaS6<Ool000eoo`06001ooc6<<H`8@P@Q0S6<0RDY
0THa0QBU00@Y:RDY5:DDY@8Li`88@P9F]@9_N`03;D/]Jc6<0092408mk`8YBP0448@DYAS67>L29BT4
7>L02TYBCW<Lib3X@Q164BU:;F/48@PR0QS60Sg_0RDY0SF]00PYBRe[2488@Q2458DDYARV0QBU00L8
@Pa38@PQ21S67<LHaP027>L00cF=<H`La`036<H28@P2<H`01b487>LU:B486<HHYRD9008Q20097>LL
aaS634<8@R487>L<@`Q2008U:@048@PLiaBU58D2=Jd031BU48@DYABU46@<HaB548@48@00Ool000Qo
o`001goo00`007oo36<HaSF]5:DYBQcW<H`YBPaS5:D248@032TZ>LhPj1cW6<HaS1RV48@U:@@Q<Ha2
408]J`07?NlLid8@?NlU:ASV<H`00Re[01<@Q3W>36=W>Be[9BUW>CF]Oom>DfnKLi`U:CW>Kg/Q25kg
<HaS6004Ool02e:DOolY:QS6Ool48F<H>LhmkeJeAS400Woo02mkgSg_OolYBWooLi`8@UJeHaPe[B48
Kg/YBV]J<H`]JcF]8@Q:LRe[:FYS65:d58DLi`aS:DX@Q1S69@TLia246<H]JaS6>Lh<H`PR5:D<HaS6
48@YBPQ2124DY@0000<@Q0076<H<H`Q2:BXQ27oo00003Goo00@007oo<H`eS@8Q2006BW9>LbU:;F/e
cCW>0S6<014<Ha1T9BTYBQS67<M244Ha9BTYBS6<=Jd]JcF]<J`<H`Q2008mk`8Li`039@TQ224800<Q
200<;D/YBSg_?NlaS2f;;F/YJRDY8BPU:B480SW>00@DYA24=JdaS08@Q00446@<HbU:9BT26<H011BU
48@000000QBU00/<H`Q25:DDYBDY;H/aS1S67>LU:BTZ008<H`048@PU:AcW8>P21242<H`02Q245:DL
ib3X5:DHYS6<=JdUBBU:0PaS0QcW0PQ200@Lib486<HHaP8<H`<Li`058@P48@Q26>HLi`025:D236<0
0goo001oo`07Ool000Moo`0L001oob487>L8@R48:DX8@RDY7>LU:A1T9BTY:RDY:DXLiaRV7>M1l3F]
=Hd@Q2U:248HaRe[7<L28@P01C6<46@Li`a36<H00QcW01164ABUMkde[G>LBU8Lif]J6<I:DS6<@Q1S
62U:Oom:DP9oo`03Nmioofmk00=oo`03?Nm:DWoo00=oo`03F]IoodYB009oo`0X6<He[B48BU9W>Goo
<H`icT8@8@P]Jf]J;F]Nmf<HCU<mkcW>:DYS6124<H`Lie9d8@PU:BU:G_LYBSF]9BU24248<H`<H`a3
48@U:B48:BX46<H03RDY7>LLiaS658D8@P@Q9BTDYA24248Ligoo000=Ool01000Oole[C6<0R480Tic
00@]JbU:>LhicP8aS00848@<HbU::DXLiaS6AS52408YBP03=Jda[2e[008e[@0834<<Hcg_?NlLib3X
8@PU:@@Q2004:DX]Jcg_@Q02<H`2;F/49BT033W>?NlDYABU<H`e[A2458D<Ha249BTYBP8HaP8DY@80
008DY@8<H`8DY@039BTaS36<008Li`04:DXU:@aS36<29BT012487>L88P@Q0S6<00PDYAB58@PLiaS6
5:De[C6/0RU:00@@I0aS8>PLi`88@P088@PLiaS66<H@I0aS8>PLi`8Q200:24888QcW7>LHYQBU46@<
Hgoo0008Ool000Moo`03001ooc6<008YBP0^36<HaPaS9BTM1cW>;F/U:A246<HaS2U:36<@Q36<46@Y
BSF==JdU:@Q2@Q0@Q2DY@S0YBT8@5:DHaSg_9BTe[DYBMkdaS48@OomJeRe[8@P8@UJe?Nm243F]Kg/3
Ool01ekg@Q1ooaS6@Q1W>Dic00Qoo`03;F]oogoo009oo`0?CW=244ic>Li245kgOole[E:D9DTYBS6/
9BTDYBe[009Nm`0N36<HaSW>AQ5BU2U:8@PmkcW>@Q0e[@Q2>LhaS248;F/Q211T7>LU:@Q2228@Q1cW
5:DLi`Q26<HLib480QBU00LQ20aS8@PLi`Q2Ool0000=Ool01P00OolYBRU:6<HLi`8Q200436<@I2DY
:BX224827>L012e[<H`icSW>0QS60S6<00THaQcW6<H88P@QCW=:DU:DCY<00RDY00HmkcW^7>LLicW>
=Jd26<H011cW6>HLiacW0RU:00@LaaS6>Lhe[@8]J`9240046:HDY@aS36<25:D011cW6<HDYABU0SF]
0QcW00<DYA246<H00aS600<mka2448@00QcW0Q2400@HaQcW5:DHYP@Q208YBP0>248<Ha2448@HaQcW
7@LQ22DY:DX<Ha1T7>LPj08@Q08<H`8@Q0051248@QS67>L<H`0248@011BU9BTU:A240QBU00<HYWoo
000027oo0007Ool01@00OolLi`PR7>L00Q24038HYSF]5:DHaPaS:DXLab48:DXQ23F]8@Q:DPa38@P]
Ja245:D]Jc6<@Q0mkaB57>LU2@Q2>Lh8@RDY6<HPj2DY5:EF]A1TBU8aS5:D:DY242e;5:Eood8@7<M>
Tac7F]Ioofmk17oo01EF]D8@Oomg_DHA>Lioof<HCW=[FWooLi`mkc6<G_LHaTic6<IRn7>LDY@00RU:
02iBU2e[OoleSEkgOolHaQcW=JdicRDY;F/U:CV^36<U2C6<:DX@Q1cW8@PLibe[36<Lib486<H8@RU:
7>L8@QB5=JdLaaRV58DU:Ac75:DLaaRV7<LLi`@QOol000eoo`04001oocV^=Jd2:DX02Qc76<HDYABU
48@<HaB548@LaaS60SF]0PaS0SW>00EBU4ic5:DDYAB5008]J`8mk`069BTYBQBU5:D<Ha1T0UJe0SW>
0QBU0RDY00@YBRe[8@PU2@8U:@8DY@8aS006:DX]Bb488@P40@@Q0Q240PaS00PHaQcW9BTU:BU:;D/L
ib3X0PaS0QcW00DHaQcW7>LHYQBU008aS0049@TQ22DY8@P224829BT0135/;F/LiacW0Re[00@DQA24
36<<@`8HaP0334<8@Q1T00<<H`047<LHaQBU48@27>L01`a3248Q21cW58D@Q2DY00<Q20047<LHaWoo
0008Ool000Moo`0M001oo`Q26<HLic6/6:HQ21cW7@Le[A246:HDYE:D:FX]Jch?7>L@Q36<>NhQ20aS
<H`@Q2485:E6<@02:DX020Q2;F/]JaS67>M240Q2?Nl2248022U:5:D@Q2U:8@PYBRUZOol2Li`02RDY
G_MoogooF]IcW248E[EJeSg_0Woo03HYBU[F;F/8@QS6HaPHaWooKi]oo`Q2OomNmgNm248mkcG=;F/i
cU[F8@PLigOM>Lha[5Je7@LQ23W>:DY:DRDY=JdYBPQ2;F/a[1RV?Pl8@QBU7>LQ:248248DYA24228D
YBU:7>L@Q1SV6<H224801ABU248Q21248BP00aS600<Ligoo00003Goo00H007oo=Jde[BDY:DX26<H2
5:D010aS46@@Q1240QS60SF]0PaS0SW>0Tic0QBU00L@Q2e[:DXmkcW^:DXU:@025:D236<2E[D2>Lh0
1QBU48@U:BDY;D/YBP8Q208U:@045:D@Q36<<H`2:DX012487>L48@000Q240PaS00@LaaS69BTU:@8Y
BP8Li`0336<8@QcW008HaP046>HLiaBU6:H2<H`38@P00bDY2488@P029BT2;F/27>L01RUZ;F/@Q124
248<H`8HaP06248<@`aS36<8@PaS0QS600`@Q1B57>LLi`Q234<Lib4848@DQB489@T28@P26<H00goo
001oo`07Ool000Moo`0o001ooaBU34<48AS65:DicQS6228HaRe[7>LU:B489@T@Q23X000LaaS6;F/@
Q0Q25:DaS1S6:DXU:DiC5:D]JcF]104e[E:DCW<Q21cW8@PLicg_46A2436<E[DU:D7`G_Lmcf]JOomF
]BTZG_MS63g_:DYoocg_E[DYBTYB00=oo`0:;F]BU5:DOolHaSW><Ha64GNmAS42IcT06ABU@Q1oobe[
HaP]JdYBAQ4U:Goo5:DaS3g_249242TZ6<HQ23F]AS4HaTiC:DY:DP@Q008HaP0?8@P@Q1S67>LPj2DY
;F/aS1BU6<I241BU248YBQS6008DY@088@PmkacW8@PU:DHAOol000eoo`06001oocF]=JdmccW>0R48
0QcW0R4800@Pj1cW>LhicP8Q2096<@07:BXU:B3X7>M>LdYB7>L00Re[0R4800@ecCW>7>LQ208DY@06
9BTYBS6<=HdYBRe;0PQ200HHaQcW5:DHYQ2458D25:D29BT012489@T<H`aS0QBU00HHaQc748@@Q0@Q
2282;F/02`PR248HaQcW46@@Q2U:;D/]JaS66:H00QcW00`<@`Q27>LLiac76<HHYQBU34<8@QcW6<H2
5:D0111T36<<H`aS0QS60PQ20QS60PaS00H<@`Q258D@Q1RV5:D248@0211T36<40@0022848AB548@2
5:D011S65:Eoo`0027oo0007Ool01000OolHaQ240PQ200LDQAS66<HU:D8@7>LDY@0224800a246<H8
@P038@P0736<>LhLicF];F]64BE9<H`YBPa3BU8HaRe[?Nm6<Cg_8@P@Q1S6CW<icSF]9BT@Q3G=248Y
BUJe0Woo00E:DTHa7>M[FSG=009oo`07AQ5oof]JKi]oog_NAS400Woo02Y[FT8@5:E:DWooBU8mk`@Q
?Nl]JdYBAS5kgTicKi]JeSW>@Q1:DS6<F]IF]BDY000LibD9=JdYBQcWBU848AS6=JdHaP@Q7>L@Q0Q2
8@PLibDY6<H29BT04`006<H@Q2DY;F]:DQS6;F/@Q3F]248aS1BU36<48BU:5:Eoo`0000eoo`04001o
oc6/=Jd2>Lh28@P37>L01b487>LLicG=>LhLib480096<@8U:@8Li`0?BU9>DaSV;F/YBR487@LicSF]
8@PLiaBU48@Y:RDY008aS08YBP88@P067<LHaQBU5:DDQA240QBU0RDY0R4800@<H`Q25:DDY@8HaP8@
Q00:22848Be[:FX8@P@Q7>LHaQ2436<2:DX00be[5:DHaP027>L010Q234<HiQcW0QS60QBU0PQ200@H
aQcW5:DDY@@<H`8HaP88@P8HaP8<H`04248<@a2448@25:D01PaS48@<H`aS00040@848@0348@DQABU
008DY@036:Ioo`0000Qoo`001goo00X007oo248<HaS69BT]JaB58@Q2408HaP0Y5:DLaa2446@U:@@Q
48@aK1S6AS4U:AcW9BU6<B48<H`U:@Q2@Q0aS1BU@Q0@Q3g_58D<HbDYDY@@Q5kg<HaS63F]CW<48G>L
=JdU:DYB7<Lmk`02Ool01gNm58DmkacWCW=6<Cg_009oo`0E7>MNmdYB9BTYBUJeF]I241S6NmiBU0aS
<Ha>D`aS8@Q>Le:D@Q1F]C6<008Q200TAS4aS3F]>Lhe[AS6F]HDYB48229>Lb48AS4]Jb3X248YBP@Q
=Jdmkb3X9BTaS0aS9@T88QBU8@PPj1cW;F/Q21S69BTDYA240R4800D<@aS66<Ioo`0000eoo`06001o
oeJeDY@]BbU:0RDY0RU:00Xe[C6<9@TQ21RV5:E6<D8@6<HDY@8aS08U:@8e[@DQ200<36<@I2489BTi
cSg_CW=BM2489@TU:BTZ0TYB00`Lib3X<H`eS@Q234<Q22DY5:DHYQBU6:H2:DX212401Q245:D<@`aS
8@PU:@88@P031248@QcW008Li`048>PLib489BT27>L29BT2<H`011RV5:DicSW>0Sg_00@@Q11T=Jde
[@8Q200@6:HDYAcW7>L48@006:HDYAc76<H<@`Q236<8@QB548@2248022TZ9BTHaQS658D@Q1B548@2
2482;F/212400goo001oo`07Ool000Moo`1M001ooaS648@Lia245:D<Hb486<HaS2DY36<HaQcW9DTY
BSg_7>L<Hac76<H@Q2e[:DX8@UJe36=>L`Q2<H`U:CW>5:De[AcW:DX002DY36<U:Cg_<H`HaU:D9BTH
aRU:AQ4YBT8@Oom_Vdic8@Pe[Cg_D[@U:BE9G_Mg_F]JDY@e[Dic>LhM1goo@Q0LibDYE[DDYEJeG_Le
[DHa8@Pe[Cg_7>M:DRe[6<HaS6]J7>M245:D48@Lib480088@P0K<J`8@QS648@LibDY124@Q1BU9BTL
iaBU:DX88P@Q46@DYAS6:DXQ21cW9BT<HaBU;F/LiaBU0088@P8@Q004:DXQ:7oo000=Ool01000OomB
U5:D0RU:0bDY00<YBS6<=Hd00R480QBU00I244Ha5:DHYRe[<H`29BT03C6/=JdM1b487@LQ21d746@<
HbD98@PmkcW>009>L`8Q208U:@9:DP8Li`8aS088@P039BTQ21RV00<DY@8YBP0<124001B548@<H`Q2
9@TQ20Q212488P@Q11cW00<Pj1cW:DX00QcW0RDY00H]Rc6<5:DHYSG=>Lh2?Nl010aS48@e[CF]0R48
00PDYARV6>HLi`00104DYARV0QS60`Q200<<@a2448@00PQ20RDY00<DYAS648@00Q2400<DQ@Q22480
0Re[0P@Q00=oo`00Ool01goo0007Ool00`00OolDY@027>L0>b48?NlDQA248@PU:Be;000aS1S648@4
8BD9125:DQcW>Lhmkac78@QBU24848@mkcF=7>L88R4834<Q23W>8@Q6<A24IcU>LeJeBU8aS4icKg/D
YEJe;F]240aS=JdLid8@G_Le[D8@BU8YBR48=JdicS6/CU<00THa01E[NWooD[ABU36<JeY6<FLiJeXi
[WooIcT@Q4HaJeX<Hekg<H`Q21BUBU800RU:02TU2BDYDY@Licg_8@P@Q4Ha6:HHaPQ29BT@Q0Q25:D<
HcF]8@PHaQ1T6<HQ2124:DX@Q0Q2>LhLibDY7>LQ21BU6<H<HaBU8@PDQ@aS5:Eoo`0000eoo`06001o
oacW6<I243g_0S6<0Re[00P]BbU:?NlmkaBU58D<@`Q20P@Q00<U:B4836<00`aS00<eSCg_@O000QcW
0R4800H48@PR46@@Q0@Q2282:DX27>L01R489BTDYABU12488P8Li`0<6:HHaQ2458DaS3F=;F/aK1RV
6<HU:BU:0QBU10Q20QBU00<<@`aS6:H00QS600@LaaBU7>LLi`800088@P8e[@086<HHYP@Q124HaQRV
9@TQ208Li`065:DDQAc76<HLaaS60PQ200@LiaS65:DDY@8@Q0048>PLib3X7>L236<2;F/030Q2228U
:BDY36<8@Qc76<HQ21cWOol000Qoo`001goo00@007oo5:DQ208<H`0>?Nl<H`@Q248Q22E9228<HbU:
5:De[A248@P@Q08<H`0a9BT]RacW=JdaS2487>L8@QcW8@P8@RDY8@P8@THa;F/e[AcW6<I6<@aS?NlU
:Be[AS5:DTHA?NlicSg_CW<U:B48248YBUlGG_LaS7NmOomBU3g_IcUoofmkCW=6<CF]8@P00Woo01QB
U248G_LLicF]125BU48@<J`YBSg_48AS66Li5:D8@R48>Lh48CF]=LdLia249BT28@P01ad79BTU:AcW
248Q22E9008DY@0A8@PU:ARV6<H8@QS67<LaS0Q2:DXaS1cW6<H<HcF]9BTaS0026<H00aBUOol0000=
Ool01000OolHaQc70Sg_00@]Jc6<;F/]J`8YBP06>Nhmka245:D8@Pa30P@Q00<Q22D936<00`aS00Da
S3g_?NlLiaS6008Q20848@0448@<H`@Q1242:DX27>L012D98@PDYABU0P@Q0QcW00@HaQBU48@@Q08a
S08]J`046<HDYBTZ9BT25:D010Q21248@P@Q0QBU00@<H`Q26<HDY@8HaP035:DHiQcW00800088@P08
<J`e[ABU6<H000@Q5:DHaP8Q208Li`0348@DYAS600<HaP061248@QS67<L@Q1BU0Q2411cW00X8@PaS
:DX]J`@Q248Q:2DY248<@`8HaP047>LQ27oo0008Ool000Moo`07001oo`@Q9BT<HbDY48@00R4802Pe
[AS6;D/DQCg_7>Le[AS646@8@R48=JdPj2U:@O0@Q2e[7>LDYBU:6:HU:@aS9BT<HacWAS4<Hc6<;F]6
<AS6<H`U:C6<9BT]JbDYAS4HaP8]J`1?F]IB]3F]9BT48BDY8@Pmkd8@8@QNeelGJeXHaRU:48@icRe[
249246mk;F]:DSg_46@icRDYCW=242U:<H`LicF]5:De[AcW58D@Q35/248mcb48<H`Licg_<H`Q21BU
58D@Q2e[8@PDQABU46@LibD96<HaS1cW5:DLiaS6124@Q1BUAQ4DYCW>?Nl@Q1BU=JdYBP@Q46@88Woo
00003Goo00X007oo>Jhe[BTZ9BTYBRDY24848@92408icP037<LHaSg_008mk`03>LhY:RDY008Q2005
46@<HaRV7>LPj0025:D22482:DX25:D27>L22482=Jd00c6<=JdQ20028@P00bD96<HLa`026<H011RV
6<HQ22480THa00@<Ha248@PU:@8@Q08U:@8<H`8Li`0458DDY@@Q2282:DX26<H01aRV:BXU:A2436<]
JbU:008U:@068>PLiaBU5:D@Q11T0PaS00@LaaS6;D/YBP848@045:D@Q2487>L224825:D00ac76<HD
Q@0348@27>L01P@1000HaQS646@<H`8]J`047<LHaWoo0008Ool000Moo`0Z001oo`00248U:B487<LH
aSF]48@eS@aS?NlU:AS65:D<@bDY8@PYJRU:9BT]JacW248Q21BU48@Q248@58E6<C6<6<I:DRU:JeXi
cR48<J`]JcG=0RDY011BU3F]E[E6<G>LE[E244Ha5:DLicg_7>L]Jc6<;F/@Q08mk`14AS4aS7>L@Q0L
iaBU>Li247oo9DTe[@@Q36=NmcF]G_M>Lbe[CW<aS5kg<H`@Q24X5:D48DHa7>LDYCW>5:D]JcF]:DXH
aQSV248DYB487@LDYCh?5:DLiaBU;F/HaPQ2:DXU:@aS248Pj2U:6:H<HbDY48@Q21cW8@PmkaS6=JdY
BR48Ool000eoo`04001oocF]=Jd39BT01bTZ12488Sh?@Q0ecCW>008HaP04>NhmkcW>>Lh29BT01AcW
8@P<H`aS5:D00QcW00HDYA2424848BU:9DT25:D011cW6<H8@P@Q0SF]00<eSC6<8@P00b481AS600<D
YB488@P00THa00@@I0aS9BTQ208@Q08U:@8<H`8Li`045:D@Q0PR1242:DX00aS65:DHaP029BT01PaS
46@YBRe[8BPU:@8Li`8DY@0436<@Q0Q236<26<H2:DX212401Q2458DLib481248@P8DY@8HaP8@Q004
36<@Q1cW7>L200026<H236<01RU:;F/HaQS6Ool000Qoo`001goo010007oo000Pj0aS7>L]J`aS48@i
cQBU8>PDYCF]248Q208@Q010=JdicQS6<H`Lia247>L8@RU:46@Q22U:5:DYBRe[8@Pe[Be[<H`]JaS6
@Q1F]BU:AS4]Jb48BU8LibDY<H`icT8@34<mkaBU9BT]Jd8@?NlHaRD936=:<U[fDY@LigNm@Q0DQC6<
8@PLibe;AS4DYE[FKg]>Lg>L:DYJ]Sg_9BT25:D012489@TQ22U:0RDY01HDYD8@36<e[CW>248mkaS6
7>LQ21cW58D<HbU:48@LibU:8@P<Ha247>LPj08DY@0@248HaSW>9BT@Q11T8@P<HaS648@8@QS65:D<
@goo000=Ool01000OolicSW>0PQ210aS00D@I0aS?Nlmkc6<00@]J`03:DX]Jbe[008U:@8YBP8DY@07
6<H]Jbe[=JdicQBU6:H00SF]00@HaQc7AS56<@8@Q0066<HLa`Q234<<Ha1T0SF]0QS600@<Ha247>LQ
208e[@8HaP075:DHYQS67<L<Ha1T5:D00aS60RDY11cW00d002U:9BTLaaS634<8@Sg_>LhHaQBU46@<
H`02?Nl01QBU48@icSW>58D@Q08Li`0336<<@`aS00<<H`0858D@Q11T36<U:B4858D@Q08<H`88@P8H
aP045:DDQAS65:D27>L2:DX00goo001oo`07Ool000Moo`0?001ooaS6248e[Ad75:De[AcW5:De[AS6
36<HaRU:008DY@039BTDYA24008DY@0?36<DYAc7000Y:Q247>LHaSF]6<HLib485:D<Hb48008HaP0I
9BTHaRUZ8@P8@S5/=Jd]Je[f<F`DYBU:248U:EkgHaQF]D8@:DXU:D8@48@HaSF];F/00SW>00QJeQS6
7<Le[E[FIcT]Je:D0SF]01<mkdYB6<HU:DHaE[De[A2434<]JcF=7>LU:@@Q<H`<Hc6<<J`<H`02AS40
6QcW9BTU:AcW48@U:A246<HaS1cW248HaQBU36<8@QS6124Liad7:DXDYBe;36<DYAS69BT248@01@aS
>LhQ27oo00003Goo00H007oo>LhicP@Q248636<02cW^?Nl]Jc6<:DX]JbU:;D/YJRe[8@P00RDY00@Y
BQ246:HDY@8]J`8e[@8DY@8e[@8HaP96<@8@Q08HaP88@P0446@<HcF]=Jd26<H01Q1T36<Pj1cW=Jda
[08HaP8DY@8HaP8<H`066:HDYAS65:DU:B4X11cW00<40BDY:DX00QS60PQ20SW>00@DYARV36<@I08m
k`0448@DQCG=>Lh248@27>L01PQ236<8@PaS248<H`8@Q00636<@I2489@T@Q1B50PaS0PQ200<DYAS6
48@00QBU00<HYQSV7>L00RU:00=oo`00Ool01goo0007Ool04`00Ool@Q2U:<H`@Q3g_7>L<HbDY248U
:A2458DicQc7CW<Q22U:008@Q00H9BTDYAcW36<@I2U:5:De[AcW?NlLicg_=Jd40Cg_7>LmkaBU9BUB
U2e[<Ha64@@Q0S6<01TQ21BU7>LU:Be[9BU24248>LioogNm?Nle[E[F?NmS67NmAS5F]FLi:BXYBUJe
GaLHaP02Ool022486<HaS3F]>LhU:C6<CW<27>L04P008>P]JcF]5:DQ21BU@Q0YBSW>?Nli[R48<F`H
aQc7248e[@8DY@0J36<@I1B57>L@Q48@7>L@I0Q2<F`@Q2486<H]JaBU8@PDYBD948@88PaS7>LYBQ24
Ool000eoo`06001ood8@@Q0mkcW^0RDY010Pj1cW7>LLiac76<HDYA24?NlikRe;:DX@I0aS5:DDQ@8]
J`09<Ha:LTic5:DHYQ1T48@<Ha1T008<H`0458DDYCG=>Lh36<H01AcW248<@aRV6<H00QcW0RU:00X8
@Pa35:DHYQS67<LHaQc78@PU:@8Li`0=48@DQ@Q234<48@PR8@PU2B489@T@Q1BU8@P00PaS0QBU00HP
j1cW;F/YBRDY8@P25:D49BT248@2;F/011B548@LiacW10aS00@HYQBU2488@P8<H`@8@P8Q208HaP04
36<<@`PR12427>L011BU58Eoo`0027oo0007Ool02@00Ool003F]58DicRU:?Nl@Q0025:D0D3W>7>LL
i`a35:D]JaS67>L<H`PR36<@Q2DY6<HYBQS6:DX8@T8@BU8DYEJe248Q22UZ36<HaQBU7>Le[BU:;F/<
HaB57>LQ24ic?NlLib48=Jd48A245:D]Jc6<8@QNmc6<E[Dmkc6<<Ja[FSF]:BXQ:2U:9BTmkbDYG_LQ
23W><H`]Jg>lCW=244Ha7@M:DS6<7>L]Jb488BPU:Be[>Lh28@P09CF]9BTHaQS67>LPj3F]6<HQ23W>
<H`@Q1cW5:DHaQ24;F/<HcW>8@P<HacW48@HaR4836<DY@aS48@<@`Q27>LHaTYB5:Eoo`0000eoo`08
001ooch?@Q0icSg_8BPU:@@Li`8HaP0448@DQCW>?Nl2:DX236<00a245:DYBP02;F/01dicBU8DYABU
48@<Ha1T00<<H`045:D@Q3W>=Jd26<H01Qc76<H8@PQ26<HDY@8Li`04:DXUB@a324825:D46<H012DY
8@PLiacW0Q2400@<@`Q222848@@Q200558D@Q248248<H`025:D27>L012U:;F/Q22D90QBU12DY00@<
Ha24;F/]J`8@Q0036>HLi`aS00<<H`8DY@041248@PaS36<2248010@Q248Lib480QS600@8@PaS1244
8@8Li`0448@DYGoo0008Ool000Moo`0_001oo`aS8@Q2411T248]JaS634<8@SF]248Li`@Q6<HLi`@Q
36<Pj1S658DHaT8@7>Lmkb487>LicSF]125:DQS636<@Q2D95:E:DR487>L8@QS648@U:@aS9@T]J`02
36<01aS66:I:DTYB<Ha6<Fmk008DY@0Y36<@Q2U:@Q16<AcWAS5oobe[BS8<Ha24G_MS64ic@Q1:DTHa
36=J]R48DY@aS48@5:DeSCg_36<]JbDY48@icRe[6<H40CF=48@e[AcW58D<H`038@P236<06P0036<L
ia1T58D88QBU00048@Q2;F/DQAcW8>P8@SF]36<Q20@Q46@8@QcW6:H<Hgoo000=Ool02P00OolPj1cW
9BTQ247`?Nle[C6<0QBU0R4800HaS2e[34<8@RD98@P26<H25:D00bTZ9BT0000236<01@PR248<H`aS
8@P01BDY00@Lib3X248<H`8Q200836<@Q12448@<Ha1T5:DHYP848@0M58DDY@aS46@DYARV6<HLaa24
58D8@Pa39BTYBR489@THaQc77>LPj1BU6<HYBQ1T36<U:B487<LHaP02;F/236<2:DX27>L050aS34<@
I0aS7<LHaR487>Le[C6<48@@I0@Q104Q21cW6:HDYARV5:D224801QBU48@U2B487<LHaP8DY@089BTQ
21cW7>L@I0aSOol000Qoo`001goo02@007oo48@Q223X;F/<H`@Q?NlHiQcW8@P8@RDY48@LiaRV6<HY
BQBU7>L48D8@9BT]Jekg248HaS6<;F/U:A249BTHaSF=7>L25:D07R4848@Q21BUCW<]JcW><H`<Ha24
6<Hec@aSAS4@Q2DYF]H]RbU:<J`Q22DY46@ikS6<AS4Lich?Li`mk`8Li`0B?NlQ248@?Nm:DS6<;F/U
:ABU8@Q>Dc6<?Nm6<AcW7@LDYC6<0QS600hicR4X:DXDYCg_;F/@Q3F]48@e[Be[:DXHaQ240PaS00D4
8ABU36<DYAS6008@Q00==Jd]J`aS5:D<H`Q26<H8@P@Q;F/48BU:24800Q2400=oo`00Ool037oo00H0
07oo7>LLib489BT2?Nl0136<=HdDYABU0R4800@]Jc6<248<@`8Q208HaP8DY@8U:@05000<H`aS2484
8@0236<01RD98@PU:B4X9BTQ:08Li`0634<8@R487>L@I0aS0Q240PaS0QBU00@48@005:D@Q08<H`8D
Y@8HaP8@Q088@P04:BXU:B488@P26<H27>L01aRV5:DYBPaS46@Q22DY008HaP8]J`8<H`059DTYBQcW
7>L8@P0336<26<H02QcW8>PaS3F=36<@Q000124Lib4811BU00@48@Q248@DQ@8Q208HaP8DY@048@PU
2ASV7>L236<00goo001oo`07Ool000Moo`0B001oocF]48@HaQBU36<YBP@Q7<L8@QRV9BTHaQ245:D8
8QS60RU:03/U:ABU:DXYBR489BT48AS69BT]JaS67>LYBQ1T:DXaS4Ha<H`U:DYB?Nle[AcW7<LYBQcW
;F/HaR485:DYBR3XDY@]Je:DDW@e[Cg_;F/Q248@EYDaS11T5:DU:CF]>LhYBTYB8@PaS1BU8@PYBSW>
124U:AS6008DY@0?7>L8@Q24:DX<HfLiDY@Q21BU36<]JbU:46@8@QB500<Li`0K5:DYBPa39BTHYRDY
9@TU:ABU124Q20Q2?NlHaRDY<H`DQ@Q29BT<HacW9BTDYBDY5:D8@RU:008U:@03Ool007oo00aoo`04
001oobe[:DX2;F/02R487>LDQA24:DXU:@@1000DYA240RDY0RU:010LaaS67<LHaQcW6<HQ212458DU
:BTZ6<HLa`Q234<HaP<Li`8@Q0069BTY:QcW8@PHYQS60P@Q11S60PaS0QBU00@]Jc6<48@@Q08<H`06
248<HaS67<L48@PR0aS600HLiaBU5:D40@@Q9BT28@P01QB548@]JbU:6<HHYP8HaP8YBP085:D@Q1S6
6<H]BbU:6:HDY@8HaP88@P0448@@I12448@2248011B548@LiaS60QcW0aS600dHYQ1T36<<@`Q27<LH
aPa3248Pj1cWOol00008Ool000Moo`0/001oo`005:D<Ha2436<UBAS636<@Q1cW48@U:AB536<Q22e[
7>L<Hbe;5:DQ22DY48ANm`aS<H`mkaS6<Fa6<CF]@S1:DRDYF]HQ22DY:DX48@009BTDY@<Li`0?9BTD
YAS6;F/ecDic6<HYBR48@Q0mke[FAS5>Lf<H009F]@07LiaW>CW>:DY>Lgoo8@P00S6<00lYBSW>6<Hm
kb489BT@Q11T48@8@Rf;8@P]JacW5:D00PQ200lYBP@Q=JdU:@aS6<HPj1S66:HHaP005:DHaPaS;F/0
0PaS00`48B489BT@I3W>104HiRU:9BTDQBDY48@28@P02@Q2;F/DYBU:7>L8@RU:Ool0000=Ool01000
OolYBRe;0Re[00`Lib3X48@@Q2DY:DX000@148@DQB4X9BT2:DX56<H27>L011B548@U:BDY0QS60PQ2
00@LiaS67>LHiP8@Q08U:@048@PLiaS65:D212446<H01PaS248DYABU<H`]J`8@Q08<H`0634<8@QS6
6<H88P@Q0QS600TLiaS65:DDY@@Q000U:AcW8@P00Q2400<YBRe[5:D00aS60RU:00@@Q1B55:DHaP8Y
BP8DY@8HaP88@P0436<@Q12448@2248248@011S67>LHiQcW0QS600@DYAS636<<H`88@P8HaP88@P8L
i`03Ool007oo00Moo`001goo00/007oo48@8@R48<H`HaR48124Pj248008U:@8Li`0?;F/HaS6<8@P]
Jd8@?Nl]J`aS;F/i[QRV>LhU:C6<008YBP0548@HaP00;F/Li`02>Lh0>48@;F/mka24124HaQcW124@
Q2489BTDYAc7?Nle[AcW=JdYBRe[6<HicT8@E[DHaQBU<Haooekg;D/aS1BUAS5:DQcW228a[3g_6<HD
YDHa<Ha6<BU:AS5_NdYB58DikPa39BTmk`Q2>Lh48ABU36<2;F/05QBU34<Pj2DY6<H@Q11T5:DU:AcW
8@P<HaBU48@48B4834<LibDY6<H<HaBU0QS600T<Hbe[58DU:ABU6<H@Q7oo00003Goo00P007ooG_MJ
eR487>LLaaS60PQ200@DYAB55:DDY@8Li`0446@<HacW6<H2248010PR124DQA240bU:12480QBU00`<
Ha1T7>LLiaS67<L@Q1B548@DQAS67<L2<H`26<H040aS48@000@1248<@aBU6:H<Ha1T48@DY@00124D
YARV0R4800/Lib48:DXYBQ2458DLib487>L88P@Q008Q2088@P848@0636<8@QcW7>L<@`Q211cW00@8
@P@Q2488@P8<H`0446@<H`PR12425:D236<01QRV5:D<H`aS22848@8@Q08Li`8@Q08]J`8@Q08Q2003
Ool007oo00Moo`001goo01/007oo2288@QB5124<HaBU248HaP@Q36<e[@aS7>LYBRDY6<HLib4836<D
YC6<36<]J`Q234<00Q2400EBU1RV?Nlmkd8@00<e[@0d:DX@Q4YB8@Pe[AS69BT<HdHa:DXLiaS6?Nl@
Q1SV8@P8@S6<@S0]JcG=8@Pe[BDY6<H]Jad7124e[F]JAS4@Q1S6124<Ha246<HLia249BTUBBe;>LhH
aRe[>Lh@Q1S6:DXaS3W>2482:DX09be[46@U:AS6000<Had77>L@Q2TZ6>HHYRDY>Lh8@SF]?NlDYBU:
48@<HacW248<@`00248@Q3W>;H/<Hb4834<DYA1T6<HDY@@QOol0000=Ool01P00OomJeU[F7>LQ208H
aP88@P0:48@DYABU5:DHiQcW36<@I1S67<L224802`@Q228@Q1B59BTYBRDY8@PM1b487@L00QBU0PaS
00DLiaSV6<HHaQB500<@Q08HaP08<H`]RaS65:D@I0aS10400088@P8DY@8<H`0458D@Q0@100025:D3
8@P00acW:DXU:@0248@00b487>LLi`02124011cW8@P8@PQ20P@Q00@8@Pa37>LLi`88@P086<HLiaSV
7>L48@PR1248@P<<H`0546@48@PR48@DY@0236<25:D236<2124010aS48@LiacW0Q240Re[00H<Ha24
7>LQ27oo0008Ool000Moo`0[001oo`@Q6<HU:A248@P<Ha24<F`Q22U:5:D8@QcW124000Q26:HYBR48
:DX@Q2e[=Jdmkbe[>Lh]JfLi:DXaS1246<HLicg_6:H@Q0aS48@aS2DY:DX00QcW01XY:R4836<@Q1BU
:DX8@QcW9BU245Zf?NlU:C6<:DXmkbTZ:DYS62e[?Nl]J`aS5:DLa`@Q0SF]02E244Ha:DXicSg_:DY6
<CF]IcT@Q5Je6<HaK1cW6<I6<@@15:DU2B48HaPU:@Q27>L<@a246<H@Q1B57>LYBQ24?NlLib48228Q
20027>L02QS648@HaPaS6<HLi`Q28@P<HacW0QBU00H40@aS58DHaWoo000=Ool01000OomF]EJe0RU:
00@<@`Q212440@@HaP0448@<Ha1T36<26<H224801AS66:HDYABU9BT00PaS00PU:BU:12488Q2458DL
ib480PQ20PaS00@8@Pa39BTU:@8aS08Q2004:DX]BacW7>L26<H01PaS46@@Q1B55:DHYP8DY@0:46@@
Q1cW8@P<Ha1T7>LPj2489@T27>L26<H01aB5<H`aS11T36<LaaS6008Q208<H`046<HDYBe[;F/25:D0
11RV5:D<@`Q20P@Q00/LaaS68@PLiaRV5:DU:B487<LHaR4800<Li`@<H`0458D@Q12448@25:D01Pa3
248HYQBUOol000Qoo`001goo028007oo6:HDY@aS;F/HaSW>:DXDYA247@LU2B487>LHaRDY48@DYC6/
8@PHaS5/6<HLicW>7>LaS0aS<J`DQBe[>LhDY@8icP8]J`106<HYBRe[9BTYBSF]7>L@Q2489DT<@b48
248@Q0aS8@Q[NTHa6:IO5fLiBU9W>FnKJeXaS0Q2<H`88Re[9BU241BU9BTDYAcW249BU6mk:DX]Jch?
?NlU:AB56<HU:AS67>M:DQcW@Q0YBP@Q6<HikRDY<H`]Ba245:D@Q0a37@L26<H01QcW<H`HaQS68@P]
J`8Q200B6:HQ21cW6<H8@QcW248U:AcW48@e[A245:D<HaB5001oo`003Goo00@007ooD[AF]@8YBP88
@P0300048AS600<HaP0436<@I0aS36<26<H03@@Q248DYAS648@DYB4836<8@RTZ9BT88P@Q008@Q004
8@PLi`Q2248236<010a3248U:BDY0S6<0R480RU:0QcW0QS600D@I0aS48@@Q1RV00<DY@0448@<Hb3X
7>L236<27>L28@P01acW6<HHaQS65:D]Rc6<008<H`8HaP097>LQ20Q236<DYARV:FX]Ja2400<DY@88
@P848@8HaP067>LPj1BU5:DQ22DY0QS600DLib3X7>LLi`Q200<<H`8@Q00436<@Q1BU5:D2248011BU
6:Ioo`0027oo0007Ool07`00Ool@Q0Q248@40@Q28>PLiaBU7>LY:R4848@000PR36<e[B489BTLib48
248@Q4YB<Ha6<@aS6<H]B`@Q008DY@8Li`8Q20089BTaS2DY@Q0U2A24<H`DY@8Q200S8>P8@Q24248D
YAcW;F/48A246<HU:CG=CW<ecC5/48@aK3W>=HdQ24ic:DXicS6<48@U:AcW@Q0YBS6<;F/e[@aS?NlP
j0038@P02Be;?NlaS2e[9BTQ23g?58De[@0248@08RDY5:D001BU36<DYBDY<H`HaRTZ36<U:AcW124a
S1BU7>LHYS6<:DX<HacW248Q21S636<Lib48228LiaBU46Aoo`003Goo00<007oo>Lh00cW>0PaS0R48
00Q:DTHaBU9:DSW>=Je>DdYB0QcW00T<H`a36:HDYAS66:H]BaBU6:H00R480RU:00@Q22DY8@PQ2088
@P07>Lhmca2448@Q22D95:D00QS600DLibe[;F/HaQc7008Q208Li`8mk`07:DX]BbDY9BT@Q1B548@0
0QB500<DYA245:D00R4800DHaQc736<<Hc6<008@Q006=HdaS1B548@Y:RDY0R4800HLiaS67>LHaQ1T
36<28@P022TZ9BTDYA2458D@Q0aS2482124236<25:D011cW6<HY:RDY0Q240QS600@48@@146@<H`8U
:@0622848ABU5:Eoo`0027oo0007Ool05000OolQ20Q2:DXHaR4836<YBPaS248Q21BU48@8@P@Q9BT@
Q1BU=Ld27>L011BU48@8@Q240QBU00@Q236<58De[@8]J`0d34<8@PQ2;F/LibU:34<DYBe;;F/Q22DY
6<HDYB486<H]JaBU=Jda[2D948@U:A246<HicRD9;F/U:BU:=JdYBQcW8@P@I2DY248Lic5/>LhHaRf;
7>LHaPPRBU9BU2DY?NlHiSW>6<H27>L032U:6<HicRe[@Q0DY@aS5:DLic6/7>L@Q08HaP06?Nl@Q1cW
48@LaaBU0R48010YBPQ248@HaR489BT@I1cW48@<Ha24124La`aS5:DQ:08DY@03Ool007oo00aoo`0;
001oocW>>LhecCW>248<HacW8@Q6<@03BU8023F]>Li:DTYB6<HLi`Q236<35:D02AS6:DXHYQBU8@PM
1bU:9BTU2@028@P00acW2488@P02>Lh248@28@P01QRV5:DLaaS6;F/YBP8HaP048@PLiacW7>L2?Nl2
:DX00bDY8@P@Q00348@01QBU48@DQA248@PM1`8HaP8<H`03<H`@Q124008aS08@Q08U:@0:7>LQ21S6
7<LHaQc736<@I1cW8@P29BT01Q2458D@Q1B5248<@`848@8<H`8DY@046<HLibDY9BT248@26<H01000
124<H`aS0RDY00H48@PR5:DDYGoo0008Ool000Moo`05001ooaB55:DU:@025:D072U:248aS2486<H@
Q1RV5:D8@P@Q58D@Q2U:8@P]J`aS34<YBQ24=JdYBSF]@O0aS124248aS1cW0RDY01L<HaS67>L]Jb48
48@Pj0aS7>LQ20@Q248Q20aS8@P<Hbe[5:E6<BU:EYE241cW009:DP079BTmkb48=JdU:Ac75:D00Q24
03/LacF]36<icTic5:DDQBe[?NlU:ABU36=F]CW>5:DU:Be[8@PU:ABU<H`YBR48104@Q0aS9BTYBR3X
36<LiaRV7>LDYC6<8@PU:@Q29BT]JacW;F/DQ@a36<H8@Q1T36<Laa247>L8@R4848@U:B487<Moo`00
00eoo`04001ooc6<<H`22482;F/0136<;F/DQA240PQ200@LiaS68@PQ208U:@031040024800<Q2003
5:D<Ha24008Q208HaP04:DX]B`aS46@27>L29BT014YBCU<e[CW>0PQ20R4800@U:BU::DXYBP8HaP06
8@PU2@@Q124Lib480PaS00`HaQc7;F/]JacW8@PLib3X6<HLibU:;D/236<022e[:BXU:@aS248DYAB5
6:H35:D2?Nl248@010Q22288@P@Q0Q2400<Pj1cW7>L00QcW00THaQRV5:DHaQBU24888RDY8@P00PaS
00@<@`Q258D@Q08Q200:58D@Q0Q2124DYA24>LhecGoo0008Ool000Moo`07001oodHA9BT8@P@Q6<H0
0QcW00hDYAS636<DYAcW5:DHaPa38@PLicF]228LicF]0RU:00`YJP@Q:DXLiaBUAS4HaRe[:DXDQBe[
6:H25:D01QcW48@Q21cW124@Q08YBP8DY@0Z36<U2BDY:DXLic6<BU9BU1cW@Q0a[1BU249>Le[F36=B
U2U:8BPYBS6<8@PDYDHA5:DaS24X=JdM1b487@L<Hb48>Li>Lb489BU:DQcW<H`8@RDY0QBU00LUB@@Q
48@<H`@Q228HiP027>L072U:6>HU:Be[6:He[Cg_36<e[B486:HHaP@15:DHaPQ234<@Q0Q29BTHaQ24
58D8@Re[125oo`003Goo00@007oo<H`aS088@P04:DX]Jbe[<F`248@010@Q248HaQcW0b4800<U:@00
00000R4800DM1b4848@@I0aS008Q20086<HDYBU::DX@I0aS7>LHiP8U:@9:DP8e[@0624848B487@LY
BRDY0RU:0QS60R480P@Q00@Pj1cW36<<H`8HaP03;F/YBR4800<Li`047<LHaRU::DX236<01Re[9BTU
:@Q234<@Q08DY@036:H@Q1BU008mk`8@Q0041248@P@Q228248@27>L011S67>LHaQc70aBU00DHYP@Q
248Q22D9008<H`04248<@a2458D28@P248@020@Q228@Q1B5=JdicWoo0008Ool000Moo`0B001ooaBU
7>L<HaBU8@P<@c6<=JdQ21cW248e[ABU;F/@Q1BU0acW00hDQABU8>PaS2e;:DX]JeJe>LhYBSF]:DXL
iaS60RDY00DQ21cW36<48B3X008@Q00A7>LDYBU:9BT]JacW124HYQcW:BXHaRU:@Q0mcc6<DYA24002
8@P030a348@Licg_<H`]JbU:?NlDY@Q2124Q208<H`0T=HdmkacW8@P88PaS228YBQcW8@PDY@@Q7>LD
YAB5<H`]JaRV:BXDY@Q25:D<HaBU7<LDYAcW0008@SF]6<H48AS68@PLiaB50QS600@8@QS65:D@Q08L
i`0936<]J`Q29BT<HaS68@Qoo`0000eoo`05001oobe[:DXe[@02<H`00be[34<8@P0236<011c76<HD
YABU0QcW00HY:RDY46@<HacW6<H348@27>L010aS46@<Ha1T0QS600XQ22D9<H`e[C6<=Hd]Jc5/36<@
I08DY@88@P8Q2088@P8]J`88@P0858DDYARV6<H@Q1BU6<HLa`8<H`04248<@b489@T28@P27>L01`00
104<@b487>L8@P@Q00@@Q0037<LHaQRV00<DY@88@P03;F/YBQcW00<Li`0548@<H`PR124Li`036<H0
223X7>LLiacW58D@Q3F=<H`248@011B548@@I0aS0PQ20PaS00@48@@1Ool000Qoo`001goo02X007oo
48@@Q1cW248YBQS634<48ABU7>LHaQcW58DDY@Q27@L@I1cW8>P]JbDY5:DYBQS6124@Q0a3:DXY:QBU
7>L<H`a37>LHaQd7228YBRDY=Jd26<H05PQ25:D@Q2DY48@LiaBU36<aS2U:<H`]Ja1T7>L48@Q2;D/U
BC6<8@PmkcF]0RDY01<88Sg_>LhHaSg_>LhU:AcW36<DYAcW48@8@RDY5:DHaPQ2<J`aS0028@P26<H0
9aBU8@Q6<A1T8@P@Q0Q27>L@Q0PR:DXHaQBU9BT<Hbe;8@PLiaBU48@8@QS6:DX48A248>P48ABU6<H@
Q0aS7>L001S636<]JaS6Ool0000=Ool01000OolicSg_0b480bDY00H]Jc6<1248@RDY:BX22482:DX2
9BT21242:DX00a246<HHaP026<H012487>LaS36<0T8@00HYBRDY@Q1241BU48@236<2248012U:9DTD
QA240R4800@HaQBU<H`aS08@Q0@Li`046:HDYAcW7>L26<H25:D29BT02AB548@@Q1245:D8@PaS248<
@`026<H0112458D@Q1B50RDY00DDYAS61248@PaS00<@Q0049BTY:QS66<H22482;F/02QS67>LHaQS6
5:DHaPQ234<8@Pa30PaS0Q2400@8@Pa336<<H`8YBP047>LPj7oo0008Ool000Moo`0>001oocg_58D0
0124124<HaBU36<YBPQ29BTe[@8Li`0@8@PU2@@Q7>LDYB3X48@Lib487<LHaRe;5:DPj1BU12446<H0
11BU8@PU:Be[0R4800@HaPaS6<H48@8DY@038@P@I1BU00<Li`035:D@I0Q2008Li`0846@Lic6<<Ha6
4FLi>Lh8@P8<H`0K46@mkc6<:DX]Bbe[9BTYBQB55:D]JcF]6:He[AS6AS4@Q1S634<<HcF]6<H@Q1cW
=JdHaQBU00<HaP0@9BTLiacW000YBQS634<icQS636<mka24>Lh@Q1cW34<236<03AB536<U:A2436<8
@QS658DHYQcW:DYoo`0000eoo`04001oocg_>Nh28@P49BT2<H`2248012U:9BT<@`Q20RU:0RDY00D8
8P@Q;D/YBQ2400@HaP8Q208aS092408YBP04@Q164ABU5:D236<020Q234<YBRU:48@DQB489@T26<H2
<H`248@47>L01QBU6:HLiacW6<HLa`8DY@8U:@0548@DQA2458DDY@0236<020a3248HaQS658D@Q1BU
48@29BT26<H2248448@02BU:9BTLaaS634<8@S5/;F/Li`046<H01ARV34<8@Pa324800PaS0Q2400X<
H`Q246@<Hbe;:DXQ21cWOol000Qoo`001goo00X007oo248Libe[000HaR489BT8@P8@Q0065:D8@R48
8@PU2Be[0QS600lLibDY34<LibU:5:DQ236<7>L<Ha248@PDQAS6:DX00QS60Q2401PDYA2448@@Q0@Q
36<HaQcW9BT<HaBU124Li`@Q5:DQ23F]8>PLid8@5:D<Ha24@Q0248@2?Nl02B487>LHiQS648@mkbU:
36<@Q002;F/00dic5:D@Q00236<02Q24>LhHaQS6248HaQcW:DX8@QBU0QS600@Q21cW24888P8Q2008
48@Q20Q25:DLibe;8@PDY@8U:@0436<]Ja247>L236<03ABU248<H`Q2124Q21S636<48AcW48Aoo`00
00eoo`03001oobDY00<U:@0<248<@cW>>Lh000@19BTY:R489@TDYARV0S6<0QcW00<48@PR:DX00RU:
00<LiaS636<00PaS00d8@Q2448@HaQBU;F/YJRe[:DXaK2e[6<HDY@0236<021cW6<He[C6<124003W>
=Ld27>L2>Lh28@P26<H2:DX29BT01AS65:D@Q12458D00a2400DDQA2448@48@PR008<H`8@Q004@S16
<AS67>L28@P011245:D<H`aS0RDY00@<Ha1T;F/aS08DY@049BTY:R488@P212426<H424826<H01P@Q
248@Q124248<@`8DY@0648@DQABU6<Ioo`0027oo0007Ool0>@00OolYBPQ236<HYR486<H8@QcW6<HL
iaBU6:H<HbU:248DYBe[58DU:AcW36<aK248:DX<Hac76<HDQ@Q26<HHYT8@9BT]BaBU7>L8@RD96<H<
Hc6/5:D8@PaS248La`@Q46@88T8@9BTicRDY124@Q0026:H05`aS;F/icP@Q8@PYBR3X8@Pmkc6<5:DQ
236<248U2AS65:DU:@0036<8@PaS9@T00RDY00<Li`a38@P00Q2402T@I1BU124DQA1T5:DLaa24:BXQ
21c77>LHaRU:46@Q21c7;F/<HbU:7>L<@a1T6<HPj36<48@40B485:DHYPPR5:DQ21c75:DU2AcW46Ao
o`0000eoo`0=001oobDY9BTY:RDY34<8@Sg?>Lh48@00:DX00RDY00TQ21RV5:DeSC6<8>PLi`Q21240
0RU:00<]BacW7>L00PaS00@<@`aS48@DQ@8HaP8]J`06:DX]Jbe[<H`HYQS60PaS0QcW00@aS3F]1044
8@8icP087>LPj3W>>LhQ22D96<HLa`8YBP8U:@8HaP<@Q0085:D@Q1B548@DQA2422848@8<H`8@Q096
<@8Li`049@TQ21BU5:D236<012TZ9BT@Q0aS0S6<0QBU00@YBRDY8@PQ20848@8HaP0<34<8@Pa3248L
aaS624888QB548@<H`Q20aBU00D@Q1S66<Ioo`0000Qoo`001goo00l007oo48@@Q11T000HYRe[36<@
Q11T5:D<@b48:DX00Re[00/ec@PR124<HacW48@HaQBU1248@QSV008<H`0348@Lib48008HaP0W6>HH
aP@Q8>PDY@aS7>L<HbU:7>LQ236<36<YBQS66:HYBQcW36<HaRU:BU8DYAS6;F/aS3h?=Jd@Q1B5:DX]
JacW48@U:@@148@U:BU:008HaP0F7<LLiaB59BTHaPQ27>LHiQ249BTQ21BU124DYAS6248DYBe[48@<
H`a312426<H01QBU000U:AcW48@YBP8HaP0F:DX@Q1S6:DXDYAS6248<Ha24248@Q1S67>LDYAS636<8
@QS6248Ligoo000=Ool01000Ool]Rc6<0PaS00<@Q1B55:D00aBU00@Q22DYBU9>D`@HaP0712488QSV
7>L8@PaS6<H00QBU0PQ200@U:B4848@@Q08Q208DY@04=JdaS1BU5:D26<H01PQ2124YBRU:24848@8Q
200446@<Hc6<;F/2>Lh011cW6>HaS36<0QS60PQ20RDY0PaS00T<@`Q246@<H`@Q000YBQS67<L00QBU
0PaS00HQ22D912448@Q234<224801P001048@PQ2:FX]J`8<H`8Li`<<H`0548@HaQS648@DQ@0248@0
10aS48@DYABU0P@Q00@<Ha248@PU:@88@P068@PU:AS66<Ioo`0027oo0007Ool03000OolDYC6<124H
aPaS48@48ABU124Li`848@0;6<H88Q2434<ecBDY<H`U:AS636<8@P027>L01a24124aS2e[5:DYBQB5
008Q2004:DXicR489BT236<021247>M242e[5:D<@c6<BU829BT04AS66:H48C6<7>L8@Re[>LhQ21S6
9BTYBRe[G]LLiac724800QBU00PLi`aS7<L8@PPR48@YBRDY0R48034DY@aS7>LHaQB548@Lac6<6<H<
H`@1248DY@aS5:D002487>LYBQ248@PLi`PR8@P8@P@Q34<Li`a36<HLi`@Q248<Ha1T124DY@aS6:H<
H`PR48@Lia24;F/@I248Ool0000=Ool01000OolaS36<0PaS00<DYA246:H00aBU0RDY00=>LdYB6<H0
0aS601D88P@Q7>LLi`aS34<LiaBU6:H8@Pa38@PU:A2458DQ22D95:DHYS6<=Jd00QBU00hHaQc72488
@RU:;D/88PQ28@PU2@aS48@]Jc6<0SW>0QcW0S6<0QS600X8@Pa39BTY:PaS46@8@Pa336<@Q0848@03
:DXLiaS6008DY@8<H`059BTQ20PR124<@`03248010@10008@PQ20Re[00@@I0aS7>LLi`8<H`0748@@
I1S66<HDYA2458D00a2400@HYQBU12448@8@Q08U:@88@P8U:@047<LHaWoo0008Ool000Moo`09001o
oa246<HHYPaS248@Q1S6008<H`0D6<HDY@aS<F`Libe;=Jd<@b485:DHaRU:6<H@Q2DY58D@Q1S65:DQ
208DY@0T248DQ@Q26<H48A2424888PaS7>LU:CW>36<DYB487>L<Ha24248e[BU:9BTLibDY;F/U:@aS
7>Lmkc6<36<]Je:d:DX8@P@Q0QS60PaS01HHaPQ25:DDYB4836<U:@PR48@Pj0Q236<8@RDY<H`Q22U:
7>LHaQ1T48@HYP8@Q00=36<Lib487>LHaQBU;H/<HaS68@P8@QRV:DX00QBU00L8@P@Q6<HLiaBU8@PH
aP027>L02@Q236<@Q1245:D8@QBUOol0000=Ool01000Ool]Jbe[0QcW00@a[3F]=Jde[@88@P8<H`8@
Q08HaP06248<@aS66<H]Jc6<0acW112400@aS2e[:BXU:@88@P8]J`0836<8@SW>=Ld<@`Q2:DXUB@8L
i`088@PLiaS66<HU2B48<H`]J`8YBP92408<H`067>LHiP00000<@`Q20QS600@DQA2434<8@P8<H`03
7>L8@Pa3008Q20046>HLiaSV7>L26<H0312458DQ:2DY48@DYASV7>L<Ha1T00048@8Q208HaP88@P03
:DX]B`@Q0088@P0334<<Ha2400848@0400048@000002124011BU6:H@Q1240QcW00=oo`00Ool01goo
0007Ool07000Ool@Q1BU000DQBDY228Li`a336<@Q1S6;D/LibDY7>LHaRDY228e[@@15:DU:ABU48@@
I1RV0Q2400@Lia246<HLi`8e[@0Q5:DYBPaS1048@Pa348@U:ABU6:HQ22TZ8@PYBQBU?NlU:BD96<H8
@Q24>LhaS1c7:DXU2A24:BX003W>=Ld<Hb48009:DP04>Li:DQcW34<26:H00be;5:DQ20029BT0<248
248icQ248@PHYQS6;F/HaR487>LmkbU:9BT@Q1BU48@Q21S636<]Ja24<H`DQBDY8@PHaQc736<Q22DY
5:D@Q0a3124<HaBU7>LU:A246<H48@aS9BT48ABUOol000eoo`04001oobe[;F/27>L4=Jd2248236<2
48@01Qc76<H<H`Q27<LHaP8aS0038>PLib3X00@@Q008;F/aS2DY:DX8@Pa3;F/aK08<H`8icP04248<
@bU::DX37>L01b486<HHaR489BT]Jc6<008YBP92408<H`8Li`800007248<@aS66<H@Q1BU24800`aS
00<HaPaS24800R4811cW00@LaaS65:D@Q08U:@065:DDQAcW7>L@Q0aS0P@Q00PU2B487<LHaPa3248]
JbU:0PQ200D<H`Q248@@I0PR00<48@06104000PR124HaQBU0Q2400@Pj1cWOol000Qoo`001goo01D0
07oo34<<Hc6<124U:@aS9BTQ20aS9BT8@QBU8@PLibU:7>LDY@008@P00Q2400/YBPQ26<HLi`Q26<He
cA248@P<HaBU0088@P0T6<H@Q1B56<H<@`@Q58D8@RDY8BP<H`Q28@PDYAcW5:DDQABU;F/HaSg_;F/@
Q3F]6<HU:AS636<]Jbf;248YBRe[48@8@QS60R4801L002488@P@Q11T8@PHaRU:46@HiRDYBU8e[@@Q
8@PU:BU:6<HQ20@Q7>L<HaS6008Li`0>6<HYBPaS;F/U:@a348@HYQ24?Nl@Q0Q2124@Q08Li`0?6<HD
YABU248Q20aS248DQB4848@48AB5=Jeoo`0000eoo`03001oocF]008e[@07>LhU:BU:9BTYBQSV7>L0
0PaS0QBU0QS60Q2400@Q22DY<H`aS08Q20055:DHYQBU8@PLi`025:D236<011S65:DQ22480Q240QBU
0QcW0PQ20RDY00HHYQBU6<HDYBDY8@P212426<H01ABU48@<H`Q29@T00b480QcW00TmkcW^36<8@QcW
6<H@I0aS48@00QS60PaS0`Q200<<@`Q236<00Q2400@8@PaS48@DQ@8DY@8@Q006;F/aS1S67>LDYARV
0R480Q240PaS00@DYARV48@@Q08HaP08:DX]J`@Q124HaQcW6<HLi`8DY@041248@Woo0008Ool000Mo
o`0>001ooacW:DXLiaB548@@I1BU8@PDYARV124Li`<Q200:124U:Ac79BT88PaS8@PYBQBU48@25:D0
2QS6;F/8@QS67<L88QcW228DY@Q20aS601PYBQBU:DXDYAcW36<aS2U:48@aK1S6124U:A1T:DY:DRU:
5:DaS1BU6<HU:CF];F/2<H`020Q236<HaQBU7>LU:@aS7>L248@03aS646@<HaS68@PeSC6<;F/<HaBU
248Q20Q2;F/8@P035:D02AS634<Q22487>L40@a38@P48@0248@01Ac75:DDY@Q2;F/00QcW00@<H`PR
6<HHaP8Li`0:48@eSA2458D<H`Q234<48Goo000=Ool01P00OolicSF]>Lhec@@YBP8Li`0646@<HaBU
5:DLaaS60Q2400@U:B48=HdaS08Q20076:HDYARV7>LQ21BU6:H00PaS00PHYQS68@PU2A2458DDYARV
0QcW00H8@Pa39BTU:ABU6:H26<H012489BT48@PR0QS600HDQABU36<<Hb489BT28@P011cW8>Pmkcg_
0PaS00<HaQcW36<00Q240QS60PaS0PQ200H<@`Q236<<@aB548@236<011BU48@DYABU0Q240S6<0QcW
00HHYQBU8@PQ21B548@236<01QS65:D@Q1247<LHaP8]J`0322848AcW008Li`036<HHYQBU0088@P03
Ool007oo00Moo`001goo02l007oo124@Q2DY36<Pj1BU6:H8@P@Q48@YBQBU48@Q21RV6<H@I0aS6<H4
8A24000HaQBU6:H8@PaS7@LaS2U:8>PQ22DY124U2B48:DX001S65:D]J`aS9BT@Q0@100<8@P0834<4
8A245:D<HaS648@DY@8e[@06248@Q124248LicW>0R4800XU:Be[248U:@Q29DTU:@@Q:DX@Q08HaP0>
8@P]Rd8@9BU2412436<8@RU:48@Q21BU<H`@Q08Li`0:6:HHaQBU8BPDQA245:D8@Pa36<H248@02BDY
5:D8@PaS48@U:AS6248]J`026<H00aBU34<8@P0236<01Pa336<YBQcWOol000eoo`04001oobU::DX2
48@2;F/2CW<48@P26<H010Q234<@Q1B50RU:0R480RU:00<Lia2436<00QS60QcW00@@Q0aS5:DDY@84
8@88@P088@PLibU::DXLaaS68@PM1`8U:@8Li`068@PLibDY9BT88P@Q0PQ20R4800HU:B486<HDYBe[
:FX27>L2;F/224801b487>LLi`Q236<Lib48008Li`0612488QcW7>L8@Pa30R4800<<Ha1T6<H00aS6
0P@Q0QS600HLib3X6<HHaQBU6<H236<324800`a37>LLi`0236<011S67>L<Ha1T0QS60Q240QBU00=o
o`00Ool01goo0007Ool06P00OolQ21RV36<HaQ1T8@P8@RD936<Laa24<F`DYBTZ6<HLaacW124DY@Q2
36<<@a2422825:D03acW228DY@aS8@P<H`a348@YBRDY6<HLiaBU9BT<@`036<H022e[9BTHaQcW36<Y
BR487<L26<H01PaS:BX@Q2TZ9BTQ208Li`<U:@0o34<icP@Q9BTU2ABU<H`Li`Q2:DX]BacW36<<@aB5
6<H]JbU:<F`DY@aS7>Le[@@1>LhLicW>8@PLabU:6<H@Q1B548@DQA24228<Ha24@Q0Lib485:D<HbTZ
36<aS1BU:DXQ20@Q6<H<@`Q27<L88QB5248DYA246<Ioo`0000eoo`04001oobe;:DX248@2;F/2CW<2
8@P022D98@PLaaS634<8@QBU48@2:DX28@P01Be;:DXQ211T48@00QS6010Lib3X46@@Q1BU6:H48@PR
248<@acW8@PYBRe;6<HLi`8Q20069BTY:QcW8>PLib480RDY00@48@Q2248<@`<Q20039BTHaQS6008]
J`047>LPj2e[;F/224828@P00aS636<<H`028@P0123X7>L8@P@Q0QcW00`<@`Q28@PQ211T36<LaaS6
7<LHaPPR12426<H00b487>LLa`026<H00aRV36<<H`0224801PaS248LiacW46@<H`8Li`0446@<Hac7
6<H248@011RV5:Eoo`0027oo0007Ool05`00Ool48@aS248DYBU:48@]JbE97>LU:ABU6<HYBQBU124<
H`@Q000HYQBU48@00PQ2014HaR48124HaPQ27>L@Q0@Q248@Q2486:HQ21cW=Jd<H`Q2008Q200H46@L
i`aS7>L@I0Q20008@Q246<H@I2f;:DXaS48@:DXDY@aS6<HikQBU;F/<Ha240QBU02HU:DYB6<HDY@PR
6>H<HaS65:D8@RD948@Q21BU=HdDYAS6124YBP@Q8@P<Hc5/>LhLibf;6<HU:@aS248@I000:DXHaQBU
36<Q20@Q0PQ200T40@Q2;F/<HacW36<@Q1BU58D00Q2400TDY@@Q36<U:@Q29BTHaWoo00003Goo00@0
07oo:DXYBP8U:@8aS0066<HLicg_@Q0]Jc6<0QBU00@@Q1BU48@DY@8Li`056<HLibDY9BTDY@027>L2
36<02S5/;F/eSC6<6<HDY@a3248<@`Q20PaS00XHaQBU48@<HaRV5:DLiaSV58D@Q08HaP88@P066:HD
YBe[:DX@I0aS0R480PQ200HaS2e[22848@a3248236<00aBU48@La`027>L212401000124<Ha240PQ2
0QcW00HDYAS61248@RDY:DX2248012U:;F/8@Pa30aBU00DHYP@Q2288@Pa3008U:@@DY@8Q200<1248
8QS66<H8@PaS48@DYA2458Eoo`0027oo0007Ool0;P00OolDYARV6<H]BaS6:DX@Q2e[6:HPj1cW:DXD
YA1T248DY@aS58DLia1T6<H8@QcW8@P]JaS646@HaQ245:D@Q1cW46@<Ha248>P]J`PR9BT<HacW248]
JdiC0RU:0RDY00HQ21S6104Lac6<8@P25:D02B485:DU:AcW48@HaQBU;F/Li`02=Jd02@Q236<@Q1S6
36<HaS6<7>LPj00248@06Be[:DX8@Re[36<icPQ2:DXLib486<HU2Be[:DY240aS7>L<@aS658D8@PaS
6<H<Hb48008Li`0<7<L@Q2DY58DLi`aS124Q21c7248]B`Q20PaS00T88P@Q10448AS648@Ligoo0000
3Goo00P007oo;D/YBRTZ9BTeSC6<0QcW00A243g_<H`]J`HDY@<Li`046<HY:RDY6<H27>L236<012e[
<H`aS3F]0QS600<8@PaS24800PaS00<@I1RV6<H00Q24010DYAS67>LLia245:DHaQc7248<@aBU6<HY
BRe[36<@Q08Q2088@P8aS0031248@PQ2008<H`0446@DYABU6<H27>L4124248@224827>L051S66:H8
@PQ2:DXU:@a3248]JbU:36<8@QRV5:DHaQBU24848@aS24829BT011RV5:DHYQBU0R4800`8@P@Q7<LH
aPaS34<DYAB55:D@Q7oo0008Ool000Moo`0G001ooaBU48@HaP@Q7>LUBB489BTYBQd7248HiR3X9BTD
YA2434<8@Q249BTQ20026<H00aBU6<H8@P0248@0B`Q25:DLiaSV48@Li`Q28@PYBR4836<Q23W>000a
K3g_>Lh<H`@Q48@DY@@Q48@DYA1T248HYPQ29@TU:@@Q5:DLibDY34<e[CW>9BTYBQS636<DYAS648@U
:C6<8@PDYARV7>LDY@aS6:HQ21245:DLi`Q29BTDYAS68@P48AS658D8@R487>Lmk`Q27>L<Ha245:D<
H`0324805Q24248DQABU48@]JacW5:DQ212436<DYA246<H]J`@Q7>LHaQBU125oo`003Goo00H007oo
AS5:<Rf;<H`2:DX36<H00ac78@PU2@026<H27>L012489BTHaQc70PQ200<@Q1BU5:D00QS600HHYQBU
58D@Q1cW6>H248@2248012DY8BPU:B4X112400@48@00=Jda[08<H`04>Lhe[AcW7>L26<H011RV5:DP
j1cW0PaS0R480QcW0P@Q0RU:00/<H`Q25:DDYAB536<@Q1BU6:HLib48008HaP88@P046<HLabE9:DX2
1240136<=JdLiacW0RDY00@000@Q6<HHaP8<H`0548@DYAS67>L0000212400`Q25:DHaP027>L29BT0
11BU6<He[CF]0PQ20RU:00=oo`00Ool01goo0007Ool02`00OolDYAS636<e[@a3=Jd@Q2DY8@P00QS6
00h]B`Q234<48ABU6<HLibDY58DU:@@Q7>LLacF]0Q2400HHYPPR124HaQcW48@27>L00`aS<H`DY@02
6<H00cF]7>LU:@0248@011c748@<HacW0P@Q010DQBe[6<HQ21RV5:DU:Be[9BTe[@aS248]Ba24;F]>
L`8Q200H7<L8@QBU:DXQ22U:8@P@I1S67>L@Q1BU1248@R48:DXLib48:BXLib489BT88PQ20R4800L]
JacW;F/8@R486<H<H`027>L02P@Q7>L8@R4836<LaaS6228HaR480QS600`<H`Q2248Li`aS7>L<HaS6
48@HYWoo000=Ool01000Oom:DTHa0S6<010]BbU:7<LHaQcW6<HU:B487<LHaR3X7>LU:B487>LHaP88
@P035:DDQAS6008HaP045:DHaQ2458D27>L0112458D8@Pa312DY11240P@Q0SF]0PaS00@ecCW>7>LL
i`8HaP065:DHYQcW8@P<Ha1T0R480QcW0P@Q00@YBRe;34<<H`8DY@<@Q0046<HDYB488@P26<H22480
21cW6<HYBRU:22848CF]<H`27>L012TZ9BT48@@Q0QS600@@I0aS5:DDQ@8Li`0412440@Q224826<H0
123X7>LU:BDY0QS600@icSF]2488@P8YBP03Ool007oo00Moo`001goo00@007oo248Li`<@Q0038@PD
YAd7008HaP0C248<HaB56<HLi`aS46@<Ha245:DHaP@Q8@P8@S6<36<@Q1BU48@00PaS01448@aS2488
@R487<L]J`aS248YBRUZ8@P<H`Q25:DQ224X008<H`04>LhLiacW24826<H03ARV248HaQcW=JdU:BD9
:DXU:C6<7>Lmkc5/008DY@0_48@LiaS69BTDYAcW36<]Jc6<6<H8@Pa336<HYPaS6:HHaQB56<H8@QBU
;D/<Hb48;F/88PQ236<@Q1S67>L48@0048@8@QcW5:D8@RDY248YBPa35:DHYP@Q34<U:@025:D02248
124HaPQ25:D@Q7oo000=Ool02P00Oola[3F]Lkag_B489BTHaQcW0QBU0Q2410aS1QBU00<<Ha1T2480
0QBU00@HYQBU8@PLi`8<H`88@P8<H`0634<8@QcW7>L<@`Q20Q240SW>00X@Q0aS9BTU:AB548@mkcW>
5:D@Q08aS0<@Q00336<48@@Q008Q200634<8@QS65:DDQA240QcW00L48@aS48@000@1248<H`022482
6<H29BT336<00a1T7>LQ20025:D29BT248@35:D02aS612448AS67<LHaQc7248<H`0012400Q2400HM
1b4848@DY@Q234<25:D236<00goo001oo`07Ool000Moo`08001ooaB5:DXHaQ24124aS08HaP0448@Q
2248;F/27>L0?A247>LYBR48248DQ@aS5:D8@S6<228YBQBU;F/DQC6<5:DDQ@aS248HaQBU36<DYB48
5:D8@Qc75:DU2@Q25:D8@QcW248Libe[58D@Q35/=JdDQ@Q2:DX]Jb48124@I2DYBS8aS2e;6<HLab48
7<LLibDY6<H8@QB500<HaP0448@Lia2424829BT248@03P@Q=Jd<HcW>7>LHaQBU8@P<HacW124]B`a3
5:D248@06QBU8@PHaPQ26<HYBP@Q=JdLibTZ124HaPaS5:DHaP@Q248HaQcW9BTHaSV^248YBWoo000=
Ool01000Oole[CF]0WNm00TU:B487>LLiaRV5:DDQA2446@00`aS00dHYQBU5:DDYARV5:D@I0aS34<D
YARV5:DHaP028@P236<224803PaS46@8@Pa37>LPj0Q234<@Q1B5>Lhmka1T48@29BT0212458DicSg_
58DDYC6<=Hd448@212428@P03PQ234<HYQS648@DQAcW8>P48A2446@48@0036<234<00`Q27<LHaP02
9BT02Q1T36<@Q0aS8@PLiaRV5:DY:RDY0Q2400@HYQBU6<HHaP848@067>LHaQcW6<H<H`a30P@Q0Q24
0R4800XDYAB534<8@QRV5:D@I0aSOol000Qoo`001goo00D007oo36<YBPaS008@Q00N6<HLiad72484
8AS67>LPj3W>5:DLi`aS9BT8@QS6228<HaBU8@P]J`aS6:H48A24<H`YBQBU8>PQ22DY0Q2400<DYA24
7>L00QS601/]JcF]48@@Q1cWBU8icQ249BTHaQBU6<H8@QS6=JdHaQ1T5:D88PQ25:Da[7Nm8@PLiaBU
48@00PaS0aBU01d@I0Q25:DDYB4836<8@PaS34<Li`a348@icPaS9BT@Q3W>48@aS0aS48@M1`a35:DD
QAcW124<H`@10088@P0G6<HU:@aS46@LiaBU9BT@Q1BU6<H48Ac76<H<@`0048@LiaB5248DY@aSOol0
000=Ool01P00OolLiacW1248@P@YBP8HaP8Li`8]J`8@Q00436<@Q2e[;F/28@P00cg_@Q0U:@037>L0
0aS612448@026<H2:DX010Q2124YBRDY0Q2400P<H`Q25:D@Q1S65:DHYQBU0QS600@eSC6<9@TQ208H
aP041040023X7>L236<022TZ9BTLaaS624848@Q21242248248@00`aS48@DY@0236<2:DX00`@Q2488
@P0324801Qd78@PQ22DY36<@I0848@048@PU:B488@P26<H25:D212429BT010@Q228LiacW0aS600<L
ab4X9BT00QBU0R4800H8@PaS=JdicWoo0008Ool000Moo`0=001oo`007<L002e;124U2A1T36<8@Q1T
24800QcW03T88P@Q248<H`@Q34<<Hc6<8@PDYAS6<H`HYQS65:DLic6<8@PLiaS6248Lia245:D@I1cW
5:DU:@@Q248eS@Q2=Jd@Q2TZ8@P<@b486<H]Ja24124Q211T5:DLib3X6<HQ22DY8>P8@Re;:DXLaacW
;F/00Q2400@]Jb48?NlY:P8Li`0C124LabU:248U:AB534<DYAS66:HHaSF]8@PLa`008>P<HacW1240
0PQ200P@Q0aS5:D<HbU:228<@`Q20R4800X@I0@Q9BTQ21c75:D88RDY228Li`8HaP079BTDYBD934<i
cWoo00003Goo00@007oo8>PLi`88@P06;D/YBRe;:DXLaaS60QcW0Re[00@DQA2448@@Q08]J`8Q2003
@Q0mkbTZ00@Li`0412488QS67<L2:DX2248022DY:DX@Q1B534<<HaB55:D26<H05ABU6<HHaQc7<H`e
[B489BTHaQc700048AcW8@P<Ha1T9BTYBQS67>L88P05248248@02PaS5:DDQA1T36<]BbU:24888Pa3
0`Q20R48010U:B4846@<H`PR124U:B489@TQ21c76<HHYQBU22848@8U:@0422848AcW7>L26<H03QcW
6<HU:BDY6:HDYBD98@P<H`a3>Lhe[Goo0008Ool000Moo`03001oogoo07ioo`03001oogoo00]oo`03
001oogoo07ioo`03001oogoo00Ioo`001goo00<007ooOol0OWoo00<007ooOol02goo00<007ooOol0
OWoo00<007ooOol01Woo0007Oon2000=Oon20008Ool00?moob5oo`00ogoo8Goo003oOolQOol00001
\
\>"],
  ImageRangeCache->{{{94.5, 381.5}, {580.063, 443.938}} -> {-0.748409, 
  3.23747, 0.00734626, 0.00734626}, {{101.875, 231.5}, {576.813, 
  447.125}} -> {-107.514, 450.727, 1.02896, 1.02896}, {{244.438, 374.125}, {
  576.813, 447.125}} -> {-127.042, 225.271, 0.514232, 0.514232}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{601, 574},
WindowMargins->{{60, Automatic}, {139, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 43, 0, 111, "Title"],
Cell[1755, 51, 130, 5, 72, "Address"],
Cell[1888, 58, 76, 2, 31, "Input"],
Cell[1967, 62, 93, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[2085, 68, 31, 0, 56, "Section"],
Cell[2119, 70, 1054, 21, 153, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3210, 96, 60, 0, 56, "Section"],
Cell[3273, 98, 727, 20, 89, "Text"],
Cell[4003, 120, 574, 14, 84, "NumberedEquation"],
Cell[4580, 136, 588, 14, 84, "NumberedEquation"],
Cell[5171, 152, 816, 26, 78, "Text"],
Cell[5990, 180, 155, 3, 25, "NumberedEquation"],
Cell[6148, 185, 210, 8, 27, "Text"],
Cell[6361, 195, 182, 4, 25, "NumberedEquation"],
Cell[6546, 201, 251, 9, 31, "Text"],
Cell[6800, 212, 317, 8, 27, "NumberedEquation"],
Cell[7120, 222, 107, 5, 27, "Text"],
Cell[7230, 229, 176, 3, 44, "Text"],

Cell[CellGroupData[{
Cell[7431, 236, 44, 0, 33, "Subsubsection"],
Cell[7478, 238, 110, 5, 27, "Text"],
Cell[7591, 245, 402, 8, 94, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8030, 258, 45, 0, 33, "Subsubsection"],
Cell[8078, 260, 815, 27, 78, "Text"],
Cell[8896, 289, 122, 4, 27, "NumberedEquation"],
Cell[9021, 295, 115, 3, 27, "Text"],
Cell[9139, 300, 271, 8, 27, "NumberedEquation"],
Cell[9413, 310, 393, 14, 44, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9843, 329, 44, 0, 33, "Subsubsection"],
Cell[9890, 331, 111, 3, 27, "Text"],
Cell[10004, 336, 205, 4, 31, "NumberedEquation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10258, 346, 61, 0, 56, "Section"],
Cell[10322, 348, 329, 9, 61, "Text"],
Cell[10654, 359, 680, 16, 48, "NumberedEquation"],
Cell[11337, 377, 663, 16, 67, "NumberedEquation"],
Cell[12003, 395, 213, 8, 51, "Text"],
Cell[12219, 405, 804, 22, 95, "Text"],
Cell[13026, 429, 720, 17, 119, "NumberedEquation"],
Cell[13749, 448, 160, 5, 27, "Text"],
Cell[13912, 455, 271, 6, 66, "Input"],

Cell[CellGroupData[{
Cell[14208, 465, 289, 7, 71, "Input"],
Cell[14500, 474, 122881, 3437, 324, 14198, 2088, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[137430, 3917, 44, 0, 56, "Section"],
Cell[137477, 3919, 807, 20, 95, "Text"],

Cell[CellGroupData[{
Cell[138309, 3943, 115, 2, 31, "Input"],
Cell[138427, 3947, 395, 9, 109, "Output"]
}, Open  ]],
Cell[138837, 3959, 217, 6, 44, "Text"],
Cell[139057, 3967, 297, 9, 27, "NumberedEquation"],
Cell[139357, 3978, 325, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[139707, 3991, 137, 3, 31, "Input"],
Cell[139847, 3996, 62, 2, 30, "Output"]
}, Open  ]],
Cell[139924, 4001, 355, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[140304, 4012, 68, 0, 33, "Subsubsection"],
Cell[140375, 4014, 439, 18, 44, "Text"],
Cell[140817, 4034, 134, 4, 27, "NumberedEquation"],
Cell[140954, 4040, 142, 4, 27, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141133, 4049, 68, 0, 33, "Subsubsection"],
Cell[141204, 4051, 307, 5, 61, "Text"],
Cell[141514, 4058, 237, 6, 27, "NumberedEquation"],
Cell[141754, 4066, 285, 7, 27, "NumberedEquation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[142088, 4079, 27, 0, 56, "Section"],
Cell[142118, 4081, 280, 7, 44, "Text"],
Cell[142401, 4090, 323, 10, 40, "Text"],
Cell[142727, 4102, 119, 3, 27, "Text"],
Cell[142849, 4107, 221, 6, 62, "Input"],
Cell[143073, 4115, 51, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[143149, 4119, 67, 2, 31, "Input"],
Cell[143219, 4123, 527, 10, 82, "Output"]
}, Open  ]],
Cell[143761, 4136, 308, 11, 44, "Text"],
Cell[144072, 4149, 100, 2, 31, "Input"],
Cell[144175, 4153, 415, 17, 44, "Text"],

Cell[CellGroupData[{
Cell[144615, 4174, 254, 6, 71, "Input"],
Cell[144872, 4182, 74329, 2259, 239, 34153, 1757, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[219216, 6444, 158, 3, 44, "Text"],
Cell[219377, 6449, 188, 4, 51, "Input"],

Cell[CellGroupData[{
Cell[219590, 6457, 288, 7, 71, "Input"],
Cell[219881, 6466, 164434, 5760, 98, 106011, 5034, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[384330, 12229, 713, 13, 112, "Text"],

Cell[CellGroupData[{
Cell[385068, 12246, 351, 8, 71, "Input"],
Cell[385422, 12256, 135194, 3345, 146, 45151, 2228, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

